diff -pruN 1.9.14~dfsg-1/ChangeLog.rst 1.9.16~dfsg-1/ChangeLog.rst
--- 1.9.14~dfsg-1/ChangeLog.rst	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/ChangeLog.rst	2020-10-16 19:10:40.000000000 +0000
@@ -1,6 +1,33 @@
 ChangeLog
 #########
 
+* 1.9.16 (2020-10-16)
+
+  * Fix/revert a change in how meta-data definitions were exposed (regression in 1.9.15)
+  * Remove jack-router Windows code from the repository
+
+* 1.9.15 (2020-10-15)
+
+  * Automated builds for macOS and Windows (see jackaudio/jack2-releases repository)
+  * Adapt wscript Windows build configuration to match old v1.9.11 installer
+  * Bump maximum default number of clients and ports (now 256 clients and 2048 ports)
+  * Delete various macOS and Windows-related files from the source code (no longer relevant)
+  * Mark JACK-Session as deprecated, please use NSM instead
+  * Remove unnecessary GPL include from LGPL code
+  * Split example-clients and tools, as done in JACK1 many years ago (WIP)
+  * Write Windows registry key during installation, so 3rd parties can find jackd.exe (as HKLM\\Software\\JACK\\Location)
+  * jack_control: Fix handling of dbus bytes
+  * jack_control: Return a proper exit status on DBus exception
+  * jack_property: Fix possible crash with "-l" argument usage
+  * jack_wait: Add client name option -n/--name
+  * Fix compilation of documentation
+  * Fix compilation of mixed mode with meta-data enabled
+  * Fix compilation with mingw
+  * Fix client-side crash if initial meta-data DB setup fails
+  * Fix macOS semaphore usage, so it works again
+  * Several fixes for Windows (with contributions from Kjetil S. Matheussen)
+  * Several minor fixes and grammar corrections (with contributions from Adam Miartus and Timo Wischer)
+
 * 1.9.14 (2019-10-28)
 
   * Fix ARM build
diff -pruN 1.9.14~dfsg-1/.ci/install-deps.sh 1.9.16~dfsg-1/.ci/install-deps.sh
--- 1.9.14~dfsg-1/.ci/install-deps.sh	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/.ci/install-deps.sh	2020-10-16 19:10:40.000000000 +0000
@@ -23,6 +23,10 @@ if [ "$TRAVIS_OS_NAME" == "osx" ]; then
   if [ "${CC}" == "gcc-8" ]; then
     brew install gcc@8
   fi
+  # force installation of gcc-9 if required
+  if [ "${CC}" == "gcc-9" ]; then
+    brew install gcc@9
+  fi
 fi
 
 if [ "$TRAVIS_OS_NAME" == "linux" ]; then
@@ -34,7 +38,6 @@ if [ "$TRAVIS_OS_NAME" == "linux" ]; the
     libsndfile-dev \
     libasound2-dev \
     libdb-dev \
-    systemd-services \
     systemd \
     libsystemd-dev \
     libpam-systemd \
@@ -73,10 +76,26 @@ if [ "$TRAVIS_OS_NAME" == "linux" ]; the
   if [ "${CC}" == "gcc-8" ]; then
     sudo apt-get install gcc-8 g++-8
   fi
+  # force installation of gcc-9 if required
+  if [ "${CC}" == "gcc-9" ]; then
+    sudo apt-get install gcc-9 g++-9
+  fi
+  # force installation of clang-3.5 if required
+  if [ "${CC}" == "clang-3.5" ]; then
+    sudo apt-get install clang-3.5
+  fi
   # force installation of clang-3.8 if required
   if [ "${CC}" == "clang-3.8" ]; then
     sudo apt-get install clang-3.8
   fi
+  # force installation of clang-6.0 if required
+  if [ "${CC}" == "clang-6.0" ]; then
+    sudo apt-get install clang-6.0
+  fi
+  # force installation of clang-8 if required
+  if [ "${CC}" == "clang-8" ]; then
+    sudo apt-get install clang-8
+  fi
 fi
 
 exit 0
diff -pruN 1.9.14~dfsg-1/common/driver_interface.h 1.9.16~dfsg-1/common/driver_interface.h
--- 1.9.14~dfsg-1/common/driver_interface.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/driver_interface.h	2020-10-16 19:10:40.000000000 +0000
@@ -133,7 +133,11 @@ typedef struct {
     char name[JACK_DRIVER_NAME_MAX + 1];      /**< The driver's canonical name */
     jack_driver_type_t type;               /**< The driver's type */
     char desc[JACK_DRIVER_PARAM_DESC + 1];    /**< The driver's extended description */
+#ifdef WIN32
+    wchar_t file[JACK_PATH_MAX + 1];             /**< The filename of the driver's shared object file */
+#else
     char file[JACK_PATH_MAX + 1];             /**< The filename of the driver's shared object file */
+#endif
     uint32_t nparams;                         /**< The number of parameters the driver has */
     jack_driver_param_desc_t * params;        /**< An array of parameter descriptors */
 }
diff -pruN 1.9.14~dfsg-1/common/jack/jack.h 1.9.16~dfsg-1/common/jack/jack.h
--- 1.9.14~dfsg-1/common/jack/jack.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/jack/jack.h	2020-10-16 19:10:40.000000000 +0000
@@ -605,6 +605,10 @@ int jack_set_xrun_callback (jack_client_
  * Clients that do not meet any of those conditions SHOULD
  * register a latency callback.
  *
+ * Another case is when a client wants to use
+ * @ref jack_port_get_latency_range(), which only returns meaninful
+ * values when ports get connected and latency values change.
+ *
  * See the documentation for  @ref jack_port_set_latency_range()
  * on how the callback should operate. Remember that the @a mode
  * argument given to the latency callback will need to be
@@ -1119,8 +1123,11 @@ void jack_port_set_latency (jack_port_t
  *
  * See @ref LatencyFunctions for the definition of each latency value.
  *
- * This is normally used in the LatencyCallback.
- * and therefor safe to execute from callbacks.
+ * This function is best used from callbacks, specifically the latency callback.
+ * Before a port is connected, this returns the default latency: zero.
+ * Therefore it only makes sense to call jack_port_get_latency_range() when
+ * the port is connected, and that gets signalled by the latency callback.
+ * See @ref jack_set_latency_callback() for details.
  */
 void jack_port_get_latency_range (jack_port_t *port, jack_latency_callback_mode_t mode, jack_latency_range_t *range) JACK_WEAK_EXPORT;
 
diff -pruN 1.9.14~dfsg-1/common/jack/metadata.h 1.9.16~dfsg-1/common/jack/metadata.h
--- 1.9.14~dfsg-1/common/jack/metadata.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/jack/metadata.h	2020-10-16 19:10:40.000000000 +0000
@@ -265,7 +265,7 @@ extern const char* JACK_METADATA_ICON_LA
  * themes.  Icons should be searched for according to the freedesktop Icon
  *
  * Theme Specification:
- * http://standards.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
+ * https://specifications.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
  */
 extern const char* JACK_METADATA_ICON_NAME;
 
diff -pruN 1.9.14~dfsg-1/common/jack/session.h 1.9.16~dfsg-1/common/jack/session.h
--- 1.9.14~dfsg-1/common/jack/session.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/jack/session.h	2020-10-16 19:10:40.000000000 +0000
@@ -30,6 +30,10 @@ extern "C" {
 
 /**
  * @defgroup SessionClientFunctions Session API for clients.
+ *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
  * @{
  */
 
@@ -156,6 +160,10 @@ typedef struct _jack_session_event jack_
  *
  * The client must promptly call jack_session_reply for this event.
  *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
+ *
  * @param event The event structure.
  * @param arg Pointer to a client supplied structure.
  */
@@ -170,11 +178,15 @@ typedef void (*JackSessionCallback)(jack
  * error. if you have a multiclient application its more sensible to create
  * a jack_client with only a session callback set.
  *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
+ *
  * @return 0 on success, otherwise a non-zero error code
  */
 int jack_set_session_callback (jack_client_t       *client,
                                JackSessionCallback  session_callback,
-                               void                *arg) JACK_WEAK_EXPORT;
+                               void                *arg) JACK_OPTIONAL_WEAK_DEPRECATED_EXPORT;
 
 /**
  * Reply to a session event.
@@ -183,18 +195,26 @@ int jack_set_session_callback (jack_clie
  * different thread.  For example, it is possible to push the event through a
  * queue and execute the save code from the GUI thread.
  *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
+ *
  * @return 0 on success, otherwise a non-zero error code
  */
 int jack_session_reply (jack_client_t        *client,
-                        jack_session_event_t *event) JACK_WEAK_EXPORT;
+                        jack_session_event_t *event) JACK_OPTIONAL_WEAK_DEPRECATED_EXPORT;
 
 
 /**
  * Free memory used by a jack_session_event_t.
  *
  * This also frees the memory used by the command_line pointer, if its non NULL.
+ *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
  */
-void jack_session_event_free (jack_session_event_t *event) JACK_WEAK_EXPORT;
+void jack_session_event_free (jack_session_event_t *event) JACK_OPTIONAL_WEAK_DEPRECATED_EXPORT;
 
 
 /**
@@ -238,8 +258,12 @@ jack_session_command_t *jack_session_not
 
 /**
  * Free the memory allocated by a session command.
+ *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
  */
-void jack_session_commands_free (jack_session_command_t *cmds) JACK_WEAK_EXPORT;
+void jack_session_commands_free (jack_session_command_t *cmds) JACK_OPTIONAL_WEAK_DEPRECATED_EXPORT;
 
 /**
  * Reserve a client name and associate it with a UUID.
@@ -258,11 +282,19 @@ jack_reserve_client_name (jack_client_t
 /**
  * Find out whether a client has set up a session callback.
  *
+ * @deprecated Use of JACK-Session is currently deprecated and unsupported.
+ * JACK developers recommend the use of NSM instead.
+ * See https://github.com/linuxaudio/new-session-manager
+ *
  * @return 0 when the client has no session callback, 1 when it has one.
  *        -1 on error.
  */
 int
-jack_client_has_session_callback (jack_client_t *client, const char *client_name) JACK_WEAK_EXPORT;
+jack_client_has_session_callback (jack_client_t *client, const char *client_name) JACK_OPTIONAL_WEAK_DEPRECATED_EXPORT;
+
+/**
+ * @}
+ */
 
 #ifdef __cplusplus
 }
diff -pruN 1.9.14~dfsg-1/common/jack/systemdeps.h 1.9.16~dfsg-1/common/jack/systemdeps.h
--- 1.9.14~dfsg-1/common/jack/systemdeps.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/jack/systemdeps.h	2020-10-16 19:10:40.000000000 +0000
@@ -70,14 +70,14 @@ Foundation, Inc., 675 Mass Ave, Cambridg
         #define __inline__ inline
         #if (!defined(int8_t) && !defined(_STDINT_H))
             #define __int8_t_defined
-            typedef char int8_t;
-            typedef unsigned char uint8_t;
-            typedef short int16_t;
-            typedef unsigned short uint16_t;
-            typedef long int32_t;
-            typedef unsigned long uint32_t;
-            typedef LONGLONG int64_t;
-            typedef ULONGLONG uint64_t;
+            typedef INT8 int8_t;
+            typedef UINT8 uint8_t;
+            typedef INT16 int16_t;
+            typedef UINT16 uint16_t;
+            typedef INT32 int32_t;
+            typedef UINT32 uint32_t;
+            typedef INT64 int64_t;
+            typedef UINT64 uint64_t;
         #endif
     #elif __MINGW32__   /* MINGW */
         #include <stdint.h>
diff -pruN 1.9.14~dfsg-1/common/JackConstants.h 1.9.16~dfsg-1/common/JackConstants.h
--- 1.9.14~dfsg-1/common/JackConstants.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackConstants.h	2020-10-16 19:10:40.000000000 +0000
@@ -24,7 +24,7 @@
 #include "config.h"
 #endif
 
-#define VERSION "1.9.14"
+#define VERSION "1.9.16"
 
 #define BUFFER_SIZE_MAX 8192
 
diff -pruN 1.9.14~dfsg-1/common/JackControlAPI.cpp 1.9.16~dfsg-1/common/JackControlAPI.cpp
--- 1.9.14~dfsg-1/common/JackControlAPI.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackControlAPI.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -1283,7 +1283,7 @@ SERVER_EXPORT union jackctl_parameter_va
 SERVER_EXPORT bool jackctl_parameter_reset(jackctl_parameter *parameter_ptr)
 {
     if (!parameter_ptr) {
-        return NULL;
+        return false;
     }
 
     if (!parameter_ptr->is_set)
@@ -1301,7 +1301,7 @@ SERVER_EXPORT bool jackctl_parameter_res
 SERVER_EXPORT bool jackctl_parameter_set_value(jackctl_parameter *parameter_ptr, const union jackctl_parameter_value * value_ptr)
 {
     if (!parameter_ptr || !value_ptr) {
-        return NULL;
+        return false;
     }
 
     parameter_ptr->is_set = true;
diff -pruN 1.9.14~dfsg-1/common/Jackdmp.cpp 1.9.16~dfsg-1/common/Jackdmp.cpp
--- 1.9.14~dfsg-1/common/Jackdmp.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/Jackdmp.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -97,7 +97,7 @@ static void copyright(FILE* file)
     fprintf(file, "jackdmp " VERSION "\n"
             "Copyright 2001-2005 Paul Davis and others.\n"
             "Copyright 2004-2016 Grame.\n"
-            "Copyright 2016-2019 Filipe Coelho.\n"
+            "Copyright 2016-2020 Filipe Coelho.\n"
             "jackdmp comes with ABSOLUTELY NO WARRANTY\n"
             "This is free software, and you are welcome to redistribute it\n"
             "under certain conditions; see the file COPYING for details\n");
diff -pruN 1.9.14~dfsg-1/common/JackDriverLoader.cpp 1.9.16~dfsg-1/common/JackDriverLoader.cpp
--- 1.9.14~dfsg-1/common/JackDriverLoader.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackDriverLoader.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -33,40 +33,46 @@ Foundation, Inc., 675 Mass Ave, Cambridg
 #endif
 
 #ifdef WIN32
+typedef wchar_t file_char_t;
+#else
+typedef char file_char_t;
+#endif
+
+#ifdef WIN32
 
-static char* locate_dll_driver_dir()
+static wchar_t* locate_dll_driver_dir()
 {
     HMODULE libjack_handle = NULL;
-    GetModuleHandleEx(GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS | GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT,
-                      reinterpret_cast<LPCSTR>(locate_dll_driver_dir), &libjack_handle);
+    GetModuleHandleExW(GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS | GET_MODULE_HANDLE_EX_FLAG_UNCHANGED_REFCOUNT,
+                       reinterpret_cast<LPCWSTR>(locate_dll_driver_dir), &libjack_handle);
 
     // For WIN32 ADDON_DIR is defined in JackConstants.h as relative path
-    char driver_dir_storage[512];
-    if (3 < GetModuleFileName(libjack_handle, driver_dir_storage, 512)) {
-        char *p = strrchr(driver_dir_storage, '\\');
+    wchar_t driver_dir_storage[512];
+    if (3 < GetModuleFileNameW(libjack_handle, driver_dir_storage, 512)) {
+        wchar_t *p = wcsrchr(driver_dir_storage, L'\\');
         if (p && (p != driver_dir_storage)) {
             *p = 0;
-        }
-        jack_info("Drivers/internals found in : %s", driver_dir_storage);
-        strcat(driver_dir_storage, "/");
-        strcat(driver_dir_storage, ADDON_DIR);
-        return strdup(driver_dir_storage);
+        }   
+        jack_info("Drivers/internals found in : %S", driver_dir_storage);
+        wcscat(driver_dir_storage, L"\\");
+        wcscat(driver_dir_storage, ADDON_DIRW);
+        return wcsdup(driver_dir_storage);
     } else {
         jack_error("Cannot get JACK dll directory : %d", GetLastError());
         return NULL;
     }
 }
 
-static char* locate_driver_dir(HANDLE& file, WIN32_FIND_DATA& filedata)
+static wchar_t* locate_driver_dir(HANDLE& file, WIN32_FIND_DATAW& filedata)
 {
     // Search drivers/internals iin the same folder of "libjackserver.dll"
-    char* driver_dir = locate_dll_driver_dir();
-    char dll_filename[512];
-    snprintf(dll_filename, sizeof(dll_filename), "%s/*.dll", driver_dir);
-    file = (HANDLE)FindFirstFile(dll_filename, &filedata);
+    wchar_t* driver_dir = locate_dll_driver_dir();
+    wchar_t dll_filename[512];
+    swprintf(dll_filename, 510, L"%S/*.dll", driver_dir);
+    file = (HANDLE)FindFirstFileW(dll_filename, &filedata);
 
     if (file == INVALID_HANDLE_VALUE) {
-        jack_error("Drivers not found ");
+        jack_error("Drivers not found in \"%S\": \"%S\"", driver_dir, dll_filename);
         free(driver_dir);
         return NULL;
     } else {
@@ -412,16 +418,20 @@ jack_driver_desc_t* jack_find_driver_des
     return desc;
 }
 
-static void* check_symbol(const char* sofile, const char* symbol, const char* driver_dir, void** res_dllhandle = NULL)
+static void* check_symbol(const file_char_t* sofile, const char* symbol, const file_char_t* driver_dir, void** res_dllhandle = NULL)
 {
     void* dlhandle;
     void* res = NULL;
-    char filename[1024];
-    sprintf(filename, "%s/%s", driver_dir, sofile);
-
+    file_char_t filename[1024];
+#ifdef WIN32
+    swprintf(filename, 1022, L"%S/%S", driver_dir, sofile);
+#else
+    snprintf(filename, 1022, "%s/%s", driver_dir, sofile);
+#endif
+    
     if ((dlhandle = LoadDriverModule(filename)) == NULL) {
 #ifdef WIN32
-        jack_error ("Could not open component .dll '%s': %ld", filename, GetLastError());
+        jack_error ("Could not open component .dll '%S': %ld", filename, GetLastError());
 #else
         jack_error ("Could not open component .so '%s': %s", filename, dlerror());
 #endif
@@ -437,25 +447,30 @@ static void* check_symbol(const char* so
     return res;
 }
 
-static jack_driver_desc_t* jack_get_descriptor (JSList* drivers, const char* sofile, const char* symbol, const char* driver_dir)
+static jack_driver_desc_t* jack_get_descriptor (JSList* drivers, const file_char_t* sofile, const char* symbol, const file_char_t* driver_dir)
 {
     jack_driver_desc_t* descriptor = NULL;
     jack_driver_desc_t* other_descriptor;
     JackDriverDescFunction so_get_descriptor = NULL;
-    char filename[1024];
+    file_char_t filename[1024];
     JSList* node;
     void* dlhandle = NULL;
 
-    sprintf(filename, "%s/%s", driver_dir, sofile);
+#ifdef WIN32
+    swprintf(filename, 1022, L"%S/%S", driver_dir, sofile);
+#else
+    snprintf(filename, 1022, "%s/%s", driver_dir, sofile);
+#endif
+    
     so_get_descriptor = (JackDriverDescFunction)check_symbol(sofile, symbol, driver_dir, &dlhandle);
 
     if (so_get_descriptor == NULL) {
-        jack_error("jack_get_descriptor : dll %s is not a driver", sofile);
+        jack_error("jack_get_descriptor : dll %S is not a driver", sofile);
         goto error;
     }
 
     if ((descriptor = so_get_descriptor ()) == NULL) {
-        jack_error("Driver from '%s' returned NULL descriptor", filename);
+        jack_error("Driver from '%S' returned NULL descriptor", filename);
         goto error;
     }
 
@@ -463,15 +478,19 @@ static jack_driver_desc_t* jack_get_desc
     for (node = drivers; node; node = jack_slist_next (node)) {
         other_descriptor = (jack_driver_desc_t*) node->data;
         if (strcmp(descriptor->name, other_descriptor->name) == 0) {
-            jack_error("The drivers in '%s' and '%s' both have the name '%s'; using the first",
+            jack_error("The drivers in '%S' and '%S' both have the name '%S'; using the first",
                        other_descriptor->file, filename, other_descriptor->name);
             /* FIXME: delete the descriptor */
             goto error;
         }
     }
 
+#ifdef WIN32
+    wcsncpy(descriptor->file, filename, JACK_PATH_MAX);
+#else
     strncpy(descriptor->file, filename, JACK_PATH_MAX);
-
+#endif
+    
 error:
     if (dlhandle) {
         UnloadDriverModule(dlhandle);
@@ -484,13 +503,13 @@ error:
 JSList * jack_drivers_load(JSList * drivers)
 {
     //char dll_filename[512];
-    WIN32_FIND_DATA filedata;
+    WIN32_FIND_DATAW filedata;
     HANDLE file;
-    const char* ptr = NULL;
+    const wchar_t* ptr = NULL;
     JSList* driver_list = NULL;
     jack_driver_desc_t* desc = NULL;
 
-    char* driver_dir = locate_driver_dir(file, filedata);
+    wchar_t* driver_dir = locate_driver_dir(file, filedata);
     if (!driver_dir) {
         jack_error("Driver folder not found");
         goto error;
@@ -498,17 +517,17 @@ JSList * jack_drivers_load(JSList * driv
 
     do {
         /* check the filename is of the right format */
-        if (strncmp ("jack_", filedata.cFileName, 5) != 0) {
+        if (wcsncmp (L"jack_", filedata.cFileName, 5) != 0) {
             continue;
         }
 
-        ptr = strrchr (filedata.cFileName, '.');
+        ptr = wcsrchr (filedata.cFileName, L'.');
         if (!ptr) {
             continue;
         }
 
         ptr++;
-        if (strncmp ("dll", ptr, 3) != 0) {
+        if (wcsncmp (L"dll", ptr, 3) != 0) {
             continue;
         }
 
@@ -521,13 +540,13 @@ JSList * jack_drivers_load(JSList * driv
         if (desc) {
             driver_list = jack_slist_append (driver_list, desc);
         } else {
-            jack_error ("jack_get_descriptor returns null for \'%s\'", filedata.cFileName);
+            jack_error ("jack_get_descriptor returns null for \'%S\'", filedata.cFileName);
         }
 
-    } while (FindNextFile(file, &filedata));
+    } while (FindNextFileW(file, &filedata));
 
     if (!driver_list) {
-        jack_error ("Could not find any drivers in %s!", driver_dir);
+        jack_error ("Could not find any drivers in %S!", driver_dir);
     }
 
 error:
@@ -613,13 +632,13 @@ JSList* jack_drivers_load (JSList * driv
 JSList* jack_internals_load(JSList * internals)
 {
     ///char dll_filename[512];
-    WIN32_FIND_DATA filedata;
+    WIN32_FIND_DATAW filedata;
     HANDLE file;
-    const char* ptr = NULL;
+    const wchar_t* ptr = NULL;
     JSList* driver_list = NULL;
     jack_driver_desc_t* desc;
 
-    char* driver_dir = locate_driver_dir(file, filedata);
+    wchar_t* driver_dir = locate_driver_dir(file, filedata);
     if (!driver_dir) {
         jack_error("Driver folder not found");
         goto error;
@@ -627,13 +646,13 @@ JSList* jack_internals_load(JSList * int
 
     do {
 
-        ptr = strrchr (filedata.cFileName, '.');
+        ptr = wcsrchr (filedata.cFileName, L'.');
         if (!ptr) {
             continue;
         }
 
         ptr++;
-        if (strncmp ("dll", ptr, 3) != 0) {
+        if (wcsncmp (L"dll", ptr, 3) != 0) {
             continue;
         }
 
@@ -649,7 +668,7 @@ JSList* jack_internals_load(JSList * int
             jack_error ("jack_get_descriptor returns null for \'%s\'", filedata.cFileName);
         }
 
-    } while (FindNextFile(file, &filedata));
+    } while (FindNextFileW(file, &filedata));
 
     if (!driver_list) {
         jack_error ("Could not find any internals in %s!", driver_dir);
@@ -745,18 +764,26 @@ Jack::JackDriverClientInterface* JackDri
     if (fHandle == NULL) {
 #ifdef WIN32
         if ((errstr = GetLastError ()) != 0) {
-            jack_error ("Can't load \"%s\": %ld", driver_desc->file, errstr);
+            jack_error ("Can't load \"%S\": %ld", driver_desc->file, errstr);
 #else
         if ((errstr = dlerror ()) != 0) {
             jack_error ("Can't load \"%s\": %s", driver_desc->file, errstr);
 #endif
 
         } else {
-            jack_error ("Error loading driver shared object %s", driver_desc->file);
+#ifdef WIN32
+          jack_error ("Error loading driver shared object %S", driver_desc->file);
+#else
+          jack_error ("Error loading driver shared object %s", driver_desc->file);
+#endif
         }
         return NULL;
     }
 
+
+    //jack_error (" ---------------------------------  Successfully opened driver \"%S\"\n", driver_desc->file);
+
+        
     fInitialize = (driverInitialize)GetDriverProc(fHandle, "driver_initialize");
 
 #ifdef WIN32
@@ -764,7 +791,12 @@ Jack::JackDriverClientInterface* JackDri
 #else
     if ((fInitialize == NULL) && (errstr = dlerror ()) != 0) {
 #endif
+
+#ifdef WIN32
+        jack_error("No initialize function in shared object %S\n", driver_desc->file);
+#else
         jack_error("No initialize function in shared object %s\n", driver_desc->file);
+#endif
         return NULL;
     }
 
diff -pruN 1.9.14~dfsg-1/common/JackEngineControl.h 1.9.16~dfsg-1/common/JackEngineControl.h
--- 1.9.14~dfsg-1/common/JackEngineControl.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackEngineControl.h	2020-10-16 19:10:40.000000000 +0000
@@ -118,6 +118,7 @@ struct SERVER_EXPORT JackEngineControl :
         fMaxUsecs = 0;
         ResetRollingUsecs();
         strncpy(fServerName, server_name, sizeof(fServerName));
+        fServerName[sizeof(fServerName) - 1] = 0;
         fCPULoad = 0.f;
         fPeriod = 0;
         fComputation = 0;
diff -pruN 1.9.14~dfsg-1/common/JackGraphManager.cpp 1.9.16~dfsg-1/common/JackGraphManager.cpp
--- 1.9.14~dfsg-1/common/JackGraphManager.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackGraphManager.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -24,7 +24,11 @@ Foundation, Inc., 59 Temple Place - Suit
 #include <assert.h>
 #include <stdlib.h>
 #include <algorithm>
+#ifdef HAVE_TRE_REGEX_H
+#include <tre/regex.h>
+#else
 #include <regex.h>
+#endif
 
 namespace Jack
 {
diff -pruN 1.9.14~dfsg-1/common/JackInternalClient.cpp 1.9.16~dfsg-1/common/JackInternalClient.cpp
--- 1.9.14~dfsg-1/common/JackInternalClient.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackInternalClient.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -77,6 +77,7 @@ int JackInternalClient::Open(const char*
     }
 
     strncpy(fServerName, server_name, sizeof(fServerName));
+    fServerName[sizeof(fServerName) - 1] = 0;
 
     // Open server/client direct channel
     char name_res[JACK_CLIENT_NAME_SIZE + 1];
diff -pruN 1.9.14~dfsg-1/common/JackLibClient.cpp 1.9.16~dfsg-1/common/JackLibClient.cpp
--- 1.9.14~dfsg-1/common/JackLibClient.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackLibClient.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -106,6 +106,7 @@ int JackLibClient::Open(const char* serv
     }
     
     strncpy(fServerName, server_name, sizeof(fServerName));
+    fServerName[sizeof(fServerName) - 1] = 0;
 
     // Open server/client channel
     char name_res[JACK_CLIENT_NAME_SIZE+1];
diff -pruN 1.9.14~dfsg-1/common/JackMetadata.cpp 1.9.16~dfsg-1/common/JackMetadata.cpp
--- 1.9.14~dfsg-1/common/JackMetadata.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackMetadata.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -68,20 +68,20 @@ JackMetadata::~JackMetadata()
     if (fIsEngine)
     {
         // cleanup after libdb, nasty!
-        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/metadata.db", jack_server_dir);
+        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/metadata.db", fDBFilesDir);
         remove (dbpath);
 
-        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/__db.001", jack_server_dir);
+        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/__db.001", fDBFilesDir);
         remove (dbpath);
 
-        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/__db.002", jack_server_dir);
+        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/__db.002", fDBFilesDir);
         remove (dbpath);
 
-        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/__db.003", jack_server_dir);
+        snprintf (dbpath, sizeof(dbpath), "%s/jack_db/__db.003", fDBFilesDir);
         remove (dbpath);
 
         // remove our custom dir
-        snprintf (dbpath, sizeof(dbpath), "%s/jack_db", jack_server_dir);
+        snprintf (dbpath, sizeof(dbpath), "%s/jack_db", fDBFilesDir);
         rmdir (dbpath);
     }
 #endif
@@ -94,6 +94,16 @@ int JackMetadata::PropertyInit()
     int ret;
     char dbpath[PATH_MAX + 1];
 
+#ifdef WIN32
+    ret = GetTempPathA (PATH_MAX, fDBFilesDir);
+    if ((ret > PATH_MAX) || (ret == 0)) {
+        jack_error ("cannot get path for temp files");
+        return -1;
+    }
+#else
+    strncpy (fDBFilesDir, jack_server_dir, PATH_MAX);
+#endif
+
     /* idempotent */
 
     if (fDBenv) {
@@ -105,24 +115,33 @@ int JackMetadata::PropertyInit()
         return -1;
     }
 
-    snprintf (dbpath, sizeof(dbpath), "%s/jack_db", jack_server_dir);
+    snprintf (dbpath, sizeof(dbpath), "%s/jack_db", fDBFilesDir);
+#ifdef WIN32
+    mkdir (dbpath);
+#else
     mkdir (dbpath, S_IRWXU | S_IRWXG);
+#endif
 
     if ((ret = fDBenv->open (fDBenv, dbpath, DB_CREATE | DB_INIT_LOCK | DB_INIT_MPOOL | DB_THREAD, 0)) != 0) {
         jack_error ("cannot open DB environment: %s", db_strerror (ret));
+        fDBenv = NULL;
         return -1;
     }
 
     if ((ret = db_create (&fDB, fDBenv, 0)) != 0) {
         jack_error ("Cannot initialize metadata DB (%s)", db_strerror (ret));
+        fDBenv->close (fDBenv, 0);
+        fDBenv = NULL;
         return -1;
     }
 
-    snprintf (dbpath, sizeof(dbpath), "%s/jack_db/metadata.db", jack_server_dir);
+    snprintf (dbpath, sizeof(dbpath), "%s/jack_db/metadata.db", fDBFilesDir);
     if ((ret = fDB->open (fDB, NULL, dbpath, NULL, DB_HASH, DB_CREATE | DB_THREAD, 0666)) != 0) {
         jack_error ("Cannot open metadata DB at %s: %s", dbpath, db_strerror (ret));
         fDB->close (fDB, 0);
         fDB = NULL;
+        fDBenv->close (fDBenv, 0);
+        fDBenv = NULL;
         return -1;
     }
 
diff -pruN 1.9.14~dfsg-1/common/JackMetadata.h 1.9.16~dfsg-1/common/JackMetadata.h
--- 1.9.14~dfsg-1/common/JackMetadata.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackMetadata.h	2020-10-16 19:10:40.000000000 +0000
@@ -24,7 +24,14 @@
 #include "config.h"
 #endif
 
+// libdb does not work in 32bit mixed mode
+#ifdef BUILD_WITH_32_64
+#undef HAVE_DB
+#define HAVE_DB 0
+#endif
+
 #include <stdint.h>
+#include <limits.h>
 
 #if HAVE_DB
 #include <db.h>
@@ -82,6 +89,7 @@ class JackMetadata
         DB* fDB;
         DB_ENV* fDBenv;
         const bool fIsEngine;
+        char fDBFilesDir[PATH_MAX + 1];
     #endif
 
         int PropertyInit();
diff -pruN 1.9.14~dfsg-1/common/JackPortType.cpp 1.9.16~dfsg-1/common/JackPortType.cpp
--- 1.9.14~dfsg-1/common/JackPortType.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackPortType.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -30,7 +30,7 @@ static const JackPortType* gPortTypes[]
     &gMidiPortType,
 };
 
-jack_port_type_id_t PORT_TYPES_MAX = sizeof(gPortTypes) / sizeof(gPortTypes[0]);
+const jack_port_type_id_t PORT_TYPES_MAX = sizeof(gPortTypes) / sizeof(gPortTypes[0]);
 
 jack_port_type_id_t GetPortTypeId(const char* port_type)
 {
diff -pruN 1.9.14~dfsg-1/common/JackPortType.h 1.9.16~dfsg-1/common/JackPortType.h
--- 1.9.14~dfsg-1/common/JackPortType.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackPortType.h	2020-10-16 19:10:40.000000000 +0000
@@ -27,7 +27,7 @@ Foundation, Inc., 59 Temple Place - Suit
 namespace Jack
 {
 
-extern jack_port_type_id_t PORT_TYPES_MAX;
+extern const jack_port_type_id_t PORT_TYPES_MAX;
 
 struct JackPortType
 {
diff -pruN 1.9.14~dfsg-1/common/JackShmMem.cpp 1.9.16~dfsg-1/common/JackShmMem.cpp
--- 1.9.14~dfsg-1/common/JackShmMem.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackShmMem.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -26,7 +26,6 @@ namespace Jack
 
 static unsigned int fSegmentNum = 0;
 static jack_shm_info_t gInfo;
-size_t JackMem::gSize = 0;
 
 JackShmMem::JackShmMem()
 {
diff -pruN 1.9.14~dfsg-1/common/JackShmMem.h 1.9.16~dfsg-1/common/JackShmMem.h
--- 1.9.14~dfsg-1/common/JackShmMem.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackShmMem.h	2020-10-16 19:10:40.000000000 +0000
@@ -39,45 +39,6 @@ void UnlockMemoryImp(void* ptr, size_t s
 void LockAllMemory();
 void UnlockAllMemory();
 
-class JackMem
-{
-    private:
-
-        size_t fSize;
-        static size_t gSize;
-
-    protected:
-
-        JackMem(): fSize(gSize)
-        {}
-        ~JackMem()
-        {}
-
-    public:
-
-        void* operator new(size_t size)
-        {
-            gSize = size;
-            return calloc(1, size);
-        }
-
-        void operator delete(void* ptr, size_t size)
-        {
-            free(ptr);
-        }
-
-        void LockMemory()
-        {
-            LockMemoryImp(this, fSize);
-        }
-
-        void UnlockMemory()
-        {
-            UnlockMemoryImp(this, fSize);
-        }
-
-};
-
 /*!
 \brief
 
diff -pruN 1.9.14~dfsg-1/common/JackTools.cpp 1.9.16~dfsg-1/common/JackTools.cpp
--- 1.9.14~dfsg-1/common/JackTools.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackTools.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -28,6 +28,7 @@
 
 #ifdef WIN32
 #include <process.h>
+#include "JackPlatformPlug_os.h"
 #endif
 
 
@@ -87,12 +88,12 @@ namespace Jack {
     /* returns the name of the per-user subdirectory of jack_tmpdir */
 #ifdef WIN32
 
-    char* JackTools::UserDir()
+    const char* JackTools::UserDir()
     {
         return "";
     }
 
-    char* JackTools::ServerDir(const char* server_name, char* server_dir)
+    const char* JackTools::ServerDir(const char* server_name, char* server_dir)
     {
         return "";
     }
@@ -105,7 +106,7 @@ namespace Jack {
     }
 
 #else
-    char* JackTools::UserDir()
+    const char* JackTools::UserDir()
     {
         static char user_dir[JACK_PATH_MAX + 1] = "";
 
@@ -122,7 +123,7 @@ namespace Jack {
     }
 
     /* returns the name of the per-server subdirectory of jack_user_dir() */
-    char* JackTools::ServerDir(const char* server_name, char* server_dir)
+    const char* JackTools::ServerDir(const char* server_name, char* server_dir)
     {
         /* format the path name into the suppled server_dir char array,
         * assuming that server_dir is at least as large as JACK_PATH_MAX + 1 */
@@ -263,7 +264,7 @@ void PrintLoadError(const char* so_name)
     lpDisplayBuf = (LPVOID)LocalAlloc(LMEM_ZEROINIT,
         (lstrlen((LPCTSTR)lpMsgBuf) + lstrlen((LPCTSTR)so_name) + 40) * sizeof(TCHAR));
     _snprintf((LPTSTR)lpDisplayBuf, LocalSize(lpDisplayBuf) / sizeof(TCHAR),
-        TEXT("error loading %s err = %s"), so_name, lpMsgBuf);
+        TEXT("error loading %s err = %s"), so_name, (LPCTSTR)lpMsgBuf);
 
     jack_error((LPCTSTR)lpDisplayBuf);
 
diff -pruN 1.9.14~dfsg-1/common/JackTools.h 1.9.16~dfsg-1/common/JackTools.h
--- 1.9.14~dfsg-1/common/JackTools.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/JackTools.h	2020-10-16 19:10:40.000000000 +0000
@@ -60,8 +60,8 @@ namespace Jack
         static void KillServer();
 
         static int MkDir(const char* path);
-        static char* UserDir();
-        static char* ServerDir(const char* server_name, char* server_dir);
+        static const char* UserDir();
+        static const char* ServerDir(const char* server_name, char* server_dir);
         static const char* DefaultServerName();
         static void CleanupFiles(const char* server_name);
         static int GetTmpdir();
diff -pruN 1.9.14~dfsg-1/common/shm.c 1.9.16~dfsg-1/common/shm.c
--- 1.9.14~dfsg-1/common/shm.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/shm.c	2020-10-16 19:10:40.000000000 +0000
@@ -79,17 +79,17 @@ static int GetPID()
 }
 
 #ifdef USE_POSIX_SHM
-static jack_shmtype_t jack_shmtype = shm_POSIX;
+static const jack_shmtype_t jack_shmtype = shm_POSIX;
 #elif WIN32
-static jack_shmtype_t jack_shmtype = shm_WIN32;
+static const jack_shmtype_t jack_shmtype = shm_WIN32;
 #else
-static jack_shmtype_t jack_shmtype = shm_SYSV;
+static const jack_shmtype_t jack_shmtype = shm_SYSV;
 #endif
 
 /* interface-dependent forward declarations */
 static int	jack_access_registry (jack_shm_info_t *ri);
 static int	jack_create_registry (jack_shm_info_t *ri);
-static void	jack_remove_shm (jack_shm_id_t *id);
+static void	jack_remove_shm (const jack_shm_id_t id);
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * common interface-independent section
@@ -103,12 +103,19 @@ static void	jack_remove_shm (jack_shm_id
  */
 
 /* per-process global data for the SHM interfaces */
+#ifdef USE_POSIX_SHM
+static const jack_shm_id_t registry_id = "/jack-shm-registry";
+#elif WIN32
+static const jack_shm_id_t registry_id = "jack-shm-registry";
+#else
 static jack_shm_id_t   registry_id;	/* SHM id for the registry */
+#endif
 
 #ifdef WIN32
 static jack_shm_info_t registry_info = {/* SHM info for the registry */
 	JACK_SHM_NULL_INDEX,
-	NULL
+	0,
+	{ NULL }
 };
 #else
 static jack_shm_info_t registry_info = { /* SHM info for the registry */
@@ -120,7 +127,6 @@ static jack_shm_info_t registry_info = {
 /* pointers to registry header and array */
 static jack_shm_header_t   *jack_shm_header = NULL;
 static jack_shm_registry_t *jack_shm_registry = NULL;
-static char jack_shm_server_prefix[JACK_SERVER_NAME_SIZE+1] = "";
 
 /* jack_shm_lock_registry() serializes updates to the shared memory
  * segment JACK uses to keep track of the SHM segments allocated to
@@ -315,16 +321,16 @@ jack_shm_validate_registry ()
  * name, in the interest of portability we use colons instead.
  */
 static void
-jack_set_server_prefix (const char *server_name)
+jack_get_server_prefix (const char* const server_name, char* const prefix, const size_t size)
 {
 #ifdef WIN32
     char buffer[UNLEN+1]={0};
     DWORD len = UNLEN+1;
     GetUserName(buffer, &len);
-    snprintf (jack_shm_server_prefix, sizeof (jack_shm_server_prefix),
+    snprintf (prefix, size,
 		  "jack-%s:%s:", buffer, server_name);
 #else
-    snprintf (jack_shm_server_prefix, sizeof (jack_shm_server_prefix),
+    snprintf (prefix, size,
 		  "jack-%d:%s:", GetUID(), server_name);
 #endif
 }
@@ -349,7 +355,7 @@ jack_server_initialize_shm (int new_regi
 	rc = jack_access_registry (&registry_info);
 
 	if (new_registry) {
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		rc = ENOENT;
 	}
 
@@ -365,7 +371,7 @@ jack_server_initialize_shm (int new_regi
 		/* Apparently, this registry was created by an older
 		 * JACK version.  Delete it so we can try again. */
 		jack_release_shm (&registry_info);
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		if ((rc = jack_create_registry (&registry_info)) != 0) {
 			jack_error ("incompatible shm registry (%s)",
 				    strerror (errno));
@@ -394,11 +400,12 @@ int
 jack_initialize_shm (const char *server_name)
 {
 	int rc;
+	char server_prefix[JACK_SERVER_NAME_SIZE+1];
 
 	if (jack_shm_header)
 		return 0;		/* already initialized */
 
-	jack_set_server_prefix (server_name);
+	jack_get_server_prefix (server_name, server_prefix, sizeof(server_prefix));
 
 	if (jack_shm_lock_registry () < 0) {
         jack_error ("jack_shm_lock_registry fails...");
@@ -429,7 +436,7 @@ jack_destroy_shm (jack_shm_info_t* si)
 	if (si->index == JACK_SHM_NULL_INDEX)
 		return;			/* segment not allocated */
 
-	jack_remove_shm (&jack_shm_registry[si->index].id);
+	jack_remove_shm (jack_shm_registry[si->index].id);
 	jack_release_shm_info (si->index);
 }
 
@@ -490,8 +497,9 @@ int
 jack_register_server (const char *server_name, int new_registry)
 {
 	int i, res = 0;
+	char server_prefix[JACK_SERVER_NAME_SIZE+1];
 
-	jack_set_server_prefix (server_name);
+	jack_get_server_prefix (server_name, server_prefix, sizeof(server_prefix));
 
 	if (jack_server_initialize_shm (new_registry))
 		return ENOMEM;
@@ -507,8 +515,8 @@ jack_register_server (const char *server
 	for (i = 0; i < MAX_SERVERS; i++) {
 
 		if (strncmp (jack_shm_header->server[i].name,
-			     jack_shm_server_prefix,
-			     JACK_SERVER_NAME_SIZE) != 0)
+			     server_prefix,
+			     sizeof(server_prefix)) != 0)
 			continue;	/* no match */
 
 		if (jack_shm_header->server[i].pid == GetPID()){
@@ -548,8 +556,8 @@ jack_register_server (const char *server
 	/* claim it */
 	jack_shm_header->server[i].pid = GetPID();
 	strncpy (jack_shm_header->server[i].name,
-		 jack_shm_server_prefix,
-		 JACK_SERVER_NAME_SIZE);
+		 server_prefix,
+		 sizeof(server_prefix));
 
  unlock:
 	jack_shm_unlock_registry ();
@@ -630,7 +638,7 @@ jack_cleanup_shm ()
 			int index = copy.index;
 
 			if ((index >= 0)  && (index < MAX_SHM_ID)) {
-				jack_remove_shm (&jack_shm_registry[index].id);
+				jack_remove_shm (jack_shm_registry[index].id);
 				jack_release_shm_entry (index);
 			}
 			r->size = 0;
@@ -715,8 +723,6 @@ jack_access_registry (jack_shm_info_t *r
 	/* registry must be locked */
 	int shm_fd;
 
-	strncpy (registry_id, "/jack-shm-registry", sizeof (registry_id));
-
 	/* try to open an existing segment */
 	if ((shm_fd = shm_open (registry_id, O_RDWR, 0666)) < 0) {
 		int rc = errno;
@@ -759,8 +765,6 @@ jack_create_registry (jack_shm_info_t *r
 	/* registry must be locked */
 	int shm_fd;
 
-	strncpy (registry_id, "/jack-shm-registry", sizeof (registry_id));
-
 	if ((shm_fd = shm_open (registry_id, O_RDWR|O_CREAT, 0666)) < 0) {
 		int rc = errno;
 		jack_error ("Cannot create shm registry segment (%s)",
@@ -779,7 +783,7 @@ jack_create_registry (jack_shm_info_t *r
 	if (ftruncate (shm_fd, JACK_SHM_REGISTRY_SIZE) < 0) {
 		int rc = errno;
 		jack_error ("Cannot set registry size (%s)", strerror (errno));
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		close (shm_fd);
 		return rc;
 	}
@@ -789,7 +793,7 @@ jack_create_registry (jack_shm_info_t *r
 				     MAP_SHARED, shm_fd, 0)) == MAP_FAILED) {
 		jack_error ("Cannot mmap shm registry segment (%s)",
 			    strerror (errno));
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		close (shm_fd);
 		return EINVAL;
 	}
@@ -806,10 +810,10 @@ jack_create_registry (jack_shm_info_t *r
 }
 
 static void
-jack_remove_shm (jack_shm_id_t *id)
+jack_remove_shm (const jack_shm_id_t id)
 {
 	/* registry may or may not be locked */
-	shm_unlink ((char *) id);
+	shm_unlink (id);
 }
 
 void
@@ -955,7 +959,6 @@ jack_access_registry (jack_shm_info_t *r
 {
 	/* registry must be locked */
 	HANDLE shm_fd;
-	strncpy (registry_id, "jack-shm-registry", sizeof (registry_id));
 
 	/* try to open an existing segment */
 
@@ -969,7 +972,7 @@ jack_access_registry (jack_shm_info_t *r
 
 	if ((ri->ptr.attached_at = MapViewOfFile (shm_fd, FILE_MAP_ALL_ACCESS, 0, 0, JACK_SHM_REGISTRY_SIZE)) == NULL) {
 		jack_error ("Cannot mmap shm registry segment (%ld)", GetLastError());
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		CloseHandle (shm_fd);
 		return EINVAL;
 	}
@@ -989,8 +992,6 @@ jack_create_registry (jack_shm_info_t *r
 	/* registry must be locked */
 	HANDLE shm_fd;
 
-	strncpy (registry_id, "jack-shm-registry", sizeof (registry_id));
-
 	if ((shm_fd = CreateFileMapping(INVALID_HANDLE_VALUE,
 									0, PAGE_READWRITE,
 									0, JACK_SHM_REGISTRY_SIZE,
@@ -1002,7 +1003,7 @@ jack_create_registry (jack_shm_info_t *r
 
 	if ((ri->ptr.attached_at = MapViewOfFile (shm_fd, FILE_MAP_ALL_ACCESS, 0, 0, JACK_SHM_REGISTRY_SIZE)) == NULL) {
 		jack_error ("Cannot mmap shm registry segment (%ld)", GetLastError());
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		CloseHandle (shm_fd);
 		return EINVAL;
 	}
@@ -1020,7 +1021,7 @@ jack_create_registry (jack_shm_info_t *r
 }
 
 static void
-jack_remove_shm (jack_shm_id_t *id)
+jack_remove_shm (const jack_shm_id_t id)
 {
 	/* nothing to do */
 }
@@ -1102,7 +1103,7 @@ jack_attach_shm (jack_shm_info_t* si)
 
 	if ((si->ptr.attached_at = MapViewOfFile (shm_fd, FILE_MAP_ALL_ACCESS, 0, 0, registry->size)) == NULL) {
 		jack_error ("Cannot mmap shm segment (%ld)", GetLastError());
-		jack_remove_shm (&registry_id);
+		jack_remove_shm (registry_id);
 		CloseHandle (shm_fd);
 		return -1;
 	}
@@ -1125,7 +1126,7 @@ jack_attach_shm_read (jack_shm_info_t* s
 
 	if ((si->ptr.attached_at = MapViewOfFile (shm_fd, FILE_MAP_READ, 0, 0, registry->size)) == NULL) {
 		jack_error("Cannot mmap shm segment (%ld)", GetLastError());
-		jack_remove_shm(&registry_id);
+		jack_remove_shm(registry_id);
 		CloseHandle(shm_fd);
 		return -1;
 	}
@@ -1224,10 +1225,10 @@ jack_create_registry (jack_shm_info_t *r
 }
 
 static void
-jack_remove_shm (jack_shm_id_t *id)
+jack_remove_shm (jack_shm_id_t id)
 {
 	/* registry may or may not be locked */
-	shmctl (*id, IPC_RMID, NULL);
+	shmctl (id, IPC_RMID, NULL);
 }
 
 void
diff -pruN 1.9.14~dfsg-1/common/wscript 1.9.16~dfsg-1/common/wscript
--- 1.9.14~dfsg-1/common/wscript	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/common/wscript	2020-10-16 19:10:40.000000000 +0000
@@ -10,12 +10,12 @@ def configure(conf):
 
     if conf.env['IS_WINDOWS']:
         try:
-            conf.check(function_name='regcomp', header_name='regex.h', lib='regex', uselib_store='REGEX', define_name='HAVE_REGEX_H')
+            conf.check(header_name='regex.h', lib='regex', uselib_store='REGEX', define_name='HAVE_REGEX_H')
         except:
-            conf.check(function_name='regcomp', header_name='regex.h', lib='tre', uselib_store='REGEX', define_name='HAVE_REGEX_H')
-        conf.check(function_name='htons', header_name='winsock2.h', lib='ws2_32', uselib_store='WS2_32', define_name='HAVE_WINSOCK2_H')
-        conf.check(function_name='timeGetDevCaps', header_name=['windows.h', 'mmsystem.h'], lib='winmm', uselib_store='WINMM', define_name='HAVE_MMSYSTEM_H')
-        conf.check(function_name='EnumProcesses', header_name=['windows.h', 'psapi.h'], lib='psapi', uselib_store='PSAPI', define_name='HAVE_PSAPI_H')
+            conf.check(header_name='tre/regex.h', lib='tre', uselib_store='REGEX', define_name='HAVE_TRE_REGEX_H')
+        conf.check(header_name='winsock2.h', lib='ws2_32', uselib_store='WS2_32', define_name='HAVE_WINSOCK2_H')
+        conf.check(header_name=['windows.h', 'mmsystem.h'], lib='winmm', uselib_store='WINMM', define_name='HAVE_MMSYSTEM_H')
+        conf.check(header_name=['windows.h', 'psapi.h'], lib='psapi', uselib_store='PSAPI', define_name='HAVE_PSAPI_H')
 
 def create_jack_process_obj(bld, target, sources, uselib = None, framework = None):
     process = bld(features = ['cxx', 'cxxshlib'])
@@ -74,7 +74,7 @@ def build(bld):
         includes.append('..')
     else:
         includes.append('../..')
-    uselib = ['PTHREAD', 'CELT', 'OPUS', 'DB']
+    uselib = ['CELT', 'OPUS', 'DB', 'PTHREAD']
 
     if bld.env['IS_LINUX']:
         common_libsources += [
@@ -116,8 +116,7 @@ def build(bld):
             '../posix/JackPosixThread.cpp',
             '../posix/JackPosixMutex.cpp',
             '../macosx/JackMachThread.mm',
-            #'../macosx/JackMachSemaphore.mm',
-            '../posix/JackPosixSemaphore.cpp',
+            '../macosx/JackMachSemaphore.mm',
             '../posix/JackSocket.cpp',
             '../macosx/JackMachTime.c',
             ]
@@ -132,26 +131,38 @@ def build(bld):
             '../windows/JackWinTime.c',
             ]
         includes = ['../windows' ] + includes
+        libsuffix = "64" if (bld.env['DEST_CPU'] == "x86_64" and not bld.variant) else ""
+        buildbindir = os.path.join('..', bld.path.get_bld().srcpath().rstrip(bld.path.srcpath()))
+        staticbuild = bool('BUILD_STATIC' in bld.env and bld.env['BUILD_STATIC'])
         uselib.append('REGEX')
         uselib.append('WS2_32')
         uselib.append('PSAPI')
         uselib.append('WINMM')
 
+    else:
+        libsuffix = ""
+
     clientlib = bld(features = ['c', 'cxx', 'cxxshlib', 'cshlib'])
     if bld.env['IS_MACOSX']:
         clientlib.framework = ['CoreAudio', 'Accelerate']
     clientlib.defines = 'HAVE_CONFIG_H'
+    clientlib.includes = includes
+    clientlib.name = 'clientlib'
+    clientlib.target = 'jack'+libsuffix
+    clientlib.install_path = '${LIBDIR}'
     clientlib.use = uselib
     if bld.env['IS_WINDOWS']:
-         clientlib.env['cxxshlib_PATTERN'] = 'lib%s.dll'
-         clientlib.install_path = '${BINDIR}'
-    else:
-         clientlib.install_path = '${LIBDIR}'
+        clientlib.env['cxxshlib_PATTERN'] = 'lib%s.dll'
+        clientlib.env['cxxstlib_PATTERN'] = 'lib%s.a'
+        clientlib.env['implib_PATTERN'] = 'lib%s.dll.a'
+        if staticbuild:
+            clientlib.env['SHLIB_MARKER'] = ''
+        clientlib.env.append_value('LINKFLAGS', ['-static-libstdc++', '--disable-auto-import'])
+        clientlib.env.append_value('LINKFLAGS', ['-Wl,--output-def,lib%s.def' % clientlib.target])
+        bld.install_files(clientlib.install_path, [os.path.join(buildbindir, 'lib%s.def' % clientlib.target)])
+
     if bld.env['AUTOSTART_METHOD'] == 'dbus':
         clientlib.use.append('DBUS-1')
-    clientlib.includes = includes
-    clientlib.name         = 'clientlib'
-    clientlib.target       = 'jack'
     clientlib.source = [] + common_libsources
     clientlib.source += [
         'JackLibClient.cpp',
@@ -185,7 +196,8 @@ def build(bld):
             '../windows/JackMMCSS.cpp',
             ]
 
-    clientlib.vnum = bld.env['JACK_API_VERSION']
+    if not bld.env['IS_WINDOWS']:
+        clientlib.vnum = bld.env['JACK_API_VERSION']
 
     if bld.env['IS_LINUX']:
         clientlib.env.append_value('CPPFLAGS', '-fvisibility=hidden')
@@ -207,14 +219,19 @@ def build(bld):
         serverlib.framework = ['CoreAudio', 'CoreFoundation', 'Accelerate']
     serverlib.defines = ['HAVE_CONFIG_H','SERVER_SIDE']
     serverlib.includes = includes
-    serverlib.name         = 'serverlib'
-    serverlib.target       = 'jackserver'
+    serverlib.name = 'serverlib'
+    serverlib.target = 'jackserver'+libsuffix
+    serverlib.install_path = '${LIBDIR}'
     serverlib.use = uselib
     if bld.env['IS_WINDOWS']:
-         serverlib.env['cxxshlib_PATTERN'] = 'lib%s.dll'
-         serverlib.install_path = '${BINDIR}'
-    else:
-         serverlib.install_path = '${LIBDIR}'
+        serverlib.env['cxxshlib_PATTERN'] = 'lib%s.dll'
+        serverlib.env['cxxstlib_PATTERN'] = 'lib%s.a'
+        serverlib.env['implib_PATTERN'] = 'lib%s.dll.a'
+        if staticbuild:
+            serverlib.env['SHLIB_MARKER'] = ''
+        serverlib.env.append_value('LINKFLAGS', ['-static-libstdc++', '--disable-auto-import'])
+        serverlib.env.append_value('LINKFLAGS', ['-Wl,--output-def,lib%s.def' % serverlib.target])
+        bld.install_files(serverlib.install_path, [os.path.join(buildbindir, 'lib%s.def' % serverlib.target)])
     serverlib.source = [] + common_libsources
     serverlib.source += [
         'JackAudioDriver.cpp',
@@ -287,7 +304,8 @@ def build(bld):
             '../windows/JackNetWinSocket.cpp',
             ]
 
-    serverlib.vnum = bld.env['JACK_API_VERSION']
+    if not bld.env['IS_WINDOWS']:
+        serverlib.vnum = bld.env['JACK_API_VERSION']
 
     if bld.env['IS_LINUX']:
         serverlib.env.append_value('CPPFLAGS', '-fvisibility=hidden')
@@ -305,18 +323,22 @@ def build(bld):
             netlib.framework =  ['CoreAudio']
         netlib.defines = ['HAVE_CONFIG_H','SERVER_SIDE']
         netlib.includes = includes
-        netlib.name         = 'netlib'
-        netlib.target       = 'jacknet'
+        netlib.name = 'netlib'
+        netlib.target = 'jacknet'+libsuffix
+        netlib.install_path = '${LIBDIR}'
         netlib.use = ['SAMPLERATE', 'CELT', 'OPUS', 'PTHREAD']
         if bld.env['IS_WINDOWS']:
-             netlib.env['cxxshlib_PATTERN'] = 'lib%s.dll'
-             netlib.install_path = '${BINDIR}'
-             netlib.use += ['WS2_32', 'WINMM']
-        elif bld.env['IS_MACOSX']:
-             netlib.install_path = '${LIBDIR}'
-        else:
-             netlib.use += ['RT']
-             netlib.install_path = '${LIBDIR}'
+            netlib.use += ['WS2_32', 'WINMM']
+            netlib.env['cxxshlib_PATTERN'] = 'lib%s.dll'
+            netlib.env['cxxstlib_PATTERN'] = 'lib%s.a'
+            netlib.env['implib_PATTERN'] = 'lib%s.dll.a'
+            if staticbuild:
+                netlib.env['SHLIB_MARKER'] = ''
+            netlib.env.append_value('LINKFLAGS', ['-static-libstdc++', '--disable-auto-import'])
+            netlib.env.append_value('LINKFLAGS', ['-Wl,--output-def,lib%s.def' % netlib.target])
+            bld.install_files(netlib.install_path, [os.path.join(buildbindir, 'lib%s.def' % netlib.target)])
+        elif not bld.env['IS_MACOSX']:
+            netlib.use += ['RT']
         netlib.source = [
             'JackNetAPI.cpp',
             'JackNetInterface.cpp',
@@ -344,7 +366,8 @@ def build(bld):
         if bld.env['IS_WINDOWS']:
             netlib.source += ['../windows/JackNetWinSocket.cpp','../windows/JackWinThread.cpp', '../windows/JackMMCSS.cpp', '../windows/JackWinTime.c']
 
-        netlib.vnum = bld.env['JACK_API_VERSION']
+        if not bld.env['IS_WINDOWS']:
+            netlib.vnum = bld.env['JACK_API_VERSION']
 
     create_jack_process_obj(bld, 'netmanager', 'JackNetManager.cpp', serverlib)
 
@@ -388,12 +411,12 @@ def build(bld):
     if bld.env['BUILD_ADAPTER'] and bld.env['IS_LINUX'] and bld.env['BUILD_DRIVER_ALSA']:
          audio_adapter_sources += ['../linux/alsa/JackAlsaAdapter.cpp']
          process = create_jack_process_obj(bld, 'audioadapter', audio_adapter_sources, serverlib)
-         process.use = ['ALSA', 'SAMPLERATE']
+         process.use += ['ALSA', 'SAMPLERATE']
 
     if bld.env['BUILD_ADAPTER'] and bld.env['IS_SUN']:
          audio_adapter_sources += ['../solaris/oss/JackOSSAdapter.cpp', 'memops.c']
          process = create_jack_process_obj(bld, 'audioadapter', audio_adapter_sources, serverlib)
-         process.use = 'SAMPLERATE'
+         process.use += 'SAMPLERATE'
 
     if bld.env['BUILD_ADAPTER'] and bld.env['IS_WINDOWS']:
          audio_adapter_sources += ['../windows/portaudio/JackPortAudioAdapter.cpp', '../windows/portaudio/JackPortAudioDevices.cpp']
@@ -408,7 +431,8 @@ def build(bld):
         features = 'subst_pc',
         source = '../jack.pc.in',
         target = 'jack.pc',
-        install_path = '${LIBDIR}/pkgconfig/',
+        install_path = '${PKGCONFDIR}',
         INCLUDEDIR = os.path.normpath(bld.env['PREFIX'] + '/include'),
+        CLIENTLIB = clientlib.target,
         SERVERLIB = serverlib.target,
         )
diff -pruN 1.9.14~dfsg-1/COPYING 1.9.16~dfsg-1/COPYING
--- 1.9.14~dfsg-1/COPYING	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/COPYING	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,280 @@
+                    GNU GENERAL PUBLIC LICENSE
+                       Version 2, June 1991
+
+ Copyright (C) 1989, 1991 Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ Everyone is permitted to copy and distribute verbatim copies
+ of this license document, but changing it is not allowed.
+
+                            Preamble
+
+  The licenses for most software are designed to take away your
+freedom to share and change it.  By contrast, the GNU General Public
+License is intended to guarantee your freedom to share and change free
+software--to make sure the software is free for all its users.  This
+General Public License applies to most of the Free Software
+Foundation's software and to any other program whose authors commit to
+using it.  (Some other Free Software Foundation software is covered by
+the GNU Lesser General Public License instead.)  You can apply it to
+your programs, too.
+
+  When we speak of free software, we are referring to freedom, not
+price.  Our General Public Licenses are designed to make sure that you
+have the freedom to distribute copies of free software (and charge for
+this service if you wish), that you receive source code or can get it
+if you want it, that you can change the software or use pieces of it
+in new free programs; and that you know you can do these things.
+
+  To protect your rights, we need to make restrictions that forbid
+anyone to deny you these rights or to ask you to surrender the rights.
+These restrictions translate to certain responsibilities for you if you
+distribute copies of the software, or if you modify it.
+
+  For example, if you distribute copies of such a program, whether
+gratis or for a fee, you must give the recipients all the rights that
+you have.  You must make sure that they, too, receive or can get the
+source code.  And you must show them these terms so they know their
+rights.
+
+  We protect your rights with two steps: (1) copyright the software, and
+(2) offer you this license which gives you legal permission to copy,
+distribute and/or modify the software.
+
+  Also, for each author's protection and ours, we want to make certain
+that everyone understands that there is no warranty for this free
+software.  If the software is modified by someone else and passed on, we
+want its recipients to know that what they have is not the original, so
+that any problems introduced by others will not reflect on the original
+authors' reputations.
+
+  Finally, any free program is threatened constantly by software
+patents.  We wish to avoid the danger that redistributors of a free
+program will individually obtain patent licenses, in effect making the
+program proprietary.  To prevent this, we have made it clear that any
+patent must be licensed for everyone's free use or not licensed at all.
+
+  The precise terms and conditions for copying, distribution and
+modification follow.
+
+                    GNU GENERAL PUBLIC LICENSE
+   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
+
+  0. This License applies to any program or other work which contains
+a notice placed by the copyright holder saying it may be distributed
+under the terms of this General Public License.  The "Program", below,
+refers to any such program or work, and a "work based on the Program"
+means either the Program or any derivative work under copyright law:
+that is to say, a work containing the Program or a portion of it,
+either verbatim or with modifications and/or translated into another
+language.  (Hereinafter, translation is included without limitation in
+the term "modification".)  Each licensee is addressed as "you".
+
+Activities other than copying, distribution and modification are not
+covered by this License; they are outside its scope.  The act of
+running the Program is not restricted, and the output from the Program
+is covered only if its contents constitute a work based on the
+Program (independent of having been made by running the Program).
+Whether that is true depends on what the Program does.
+
+  1. You may copy and distribute verbatim copies of the Program's
+source code as you receive it, in any medium, provided that you
+conspicuously and appropriately publish on each copy an appropriate
+copyright notice and disclaimer of warranty; keep intact all the
+notices that refer to this License and to the absence of any warranty;
+and give any other recipients of the Program a copy of this License
+along with the Program.
+
+You may charge a fee for the physical act of transferring a copy, and
+you may at your option offer warranty protection in exchange for a fee.
+
+  2. You may modify your copy or copies of the Program or any portion
+of it, thus forming a work based on the Program, and copy and
+distribute such modifications or work under the terms of Section 1
+above, provided that you also meet all of these conditions:
+
+    a) You must cause the modified files to carry prominent notices
+    stating that you changed the files and the date of any change.
+
+    b) You must cause any work that you distribute or publish, that in
+    whole or in part contains or is derived from the Program or any
+    part thereof, to be licensed as a whole at no charge to all third
+    parties under the terms of this License.
+
+    c) If the modified program normally reads commands interactively
+    when run, you must cause it, when started running for such
+    interactive use in the most ordinary way, to print or display an
+    announcement including an appropriate copyright notice and a
+    notice that there is no warranty (or else, saying that you provide
+    a warranty) and that users may redistribute the program under
+    these conditions, and telling the user how to view a copy of this
+    License.  (Exception: if the Program itself is interactive but
+    does not normally print such an announcement, your work based on
+    the Program is not required to print an announcement.)
+
+These requirements apply to the modified work as a whole.  If
+identifiable sections of that work are not derived from the Program,
+and can be reasonably considered independent and separate works in
+themselves, then this License, and its terms, do not apply to those
+sections when you distribute them as separate works.  But when you
+distribute the same sections as part of a whole which is a work based
+on the Program, the distribution of the whole must be on the terms of
+this License, whose permissions for other licensees extend to the
+entire whole, and thus to each and every part regardless of who wrote it.
+
+Thus, it is not the intent of this section to claim rights or contest
+your rights to work written entirely by you; rather, the intent is to
+exercise the right to control the distribution of derivative or
+collective works based on the Program.
+
+In addition, mere aggregation of another work not based on the Program
+with the Program (or with a work based on the Program) on a volume of
+a storage or distribution medium does not bring the other work under
+the scope of this License.
+
+  3. You may copy and distribute the Program (or a work based on it,
+under Section 2) in object code or executable form under the terms of
+Sections 1 and 2 above provided that you also do one of the following:
+
+    a) Accompany it with the complete corresponding machine-readable
+    source code, which must be distributed under the terms of Sections
+    1 and 2 above on a medium customarily used for software interchange; or,
+
+    b) Accompany it with a written offer, valid for at least three
+    years, to give any third party, for a charge no more than your
+    cost of physically performing source distribution, a complete
+    machine-readable copy of the corresponding source code, to be
+    distributed under the terms of Sections 1 and 2 above on a medium
+    customarily used for software interchange; or,
+
+    c) Accompany it with the information you received as to the offer
+    to distribute corresponding source code.  (This alternative is
+    allowed only for noncommercial distribution and only if you
+    received the program in object code or executable form with such
+    an offer, in accord with Subsection b above.)
+
+The source code for a work means the preferred form of the work for
+making modifications to it.  For an executable work, complete source
+code means all the source code for all modules it contains, plus any
+associated interface definition files, plus the scripts used to
+control compilation and installation of the executable.  However, as a
+special exception, the source code distributed need not include
+anything that is normally distributed (in either source or binary
+form) with the major components (compiler, kernel, and so on) of the
+operating system on which the executable runs, unless that component
+itself accompanies the executable.
+
+If distribution of executable or object code is made by offering
+access to copy from a designated place, then offering equivalent
+access to copy the source code from the same place counts as
+distribution of the source code, even though third parties are not
+compelled to copy the source along with the object code.
+
+  4. You may not copy, modify, sublicense, or distribute the Program
+except as expressly provided under this License.  Any attempt
+otherwise to copy, modify, sublicense or distribute the Program is
+void, and will automatically terminate your rights under this License.
+However, parties who have received copies, or rights, from you under
+this License will not have their licenses terminated so long as such
+parties remain in full compliance.
+
+  5. You are not required to accept this License, since you have not
+signed it.  However, nothing else grants you permission to modify or
+distribute the Program or its derivative works.  These actions are
+prohibited by law if you do not accept this License.  Therefore, by
+modifying or distributing the Program (or any work based on the
+Program), you indicate your acceptance of this License to do so, and
+all its terms and conditions for copying, distributing or modifying
+the Program or works based on it.
+
+  6. Each time you redistribute the Program (or any work based on the
+Program), the recipient automatically receives a license from the
+original licensor to copy, distribute or modify the Program subject to
+these terms and conditions.  You may not impose any further
+restrictions on the recipients' exercise of the rights granted herein.
+You are not responsible for enforcing compliance by third parties to
+this License.
+
+  7. If, as a consequence of a court judgment or allegation of patent
+infringement or for any other reason (not limited to patent issues),
+conditions are imposed on you (whether by court order, agreement or
+otherwise) that contradict the conditions of this License, they do not
+excuse you from the conditions of this License.  If you cannot
+distribute so as to satisfy simultaneously your obligations under this
+License and any other pertinent obligations, then as a consequence you
+may not distribute the Program at all.  For example, if a patent
+license would not permit royalty-free redistribution of the Program by
+all those who receive copies directly or indirectly through you, then
+the only way you could satisfy both it and this License would be to
+refrain entirely from distribution of the Program.
+
+If any portion of this section is held invalid or unenforceable under
+any particular circumstance, the balance of the section is intended to
+apply and the section as a whole is intended to apply in other
+circumstances.
+
+It is not the purpose of this section to induce you to infringe any
+patents or other property right claims or to contest validity of any
+such claims; this section has the sole purpose of protecting the
+integrity of the free software distribution system, which is
+implemented by public license practices.  Many people have made
+generous contributions to the wide range of software distributed
+through that system in reliance on consistent application of that
+system; it is up to the author/donor to decide if he or she is willing
+to distribute software through any other system and a licensee cannot
+impose that choice.
+
+This section is intended to make thoroughly clear what is believed to
+be a consequence of the rest of this License.
+
+  8. If the distribution and/or use of the Program is restricted in
+certain countries either by patents or by copyrighted interfaces, the
+original copyright holder who places the Program under this License
+may add an explicit geographical distribution limitation excluding
+those countries, so that distribution is permitted only in or among
+countries not thus excluded.  In such case, this License incorporates
+the limitation as if written in the body of this License.
+
+  9. The Free Software Foundation may publish revised and/or new versions
+of the General Public License from time to time.  Such new versions will
+be similar in spirit to the present version, but may differ in detail to
+address new problems or concerns.
+
+Each version is given a distinguishing version number.  If the Program
+specifies a version number of this License which applies to it and "any
+later version", you have the option of following the terms and conditions
+either of that version or of any later version published by the Free
+Software Foundation.  If the Program does not specify a version number of
+this License, you may choose any version ever published by the Free Software
+Foundation.
+
+  10. If you wish to incorporate parts of the Program into other free
+programs whose distribution conditions are different, write to the author
+to ask for permission.  For software which is copyrighted by the Free
+Software Foundation, write to the Free Software Foundation; we sometimes
+make exceptions for this.  Our decision will be guided by the two goals
+of preserving the free status of all derivatives of our free software and
+of promoting the sharing and reuse of software generally.
+
+                            NO WARRANTY
+
+  11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED
+OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE RISK AS
+TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.  SHOULD THE
+PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY SERVICING,
+REPAIR OR CORRECTION.
+
+  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES,
+INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING
+OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED
+TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY
+YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
+PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
+POSSIBILITY OF SUCH DAMAGES.
+
+                     END OF TERMS AND CONDITIONS
diff -pruN 1.9.14~dfsg-1/debian/changelog 1.9.16~dfsg-1/debian/changelog
--- 1.9.14~dfsg-1/debian/changelog	2020-08-24 19:13:05.000000000 +0000
+++ 1.9.16~dfsg-1/debian/changelog	2020-10-18 14:56:14.000000000 +0000
@@ -1,3 +1,13 @@
+jackd2 (1.9.16~dfsg-1) unstable; urgency=medium
+
+  * Team upload
+  * New upstream release
+  * debian/copyright:
+    - Fix pattern in Files-Excluded
+    - Update paths of moved files
+
+ -- Sebastian Ramacher <sramacher@debian.org>  Sun, 18 Oct 2020 16:56:14 +0200
+
 jackd2 (1.9.14~dfsg-1) unstable; urgency=medium
 
   * Team upload
diff -pruN 1.9.14~dfsg-1/debian/copyright 1.9.16~dfsg-1/debian/copyright
--- 1.9.14~dfsg-1/debian/copyright	2020-08-23 22:29:08.000000000 +0000
+++ 1.9.16~dfsg-1/debian/copyright	2020-10-18 14:54:36.000000000 +0000
@@ -4,7 +4,7 @@ Upstream-Contact: JACK developers <jack-
 Source: https://github.com/jackaudio/jack2
  Repackaged, excluding non-DFSG files
 Files-Excluded:
- ./windows/**.rc
+ windows/*.rc
 
 Files: *
 Copyright: 2004-2012, Grame <grame@grame.fr>
@@ -214,8 +214,8 @@ License: LGPL-2.1+
 
 Files: common/memops.c
  common/memops.h
- example-clients/evmon.c
- example-clients/freewheel.c
+ tools/evmon.c
+ tools/freewheel.c
  linux/alsa/alsa_driver.c
  linux/alsa/alsa_driver.h
  linux/alsa/generic.h
@@ -298,9 +298,9 @@ Copyright: 2009, Grame
   2011, Devin Anderson
 License: GPL-2+
 
-Files: example-clients/bufsize.c
- example-clients/samplerate.c
- example-clients/transport.c
+Files: tools/bufsize.c
+ tools/samplerate.c
+ tools/transport.c
  linux/alsa/bitset.h
 Copyright: 2003, 2005, Jack O'Quin
 License: GPL-2+
@@ -413,7 +413,7 @@ Files: example-clients/midiseq.c
 Copyright: 2004, Ian Esten
 License: GPL-2+
 
-Files: example-clients/connect.c
+Files: tools/connect.c
  example-clients/zombie.c
 Copyright: 2002, Jeremy Hall
 License: GPL-2+
@@ -426,7 +426,7 @@ Copyright: 2001, Paul Davis
 License: GPL-2+
 
 Files: common/netjack_packet.c
- example-clients/netsource.c
+ tools/netsource.c
 Copyright: 2006, Torben Hohn <torbenh@gmx.de>
   2008, Marc-Olivier Barre <marco@marcochapeau.org>
   2008, Pieter Palmers <pieterpalmers@users.sourceforge.net>
@@ -605,7 +605,7 @@ Copyright: 2001, Steve Harris
 License: GPL-2+
 
 Files: common/netjack_packet.h
- example-clients/session_notify.c
+ tools/session_notify.c
 Copyright: 2006, Torben Hohn <torbenh@gmx.de>
 License: GPL-2+
 
@@ -909,4 +909,4 @@ License: LGPL-2+
  .
  You should have received a copy of the GNU Library General Public
  License along with this program.  If not, see
- <https//www.gnu.org/licenses/>.
\ No newline at end of file
+ <https//www.gnu.org/licenses/>.
diff -pruN 1.9.14~dfsg-1/example-clients/alias.c 1.9.16~dfsg-1/example-clients/alias.c
--- 1.9.14~dfsg-1/example-clients/alias.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/alias.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,133 +0,0 @@
-/*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <getopt.h>
-#include <jack/jack.h>
-
-char * my_name;
-
-void
-show_version (void)
-{
-	//fprintf (stderr, "%s: JACK Audio Connection Kit version " VERSION "\n", my_name);
-}
-
-void
-show_usage (void)
-{
-	show_version ();
-	fprintf (stderr, "\nUsage: %s [options] portname alias\n", my_name);
-	fprintf (stderr, "List active Jack ports, and optionally display extra information.\n\n");
-	fprintf (stderr, "Display options:\n");
-	fprintf (stderr, "        -u, --unalias         remove `alias' as an alias for `port'\n");
-	fprintf (stderr, "        -h, --help            Display this help message\n");
-	fprintf (stderr, "        --version             Output version information and exit\n\n");
-	fprintf (stderr, "For more information see http://jackaudio.org/\n");
-}
-
-int
-main (int argc, char *argv[])
-{
-	jack_client_t *client;
-	jack_status_t status;
-	char* portname;
-	char* alias;
-	int unset = 0;
-	int ret;
-	int c;
-	int option_index;
-	extern int optind;
-	jack_port_t* port;
-
-	struct option long_options[] = {
-		{ "unalias", 0, 0, 'u' },
-		{ "help", 0, 0, 'h' },
-		{ "version", 0, 0, 'v' },
-		{ 0, 0, 0, 0 }
-	};
-
-	if (argc < 3) {
-		show_usage ();
-		return 1;
-	}
-
-	my_name = strrchr(argv[0], '/');
-	if (my_name == 0) {
-		my_name = argv[0];
-	} else {
-		my_name ++;
-	}
-
-	while ((c = getopt_long (argc, argv, "uhv", long_options, &option_index)) >= 0) {
-		switch (c) {
-		case 'u':
-			unset = 1;
-			break;
-		case 'h':
-			show_usage ();
-			return 1;
-			break;
-		case 'v':
-			show_version ();
-			return 1;
-			break;
-		default:
-			show_usage ();
-			return 1;
-			break;
-		}
-	}
-
-	portname = argv[optind++];
-	alias = argv[optind];
-
-	/* Open a client connection to the JACK server.  Starting a
-	 * new server only to list its ports seems pointless, so we
-	 * specify JackNoStartServer. */
-	//JOQ: need a new server name option
-
-	client = jack_client_open ("lsp", JackNoStartServer, &status);
-
-	if (client == NULL) {
-		if (status & JackServerFailed) {
-			fprintf (stderr, "JACK server not running\n");
-		} else {
-			fprintf (stderr, "jack_client_open() failed, "
-				 "status = 0x%2.0x\n", status);
-		}
-		return 1;
-	}
-
-	if ((port = jack_port_by_name (client, portname)) == 0) {
-		fprintf (stderr, "No port named \"%s\"\n", portname);
-		return 1;
-	}
-
-	if (!unset) {
-		ret = jack_port_set_alias (port, alias);
-	} else {
-		ret = jack_port_unset_alias (port, alias);
-	}
-
-	jack_client_close (client);
-
-	return ret;
-
-}
diff -pruN 1.9.14~dfsg-1/example-clients/alsa_in.c 1.9.16~dfsg-1/example-clients/alsa_in.c
--- 1.9.14~dfsg-1/example-clients/alsa_in.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/alsa_in.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,846 +0,0 @@
-/** @file simple_client.c
- *
- * @brief This simple client demonstrates the basic features of JACK
- * as they would be used by many applications.
- */
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-#include <signal.h>
-
-#include <math.h>
-
-#include <jack/jack.h>
-#include <jack/jslist.h>
-#include "memops.h"
-
-#include "alsa/asoundlib.h"
-
-#include <samplerate.h>
-
-// Here are the lists of the jack ports...
-
-JSList	   *capture_ports = NULL;
-JSList	   *capture_srcs = NULL;
-JSList	   *playback_ports = NULL;
-JSList	   *playback_srcs = NULL;
-jack_client_t *client;
-
-snd_pcm_t *alsa_handle;
-
-int jack_sample_rate;
-int jack_buffer_size;
-
-int quit = 0;
-double resample_mean = 1.0;
-double static_resample_factor = 1.0;
-double resample_lower_limit = 0.25;
-double resample_upper_limit = 4.0;
-
-double *offset_array;
-double *window_array;
-int offset_differential_index = 0;
-
-double offset_integral = 0;
-
-// ------------------------------------------------------ commandline parameters
-
-int sample_rate = 0;				 /* stream rate */
-int num_channels = 2;				 /* count of channels */
-int period_size = 1024;
-int num_periods = 2;
-
-int target_delay = 0;	    /* the delay which the program should try to approach. */
-int max_diff = 0;	    /* the diff value, when a hard readpointer skip should occur */
-int catch_factor = 100000;
-int catch_factor2 = 10000;
-double pclamp = 15.0;
-double controlquant = 10000.0;
-int smooth_size = 256;
-int good_window=0;
-int verbose = 0;
-int instrument = 0;
-int samplerate_quality = 2;
-
-// Debug stuff:
-
-volatile float output_resampling_factor = 1.0;
-volatile int output_new_delay = 0;
-volatile float output_offset = 0.0;
-volatile float output_integral = 0.0;
-volatile float output_diff = 0.0;
-volatile int running_freewheel = 0;
-
-snd_pcm_uframes_t real_buffer_size;
-snd_pcm_uframes_t real_period_size;
-
-// buffers
-
-char *tmpbuf;
-char *outbuf;
-float *resampbuf;
-
-// format selection, and corresponding functions from memops in a nice set of structs.
-
-typedef struct alsa_format {
-	snd_pcm_format_t format_id;
-	size_t sample_size;
-	void (*jack_to_soundcard) (char *dst, jack_default_audio_sample_t *src, unsigned long nsamples, unsigned long dst_skip, dither_state_t *state);
-	void (*soundcard_to_jack) (jack_default_audio_sample_t *dst, char *src, unsigned long nsamples, unsigned long src_skip);
-	const char *name;
-} alsa_format_t;
-
-alsa_format_t formats[] = {
-	{ SND_PCM_FORMAT_FLOAT_LE, 4, sample_move_dS_floatLE, sample_move_floatLE_sSs, "float" },
-	{ SND_PCM_FORMAT_S32, 4, sample_move_d32u24_sS, sample_move_dS_s32u24, "32bit" },
-	{ SND_PCM_FORMAT_S24_3LE, 3, sample_move_d24_sS, sample_move_dS_s24, "24bit - real" },
-	{ SND_PCM_FORMAT_S24, 4, sample_move_d24_sS, sample_move_dS_s24, "24bit" },
-	{ SND_PCM_FORMAT_S16, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit" }
-#ifdef __ANDROID__
-	,{ SND_PCM_FORMAT_S16_LE, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit little-endian" }
-#endif
-};
-#define NUMFORMATS (sizeof(formats)/sizeof(formats[0]))
-int format=0;
-
-// Alsa stuff... i don't want to touch this bullshit in the next years.... please...
-
-static int xrun_recovery(snd_pcm_t *handle, int err) {
-//    printf( "xrun !!!.... %d\n", err );
-	if (err == -EPIPE) {	/* under-run */
-		err = snd_pcm_prepare(handle);
-		if (err < 0)
-			printf("Can't recover from underrun, prepare failed: %s\n", snd_strerror(err));
-		return 0;
-	} else if (err == -ESTRPIPE) {
-		while ((err = snd_pcm_resume(handle)) == -EAGAIN)
-			usleep(100);	/* wait until the suspend flag is released */
-		if (err < 0) {
-			err = snd_pcm_prepare(handle);
-			if (err < 0)
-				printf("Can't recover from suspend, prepare failed: %s\n", snd_strerror(err));
-		}
-		return 0;
-	}
-	return err;
-}
-
-static int set_hwformat( snd_pcm_t *handle, snd_pcm_hw_params_t *params )
-{
-#ifdef __ANDROID__
-	format = 5;
-	snd_pcm_hw_params_set_format(handle, params, formats[format].format_id);
-	return 0;
-#else
-	int i;
-	int err;
-
-	for( i=0; i<NUMFORMATS; i++ ) {
-		/* set the sample format */
-		err = snd_pcm_hw_params_set_format(handle, params, formats[i].format_id);
-		if (err == 0) {
-			format = i;
-			return 0;
-		}
-	}
-
-	return err;
-#endif
-}
-
-static int set_hwparams(snd_pcm_t *handle, snd_pcm_hw_params_t *params, snd_pcm_access_t access, int rate, int channels, int period, int nperiods ) {
-	int err, dir=0;
-	unsigned int buffer_time;
-	unsigned int period_time;
-	unsigned int rrate;
-	unsigned int rchannels;
-
-	/* choose all parameters */
-	err = snd_pcm_hw_params_any(handle, params);
-	if (err < 0) {
-		printf("Broken configuration for playback: no configurations available: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* set the interleaved read/write format */
-	err = snd_pcm_hw_params_set_access(handle, params, access);
-	if (err < 0) {
-		printf("Access type not available for playback: %s\n", snd_strerror(err));
-		return err;
-	}
-
-	/* set the sample format */
-	err = set_hwformat(handle, params);
-	if (err < 0) {
-		printf("Sample format not available for playback: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* set the count of channels */
-	rchannels = channels;
-	err = snd_pcm_hw_params_set_channels_near(handle, params, &rchannels);
-	if (err < 0) {
-		printf("Channels count (%i) not available for record: %s\n", channels, snd_strerror(err));
-		return err;
-	}
-	if (rchannels != channels) {
-		printf("WARNING: channel count does not match (requested %d got %d)\n", channels, rchannels);
-		num_channels = rchannels;
-	}
-	/* set the stream rate */
-	rrate = rate;
-	err = snd_pcm_hw_params_set_rate_near(handle, params, &rrate, 0);
-	if (err < 0) {
-		printf("Rate %iHz not available for playback: %s\n", rate, snd_strerror(err));
-		return err;
-	}
-	if (rrate != rate) {
-		printf("WARNING: Rate doesn't match (requested %iHz, get %iHz)\n", rate, rrate);
-		sample_rate = rrate;
-	}
-	/* set the buffer time */
-
-	buffer_time = 1000000*(uint64_t)period*nperiods/rate;
-	err = snd_pcm_hw_params_set_buffer_time_near(handle, params, &buffer_time, &dir);
-	if (err < 0) {
-		printf("Unable to set buffer time %i for playback: %s\n",  1000000*period*nperiods/rate, snd_strerror(err));
-		return err;
-	}
-	err = snd_pcm_hw_params_get_buffer_size( params, &real_buffer_size );
-	if (err < 0) {
-		printf("Unable to get buffer size back: %s\n", snd_strerror(err));
-		return err;
-	}
-	if( real_buffer_size != nperiods * period ) {
-	    printf( "WARNING: buffer size does not match: (requested %d, got %d)\n", nperiods * period, (int) real_buffer_size );
-	}
-	/* set the period time */
-	period_time = 1000000*(uint64_t)period/rate;
-	err = snd_pcm_hw_params_set_period_time_near(handle, params, &period_time, &dir);
-	if (err < 0) {
-		printf("Unable to set period time %i for playback: %s\n", 1000000*period/rate, snd_strerror(err));
-		return err;
-	}
-	err = snd_pcm_hw_params_get_period_size(params, &real_period_size, NULL );
-	if (err < 0) {
-		printf("Unable to get period size back: %s\n", snd_strerror(err));
-		return err;
-	}
-	if( real_period_size != period ) {
-	    printf( "WARNING: period size does not match: (requested %i, got %i)\n", period, (int)real_period_size );
-	}
-	/* write the parameters to device */
-	err = snd_pcm_hw_params(handle, params);
-	if (err < 0) {
-		printf("Unable to set hw params for playback: %s\n", snd_strerror(err));
-		return err;
-	}
-	return 0;
-}
-
-static int set_swparams(snd_pcm_t *handle, snd_pcm_sw_params_t *swparams, int period) {
-	int err;
-
-	/* get the current swparams */
-	err = snd_pcm_sw_params_current(handle, swparams);
-	if (err < 0) {
-		printf("Unable to determine current swparams for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* start the transfer when the buffer is full */
-	err = snd_pcm_sw_params_set_start_threshold(handle, swparams, period );
-	if (err < 0) {
-		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	err = snd_pcm_sw_params_set_stop_threshold(handle, swparams, -1 );
-	if (err < 0) {
-		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* allow the transfer when at least period_size samples can be processed */
-	err = snd_pcm_sw_params_set_avail_min(handle, swparams, 2*period );
-	if (err < 0) {
-		printf("Unable to set avail min for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* align all transfers to 1 sample */
-	err = snd_pcm_sw_params_set_xfer_align(handle, swparams, 1);
-	if (err < 0) {
-		printf("Unable to set transfer align for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* write the parameters to the playback device */
-	err = snd_pcm_sw_params(handle, swparams);
-	if (err < 0) {
-		printf("Unable to set sw params for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	return 0;
-}
-
-// ok... i only need this function to communicate with the alsa bloat api...
-
-static snd_pcm_t *open_audiofd( char *device_name, int capture, int rate, int channels, int period, int nperiods ) {
-  int err;
-  snd_pcm_t *handle;
-  snd_pcm_hw_params_t *hwparams;
-  snd_pcm_sw_params_t *swparams;
-
-  snd_pcm_hw_params_alloca(&hwparams);
-  snd_pcm_sw_params_alloca(&swparams);
-
-  if ((err = snd_pcm_open(&(handle), device_name, capture ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK )) < 0) {
-      printf("Capture open error: %s\n", snd_strerror(err));
-      return NULL;
-  }
-
-  if ((err = set_hwparams(handle, hwparams,SND_PCM_ACCESS_RW_INTERLEAVED, rate, channels, period, nperiods )) < 0) {
-      printf("Setting of hwparams failed: %s\n", snd_strerror(err));
-      return NULL;
-  }
-  if ((err = set_swparams(handle, swparams, period)) < 0) {
-      printf("Setting of swparams failed: %s\n", snd_strerror(err));
-      return NULL;
-  }
-
-  snd_pcm_start( handle );
-  snd_pcm_wait( handle, 200 );
-
-  return handle;
-}
-
-double hann( double x )
-{
-	return 0.5 * (1.0 - cos( 2*M_PI * x ) );
-}
-
-/**
- * The freewheel callback.
- */
-void freewheel (int starting, void* arg) {
-    running_freewheel = starting;
-}
-
-/**
- * The process callback for this JACK application.
- * It is called by JACK at the appropriate times.
- */
-int process (jack_nframes_t nframes, void *arg) {
-
-    if (running_freewheel) {
-	JSList *node = capture_ports;
-
-	while ( node != NULL)
-	{
-	    jack_port_t *port = (jack_port_t *) node->data;
-	    float *buf = jack_port_get_buffer (port, nframes);
-
-	    memset(buf, 0, sizeof(float)*nframes);
-
-	    node = jack_slist_next (node);
-	}
-
-	return 0;
-    }
-
-    int rlen;
-    int err;
-    snd_pcm_sframes_t delay = target_delay;
-    int put_back_samples=0;
-    int i;
-
-    delay = snd_pcm_avail( alsa_handle );
-
-    delay -= round( jack_frames_since_cycle_start( client ) / static_resample_factor );
-    // Do it the hard way.
-    // this is for compensating xruns etc...
-
-    if( delay > (target_delay+max_diff) ) {
-
-	output_new_delay = (int) delay;
-
-	while ((delay-target_delay) > 0) {
-	    snd_pcm_uframes_t to_read = ((delay-target_delay) > 512) ? 512 : (delay-target_delay);
-	    snd_pcm_readi( alsa_handle, tmpbuf, to_read );
-	    delay -= to_read;
-	}
-
-	delay = target_delay;
-
-	// Set the resample_rate... we need to adjust the offset integral, to do this.
-	// first look at the PI controller, this code is just a special case, which should never execute once
-	// everything is swung in. 
-	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
-	// Also clear the array. we are beginning a new control cycle.
-	for( i=0; i<smooth_size; i++ )
-		offset_array[i] = 0.0;
-    }
-    if( delay < (target_delay-max_diff) ) {
-	snd_pcm_rewind( alsa_handle, target_delay - delay );
-	output_new_delay = (int) delay;
-	delay = target_delay;
-
-	// Set the resample_rate... we need to adjust the offset integral, to do this.
-	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
-	// Also clear the array. we are beginning a new control cycle.
-	for( i=0; i<smooth_size; i++ )
-		offset_array[i] = 0.0;
-    }
-    /* ok... now we should have target_delay +- max_diff on the alsa side.
-     *
-     * calculate the number of frames, we want to get.
-     */
-
-    double offset = delay - target_delay;
-
-    // Save offset.
-    offset_array[(offset_differential_index++)% smooth_size ] = offset;
-
-    // Build the mean of the windowed offset array
-    // basically fir lowpassing.
-    double smooth_offset = 0.0;
-    for( i=0; i<smooth_size; i++ )
-	    smooth_offset +=
-		    offset_array[ (i + offset_differential_index-1) % smooth_size] * window_array[i];
-    smooth_offset /= (double) smooth_size;
-
-    // this is the integral of the smoothed_offset
-    offset_integral += smooth_offset;
-
-    // Clamp offset.
-    // the smooth offset still contains unwanted noise
-    // which would go straight onto the resample coeff.
-    // it only used in the P component and the I component is used for the fine tuning anyways.
-    if( fabs( smooth_offset ) < pclamp )
-	    smooth_offset = 0.0;
-
-    // ok. now this is the PI controller. 
-    // u(t) = K * ( e(t) + 1/T \int e(t') dt' )
-    // K = 1/catch_factor and T = catch_factor2
-    double current_resample_factor = static_resample_factor - smooth_offset / (double) catch_factor - offset_integral / (double) catch_factor / (double)catch_factor2;
-
-    // now quantize this value around resample_mean, so that the noise which is in the integral component doesn't hurt.
-    current_resample_factor = floor( (current_resample_factor - resample_mean) * controlquant + 0.5 ) / controlquant + resample_mean;
-
-    // Output "instrumentatio" gonna change that to real instrumentation in a few.
-    output_resampling_factor = (float) current_resample_factor;
-    output_diff = (float) smooth_offset;
-    output_integral = (float) offset_integral;
-    output_offset = (float) offset;
-
-    // Clamp a bit.
-    if( current_resample_factor < resample_lower_limit ) current_resample_factor = resample_lower_limit;
-    if( current_resample_factor > resample_upper_limit ) current_resample_factor = resample_upper_limit;
-
-    // Now Calculate how many samples we need.
-    rlen = ceil( ((double)nframes) / current_resample_factor )+2;
-    assert( rlen > 2 );
-
-    // Calculate resample_mean so we can init ourselves to saner values.
-    resample_mean = 0.9999 * resample_mean + 0.0001 * current_resample_factor;
-
-    // get the data...
-again:
-    err = snd_pcm_readi(alsa_handle, outbuf, rlen);
-    if( err < 0 ) {
-	printf( "err = %d\n", err );
-	if (xrun_recovery(alsa_handle, err) < 0) {
-	    //printf("Write error: %s\n", snd_strerror(err));
-	    //exit(EXIT_FAILURE);
-	}
-	goto again;
-    }
-    if( err != rlen ) {
-	//printf( "read = %d\n", rlen );
-    }
-
-    /*
-     * render jack ports to the outbuf...
-     */
-
-    int chn = 0;
-    JSList *node = capture_ports;
-    JSList *src_node = capture_srcs;
-    SRC_DATA src;
-
-    while ( node != NULL)
-    {
-	jack_port_t *port = (jack_port_t *) node->data;
-	float *buf = jack_port_get_buffer (port, nframes);
-
-	SRC_STATE *src_state = src_node->data;
-
-	formats[format].soundcard_to_jack( resampbuf, outbuf + format[formats].sample_size * chn, rlen, num_channels*format[formats].sample_size );
-
-	src.data_in = resampbuf;
-	src.input_frames = rlen;
-
-	src.data_out = buf;
-	src.output_frames = nframes;
-	src.end_of_input = 0;
-
-	src.src_ratio = current_resample_factor;
-
-	src_process( src_state, &src );
-
-	put_back_samples = rlen-src.input_frames_used;
-
-	src_node = jack_slist_next (src_node);
-	node = jack_slist_next (node);
-	chn++;
-    }
-
-    // Put back the samples libsamplerate did not consume.
-    //printf( "putback = %d\n", put_back_samples );
-    snd_pcm_rewind( alsa_handle, put_back_samples );
-
-    return 0;      
-}
-
-/**
- * the latency callback.
- * sets up the latencies on the ports.
- */
-
-void
-latency_cb (jack_latency_callback_mode_t mode, void *arg)
-{
-	jack_latency_range_t range;
-	JSList *node;
-
-	range.min = range.max = round(target_delay * static_resample_factor);
-
-	if (mode == JackCaptureLatency) {
-		for (node = capture_ports; node; node = jack_slist_next (node)) {
-			jack_port_t *port = node->data;
-			jack_port_set_latency_range (port, mode, &range);
-		}
-	} else {
-		for (node = playback_ports; node; node = jack_slist_next (node)) {
-			jack_port_t *port = node->data;
-			jack_port_set_latency_range (port, mode, &range);
-		}
-	}
-}
-
-
-/**
- * Allocate the necessary jack ports...
- */
-
-void alloc_ports( int n_capture, int n_playback ) {
-
-    int port_flags = JackPortIsOutput;
-    int chn;
-    jack_port_t *port;
-    char buf[32];
-
-    capture_ports = NULL;
-    for (chn = 0; chn < n_capture; chn++)
-    {
-	snprintf (buf, sizeof(buf) - 1, "capture_%u", chn+1);
-
-	port = jack_port_register (client, buf,
-		JACK_DEFAULT_AUDIO_TYPE,
-		port_flags, 0);
-
-	if (!port)
-	{
-	    printf( "jacknet_client: cannot register port for %s", buf);
-	    break;
-	}
-
-	capture_srcs = jack_slist_append( capture_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
-	capture_ports = jack_slist_append (capture_ports, port);
-    }
-
-    port_flags = JackPortIsInput;
-
-    playback_ports = NULL;
-    for (chn = 0; chn < n_playback; chn++)
-    {
-	snprintf (buf, sizeof(buf) - 1, "playback_%u", chn+1);
-
-	port = jack_port_register (client, buf,
-		JACK_DEFAULT_AUDIO_TYPE,
-		port_flags, 0);
-
-	if (!port)
-	{
-	    printf( "jacknet_client: cannot register port for %s", buf);
-	    break;
-	}
-
-	playback_srcs = jack_slist_append( playback_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
-	playback_ports = jack_slist_append (playback_ports, port);
-    }
-}
-
-/**
- * This is the shutdown callback for this JACK application.
- * It is called by JACK if the server ever shuts down or
- * decides to disconnect the client.
- */
-
-void jack_shutdown (void *arg) {
-
-	exit (1);
-}
-
-/**
- * be user friendly.
- * be user friendly.
- * be user friendly.
- */
-
-void printUsage() {
-fprintf(stderr, "usage: alsa_out [options]\n"
-		"\n"
-		"  -j <jack name> - client name\n"
-		"  -S <server name> - server to connect\n"
-		"  -d <alsa_device> \n"
-		"  -c <channels> \n"
-		"  -p <period_size> \n"
-		"  -n <num_period> \n"
-		"  -r <sample_rate> \n"
-		"  -q <sample_rate quality [0..4]\n"
-		"  -m <max_diff> \n"
-		"  -t <target_delay> \n"
-		"  -i  turns on instrumentation\n"
-		"  -v  turns on printouts\n"
-		"\n");
-}
-
-
-/**
- * the main function....
- */
-
-void
-sigterm_handler( int signal )
-{
-	quit = 1;
-}
-
-
-int main (int argc, char *argv[]) {
-    char jack_name[30] = "alsa_in";
-    char alsa_device[30] = "hw:0";
-    char *server_name = NULL;
-    int jack_opts = 0;
-
-    extern char *optarg;
-    extern int optind, optopt;
-    int errflg=0;
-    int c;
-
-    while ((c = getopt(argc, argv, "ivj:r:c:p:n:d:q:m:t:f:F:C:Q:s:S:")) != -1) {
-	switch(c) {
-	    case 'j':
-		strcpy(jack_name,optarg);
-		break;
-	    case 'r':
-		sample_rate = atoi(optarg);
-		break;
-	    case 'c':
-		num_channels = atoi(optarg);
-		break;
-	    case 'p':
-		period_size = atoi(optarg);
-		break;
-	    case 'n':
-		num_periods = atoi(optarg);
-		break;
-	    case 'd':
-		strcpy(alsa_device,optarg);
-		break;
-	    case 't':
-		target_delay = atoi(optarg);
-		break;
-	    case 'q':
-		samplerate_quality = atoi(optarg);
-		break;
-	    case 'm':
-		max_diff = atoi(optarg);
-		break;
-	    case 'f':
-		catch_factor = atoi(optarg);
-		break;
-	    case 'F':
-		catch_factor2 = atoi(optarg);
-		break;
-	    case 'C':
-		pclamp = (double) atoi(optarg);
-		break;
-	    case 'Q':
-		controlquant = (double) atoi(optarg);
-		break;
-	    case 'v':
-		verbose = 1;
-		break;
-	    case 'i':
-		instrument = 1;
-		break;
-	    case 's':
-		smooth_size = atoi(optarg);
-		break;
-	    case 'S':
-		server_name = optarg;
-		jack_opts |= JackServerName;
-		break;
-	    case ':':
-		fprintf(stderr,
-			"Option -%c requires an operand\n", optopt);
-		errflg++;
-		break;
-	    case '?':
-		fprintf(stderr,
-			"Unrecognized option: -%c\n", optopt);
-		errflg++;
-	}
-    }
-    if (errflg) {
-	printUsage();
-	exit(2);
-    }
-
-    if( (samplerate_quality < 0) || (samplerate_quality > 4) ) {
-	fprintf (stderr, "invalid samplerate quality\n");
-	return 1;
-    }
-    if ((client = jack_client_open (jack_name, jack_opts, NULL, server_name)) == 0) {
-	fprintf (stderr, "jack server not running?\n");
-	return 1;
-    }
-
-    /* tell the JACK server to call `process()' whenever
-       there is work to be done.
-       */
-
-    jack_set_process_callback (client, process, 0);
-
-    /* tell the JACK server to call `freewheel()' whenever
-       freewheel mode changes.
-       */
-
-    jack_set_freewheel_callback (client, freewheel, 0);
-
-    /* tell the JACK server to call `jack_shutdown()' if
-       it ever shuts down, either entirely, or if it
-       just decides to stop calling us.
-       */
-
-    jack_on_shutdown (client, jack_shutdown, 0);
-
-    if (jack_set_latency_callback)
-	    jack_set_latency_callback (client, latency_cb, 0);
-
-    // get jack sample_rate
-    
-    jack_sample_rate = jack_get_sample_rate( client );
-
-    if( !sample_rate )
-	sample_rate = jack_sample_rate;
-
-    // now open the alsa fd...
-    alsa_handle = open_audiofd( alsa_device, 1, sample_rate, num_channels, period_size, num_periods);
-    if( alsa_handle == 0 )
-	exit(20);
-
-    printf( "selected sample format: %s\n", formats[format].name );
-
-    static_resample_factor = (double) jack_sample_rate / (double) sample_rate;
-    resample_lower_limit = static_resample_factor * 0.25;
-    resample_upper_limit = static_resample_factor * 4.0;
-    resample_mean = static_resample_factor;
-
-    offset_array = malloc( sizeof(double) * smooth_size );
-    if( offset_array == NULL ) {
-	    fprintf( stderr, "no memory for offset_array !!!\n" );
-	    exit(20);
-    }
-    window_array = malloc( sizeof(double) * smooth_size );
-    if( window_array == NULL ) {
-	    fprintf( stderr, "no memory for window_array !!!\n" );
-	    exit(20);
-    }
-    int i;
-    for( i=0; i<smooth_size; i++ ) {
-	    offset_array[i] = 0.0;
-	    window_array[i] = hann( (double) i / ((double) smooth_size - 1.0) );
-    }
-
-    jack_buffer_size = jack_get_buffer_size( client );
-    // Setup target delay and max_diff for the normal user, who does not play with them...
-    if( !target_delay ) 
-	target_delay = (num_periods*period_size / 2) + jack_buffer_size/2;
-
-    if( !max_diff )
-	max_diff = num_periods*period_size - target_delay ;	
-
-    if( max_diff > target_delay ) {
-	    fprintf( stderr, "target_delay (%d) can not be smaller than max_diff(%d)\n", target_delay, max_diff );
-	    exit(20);
-    }
-    if( (target_delay+max_diff) > (num_periods*period_size) ) {
-	    fprintf( stderr, "target_delay+max_diff (%d) can not be bigger than buffersize(%d)\n", target_delay+max_diff, num_periods*period_size );
-	    exit(20);
-    }
-    // alloc input ports, which are blasted out to alsa...
-    alloc_ports( num_channels, 0 );
-
-    outbuf = malloc( num_periods * period_size * formats[format].sample_size * num_channels );
-    resampbuf = malloc( num_periods * period_size * sizeof( float ) );
-    tmpbuf = malloc( 512 * formats[format].sample_size * num_channels );
-
-    if ((outbuf == NULL) || (resampbuf == NULL) || (tmpbuf == NULL))
-    {
-	    fprintf( stderr, "no memory for buffers.\n" );
-	    exit(20);
-    }
-
-    memset( tmpbuf, 0, 512 * formats[format].sample_size * num_channels);
-
-    /* tell the JACK server that we are ready to roll */
-
-    if (jack_activate (client)) {
-	fprintf (stderr, "cannot activate client");
-	return 1;
-    }
-
-    signal( SIGTERM, sigterm_handler );
-    signal( SIGINT, sigterm_handler );
-
-    if( verbose ) {
-	    while(!quit) {
-		    usleep(500000);
-		    if( output_new_delay ) {
-			    printf( "delay = %d\n", output_new_delay );
-			    output_new_delay = 0;
-		    }
-		    printf( "res: %f, \tdiff = %f, \toffset = %f \n", output_resampling_factor, output_diff, output_offset );
-	    }
-    } else if( instrument ) {
-	    printf( "# n\tresamp\tdiff\toffseti\tintegral\n");
-	    int n=0;
-	    while(!quit) {
-		    usleep(1000);
-		    printf( "%d\t%f\t%f\t%f\t%f\n", n++, output_resampling_factor, output_diff, output_offset, output_integral );
-	    }
-    } else {
-	    while(!quit)
-	    {
-		    usleep(500000);
-		    if( output_new_delay ) {
-			    printf( "delay = %d\n", output_new_delay );
-			    output_new_delay = 0;
-		    }
-	    }
-    }
-
-    jack_deactivate( client );
-    jack_client_close (client);
-    exit (0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/alsa_out.c 1.9.16~dfsg-1/example-clients/alsa_out.c
--- 1.9.14~dfsg-1/example-clients/alsa_out.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/alsa_out.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,848 +0,0 @@
-/** @file simple_client.c
- *
- * @brief This simple client demonstrates the basic features of JACK
- * as they would be used by many applications.
- */
-
-#include <alloca.h>
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-#include <signal.h>
-
-#include <math.h>
-
-#include <jack/jack.h>
-#include <jack/jslist.h>
-#include "memops.h"
-
-#include "alsa/asoundlib.h"
-
-#include <samplerate.h>
-
-// Here are the lists of the jack ports...
-
-JSList	   *capture_ports = NULL;
-JSList	   *capture_srcs = NULL;
-JSList	   *playback_ports = NULL;
-JSList	   *playback_srcs = NULL;
-jack_client_t *client;
-
-snd_pcm_t *alsa_handle;
-
-int jack_sample_rate;
-int jack_buffer_size;
-
-int quit = 0;
-double resample_mean = 1.0;
-double static_resample_factor = 1.0;
-double resample_lower_limit = 0.25;
-double resample_upper_limit = 4.0;
-
-double *offset_array;
-double *window_array;
-int offset_differential_index = 0;
-
-double offset_integral = 0;
-
-// ------------------------------------------------------ commandline parameters
-
-int sample_rate = 0;				 /* stream rate */
-int num_channels = 2;				 /* count of channels */
-int period_size = 1024;
-int num_periods = 2;
-
-int target_delay = 0;	    /* the delay which the program should try to approach. */
-int max_diff = 0;	    /* the diff value, when a hard readpointer skip should occur */
-int catch_factor = 100000;
-int catch_factor2 = 10000;
-double pclamp = 15.0;
-double controlquant = 10000.0;
-int smooth_size = 256;
-int good_window=0;
-int verbose = 0;
-int instrument = 0;
-int samplerate_quality = 2;
-
-// Debug stuff:
-
-volatile float output_resampling_factor = 1.0;
-volatile int output_new_delay = 0;
-volatile float output_offset = 0.0;
-volatile float output_integral = 0.0;
-volatile float output_diff = 0.0;
-volatile int running_freewheel = 0;
-
-snd_pcm_uframes_t real_buffer_size;
-snd_pcm_uframes_t real_period_size;
-
-// buffers
-
-char *tmpbuf;
-char *outbuf;
-float *resampbuf;
-
-// format selection, and corresponding functions from memops in a nice set of structs.
-
-typedef struct alsa_format {
-	snd_pcm_format_t format_id;
-	size_t sample_size;
-	void (*jack_to_soundcard) (char *dst, jack_default_audio_sample_t *src, unsigned long nsamples, unsigned long dst_skip, dither_state_t *state);
-	void (*soundcard_to_jack) (jack_default_audio_sample_t *dst, char *src, unsigned long nsamples, unsigned long src_skip);
-	const char *name;
-} alsa_format_t;
-
-alsa_format_t formats[] = {
-	{ SND_PCM_FORMAT_FLOAT_LE, 4, sample_move_dS_floatLE, sample_move_floatLE_sSs, "float" },
-	{ SND_PCM_FORMAT_S32, 4, sample_move_d32u24_sS, sample_move_dS_s32u24, "32bit" },
-	{ SND_PCM_FORMAT_S24_3LE, 3, sample_move_d24_sS, sample_move_dS_s24, "24bit - real" },
-	{ SND_PCM_FORMAT_S24, 4, sample_move_d24_sS, sample_move_dS_s24, "24bit" },
-	{ SND_PCM_FORMAT_S16, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit" }
-#ifdef __ANDROID__
-	,{ SND_PCM_FORMAT_S16_LE, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit little-endian" }
-#endif
-};
-#define NUMFORMATS (sizeof(formats)/sizeof(formats[0]))
-int format=0;
-
-// Alsa stuff... i don't want to touch this bullshit in the next years.... please...
-
-static int xrun_recovery(snd_pcm_t *handle, int err) {
-//    printf( "xrun !!!.... %d\n", err );
-	if (err == -EPIPE) {	/* under-run */
-		err = snd_pcm_prepare(handle);
-		if (err < 0)
-			printf("Can't recovery from underrun, prepare failed: %s\n", snd_strerror(err));
-		return 0;
-	} else if (err == -ESTRPIPE) {
-		while ((err = snd_pcm_resume(handle)) == -EAGAIN)
-			usleep(100);	/* wait until the suspend flag is released */
-		if (err < 0) {
-			err = snd_pcm_prepare(handle);
-			if (err < 0)
-				printf("Can't recovery from suspend, prepare failed: %s\n", snd_strerror(err));
-		}
-		return 0;
-	}
-	return err;
-}
-
-static int set_hwformat( snd_pcm_t *handle, snd_pcm_hw_params_t *params )
-{
-#ifdef __ANDROID__
-	format = 5;
-	snd_pcm_hw_params_set_format(handle, params, formats[format].format_id);
-	return 0;
-#else
-	int i;
-	int err;
-
-	for( i=0; i<NUMFORMATS; i++ ) {
-		/* set the sample format */
-		err = snd_pcm_hw_params_set_format(handle, params, formats[i].format_id);
-		if (err == 0) {
-			format = i;
-			return 0;
-		}
-	}
-
-	return err;
-#endif
-}
-
-static int set_hwparams(snd_pcm_t *handle, snd_pcm_hw_params_t *params, snd_pcm_access_t access, int rate, int channels, int period, int nperiods ) {
-	int err, dir=0;
-	unsigned int buffer_time;
-	unsigned int period_time;
-	unsigned int rrate;
-	unsigned int rchannels;
-
-	/* choose all parameters */
-	err = snd_pcm_hw_params_any(handle, params);
-	if (err < 0) {
-		printf("Broken configuration for playback: no configurations available: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* set the interleaved read/write format */
-	err = snd_pcm_hw_params_set_access(handle, params, access);
-	if (err < 0) {
-		printf("Access type not available for playback: %s\n", snd_strerror(err));
-		return err;
-	}
-
-	/* set the sample format */
-	err = set_hwformat(handle, params);
-	if (err < 0) {
-		printf("Sample format not available for playback: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* set the count of channels */
-	rchannels = channels;
-	err = snd_pcm_hw_params_set_channels_near(handle, params, &rchannels);
-	if (err < 0) {
-		printf("Channels count (%i) not available for record: %s\n", channels, snd_strerror(err));
-		return err;
-	}
-	if (rchannels != channels) {
-		printf("WARNING: channel count does not match (requested %d got %d)\n", channels, rchannels);
-		num_channels = rchannels;
-	}
-	/* set the stream rate */
-	rrate = rate;
-	err = snd_pcm_hw_params_set_rate_near(handle, params, &rrate, 0);
-	if (err < 0) {
-		printf("Rate %iHz not available for playback: %s\n", rate, snd_strerror(err));
-		return err;
-	}
-	if (rrate != rate) {
-		printf("Rate doesn't match (requested %iHz, get %iHz)\n", rate, rrate);
-		return -EINVAL;
-	}
-	/* set the buffer time */
-
-	buffer_time = 1000000*(uint64_t)period*nperiods/rate;
-	err = snd_pcm_hw_params_set_buffer_time_near(handle, params, &buffer_time, &dir);
-	if (err < 0) {
-		printf("Unable to set buffer time %i for playback: %s\n",  1000000*period*nperiods/rate, snd_strerror(err));
-		return err;
-	}
-	err = snd_pcm_hw_params_get_buffer_size( params, &real_buffer_size );
-	if (err < 0) {
-		printf("Unable to get buffer size back: %s\n", snd_strerror(err));
-		return err;
-	}
-	if( real_buffer_size != nperiods * period ) {
-	    printf( "WARNING: buffer size does not match: (requested %d, got %d)\n", nperiods * period, (int) real_buffer_size );
-	}
-	/* set the period time */
-	period_time = 1000000*(uint64_t)period/rate;
-	err = snd_pcm_hw_params_set_period_time_near(handle, params, &period_time, &dir);
-	if (err < 0) {
-		printf("Unable to set period time %i for playback: %s\n", 1000000*period/rate, snd_strerror(err));
-		return err;
-	}
-	err = snd_pcm_hw_params_get_period_size(params, &real_period_size, NULL );
-	if (err < 0) {
-		printf("Unable to get period size back: %s\n", snd_strerror(err));
-		return err;
-	}
-	if( real_period_size != period ) {
-	    printf( "WARNING: period size does not match: (requested %i, got %i)\n", period, (int)real_period_size );
-	}
-	/* write the parameters to device */
-	err = snd_pcm_hw_params(handle, params);
-	if (err < 0) {
-		printf("Unable to set hw params for playback: %s\n", snd_strerror(err));
-		return err;
-	}
-	return 0;
-}
-
-static int set_swparams(snd_pcm_t *handle, snd_pcm_sw_params_t *swparams, int period, int nperiods) {
-	int err;
-
-	/* get the current swparams */
-	err = snd_pcm_sw_params_current(handle, swparams);
-	if (err < 0) {
-		printf("Unable to determine current swparams for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* start the transfer when the buffer is full */
-	err = snd_pcm_sw_params_set_start_threshold(handle, swparams, period );
-	if (err < 0) {
-		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	err = snd_pcm_sw_params_set_stop_threshold(handle, swparams, -1 );
-	if (err < 0) {
-		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* allow the transfer when at least period_size samples can be processed */
-	err = snd_pcm_sw_params_set_avail_min(handle, swparams, 1 );
-	if (err < 0) {
-		printf("Unable to set avail min for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* align all transfers to 1 sample */
-	err = snd_pcm_sw_params_set_xfer_align(handle, swparams, 1);
-	if (err < 0) {
-		printf("Unable to set transfer align for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	/* write the parameters to the playback device */
-	err = snd_pcm_sw_params(handle, swparams);
-	if (err < 0) {
-		printf("Unable to set sw params for capture: %s\n", snd_strerror(err));
-		return err;
-	}
-	return 0;
-}
-
-// ok... i only need this function to communicate with the alsa bloat api...
-
-static snd_pcm_t *open_audiofd( char *device_name, int capture, int rate, int channels, int period, int nperiods ) {
-  int err;
-  snd_pcm_t *handle;
-  snd_pcm_hw_params_t *hwparams;
-  snd_pcm_sw_params_t *swparams;
-
-  snd_pcm_hw_params_alloca(&hwparams);
-  snd_pcm_sw_params_alloca(&swparams);
-
-  if ((err = snd_pcm_open(&(handle), device_name, capture ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK )) < 0) {
-      printf("Capture open error: %s\n", snd_strerror(err));
-      return NULL;
-  }
-
-  if ((err = set_hwparams(handle, hwparams,SND_PCM_ACCESS_RW_INTERLEAVED, rate, channels, period, nperiods )) < 0) {
-      printf("Setting of hwparams failed: %s\n", snd_strerror(err));
-      return NULL;
-  }
-  if ((err = set_swparams(handle, swparams, period, nperiods)) < 0) {
-      printf("Setting of swparams failed: %s\n", snd_strerror(err));
-      return NULL;
-  }
-
-  //snd_pcm_start( handle );
-  //snd_pcm_wait( handle, 200 );
-  int num_null_samples = nperiods * period * channels;
-  char *tmp = alloca( num_null_samples * formats[format].sample_size ); 
-  memset( tmp, 0, num_null_samples * formats[format].sample_size );
-  snd_pcm_writei( handle, tmp, num_null_samples );
-  
-
-  return handle;
-}
-
-double hann( double x )
-{
-	return 0.5 * (1.0 - cos( 2*M_PI * x ) );
-}
-
-/**
- * The freewheel callback.
- */
-void freewheel (int starting, void* arg) {
-    running_freewheel = starting;
-}
-
-/**
- * The process callback for this JACK application.
- * It is called by JACK at the appropriate times.
- */
-int process (jack_nframes_t nframes, void *arg) {
-
-    if (running_freewheel) {
-	JSList *node = playback_ports;
-
-	while ( node != NULL)
-	{
-	    jack_port_t *port = (jack_port_t *) node->data;
-	    float *buf = jack_port_get_buffer (port, nframes);
-
-	    memset(buf, 0, sizeof(float)*nframes);
-
-	    node = jack_slist_next (node);
-	}
-
-	return 0;
-    }
-
-    int rlen;
-    int err;
-    snd_pcm_sframes_t delay = target_delay;
-    int i;
-
-    delay = (num_periods*period_size)-snd_pcm_avail( alsa_handle ) ;
-
-    delay -= round( jack_frames_since_cycle_start( client ) * static_resample_factor );
-    // Do it the hard way.
-    // this is for compensating xruns etc...
-
-    if( delay > (target_delay+max_diff) ) {
-	snd_pcm_rewind( alsa_handle, delay - target_delay );
-	output_new_delay = (int) delay;
-
-	delay = target_delay;
-
-	// Set the resample_rate... we need to adjust the offset integral, to do this.
-	// first look at the PI controller, this code is just a special case, which should never execute once
-	// everything is swung in. 
-	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
-	// Also clear the array. we are beginning a new control cycle.
-	for( i=0; i<smooth_size; i++ )
-		offset_array[i] = 0.0;
-    }
-    if( delay < (target_delay-max_diff) ) {
-
-	output_new_delay = (int) delay;
-
-	while ((target_delay-delay) > 0) {
-	    snd_pcm_uframes_t to_write = ((target_delay-delay) > 512) ? 512 : (target_delay-delay);
-	    snd_pcm_writei( alsa_handle, tmpbuf, to_write );
-	    delay += to_write;
-	}
-
-	delay = target_delay;
-
-	// Set the resample_rate... we need to adjust the offset integral, to do this.
-	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
-	// Also clear the array. we are beginning a new control cycle.
-	for( i=0; i<smooth_size; i++ )
-		offset_array[i] = 0.0;
-    }
-    /* ok... now we should have target_delay +- max_diff on the alsa side.
-     *
-     * calculate the number of frames, we want to get.
-     */
-
-    double offset = delay - target_delay;
-
-    // Save offset.
-    offset_array[(offset_differential_index++)% smooth_size ] = offset;
-
-    // Build the mean of the windowed offset array
-    // basically fir lowpassing.
-    double smooth_offset = 0.0;
-    for( i=0; i<smooth_size; i++ )
-	    smooth_offset +=
-		    offset_array[ (i + offset_differential_index-1) % smooth_size] * window_array[i];
-    smooth_offset /= (double) smooth_size;
-
-    // this is the integral of the smoothed_offset
-    offset_integral += smooth_offset;
-
-    // Clamp offset.
-    // the smooth offset still contains unwanted noise
-    // which would go straight onto the resample coeff.
-    // it only used in the P component and the I component is used for the fine tuning anyways.
-    if( fabs( smooth_offset ) < pclamp )
-	    smooth_offset = 0.0;
-
-    // ok. now this is the PI controller. 
-    // u(t) = K * ( e(t) + 1/T \int e(t') dt' )
-    // K = 1/catch_factor and T = catch_factor2
-    double current_resample_factor = static_resample_factor - smooth_offset / (double) catch_factor - offset_integral / (double) catch_factor / (double)catch_factor2;
-
-    // now quantize this value around resample_mean, so that the noise which is in the integral component doesn't hurt.
-    current_resample_factor = floor( (current_resample_factor - resample_mean) * controlquant + 0.5 ) / controlquant + resample_mean;
-
-    // Output "instrumentatio" gonna change that to real instrumentation in a few.
-    output_resampling_factor = (float) current_resample_factor;
-    output_diff = (float) smooth_offset;
-    output_integral = (float) offset_integral;
-    output_offset = (float) offset;
-
-    // Clamp a bit.
-    if( current_resample_factor < resample_lower_limit ) current_resample_factor = resample_lower_limit;
-    if( current_resample_factor > resample_upper_limit ) current_resample_factor = resample_upper_limit;
-
-    // Now Calculate how many samples we need.
-    rlen = ceil( ((double)nframes) * current_resample_factor )+2;
-    assert( rlen > 2 );
-
-    // Calculate resample_mean so we can init ourselves to saner values.
-    resample_mean = 0.9999 * resample_mean + 0.0001 * current_resample_factor;
-    /*
-     * now this should do it...
-     */
-
-    outbuf = alloca( rlen * formats[format].sample_size * num_channels );
-
-    resampbuf = alloca( rlen * sizeof( float ) );
-    /*
-     * render jack ports to the outbuf...
-     */
-
-    int chn = 0;
-    JSList *node = playback_ports;
-    JSList *src_node = playback_srcs;
-    SRC_DATA src;
-
-    while ( node != NULL)
-    {
-	jack_port_t *port = (jack_port_t *) node->data;
-	float *buf = jack_port_get_buffer (port, nframes);
-
-	SRC_STATE *src_state = src_node->data;
-
-	src.data_in = buf;
-	src.input_frames = nframes;
-
-	src.data_out = resampbuf;
-	src.output_frames = rlen;
-	src.end_of_input = 0;
-
-	src.src_ratio = current_resample_factor;
-
-	src_process( src_state, &src );
-
-	formats[format].jack_to_soundcard( outbuf + format[formats].sample_size * chn, resampbuf, src.output_frames_gen, num_channels*format[formats].sample_size, NULL);
-
-	src_node = jack_slist_next (src_node);
-	node = jack_slist_next (node);
-	chn++;
-    }
-
-    // now write the output...
-again:
-  err = snd_pcm_writei(alsa_handle, outbuf, src.output_frames_gen);
-  //err = snd_pcm_writei(alsa_handle, outbuf, src.output_frames_gen);
-  if( err < 0 ) {
-      printf( "err = %d\n", err );
-      if (xrun_recovery(alsa_handle, err) < 0) {
-	  printf("Write error: %s\n", snd_strerror(err));
-	  exit(EXIT_FAILURE);
-      }
-      goto again;
-  }
-
-    return 0;      
-}
-
-/**
- * the latency callback.
- * sets up the latencies on the ports.
- */
-
-void
-latency_cb (jack_latency_callback_mode_t mode, void *arg)
-{
-	jack_latency_range_t range;
-	JSList *node;
-
-	range.min = range.max = round(target_delay / static_resample_factor);
-
-	if (mode == JackCaptureLatency) {
-		for (node = capture_ports; node; node = jack_slist_next (node)) {
-			jack_port_t *port = node->data;
-			jack_port_set_latency_range (port, mode, &range);
-		}
-	} else {
-		for (node = playback_ports; node; node = jack_slist_next (node)) {
-			jack_port_t *port = node->data;
-			jack_port_set_latency_range (port, mode, &range);
-		}
-	}
-}
-
-
-/**
- * Allocate the necessary jack ports...
- */
-
-void alloc_ports( int n_capture, int n_playback ) {
-
-    int port_flags = JackPortIsOutput | JackPortIsPhysical | JackPortIsTerminal;
-    int chn;
-    jack_port_t *port;
-    char buf[32];
-
-    capture_ports = NULL;
-    for (chn = 0; chn < n_capture; chn++)
-    {
-	snprintf (buf, sizeof(buf) - 1, "capture_%u", chn+1);
-
-	port = jack_port_register (client, buf,
-		JACK_DEFAULT_AUDIO_TYPE,
-		port_flags, 0);
-
-	if (!port)
-	{
-	    printf( "jacknet_client: cannot register port for %s", buf);
-	    break;
-	}
-
-	capture_srcs = jack_slist_append( capture_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
-	capture_ports = jack_slist_append (capture_ports, port);
-    }
-
-    port_flags = JackPortIsInput;
-
-    playback_ports = NULL;
-    for (chn = 0; chn < n_playback; chn++)
-    {
-	snprintf (buf, sizeof(buf) - 1, "playback_%u", chn+1);
-
-	port = jack_port_register (client, buf,
-		JACK_DEFAULT_AUDIO_TYPE,
-		port_flags, 0);
-
-	if (!port)
-	{
-	    printf( "jacknet_client: cannot register port for %s", buf);
-	    break;
-	}
-
-	playback_srcs = jack_slist_append( playback_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
-	playback_ports = jack_slist_append (playback_ports, port);
-    }
-}
-
-/**
- * This is the shutdown callback for this JACK application.
- * It is called by JACK if the server ever shuts down or
- * decides to disconnect the client.
- */
-
-void jack_shutdown (void *arg) {
-
-	exit (1);
-}
-
-/**
- * be user friendly.
- * be user friendly.
- * be user friendly.
- */
-
-void printUsage() {
-fprintf(stderr, "usage: alsa_out [options]\n"
-		"\n"
-		"  -j <jack name> - client name\n"
-		"  -d <alsa_device> \n"
-		"  -c <channels> \n"
-		"  -p <period_size> \n"
-		"  -n <num_period> \n"
-		"  -r <sample_rate> \n"
-		"  -q <sample_rate quality [0..4]\n"
-		"  -m <max_diff> \n"
-		"  -t <target_delay> \n"
-		"  -i  turns on instrumentation\n"
-		"  -v  turns on printouts\n"
-		"\n");
-}
-
-
-/**
- * the main function....
- */
-
-void
-sigterm_handler( int signal )
-{
-	quit = 1;
-}
-
-
-int main (int argc, char *argv[]) {
-    char jack_name[30] = "alsa_out";
-    char alsa_device[30] = "hw:0";
-    int jack_opts = 0;
-    char *server_name = NULL;
-
-    extern char *optarg;
-    extern int optind, optopt;
-    int errflg=0;
-    int c;
-
-    while ((c = getopt(argc, argv, "ivj:r:c:p:n:d:q:m:t:f:F:C:Q:s:S:")) != -1) {
-	switch(c) {
-	    case 'j':
-		strcpy(jack_name,optarg);
-		break;
-	    case 'r':
-		sample_rate = atoi(optarg);
-		break;
-	    case 'c':
-		num_channels = atoi(optarg);
-		break;
-	    case 'p':
-		period_size = atoi(optarg);
-		break;
-	    case 'n':
-		num_periods = atoi(optarg);
-		break;
-	    case 'd':
-		strcpy(alsa_device,optarg);
-		break;
-	    case 't':
-		target_delay = atoi(optarg);
-		break;
-	    case 'q':
-		samplerate_quality = atoi(optarg);
-		break;
-	    case 'm':
-		max_diff = atoi(optarg);
-		break;
-	    case 'f':
-		catch_factor = atoi(optarg);
-		break;
-	    case 'F':
-		catch_factor2 = atoi(optarg);
-		break;
-	    case 'C':
-		pclamp = (double) atoi(optarg);
-		break;
-	    case 'Q':
-		controlquant = (double) atoi(optarg);
-		break;
-	    case 'v':
-		verbose = 1;
-		break;
-	    case 'i':
-		instrument = 1;
-		break;
-	    case 's':
-		smooth_size = atoi(optarg);
-		break;
-	    case 'S':
-		server_name = optarg;
-		jack_opts |= JackServerName;
-		break;
-	    case ':':
-		fprintf(stderr,
-			"Option -%c requires an operand\n", optopt);
-		errflg++;
-		break;
-	    case '?':
-		fprintf(stderr,
-			"Unrecognized option: -%c\n", optopt);
-		errflg++;
-	}
-    }
-    if (errflg) {
-	printUsage();
-	exit(2);
-    }
-
-    if( (samplerate_quality < 0) || (samplerate_quality > 4) ) {
-	fprintf (stderr, "invalid samplerate quality\n");
-	return 1;
-    }
-    if ((client = jack_client_open (jack_name, jack_opts, NULL, server_name)) == 0) {
-	fprintf (stderr, "jack server not running?\n");
-	return 1;
-    }
-
-    /* tell the JACK server to call `process()' whenever
-       there is work to be done.
-       */
-
-    jack_set_process_callback (client, process, 0);
-
-    /* tell the JACK server to call `freewheel()' whenever
-       freewheel mode changes.
-       */
-
-    jack_set_freewheel_callback (client, freewheel, 0);
-
-    /* tell the JACK server to call `jack_shutdown()' if
-       it ever shuts down, either entirely, or if it
-       just decides to stop calling us.
-       */
-
-    jack_on_shutdown (client, jack_shutdown, 0);
-
-    if (jack_set_latency_callback)
-	    jack_set_latency_callback (client, latency_cb, 0);
-
-    // get jack sample_rate
-    
-    jack_sample_rate = jack_get_sample_rate( client );
-
-    if( !sample_rate )
-	sample_rate = jack_sample_rate;
-
-    static_resample_factor =  (double) sample_rate / (double) jack_sample_rate;
-    resample_lower_limit = static_resample_factor * 0.25;
-    resample_upper_limit = static_resample_factor * 4.0;
-    resample_mean = static_resample_factor;
-
-    offset_array = malloc( sizeof(double) * smooth_size );
-    if( offset_array == NULL ) {
-	    fprintf( stderr, "no memory for offset_array !!!\n" );
-	    exit(20);
-    }
-    window_array = malloc( sizeof(double) * smooth_size );
-    if( window_array == NULL ) {
-	    fprintf( stderr, "no memory for window_array !!!\n" );
-	    exit(20);
-    }
-    int i;
-    for( i=0; i<smooth_size; i++ ) {
-	    offset_array[i] = 0.0;
-	    window_array[i] = hann( (double) i / ((double) smooth_size - 1.0) );
-    }
-
-    jack_buffer_size = jack_get_buffer_size( client );
-    // Setup target delay and max_diff for the normal user, who does not play with them...
-    if( !target_delay ) 
-	target_delay = (num_periods*period_size / 2) - jack_buffer_size/2;
-
-    if( !max_diff )
-	max_diff = target_delay;	
-
-    if( max_diff > target_delay ) {
-	    fprintf( stderr, "target_delay (%d) can not be smaller than max_diff(%d)\n", target_delay, max_diff );
-	    exit(20);
-    }
-    if( (target_delay+max_diff) > (num_periods*period_size) ) {
-	    fprintf( stderr, "target_delay+max_diff (%d) can not be bigger than buffersize(%d)\n", target_delay+max_diff, num_periods*period_size );
-	    exit(20);
-    }
-    // now open the alsa fd...
-    alsa_handle = open_audiofd( alsa_device, 0, sample_rate, num_channels, period_size, num_periods);
-    if( alsa_handle == 0 )
-	exit(20);
-
-    printf( "selected sample format: %s\n", formats[format].name );
-
-    // alloc input ports, which are blasted out to alsa...
-    alloc_ports( 0, num_channels );
-
-    outbuf = malloc( num_periods * period_size * formats[format].sample_size * num_channels );
-    resampbuf = malloc( num_periods * period_size * sizeof( float ) );
-    tmpbuf = malloc( 512 * formats[format].sample_size * num_channels );
-
-    if ((outbuf == NULL) || (resampbuf == NULL) || (tmpbuf == NULL))
-    {
-	    fprintf( stderr, "no memory for buffers.\n" );
-	    exit(20);
-    }
-
-
-    /* tell the JACK server that we are ready to roll */
-
-    if (jack_activate (client)) {
-	fprintf (stderr, "cannot activate client");
-	return 1;
-    }
-
-    signal( SIGTERM, sigterm_handler );
-    signal( SIGINT, sigterm_handler );
-
-    if( verbose ) {
-	    while(!quit) {
-		    usleep(500000);
-		    if( output_new_delay ) {
-			    printf( "delay = %d\n", output_new_delay );
-			    output_new_delay = 0;
-		    }
-		    printf( "res: %f, \tdiff = %f, \toffset = %f \n", output_resampling_factor, output_diff, output_offset );
-	    }
-    } else if( instrument ) {
-	    printf( "# n\tresamp\tdiff\toffseti\tintegral\n");
-	    int n=0;
-	    while(!quit) {
-		    usleep(1000);
-		    printf( "%d\t%f\t%f\t%f\t%f\n", n++, output_resampling_factor, output_diff, output_offset, output_integral );
-	    }
-    } else {
-	    while(!quit)
-	    {
-		    usleep(500000);
-		    if( output_new_delay ) {
-			    printf( "delay = %d\n", output_new_delay );
-			    output_new_delay = 0;
-		    }
-	    }
-    }
-
-    jack_deactivate( client );
-    jack_client_close (client);
-    exit (0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/bufsize.c 1.9.16~dfsg-1/example-clients/bufsize.c
--- 1.9.14~dfsg-1/example-clients/bufsize.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/bufsize.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,124 +0,0 @@
-/*
- *  bufsize.c -- change JACK buffer size.
- *
- *  Copyright (C) 2003 Jack O'Quin.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <string.h>
-#include <jack/jack.h>
-#include <jack/transport.h>
-
-char *package;				/* program name */
-jack_client_t *client;
-jack_nframes_t nframes;
-int just_print_bufsize=0;
-
-void jack_shutdown(void *arg)
-{
-	fprintf(stderr, "JACK shut down, exiting ...\n");
-	exit(1);
-}
-
-void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-void parse_arguments(int argc, char *argv[])
-{
-	/* basename $0 */
-	package = strrchr(argv[0], '/');
-	if (package == 0)
-		package = argv[0];
-	else
-		package++;
-
-	if (argc==1) {
-		just_print_bufsize = 1;
-		return;
-	}
-	if (argc < 2) {
-		fprintf(stderr, "usage: %s <bufsize>\n", package);
-		exit(9);
-	}
-
-	if (strspn (argv[1], "0123456789") != strlen (argv[1])) {
-		fprintf(stderr, "usage: %s <bufsize>\n", package);
-		exit(8);
-	}
-
-	nframes = strtoul(argv[1], NULL, 0);
-	if (errno == ERANGE) {
-		fprintf(stderr, "%s: invalid buffer size: %s (range is 1-16384)\n",
-			package, argv[1]);
-		exit(2);
-	}
-	if (nframes < 1 || nframes > 16384) {
-		fprintf(stderr, "%s: invalid buffer size: %s (range is 1-16384)\n",
-			package, argv[1]);
-		exit(3);
-	}
-}
-
-void silent_function( const char *ignore )
-{
-}
-
-int main(int argc, char *argv[])
-{
-	int rc;
-	parse_arguments(argc, argv);
-
-	if (just_print_bufsize)
-		jack_set_info_function( silent_function );
-
-	/* become a JACK client */
-	if ((client = jack_client_open(package, JackNoStartServer, NULL)) == 0) {
-		fprintf(stderr, "JACK server not running?\n");
-		exit(1);
-	}
-
-#ifndef WIN32
-	signal(SIGQUIT, signal_handler);
-	signal(SIGHUP, signal_handler);
-#endif
-	signal(SIGTERM, signal_handler);
-	signal(SIGINT, signal_handler);
-
-	jack_on_shutdown(client, jack_shutdown, 0);
-
-	if (just_print_bufsize) {
-		fprintf(stdout, "%d\n", jack_get_buffer_size( client ) );
-		rc = 0;
-	}
-	else
-	{
-		rc = jack_set_buffer_size(client, nframes);
-		if (rc)
-			fprintf(stderr, "jack_set_buffer_size(): %s\n", strerror(rc));
-	}
-	jack_client_close(client);
-
-	return rc;
-}
diff -pruN 1.9.14~dfsg-1/example-clients/connect.c 1.9.16~dfsg-1/example-clients/connect.c
--- 1.9.14~dfsg-1/example-clients/connect.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/connect.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,248 +0,0 @@
-/*
-    Copyright (C) 2002 Jeremy Hall
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <stdio.h>
-#include <errno.h>
-#ifndef WIN32
-#include <unistd.h>
-#endif
-#include <string.h>
-#include <stdlib.h>
-#include <getopt.h>
-
-#include <jack/jack.h>
-#include <jack/session.h>
-
-#define TRUE 1
-#define FALSE 0
-
-volatile int done = 0;
-
-void port_connect_callback(jack_port_id_t a, jack_port_id_t b, int connect, void* arg)
-{
-	done = 1;
-}
-
-void
-show_version (char *my_name)
-{
-	//fprintf (stderr, "%s: JACK Audio Connection Kit version " VERSION "\n", my_name);
-}
-
-void
-show_usage (char *my_name)
-{
-	show_version (my_name);
-	fprintf (stderr, "\nusage: %s [options] port1 port2\n", my_name);
-	fprintf (stderr, "Connects two JACK ports together.\n\n");
-	fprintf (stderr, "        -s, --server <name>   Connect to the jack server named <name>\n");
-	fprintf (stderr, "        -v, --version         Output version information and exit\n");
-	fprintf (stderr, "        -h, --help            Display this help message\n\n");
-	fprintf (stderr, "For more information see http://jackaudio.org/\n");
-}
-
-int
-main (int argc, char *argv[])
-{
-	jack_client_t *client;
-	jack_status_t status;
-	char *server_name = NULL;
-	int c;
-	int option_index;
-	jack_options_t options = JackNoStartServer;
-	char *my_name = strrchr(argv[0], '/');
-	jack_port_t *src_port = 0;
-	jack_port_t *dst_port = 0;
-	jack_port_t *port1 = 0;
-	jack_port_t *port2 = 0;
-	char portA[300];
-	char portB[300];
-	int use_uuid=0;
-	int connecting, disconnecting;
-	int port1_flags, port2_flags;
-	int rc = 1;
-
-	struct option long_options[] = {
-		{ "server", 1, 0, 's' },
-		{ "help", 0, 0, 'h' },
-		{ "version", 0, 0, 'v' },
-		{ "uuid", 0, 0, 'u' },
-		{ 0, 0, 0, 0 }
-	};
-
-	while ((c = getopt_long (argc, argv, "s:hvu", long_options, &option_index)) >= 0) {
-		switch (c) {
-		case 's':
-			server_name = (char *) malloc (sizeof (char) * strlen(optarg));
-			strcpy (server_name, optarg);
-			options |= JackServerName;
-			break;
-		case 'u':
-			use_uuid = 1;
-			break;
-		case 'h':
-			show_usage (my_name);
-			return 1;
-			break;
-		case 'v':
-			show_version (my_name);
-			return 1;
-			break;
-		default:
-			show_usage (my_name);
-			return 1;
-			break;
-		}
-	}
-
-	connecting = disconnecting = FALSE;
-	if (my_name == 0) {
-		my_name = argv[0];
-	} else {
-		my_name ++;
-	}
-
-	if (strstr(my_name, "disconnect")) {
-		disconnecting = 1;
-	} else if (strstr(my_name, "connect")) {
-		connecting = 1;
-	} else {
-		fprintf(stderr, "ERROR! client should be called jack_connect or jack_disconnect. client is called %s\n", my_name);
-		return 1;
-	}
-
-	if (argc < 3) {
-		show_usage(my_name);
-		return 1;
-	}
-
-	/* try to become a client of the JACK server */
-
-	if ((client = jack_client_open (my_name, options, &status, server_name)) == 0) {
-		fprintf (stderr, "jack server not running?\n");
-		return 1;
-	}
-
-	jack_set_port_connect_callback(client, port_connect_callback, NULL);
-
-	/* find the two ports */
-
-	if( use_uuid ) {
-		char *tmpname;
-		char *clientname;
-		char *portname;
-		tmpname = strdup( argv[argc-1] );
-		portname = strchr( tmpname, ':' );
-		portname[0] = '\0';
-		portname+=1;
-		clientname = jack_get_client_name_by_uuid( client, tmpname );
-		if( clientname ) {
-
-			snprintf( portA, sizeof(portA), "%s:%s", clientname, portname );
-			jack_free( clientname );
-		} else {
-			snprintf( portA, sizeof(portA), "%s", argv[argc-1] );
-		}
-		free( tmpname );
-
-		tmpname = strdup( argv[argc-2] );
-		portname = strchr( tmpname, ':' );
-		portname[0] = '\0';
-		portname+=1;
-		clientname = jack_get_client_name_by_uuid( client, tmpname );
-		if( clientname ) {
-			snprintf( portB, sizeof(portB), "%s:%s", clientname, portname );
-			jack_free( clientname );
-		} else {
-			snprintf( portB, sizeof(portB), "%s", argv[argc-2] );
-		}
-
-		free( tmpname );
-
-	} else {
-		snprintf( portA, sizeof(portA), "%s", argv[argc-1] );
-		snprintf( portB, sizeof(portB), "%s", argv[argc-2] );
-	}
-	if ((port1 = jack_port_by_name(client, portA)) == 0) {
-		fprintf (stderr, "ERROR %s not a valid port\n", portA);
-		goto exit;
-	}
-	if ((port2 = jack_port_by_name(client, portB)) == 0) {
-		fprintf (stderr, "ERROR %s not a valid port\n", portB);
-		goto exit;
-	}
-
-	port1_flags = jack_port_flags (port1);
-	port2_flags = jack_port_flags (port2);
-
-	if (port1_flags & JackPortIsInput) {
-		if (port2_flags & JackPortIsOutput) {
-			src_port = port2;
-			dst_port = port1;
-		}
-	} else {
-		if (port2_flags & JackPortIsInput) {
-			src_port = port1;
-			dst_port = port2;
-		}
-	}
-
-	if (!src_port || !dst_port) {
-		fprintf (stderr, "arguments must include 1 input port and 1 output port\n");
-		goto exit;
-	}
-
-	/* tell the JACK server that we are ready to roll */
-	if (jack_activate (client)) {
-		fprintf (stderr, "cannot activate client");
-		goto exit;
-	}
-
-	/* connect the ports. Note: you can't do this before
-	   the client is activated (this may change in the future).
-	*/
-
-	if (connecting) {
-		if (jack_connect(client, jack_port_name(src_port), jack_port_name(dst_port))) {
-			fprintf (stderr, "cannot connect client, already connected?\n");
-			goto exit;
-		}
-	}
-	if (disconnecting) {
-		if (jack_disconnect(client, jack_port_name(src_port), jack_port_name(dst_port))) {
-			fprintf (stderr, "cannot disconnect client, already disconnected?\n");
-			goto exit;
-		}
-	}
-
-	// Wait for connection/disconnection to be effective
-	while(!done) {
-#ifdef WIN32
-		Sleep(10);
-#else
-		usleep(10000);
-#endif
-	}
-
-	/* everything was ok, so setting exitcode to 0 */
-	rc = 0;
-
-exit:
-	jack_client_close (client);
-	exit (rc);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/evmon.c 1.9.16~dfsg-1/example-clients/evmon.c
--- 1.9.14~dfsg-1/example-clients/evmon.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/evmon.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,164 +0,0 @@
-/*
-    Copyright (C) 2007 Paul Davis
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <stdio.h>
-#include <errno.h>
-#ifndef WIN32
-#include <unistd.h>
-#endif
-#include <string.h>
-#include <signal.h>
-#include <stdlib.h>
-
-#include <jack/jack.h>
-#include <jack/metadata.h>
-#include <jack/uuid.h>
-
-jack_client_t *client;
-
-static void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-static void
-port_rename_callback (jack_port_id_t port, const char* old_name, const char* new_name, void* arg)
-{
-	printf ("Port %d renamed from %s to %s\n", port, old_name, new_name);
-}
-
-static void
-port_callback (jack_port_id_t port, int yn, void* arg)
-{
-	printf ("Port %d %s\n", port, (yn ? "registered" : "unregistered"));
-}
-
-static void
-connect_callback (jack_port_id_t a, jack_port_id_t b, int yn, void* arg)
-{
-	printf ("Ports %d and %d %s\n", a, b, (yn ? "connected" : "disconnected"));
-}
-
-static void
-client_callback (const char* client, int yn, void* arg)
-{
-	printf ("Client %s %s\n", client, (yn ? "registered" : "unregistered"));
-}
-
-static int
-graph_callback (void* arg)
-{
-	printf ("Graph reordered\n");
-	return 0;
-}
-
-static void
-propchange (jack_uuid_t subject, const char* key, jack_property_change_t change, void* arg)
-{
-        char buf[JACK_UUID_STRING_SIZE];
-        const char* action = "";
-
-        switch (change) {
-        case PropertyCreated:
-                action = "created";
-                break;
-
-        case PropertyChanged:
-                action = "changed";
-                break;
-
-        case PropertyDeleted:
-                action = "deleted";
-                break;
-        }
-
-        if (jack_uuid_empty (subject)) {
-                printf ("All properties changed!\n");
-        } else {
-                jack_uuid_unparse (subject, buf);
-                
-                if (key) {
-                        printf ("key [%s] for %s %s\n", key, buf, action);
-                } else {
-                        printf ("all keys for %s %s\n", buf, action);
-                }
-        }
-}
-
-int
-main (int argc, char *argv[])
-{
-	jack_options_t options = JackNullOption;
-	jack_status_t status;
-
-	if ((client = jack_client_open ("event-monitor", options, &status, NULL)) == 0) {
-		fprintf (stderr, "jack_client_open() failed, "
-			 "status = 0x%2.0x\n", status);
-		if (status & JackServerFailed) {
-			fprintf (stderr, "Unable to connect to JACK server\n");
-		}
-		return 1;
-	}
-	
-	if (jack_set_port_registration_callback (client, port_callback, NULL)) {
-		fprintf (stderr, "cannot set port registration callback\n");
-		return 1;
-	}
-	if (jack_set_port_rename_callback (client, port_rename_callback, NULL)) {
-		fprintf (stderr, "cannot set port registration callback\n");
-		return 1;
-	}
-	if (jack_set_port_connect_callback (client, connect_callback, NULL)) {
-		fprintf (stderr, "cannot set port connect callback\n");
-		return 1;
-	}
-	if (jack_set_client_registration_callback (client, client_callback, NULL)) {
-		fprintf (stderr, "cannot set client registration callback\n");
-		return 1;
-	}
-	if (jack_set_graph_order_callback (client, graph_callback, NULL)) {
-		fprintf (stderr, "cannot set graph order registration callback\n");
-		return 1;
-	}
-	if (jack_set_property_change_callback (client, propchange, NULL)) {
-		fprintf (stderr, "cannot set property change callback\n");
-		return 1;
-	}
-	if (jack_activate (client)) {
-		fprintf (stderr, "cannot activate client");
-		return 1;
-	}
-
-#ifndef WIN32
-	signal(SIGINT, signal_handler);
-	signal(SIGQUIT, signal_handler);
-	signal(SIGHUP, signal_handler);
-#endif
-	signal(SIGABRT, signal_handler);
-	signal(SIGTERM, signal_handler);
-
-#ifdef WIN32
-	Sleep(INFINITE);
-#else
-	sleep (-1);
-#endif
-	exit (0);
-}
-
diff -pruN 1.9.14~dfsg-1/example-clients/freewheel.c 1.9.16~dfsg-1/example-clients/freewheel.c
--- 1.9.14~dfsg-1/example-clients/freewheel.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/freewheel.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- *  freewheel - start/stop JACK "freewheeling" mode
- *
- *  Copyright (C) 2003 Paul Davis.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <string.h>
-#include <jack/jack.h>
-#include <jack/transport.h>
-
-char *package;				/* program name */
-jack_client_t *client;
-int onoff;
-
-static void jack_shutdown(void *arg)
-{
-	fprintf(stderr, "JACK shut down, exiting ...\n");
-	exit(1);
-}
-
-static void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-static void parse_arguments(int argc, char *argv[])
-{
-	if (argc < 2) {
-		fprintf(stderr, "usage: %s y|n\n", package);
-		exit(9);
-	}
-
-	if (argv[1][0] == 'y' || argv[1][0] == 'Y' || argv[1][0] == '1') {
-		onoff = 1;
-	} else {
-		onoff = 0;
-	}
-}
-
-int
-main (int argc, char *argv[])
-{
-	parse_arguments (argc, argv);
-
-	/* become a JACK client */
-	if ((client = jack_client_open ("freewheel", JackNullOption, NULL)) == 0) {
-		fprintf (stderr, "JACK server not running?\n");
-		exit(1);
-	}
-
-#ifndef WIN32
-	signal (SIGQUIT, signal_handler);
-	signal (SIGHUP, signal_handler);
-#endif
-	signal (SIGTERM, signal_handler);
-	signal (SIGINT, signal_handler);
-
-	jack_on_shutdown (client, jack_shutdown, 0);
-
-	if (jack_set_freewheel (client, onoff)) {
-		fprintf (stderr, "failed to reset freewheel mode\n");
-	}
-
-	jack_client_close(client);
-	return 0;
-}
diff -pruN 1.9.14~dfsg-1/example-clients/ipload.c 1.9.16~dfsg-1/example-clients/ipload.c
--- 1.9.14~dfsg-1/example-clients/ipload.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/ipload.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,246 +0,0 @@
-/*
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <signal.h>
-#ifndef WIN32
-#include <unistd.h>
-#endif
-#include <getopt.h>
-#include <jack/jack.h>
-#include <jack/intclient.h>
-
-jack_client_t *client;
-jack_intclient_t intclient;
-char *client_name;
-char *intclient_name;
-char *load_name;
-char *load_init = "";
-char *server_name = NULL;
-int autoclose_opt = 0;
-int wait_opt = 0;
-volatile int idling = 1;
-
-static void
-signal_handler (int sig)
-{
-	/* do nothing if internal client closed itself */
-	if (idling == 0)
-		return;
-
-	jack_status_t status;
-
-	fprintf (stderr, "signal received, unloading...");
-	status = jack_internal_client_unload (client, intclient);
-	if (status & JackFailure)
-		fprintf (stderr, "(failed), status = 0x%2.0x\n", status);
-	else
-		fprintf (stderr, "(succeeded)\n");
-	if (autoclose_opt)
-		jack_deactivate(client);
-	jack_client_close (client);
-	exit (0);
-}
-
-static void
-registration_callback (const char *name, int reg, void *arg)
-{
-	if (reg || strcmp(intclient_name, name))
-		return;
-
-	/* this will stop the wait loop and thus close this application. */
-	idling = 0;
-	return;
-
-	/* unused */
-	(void)arg;
-}
-
-static void
-show_usage ()
-{
-	fprintf (stderr, "usage: %s [ options ] client-name [ load-name "
-		 "[ init-string]]\n\noptions:\n", client_name);
-	fprintf (stderr,
-		 "\t-h, --help \t\t print help message\n"
-		 "\t-a, --autoclose\t automatically close when intclient is unloaded\n"
-		 "\t-i, --init string\t initialize string\n"
-		 "\t-s, --server name\t select JACK server\n"
-		 "\t-w, --wait \t\t wait for signal, then unload\n"
-		 "\n"
-		);
-}
-
-static int
-parse_args (int argc, char *argv[])
-{
-	int c;
-	int option_index = 0;
-	char *short_options = "hai:s:w";
-	struct option long_options[] = {
-		{ "help", 0, 0, 'h' },
-		{ "autoclose", 0, 0, 'a' },
-		{ "init", required_argument, 0, 'i' },
-		{ "server", required_argument, 0, 's' },
-		{ "wait", 0, 0, 'w' },
-		{ 0, 0, 0, 0 }
-	};
-
-	client_name = strrchr(argv[0], '/');
-	if (client_name == NULL) {
-		client_name = argv[0];
-	} else {
-		client_name++;
-	}
-
-	while ((c = getopt_long (argc, argv, short_options, long_options,
-				 &option_index)) >= 0) {
-		switch (c) {
-		case 'a':
-			autoclose_opt = 1;
-			break;
-		case 'i':
-			load_init = optarg;
-			break;
-		case 's':
-			server_name = optarg;
-			break;
-		case 'w':
-			wait_opt = 1;
-			break;
-		case 'h':
-		default:
-			show_usage ();
-			return 1;
-		}
-	}
-
-	/* autoclose makes no sense without wait */
-	if (autoclose_opt && ! wait_opt)
-		autoclose_opt = 0;
-
-	if (optind == argc) {		/* no positional args? */
-		show_usage ();
-		return 1;
-	}
-	if (optind < argc)
-		load_name = intclient_name = argv[optind++];
-
-	if (optind < argc)
-		load_name = argv[optind++];
-
-	if (optind < argc)
-		load_init = argv[optind++];
-
-	//fprintf (stderr, "client-name = `%s', load-name = `%s', "
-	//	 "load-init = `%s', wait = %d\n",
-	//	 intclient_name, load_name, load_init, wait_opt);
-
-	return 0;			/* args OK */
-}
-
-int
-main (int argc, char *argv[])
-{
-	jack_status_t status;
-	char* name;
-
-	/* parse and validate command arguments */
-	if (parse_args (argc, argv))
-		exit (1);		/* invalid command line */
-
-	/* first, become a JACK client */
-	client = jack_client_open (client_name, JackServerName,
-				   &status, server_name);
-	if (client == NULL) {
-		fprintf (stderr, "jack_client_open() failed, "
-			 "status = 0x%2.0x\n", status);
-		if (status & JackServerFailed) {
-			fprintf (stderr, "Unable to connect to JACK server\n");
-		}
-		exit (1);
-	}
-	if (status & JackServerStarted) {
-		fprintf (stderr, "JACK server started\n");
-	}
-	if (status & JackNameNotUnique) {
-		client_name = jack_get_client_name(client);
-		fprintf (stderr, "unique name `%s' assigned\n", client_name);
-	}
-
-	/* then, load the internal client */
-	intclient = jack_internal_client_load (client, intclient_name,
-					       (JackLoadName|JackLoadInit),
-					       &status, load_name, load_init);
-	if (status & JackFailure) {
-		fprintf (stderr, "could not load %s, intclient = %d status = 0x%2.0x\n",
-			 load_name, (int)intclient, status);
-		return 2;
-	}
-	if (status & JackNameNotUnique) {
-		intclient_name =
-			jack_get_internal_client_name (client, intclient);
-		fprintf (stderr, "unique internal client name `%s' assigned\n",
-			 intclient_name);
-	}
-
-	fprintf (stdout, "%s is running.\n", load_name);
-
-	name = jack_get_internal_client_name(client, intclient);
-	if (name) {
-		printf("client name = %s\n", name);
-		free(name);
-	}
-	fflush(stdout);
-
-	if (autoclose_opt) {
-		jack_set_client_registration_callback(client, registration_callback, NULL);
-		jack_activate(client);
-	}
-
-	if (wait_opt) {
-		/* define a signal handler to unload the client, then
-		 * wait for it to exit */
-	#ifdef WIN32
-		signal(SIGINT, signal_handler);
-		signal(SIGABRT, signal_handler);
-		signal(SIGTERM, signal_handler);
-	#else
-		signal(SIGQUIT, signal_handler);
-		signal(SIGTERM, signal_handler);
-		signal(SIGHUP, signal_handler);
-		signal(SIGINT, signal_handler);
-	#endif
-
-		while (idling) {
-			#ifdef WIN32
-				Sleep(1000);
-			#else
-				sleep (1);
-			#endif
-		}
-	}
-
-	if (autoclose_opt) {
-		jack_deactivate(client);
-	}
-
-	jack_client_close(client);
-	return 0;
-}
-
diff -pruN 1.9.14~dfsg-1/example-clients/ipunload.c 1.9.16~dfsg-1/example-clients/ipunload.c
--- 1.9.14~dfsg-1/example-clients/ipunload.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/ipunload.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,93 +0,0 @@
-/*
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <string.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <jack/jack.h>
-#include <jack/intclient.h>
-
-int
-main (int argc, char *argv[])
-{
-	char *my_name;
-	char *client_name;
-	jack_client_t *client;
-	jack_status_t status;
-	jack_intclient_t intclient;
-
-	/* validate args */
-	if ((argc < 2) || (argc > 3)) {
-		fprintf (stderr, "usage: %s client-name [ server-name ]]\n",
-			 argv[0]);
-		return 1;
-	}
-
-	/* use `basename $0` for my own client name */
-	my_name = strrchr(argv[0], '/');
-	if (my_name == 0) {
-		my_name = argv[0];
-	} else {
-		my_name++;
-	}
-
-	/* first, become a JACK client */
-	if (argc > 2) {
-		client = jack_client_open (my_name,
-					   (JackServerName|JackNoStartServer),
-					   &status, argv[2]);
-	} else {
-		client = jack_client_open (my_name, JackNoStartServer, &status);
-	}
-
-	if (client == NULL) {
-		if (status & JackServerFailed) {
-			fprintf (stderr, "JACK server not running.\n");
-		} else {
-			fprintf (stderr, "JACK open failed, "
-				 "status = 0x%2.0x\n", status);
-		}
-		exit (1);
-	}
-
-	/* then, get the internal client handle */
-	client_name = argv[1];
-	intclient = jack_internal_client_handle (client, client_name, &status);
-	if (status & JackFailure) {
-		fprintf (stderr, "client %s not found.\n", client_name);
-		exit (2);
-	}
-
-	/* now, unload the internal client */
-	status = jack_internal_client_unload (client, intclient);
-	if (status & JackFailure) {
-		if (status & JackNoSuchClient) {
-			fprintf (stderr, "client %s is gone.\n",
-				 client_name);
-		} else {
-			fprintf (stderr, "could not unload %s, "
-				 "returns 0x%2.0x\n", client_name, status);
-		}
-		exit (3);
-	} else {
-		fprintf (stdout, "%s unloaded.\n", client_name);
-	}
-
-    jack_client_close(client);
-	return 0;
-}
-
-
diff -pruN 1.9.14~dfsg-1/example-clients/jack_control 1.9.16~dfsg-1/example-clients/jack_control
--- 1.9.14~dfsg-1/example-clients/jack_control	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/jack_control	1970-01-01 00:00:00.000000000 +0000
@@ -1,400 +0,0 @@
-#!/usr/bin/python3
-
-from __future__ import print_function
-name_base = 'org.jackaudio'
-control_interface_name = name_base + '.JackControl'
-configure_interface_name = name_base + '.Configure'
-service_name = name_base + '.service'
-
-import sys
-import os
-from traceback import print_exc
-
-import dbus
-
-def bool_convert(str_value):
-    if str_value.lower() == "false":
-        return False
-
-    if str_value.lower() == "off":
-        return False
-
-    if str_value.lower() == "no":
-        return False
-
-    if str_value == "0":
-        return False
-
-    if str_value.lower() == "(null)":
-        return False
-
-    return bool(str_value)
-
-def dbus_type_to_python_type(dbus_value):
-    if type(dbus_value) == dbus.Boolean:
-        return bool(dbus_value)
-    if type(dbus_value) == dbus.Int32 or type(dbus_value) == dbus.UInt32:
-        return int(dbus_value)
-    return dbus_value
-
-def python_type_to_jackdbus_type(value, type_char):
-    type_char = str(type_char)
-
-    if type_char == "b":
-        return bool_convert(value);
-    elif type_char == "y":
-        return dbus.Byte(value);
-    elif type_char == "i":
-        return dbus.Int32(value)
-    elif type_char == "u":
-        return dbus.UInt32(value)
-
-    return value
-
-def dbus_type_to_type_string(dbus_value):
-    if type(dbus_value) == dbus.Boolean:
-        return "bool"
-    if type(dbus_value) == dbus.Int32:
-        return "sint"
-    if type(dbus_value) == dbus.UInt32:
-        return "uint"
-    if type(dbus_value) == dbus.Byte:
-        return "char"
-    if type(dbus_value) == dbus.String:
-        return "str"
-
-    return None                         # throw exception here?
-
-def dbus_typesig_to_type_string(type_char):
-    type_char = str(type_char)
-    if type_char == 'i':
-        return "sint"
-    if type_char == 'u':
-        return "uint"
-    if type_char == 'y':
-        return "char"
-    if type_char == 's':
-        return "str"
-    if type_char == 'b':
-        return "bool"
-
-    print('shit')
-    return None                         # throw exception here?
-
-def get_parameters(iface, path):
-    params = iface.GetParametersInfo(path)
-
-    #print params
-    for param in params:
-        typestr = dbus_typesig_to_type_string(param[0])
-        name = param[1]
-        #print name
-        descr = param[2]
-        #print descr
-        isset, default, value = iface.GetParameterValue(path + [name])
-        #print typestr
-        if bool(isset):
-            isset = "set"
-        else:
-            isset = "notset"
-        value = dbus_type_to_python_type(value)
-        default = dbus_type_to_python_type(default)
-
-        print("%20s: %s (%s:%s:%s:%s)" %(name, descr, typestr, isset, default, value))
-
-def print_help():
-    print("Usage: %s [command] [command] ..." % os.path.basename(sys.argv[0]))
-    print("Commands:")
-    print("    exit                       - exit jack dbus service (stops jack server if currently running)")
-    print("    help                       - print this help text")
-    print("    status                     - check whether jack server is started, return value is 0 if running and 1 otherwise")
-    print("    start                      - start jack server if not currently started")
-    print("    stop                       - stop jack server if currently started")
-    print("    sm                         - switch master to currently selected driver")
-    print("    dl                         - get list of available drivers")
-    print("    dg                         - get currently selected driver")
-    print("    ds <driver>                - select driver")
-    print("    dp                         - get parameters of currently selected driver")
-    print("    dpd <param>                - get long description for driver parameter")
-    print("    dps <param> <value>        - set driver parameter")
-    print("    dpr <param>                - reset driver parameter to its default value")
-    print("    asd <driver>               - add slave driver")
-    print("    rsd <driver>               - remove slave driver")
-    print("    il                         - get list of available internals")
-    print("    ip <name>                  - get parameters of given internal")
-    print("    ipd <name> <param>         - get long description for internal parameter")
-    print("    ips <name> <param> <value> - set internal parameter")
-    print("    ipr <name> <param>         - reset internal parameter to its default value")
-    print("    iload <name>               - load internal")
-    print("    iunload <name>             - unload internal")
-    print("    ep                         - get engine parameters")
-    print("    epd <param>                - get long description for engine parameter")
-    print("    eps <param> <value>        - set engine parameter")
-    print("    epr <param>                - reset engine parameter to its default value")
-
-def maybe_print_param_constraint(iface, param):
-    is_range, is_strict, is_fake, values = iface.GetParameterConstraint(param)
-    if is_range:
-        print()
-        print(("allowed range: %s to %s (inclusive)" % (values[0][0], values[1][0])))
-    elif len(values):
-        print()
-        if is_strict:
-            print("allowed values:")
-        else:
-            print("suggested values:")
-
-        max_len = 0
-        for value in values:
-            if len(str(value[0])) > max_len:
-                   max_len = len(str(value[0]))
-        for value in values:
-            print(("%*s'%s' - %s" % (1 + max_len - len(str(value[0])), "", str(value[0]), str(value[1]))))
-
-def main():
-    if len(sys.argv) == 1 or sys.argv[1] in ["-h", "--help", "help"]:
-        print_help()
-        sys.exit(0)
-
-    bus = dbus.SessionBus()
-
-    controller = bus.get_object(service_name, "/org/jackaudio/Controller")
-    control_iface = dbus.Interface(controller, control_interface_name)
-    configure_iface = dbus.Interface(controller, configure_interface_name)
-
-    # check arguments
-    index = 1
-    while index < len(sys.argv):
-        arg = sys.argv[index]
-        index += 1
-        try:
-            if arg == "exit":
-                print("--- exit")
-                control_iface.Exit()
-            elif arg == "status":
-                print("--- status")
-                if control_iface.IsStarted():
-                    print("started")
-                    sys.exit(0)
-                else:
-                    print("stopped")
-                    sys.exit(1)
-            elif arg == 'start':
-                print("--- start")
-                control_iface.StartServer()
-            elif arg == 'stop':
-                print("--- stop")
-                control_iface.StopServer()
-            elif arg == 'sm':
-                print("--- switch master driver")
-                control_iface.SwitchMaster()
-            elif arg == 'ism':
-                if control_iface.IsManuallyActivated():
-                    print("Manually activated")
-                else:
-                    print("Automatically activated")
-            elif arg == 'dl':
-                print("--- drivers list")
-                is_range, is_strict, is_fake_values, values = configure_iface.GetParameterConstraint(['engine', 'driver'])
-                for value in values:
-                    print(value[1])
-            elif arg == 'dg':
-                print("--- get selected driver")
-                isset, default, value = configure_iface.GetParameterValue(['engine', 'driver'])
-                print(value)
-            elif arg == 'ds':
-                if index >= len(sys.argv):
-                    print("driver select command requires driver name argument")
-                    sys.exit()
-
-                arg = sys.argv[index]
-                index += 1
-
-                print("--- driver select \"%s\"" % arg)
-                configure_iface.SetParameterValue(['engine', 'driver'], dbus.String(arg))
-            elif arg == 'dp':
-                print("--- get driver parameters (type:isset:default:value)")
-                get_parameters(configure_iface, ['driver'])
-            elif arg == 'dpd':
-                if index >= len(sys.argv):
-                    print("get driver parameter long description command requires parameter name argument")
-                    sys.exit()
-
-                param = sys.argv[index]
-                index += 1
-
-                print("--- get driver parameter description (%s)" % param)
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['driver', param])
-                print(long_descr)
-                maybe_print_param_constraint(configure_iface, ['driver', param])
-            elif arg == 'dps':
-                if index + 1 >= len(sys.argv):
-                    print("driver parameter set command requires parameter name and value arguments")
-                    sys.exit()
-
-                param = sys.argv[index]
-                index += 1
-                value = sys.argv[index]
-                index += 1
-
-                print("--- driver param set \"%s\" -> \"%s\"" % (param, value))
-
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['driver', param])
-                configure_iface.SetParameterValue(['driver', param], python_type_to_jackdbus_type(value, type_char))
-            elif arg == 'dpr':
-                if index >= len(sys.argv):
-                    print("driver parameter reset command requires parameter name argument")
-                    sys.exit()
-
-                param = sys.argv[index]
-                index += 1
-
-                print("--- driver param reset \"%s\"" % param)
-                configure_iface.ResetParameterValue(['driver', param])
-            elif arg == 'ep':
-                print("--- get engine parameters (type:isset:default:value)")
-                get_parameters(configure_iface, ['engine'])
-            elif arg == 'epd':
-                if index >= len(sys.argv):
-                    print("get engine parameter long description command requires parameter name argument")
-                    sys.exit()
-
-                param_name = sys.argv[index]
-                index += 1
-
-                print("--- get engine parameter description (%s)" % param_name)
-
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['engine', param_name])
-                print(long_descr)
-                maybe_print_param_constraint(configure_iface, ['engine', param_name])
-            elif arg == 'eps':
-                if index + 1 >= len(sys.argv):
-                    print("engine parameter set command requires parameter name and value arguments")
-                    sys.exit()
-
-                param = sys.argv[index]
-                index += 1
-                value = sys.argv[index]
-                index += 1
-
-                print("--- engine param set \"%s\" -> \"%s\"" % (param, value))
-
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['engine', param])
-                configure_iface.SetParameterValue(['engine', param], python_type_to_jackdbus_type(value, type_char))
-            elif arg == 'epr':
-                if index >= len(sys.argv):
-                    print("engine parameter reset command requires parameter name")
-                    sys.exit()
-
-                param = sys.argv[index]
-                index += 1
-
-                print("--- engine param reset \"%s\"" % param)
-
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['engine', param])
-                configure_iface.ResetParameterValue(['engine', param])
-            elif arg == 'il':
-                print("--- internals list")
-                is_leaf, internals = configure_iface.ReadContainer(['internals'])
-                for internal in internals:
-                    print(internal)
-            elif arg == 'ip':
-                print("--- get internal parameters (type:isset:default:value)")
-
-                if index >= len(sys.argv):
-                    print("internal parameters command requires internal name argument")
-                    sys.exit()
-
-                internal_name = sys.argv[index]
-                index += 1
-
-                get_parameters(configure_iface, ['internals', internal_name])
-            elif arg == 'ipd':
-                if index + 1 >= len(sys.argv):
-                    print("get internal parameter long description command requires internal and parameter name arguments")
-                    sys.exit()
-
-                name = sys.argv[index]
-                index += 1
-                param = sys.argv[index]
-                index += 1
-
-                print("--- get internal parameter description (%s)" % param)
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['internals', name, param])
-                print(long_descr)
-            elif arg == 'ips':
-                if index + 2 >= len(sys.argv):
-                    print("internal parameter set command requires internal, parameter name and value arguments")
-                    sys.exit()
-
-                internal_name = sys.argv[index]
-                index += 1
-                param = sys.argv[index]
-                index += 1
-                value = sys.argv[index]
-                index += 1
-
-                print("--- internal param set \"%s\" -> \"%s\"" % (param, value))
-
-                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['internals', internal_name, param])
-                configure_iface.SetParameterValue(['internals', internal_name, param], python_type_to_jackdbus_type(value, type_char))
-            elif arg == 'ipr':
-                if index + 1 >= len(sys.argv):
-                    print("reset internal parameter command requires internal and parameter name arguments")
-                    sys.exit()
-
-                internal_name = sys.argv[index]
-                index += 1
-                param = sys.argv[index]
-                index += 1
-
-                print("--- internal param reset \"%s\"" % param)
-
-                configure_iface.ResetParameterValue(['internals', internal_name, param])
-            elif arg == 'iload':
-                print("--- load internal")
-
-                if index >= len(sys.argv):
-                    print("load internal command requires internal name argument")
-                    sys.exit()
-
-                name = sys.argv[index]
-                index += 1
-                result = control_iface.LoadInternal(name)
-            elif arg == 'iunload':
-                print("--- unload internal")
-
-                if index >= len(sys.argv):
-                    print("unload internal command requires internal name argument")
-                    sys.exit()
-
-                name = sys.argv[index]
-                index += 1
-                result = control_iface.UnloadInternal(name)
-            elif arg == 'asd':
-                print("--- add slave driver")
-
-                if index >= len(sys.argv):
-                    print("add slave driver command requires driver name argument")
-                    sys.exit()
-
-                name = sys.argv[index]
-                index += 1
-                result = control_iface.AddSlaveDriver(name)
-            elif arg == 'rsd':
-                print("--- remove slave driver")
-
-                if index >= len(sys.argv):
-                    print("remove slave driver command requires driver name argument")
-                    sys.exit()
-
-                name = sys.argv[index]
-                index += 1
-                result = control_iface.RemoveSlaveDriver(name)
-            else:
-                print("Unknown command '%s'" % arg)
-        except dbus.DBusException as e:
-            print("DBus exception: %s" % str(e))
-
-if __name__ == '__main__':
-    main()
diff -pruN 1.9.14~dfsg-1/example-clients/lsp.c 1.9.16~dfsg-1/example-clients/lsp.c
--- 1.9.14~dfsg-1/example-clients/lsp.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/lsp.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,291 +0,0 @@
-/*
- This program is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- This program is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <stdio.h>
-#include <stdlib.h>
-#ifndef WIN32
-#include <unistd.h>
-#endif
-#include <string.h>
-#include <getopt.h>
-#include <inttypes.h>
-
-#include <jack/jack.h>
-#include <jack/session.h>
-#include <jack/uuid.h>
-
-char * my_name;
-
-static void
-show_version (void)
-{
-	//fprintf (stderr, "%s: JACK Audio Connection Kit version " VERSION "\n", my_name);
-}
-
-static void
-printf_name2uuid (jack_client_t* client, const char* pname)
-{
-	char *port_component = strchr( pname, ':' );
-	size_t csize = port_component - pname + 1;
-	char client_component[csize];
-	snprintf(client_component, csize, "%s", pname);
-
-	char *uuid = jack_get_uuid_for_client_name(client, client_component);
-	if (uuid) {
-		printf("%s%s\n", uuid, port_component );
-	} else {
-		printf("%s\n",pname);
-	}
-	jack_free(uuid);
-}
-
-static void
-show_usage (void)
-{
-	show_version ();
-	fprintf (stderr, "\nUsage: %s [options] [filter string]\n", my_name);
-	fprintf (stderr, "List active Jack ports, and optionally display extra information.\n");
-	fprintf (stderr, "Optionally filter ports which match ALL strings provided after any options.\n\n");
-	fprintf (stderr, "Display options:\n");
-	fprintf (stderr, "        -s, --server <name>   Connect to the jack server named <name>\n");
-	fprintf (stderr, "        -A, --aliases         List aliases for each port\n");
-	fprintf (stderr, "        -c, --connections     List connections to/from each port\n");
-	fprintf (stderr, "        -l, --port-latency    Display per-port latency in frames at each port\n");
-	fprintf (stderr, "        -L, --total-latency   Display total latency in frames at each port\n");
-	fprintf (stderr, "        -p, --properties      Display port properties. Output may include:\n"
-			 "                              input|output, can-monitor, physical, terminal\n\n");
-	fprintf (stderr, "        -t, --type            Display port type\n");
-	fprintf (stderr, "        -u, --uuid            Display uuid instead of client name (if available)\n");
-	fprintf (stderr, "        -U, --port-uuid       Display port uuid\n");
-	fprintf (stderr, "        -h, --help            Display this help message\n");
-	fprintf (stderr, "        --version             Output version information and exit\n\n");
-	fprintf (stderr, "For more information see http://jackaudio.org/\n");
-}
-
-int
-main (int argc, char *argv[])
-{
-	jack_client_t *client;
-	jack_status_t status;
-	jack_options_t options = JackNoStartServer;
-	const char **ports, **connections;
-	unsigned int i, j, k;
-	int skip_port;
-	int show_aliases = 0;
-	int show_con = 0;
-	int show_port_latency = 0;
-	int show_total_latency = 0;
-	int show_properties = 0;
-	int show_type = 0;
-	int show_uuid = 0;
-	int show_port_uuid = 0;
-	int c;
-	int option_index;
-	char* aliases[2];
-	char *server_name = NULL;
-
-	struct option long_options[] = {
-		{ "server", 1, 0, 's' },
-		{ "aliases", 0, 0, 'A' },
-		{ "connections", 0, 0, 'c' },
-		{ "port-latency", 0, 0, 'l' },
-		{ "total-latency", 0, 0, 'L' },
-		{ "properties", 0, 0, 'p' },
-		{ "type", 0, 0, 't' },
-		{ "uuid", 0, 0, 'u' },
-		{ "port-uuid", 0, 0, 'U' },
-		{ "help", 0, 0, 'h' },
-		{ "version", 0, 0, 'v' },
-		{ 0, 0, 0, 0 }
-	};
-
-	my_name = strrchr(argv[0], '/');
-	if (my_name == 0) {
-		my_name = argv[0];
-	} else {
-		my_name ++;
-	}
-
-	while ((c = getopt_long (argc, argv, "s:AclLphvtuU", long_options, &option_index)) >= 0) {
-		switch (c) {
-		case 's':
-			server_name = (char *) malloc (sizeof (char) * strlen(optarg));
-			strcpy (server_name, optarg);
-			options |= JackServerName;
-			break;
-		case 'A':
-			aliases[0] = (char *) malloc (jack_port_name_size());
-			aliases[1] = (char *) malloc (jack_port_name_size());
-			show_aliases = 1;
-			break;
-		case 'c':
-			show_con = 1;
-			break;
-		case 'l':
-			show_port_latency = 1;
-			break;
-		case 'L':
-			show_total_latency = 1;
-			break;
-		case 'p':
-			show_properties = 1;
-			break;
-		case 't':
-			show_type = 1;
-			break;
-		case 'u':
-			show_uuid = 1;
-			break;
-		case 'U':
-			show_port_uuid = 1;
-			break;
-		case 'h':
-			show_usage ();
-			return 1;
-			break;
-		case 'v':
-			show_version ();
-			return 1;
-			break;
-		default:
-			show_usage ();
-			return 1;
-			break;
-		}
-	}
-
-	/* Open a client connection to the JACK server.  Starting a
-	 * new server only to list its ports seems pointless, so we
-	 * specify JackNoStartServer. */
-	if ((client = jack_client_open ("lsp", options, &status, server_name)) == 0) {
-		fprintf (stderr, "Error: cannot connect to JACK, ");
-		if (status & JackServerFailed) {
-			fprintf (stderr, "server is not running.\n");
-		} else {
-			fprintf (stderr, "jack_client_open() failed, status = 0x%2.0x\n", status);
-		}
-		return 1;
-	}
-
-	ports = jack_get_ports (client, NULL, NULL, 0);
-
-	for (i = 0; ports && ports[i]; ++i) {
-		// skip over any that don't match ALL of the strings presented at command line
-		skip_port = 0;
-		for (k = optind; k < argc; k++){
-			if (strstr(ports[i], argv[k]) == NULL ){
-				skip_port = 1;
-			}
-		}
-		if (skip_port) continue;
-
-		if (show_uuid) {
-			printf_name2uuid(client, ports[i]);
-		} else {
-			printf ("%s\n", ports[i]);
-		}
-
-		jack_port_t *port = jack_port_by_name (client, ports[i]);
-
-		if (show_port_uuid) {
-			char buf[JACK_UUID_STRING_SIZE];
-			jack_uuid_t uuid = jack_port_uuid (port);
-			jack_uuid_unparse (uuid, buf);
-			printf ("	uuid: %s\n", buf);
-		}
-
-		if (show_aliases) {
-			int cnt;
-			int i;
-
-			cnt = jack_port_get_aliases (port, aliases);
-			for (i = 0; i < cnt; ++i) {
-				printf ("   %s\n", aliases[i]);
-			}
-		}
-
-		if (show_con) {
-			if ((connections = jack_port_get_all_connections (client, jack_port_by_name(client, ports[i]))) != 0) {
-				for (j = 0; connections[j]; j++) {
-					printf("   ");
-					if (show_uuid) {
-						printf_name2uuid(client, connections[j]);
-					} else {
-						printf("%s\n", connections[j]);
-					}
-				}
-				jack_free (connections);
-			}
-		}
-		if (show_port_latency) {
-			if (port) {
-				jack_latency_range_t range;
-
-				jack_port_get_latency_range (port, JackPlaybackLatency, &range);
-				printf ("	port playback latency = [ %" PRIu32 " %" PRIu32 " ] frames\n",
-					range.min, range.max);
-
-				jack_port_get_latency_range (port, JackCaptureLatency, &range);
-				printf ("	port capture latency = [ %" PRIu32 " %" PRIu32 " ] frames\n",
-					range.min, range.max);
-			}
-		}
-		if (show_total_latency) {
-			if (port) {
-				printf ("	total latency = %d frames\n",
-					jack_port_get_total_latency (client, port));
-			}
-		}
-		if (show_properties) {
-			if (port) {
-				int flags = jack_port_flags (port);
-				printf ("	properties: ");
-				if (flags & JackPortIsInput) {
-					fputs ("input,", stdout);
-				}
-				if (flags & JackPortIsOutput) {
-					fputs ("output,", stdout);
-				}
-				if (flags & JackPortCanMonitor) {
-					fputs ("can-monitor,", stdout);
-				}
-				if (flags & JackPortIsPhysical) {
-					fputs ("physical,", stdout);
-				}
-				if (flags & JackPortIsTerminal) {
-					fputs ("terminal,", stdout);
-				}
-				putc ('\n', stdout);
-			}
-		}
-		if (show_type) {
-			if (port) {
-				putc ('\t', stdout);
-				fputs (jack_port_type (port), stdout);
-				putc ('\n', stdout);
-			}
-		}
-	}
-
-	if (show_aliases) {
-		free(aliases[0]);
-		free(aliases[1]);
-	}
-	if (ports)
-		jack_free (ports);
-	jack_client_close (client);
-	exit (0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/midi_dump.c 1.9.16~dfsg-1/example-clients/midi_dump.c
--- 1.9.14~dfsg-1/example-clients/midi_dump.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/midi_dump.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,233 +0,0 @@
-// gcc -o jack_midi_dump -Wall midi_dump.c -ljack -pthread
-
-#include <stdio.h>
-#include <string.h>
-#include <unistd.h>
-#include <assert.h>
-#include <inttypes.h>
-#include <jack/jack.h>
-#include <jack/midiport.h>
-#include <jack/ringbuffer.h>
-
-#ifdef __MINGW32__
-#include <pthread.h>
-#endif
-
-#ifndef WIN32
-#include <signal.h>
-#include <pthread.h>
-#include <sys/mman.h>
-#endif
-
-static jack_port_t* port;
-static jack_ringbuffer_t *rb = NULL;
-static pthread_mutex_t msg_thread_lock = PTHREAD_MUTEX_INITIALIZER;
-static pthread_cond_t data_ready = PTHREAD_COND_INITIALIZER;
-
-static int keeprunning = 1;
-static uint64_t monotonic_cnt = 0;
-
-#define RBSIZE 100
-#define MSG_BUFFER_SIZE 4096
-
-typedef struct {
-	uint8_t  buffer[MSG_BUFFER_SIZE];
-	uint32_t size;
-	uint32_t tme_rel;
-	uint64_t tme_mon;
-} midimsg;
-
-static void
-describe (midimsg* event)
-{
-	if (event->size == 0) {
-		return;
-	}
-
-	uint8_t type = event->buffer[0] & 0xf0;
-	uint8_t channel = event->buffer[0] & 0xf;
-
-	switch (type) {
-		case 0x90:
-			assert (event->size == 3);
-			printf (" note on  (channel %2d): pitch %3d, velocity %3d", channel, event->buffer[1], event->buffer[2]);
-			break;
-		case 0x80:
-			assert (event->size == 3);
-			printf (" note off (channel %2d): pitch %3d, velocity %3d", channel, event->buffer[1], event->buffer[2]);
-			break;
-		case 0xb0:
-			assert (event->size == 3);
-			printf (" control change (channel %2d): controller %3d, value %3d", channel, event->buffer[1], event->buffer[2]);
-			break;
-		default:
-			break;
-	}
-}
-
-int
-process (jack_nframes_t frames, void* arg)
-{
-	void* buffer;
-	jack_nframes_t N;
-	jack_nframes_t i;
-
-	buffer = jack_port_get_buffer (port, frames);
-	assert (buffer);
-
-	N = jack_midi_get_event_count (buffer);
-	for (i = 0; i < N; ++i) {
-		jack_midi_event_t event;
-		int r;
-		r = jack_midi_event_get (&event, buffer, i);
-
-		if (r != 0) {continue;}
-
-		if (event.size > MSG_BUFFER_SIZE) {
-			fprintf(stderr, "Error: MIDI message was too large, skipping event. Max. allowed size: %d bytes\n", MSG_BUFFER_SIZE);
-		}
-		else if (jack_ringbuffer_write_space (rb) >= sizeof(midimsg)) {
-			midimsg m;
-			m.tme_mon = monotonic_cnt;
-			m.tme_rel = event.time;
-			m.size    = event.size;
-			memcpy (m.buffer, event.buffer, event.size);
-			jack_ringbuffer_write (rb, (void *) &m, sizeof(midimsg));
-		}
-		else {
-			fprintf (stderr, "Error: ringbuffer was full, skipping event.\n");
-		}
-	}
-
-	monotonic_cnt += frames;
-
-	if (pthread_mutex_trylock (&msg_thread_lock) == 0) {
-		pthread_cond_signal (&data_ready);
-		pthread_mutex_unlock (&msg_thread_lock);
-	}
-
-	return 0;
-}
-
-static void wearedone(int sig) {
-	fprintf(stderr, "Shutting down\n");
-	keeprunning = 0;
-}
-
-static void usage (int status) {
-	printf ("jack_midi_dump - JACK MIDI Monitor.\n\n");
-	printf ("Usage: jack_midi_dump [ OPTIONS ] [CLIENT-NAME]\n\n");
-	printf ("Options:\n\
-  -a        use absolute timestamps relative to application start\n\
-  -h        display this help and exit\n\
-  -r        use relative timestamps to previous MIDI event\n\
-\n");
-	printf ("\n\
-This tool listens for MIDI events on a JACK MIDI port and prints\n\
-the message to stdout.\n\
-\n\
-If no client name is given it defaults to 'midi-monitor'.\n\
-\n\
-See also: jackd(1)\n\
-\n");
-	exit (status);
-}
-
-int
-main (int argc, char* argv[])
-{
-	jack_client_t* client;
-	char const default_name[] = "midi-monitor";
-	char const * client_name;
-	int time_format = 0;
-	int r;
-
-	int cn = 1;
-
-	if (argc > 1) {
-		if      (!strcmp (argv[1], "-a")) { time_format = 1; cn = 2; }
-		else if (!strcmp (argv[1], "-r")) { time_format = 2; cn = 2; }
-		else if (!strcmp (argv[1], "-h")) { usage (EXIT_SUCCESS); }
-		else if (argv[1][0] == '-')       { usage (EXIT_FAILURE); }
-	}
-
-	if (argc > cn) {
-		client_name = argv[cn];
-	} else {
-		client_name = default_name;
-	}
-
-	client = jack_client_open (client_name, JackNullOption, NULL);
-	if (client == NULL) {
-		fprintf (stderr, "Could not create JACK client.\n");
-		exit (EXIT_FAILURE);
-	}
-
-	rb = jack_ringbuffer_create (RBSIZE * sizeof(midimsg));
-
-	jack_set_process_callback (client, process, 0);
-
-	port = jack_port_register (client, "input", JACK_DEFAULT_MIDI_TYPE, JackPortIsInput, 0);
-	if (port == NULL) {
-		fprintf (stderr, "Could not register port.\n");
-		exit (EXIT_FAILURE);
-	}
-
-#ifndef WIN32
-	if (mlockall (MCL_CURRENT | MCL_FUTURE)) {
-		fprintf (stderr, "Warning: Can not lock memory.\n");
-	}
-#endif
-
-	r = jack_activate (client);
-	if (r != 0) {
-		fprintf (stderr, "Could not activate client.\n");
-		exit (EXIT_FAILURE);
-	}
-
-#ifndef WIN32
-	signal(SIGHUP, wearedone);
-	signal(SIGINT, wearedone);
-#endif
-
-	pthread_mutex_lock (&msg_thread_lock);
-
-	uint64_t prev_event = 0;
-	while (keeprunning) {
-		const int mqlen = jack_ringbuffer_read_space (rb) / sizeof(midimsg);
-		int i;
-		for (i=0; i < mqlen; ++i) {
-			size_t j;
-			midimsg m;
-			jack_ringbuffer_read(rb, (char*) &m, sizeof(midimsg));
-
-			switch(time_format) {
-				case 1:
-					printf ("%7"PRId64":", m.tme_rel + m.tme_mon);
-					break;
-				case 2:
-					printf ("%+6"PRId64":", m.tme_rel + m.tme_mon - prev_event);
-					break;
-				default:
-					printf ("%4d:", m.tme_rel);
-					break;
-			}
-			for (j = 0; j < m.size && j < sizeof(m.buffer); ++j) {
-				printf (" %02x", m.buffer[j]);
-			}
-
-			describe (&m);
-			printf("\n");
-			prev_event = m.tme_rel + m.tme_mon;
-		}
-		fflush (stdout);
-		pthread_cond_wait (&data_ready, &msg_thread_lock);
-	}
-	pthread_mutex_unlock (&msg_thread_lock);
-
-	jack_deactivate (client);
-	jack_client_close (client);
-	jack_ringbuffer_free (rb);
-
-	return 0;
-}
diff -pruN 1.9.14~dfsg-1/example-clients/monitor_client.c 1.9.16~dfsg-1/example-clients/monitor_client.c
--- 1.9.14~dfsg-1/example-clients/monitor_client.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/monitor_client.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,66 +0,0 @@
-/*
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-*/
-
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <jack/jack.h>
-
-#define TRUE 1
-#define FALSE 0
-
-int
-main (int argc, char *argv[])
-{
-	jack_client_t *client;
-	char *my_name = strrchr(argv[0], '/');
-
-	if (my_name == 0) {
-		my_name = argv[0];
-	} else {
-		my_name ++;
-	}
-
-	if (argc != 2) {
-		fprintf (stderr, "Usage: %s client\n", my_name);
-		return 1;
-	}
-
-	if ((client = jack_client_open ("input monitoring", JackNullOption, NULL)) == 0) {
-		fprintf (stderr, "JACK server not running?\n");
-		return 1;
-	}
-
-	if (jack_port_request_monitor_by_name (client, argv[1], TRUE)) {
-		fprintf (stderr, "could not enable monitoring for %s\n", argv[1]);
-		jack_client_close (client);
-		return 1;
-	}
-
-#ifdef WIN32
-	Sleep (30*1000);
-#else
-	sleep (30);
-#endif
-	if (jack_port_request_monitor_by_name (client, argv[1], FALSE)) {
-		fprintf (stderr, "could not disable monitoring for %s\n", argv[1]);
-	}
-	jack_client_close (client);
-	exit (0);
-}
-
diff -pruN 1.9.14~dfsg-1/example-clients/netsource.c 1.9.16~dfsg-1/example-clients/netsource.c
--- 1.9.14~dfsg-1/example-clients/netsource.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/netsource.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,802 +0,0 @@
-/*
-NetJack Client
-
-Copyright (C) 2008 Marc-Olivier Barre <marco@marcochapeau.org>
-Copyright (C) 2008 Pieter Palmers <pieterpalmers@users.sourceforge.net>
-Copyright (C) 2006 Torben Hohn <torbenh@gmx.de>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
-*/
-
-/** @file netsource.c
- *
- * @brief This client connects a remote slave JACK to a local JACK server assumed to be the master
- */
-
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-#include <signal.h>
-
-#if defined(HAVE_CONFIG_H)
-#include "config.h"
-#endif
-
-#ifdef WIN32
-#include <winsock2.h>
-#define socklen_t int
-#include <malloc.h>
-#else
-#include <netinet/in.h>
-#include <netdb.h>
-#include <sys/socket.h>
-#endif
-
-/* These two required by FreeBSD. */
-#include <sys/types.h>
-
-#include <jack/jack.h>
-
-#include <netjack_packet.h>
-#if HAVE_SAMPLERATE
-#include <samplerate.h>
-#endif
-
-#if HAVE_CELT
-#include <celt/celt.h>
-#endif
-
-#ifndef CUSTOM_MODES
-#define CUSTOM_MODES // for opus_custom_decoder_init
-#endif
-
-#if HAVE_OPUS
-#include <opus/opus.h>
-#include <opus/opus_custom.h>
-#endif
-
-#include <math.h>
-
-JSList *capture_ports = NULL;
-JSList *capture_srcs = NULL;
-int capture_channels = 0;
-int capture_channels_audio = 2;
-int capture_channels_midi = 1;
-JSList *playback_ports = NULL;
-JSList *playback_srcs = NULL;
-int playback_channels = 0;
-int playback_channels_audio = 2;
-int playback_channels_midi = 1;
-int dont_htonl_floats = 0;
-
-int latency = 5;
-jack_nframes_t factor = 1;
-int bitdepth = 0;
-int mtu = 1400;
-int reply_port = 0;
-int bind_port = 0;
-int redundancy = 1;
-jack_client_t *client;
-packet_cache * packcache = 0;
-
-int state_connected = 0;
-int state_latency = 0;
-int state_netxruns = 0;
-int state_currentframe = 0;
-int state_recv_packet_queue_time = 0;
-
-int quit = 0;
-
-
-int outsockfd;
-int insockfd;
-#ifdef WIN32
-struct sockaddr_in destaddr;
-struct sockaddr_in bindaddr;
-#else
-struct sockaddr destaddr;
-struct sockaddr bindaddr;
-#endif
-
-int sync_state;
-jack_transport_state_t last_transport_state;
-
-int framecnt = 0;
-
-int cont_miss = 0;
-
-int freewheeling = 0;
-
-/**
- * This Function allocates all the I/O Ports which are added the lists.
- */
-void
-alloc_ports (int n_capture_audio, int n_playback_audio, int n_capture_midi, int n_playback_midi)
-{
-
-    int port_flags = JackPortIsOutput;
-    int chn;
-    jack_port_t *port;
-    char buf[32];
-
-    capture_ports = NULL;
-    /* Allocate audio capture channels */
-    for (chn = 0; chn < n_capture_audio; chn++) {
-        snprintf (buf, sizeof (buf) - 1, "capture_%u", chn + 1);
-        port = jack_port_register (client, buf, JACK_DEFAULT_AUDIO_TYPE, port_flags, 0);
-        if (!port) {
-            printf( "jack_netsource: cannot register %s port\n", buf);
-            break;
-        }
-        if (bitdepth == 1000) {
-#if HAVE_CELT
-#if HAVE_CELT_API_0_11
-            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate( client ), jack_get_buffer_size(client), NULL );
-            capture_srcs = jack_slist_append(capture_srcs, celt_decoder_create_custom( celt_mode, 1, NULL ) );
-#elif HAVE_CELT_API_0_7 || HAVE_CELT_API_0_8
-            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate( client ), jack_get_buffer_size(client), NULL );
-            capture_srcs = jack_slist_append(capture_srcs, celt_decoder_create( celt_mode, 1, NULL ) );
-#else
-            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate( client ), 1, jack_get_buffer_size(client), NULL );
-            capture_srcs = jack_slist_append(capture_srcs, celt_decoder_create( celt_mode ) );
-#endif
-#endif
-        } else if (bitdepth == 999) {
-#if HAVE_OPUS
-            int err;
-            OpusCustomMode *opus_mode = opus_custom_mode_create(jack_get_sample_rate( client ), jack_get_buffer_size(client), &err);
-            if (err != OPUS_OK) { printf("OPUS MODE FAILED\n"); }
-            OpusCustomDecoder *decoder = opus_custom_decoder_create(opus_mode, 1, &err);
-            if (err != OPUS_OK) { printf("OPUS DECODER FAILED\n"); }
-            opus_custom_decoder_init(decoder, opus_mode, 1);
-            capture_srcs = jack_slist_append(capture_srcs, decoder);
-#endif
-        } else {
-#if HAVE_SAMPLERATE
-            capture_srcs = jack_slist_append (capture_srcs, src_new (SRC_LINEAR, 1, NULL));
-#endif
-        }
-        capture_ports = jack_slist_append (capture_ports, port);
-    }
-
-    /* Allocate midi capture channels */
-    for (chn = n_capture_audio; chn < n_capture_midi + n_capture_audio; chn++) {
-        snprintf (buf, sizeof (buf) - 1, "capture_%u", chn + 1);
-        port = jack_port_register (client, buf, JACK_DEFAULT_MIDI_TYPE, port_flags, 0);
-        if (!port) {
-            printf ("jack_netsource: cannot register %s port\n", buf);
-            break;
-        }
-        capture_ports = jack_slist_append(capture_ports, port);
-    }
-
-    /* Allocate audio playback channels */
-    port_flags = JackPortIsInput;
-    playback_ports = NULL;
-    for (chn = 0; chn < n_playback_audio; chn++) {
-        snprintf (buf, sizeof (buf) - 1, "playback_%u", chn + 1);
-        port = jack_port_register (client, buf, JACK_DEFAULT_AUDIO_TYPE, port_flags, 0);
-        if (!port) {
-            printf ("jack_netsource: cannot register %s port\n", buf);
-            break;
-        }
-        if( bitdepth == 1000 ) {
-#if HAVE_CELT
-#if HAVE_CELT_API_0_11
-            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate (client), jack_get_buffer_size(client), NULL );
-            playback_srcs = jack_slist_append(playback_srcs, celt_encoder_create_custom( celt_mode, 1, NULL ) );
-#elif HAVE_CELT_API_0_7 || HAVE_CELT_API_0_8
-            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate (client), jack_get_buffer_size(client), NULL );
-            playback_srcs = jack_slist_append(playback_srcs, celt_encoder_create( celt_mode, 1, NULL ) );
-#else
-            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate (client), 1, jack_get_buffer_size(client), NULL );
-            playback_srcs = jack_slist_append(playback_srcs, celt_encoder_create( celt_mode ) );
-#endif
-#endif
-        } else if( bitdepth == 999 ) {
-#if HAVE_OPUS
-            const int kbps = factor;
-            printf("new opus encoder %d kbps\n", kbps);
-            int err;
-            OpusCustomMode *opus_mode = opus_custom_mode_create(jack_get_sample_rate (client), jack_get_buffer_size(client), &err ); // XXX free me
-            if (err != OPUS_OK) { printf("OPUS MODE FAILED\n"); }
-            OpusCustomEncoder *oe = opus_custom_encoder_create( opus_mode, 1, &err );
-            if (err != OPUS_OK) { printf("OPUS ENCODER FAILED\n"); }
-            opus_custom_encoder_ctl(oe, OPUS_SET_BITRATE(kbps*1024)); // bits per second
-            opus_custom_encoder_ctl(oe, OPUS_SET_COMPLEXITY(10));
-            opus_custom_encoder_ctl(oe, OPUS_SET_SIGNAL(OPUS_SIGNAL_MUSIC));
-            opus_custom_encoder_ctl(oe, OPUS_SET_SIGNAL(OPUS_APPLICATION_RESTRICTED_LOWDELAY));
-            opus_custom_encoder_init(oe, opus_mode, 1);
-            playback_srcs = jack_slist_append(playback_srcs, oe);
-#endif
-        } else {
-#if HAVE_SAMPLERATE
-            playback_srcs = jack_slist_append (playback_srcs, src_new (SRC_LINEAR, 1, NULL));
-#endif
-        }
-        playback_ports = jack_slist_append (playback_ports, port);
-    }
-
-    /* Allocate midi playback channels */
-    for (chn = n_playback_audio; chn < n_playback_midi + n_playback_audio; chn++) {
-        snprintf (buf, sizeof (buf) - 1, "playback_%u", chn + 1);
-        port = jack_port_register (client, buf, JACK_DEFAULT_MIDI_TYPE, port_flags, 0);
-        if (!port) {
-            printf ("jack_netsource: cannot register %s port\n", buf);
-            break;
-        }
-        playback_ports = jack_slist_append (playback_ports, port);
-    }
-}
-
-/**
- * The Sync callback... sync state is set elsewhere...
- * we will see if this is working correctly.
- * i don't really believe in it yet.
- */
-int
-sync_cb (jack_transport_state_t state, jack_position_t *pos, void *arg)
-{
-    static int latency_count = 0;
-    int retval = sync_state;
-
-    if (! state_connected) {
-        return 1;
-    }
-    if (latency_count) {
-        latency_count--;
-        retval = 0;
-    }
-
-    else if (state == JackTransportStarting && last_transport_state != JackTransportStarting) {
-        retval = 0;
-        latency_count = latency - 1;
-    }
-
-    last_transport_state = state;
-    return retval;
-}
-
-void
-freewheel_cb (int starting, void *arg)
-{
-    freewheeling = starting;
-}
-
-int deadline_goodness = 0;
-/**
- * The process callback for this JACK application.
- * It is called by JACK at the appropriate times.
- */
-int
-process (jack_nframes_t nframes, void *arg)
-{
-    jack_nframes_t net_period;
-    int rx_bufsize, tx_bufsize;
-
-    jack_default_audio_sample_t *buf;
-    jack_port_t *port;
-    JSList *node;
-    int chn;
-    int size, i;
-    const char *porttype;
-    int input_fd;
-
-    jack_position_t local_trans_pos;
-
-    uint32_t *packet_buf_tx, *packet_bufX;
-    uint32_t *rx_packet_ptr;
-    jack_time_t packet_recv_timestamp;
-
-    if( bitdepth == 1000 || bitdepth == 999)
-        net_period = (factor * jack_get_buffer_size(client) * 1024 / jack_get_sample_rate(client) / 8) & (~1) ;
-    else
-        net_period = (float) nframes / (float) factor;
-
-    rx_bufsize =  get_sample_size (bitdepth) * capture_channels * net_period + sizeof (jacknet_packet_header);
-    tx_bufsize =  get_sample_size (bitdepth) * playback_channels * net_period + sizeof (jacknet_packet_header);
-
-    /* Allocate a buffer where both In and Out Buffer will fit */
-    packet_buf_tx = alloca (tx_bufsize);
-
-    jacknet_packet_header *pkthdr_tx = (jacknet_packet_header *) packet_buf_tx;
-
-    /*
-     * for latency==0 we need to send out the packet before we wait on the reply.
-     * but this introduces a cycle of latency, when netsource is connected to itself.
-     * so we send out before read only in zero latency mode.
-     *
-     */
-
-    if( latency == 0 ) {
-        /* reset packet_bufX... */
-        packet_bufX = packet_buf_tx + sizeof (jacknet_packet_header) / sizeof (jack_default_audio_sample_t);
-
-        /* ---------- Send ---------- */
-        render_jack_ports_to_payload (bitdepth, playback_ports, playback_srcs, nframes,
-                                      packet_bufX, net_period, dont_htonl_floats);
-
-        /* fill in packet hdr */
-        pkthdr_tx->transport_state = jack_transport_query (client, &local_trans_pos);
-        pkthdr_tx->transport_frame = local_trans_pos.frame;
-        pkthdr_tx->framecnt = framecnt;
-        pkthdr_tx->latency = latency;
-        pkthdr_tx->reply_port = reply_port;
-        pkthdr_tx->sample_rate = jack_get_sample_rate (client);
-        pkthdr_tx->period_size = nframes;
-
-        /* playback for us is capture on the other side */
-        pkthdr_tx->capture_channels_audio = playback_channels_audio;
-        pkthdr_tx->playback_channels_audio = capture_channels_audio;
-        pkthdr_tx->capture_channels_midi = playback_channels_midi;
-        pkthdr_tx->playback_channels_midi = capture_channels_midi;
-        pkthdr_tx->mtu = mtu;
-        if( freewheeling != 0 )
-            pkthdr_tx->sync_state = (jack_nframes_t)MASTER_FREEWHEELS;
-        else
-            pkthdr_tx->sync_state = (jack_nframes_t)deadline_goodness;
-        //printf("goodness=%d\n", deadline_goodness );
-
-        packet_header_hton (pkthdr_tx);
-        if (cont_miss < 3 * latency + 5) {
-            int r;
-            for( r = 0; r < redundancy; r++ )
-                netjack_sendto (outsockfd, (char *) packet_buf_tx, tx_bufsize, 0, &destaddr, sizeof (destaddr), mtu);
-        } else if (cont_miss > 50 + 5 * latency) {
-            state_connected = 0;
-            packet_cache_reset_master_address( packcache );
-            //printf ("Frame %d  \tRealy too many packets missed (%d). Let's reset the counter\n", framecnt, cont_miss);
-            cont_miss = 0;
-        }
-    }
-
-    /*
-     * ok... now the RECEIVE code.
-     *
-     */
-
-
-    if( reply_port )
-        input_fd = insockfd;
-    else
-        input_fd = outsockfd;
-
-    // for latency == 0 we can poll.
-    if( (latency == 0) || (freewheeling != 0)  ) {
-        jack_time_t deadline = jack_get_time() + 1000000 * jack_get_buffer_size(client) / jack_get_sample_rate(client);
-        // Now loop until we get the right packet.
-        while(1) {
-            jack_nframes_t got_frame;
-            if ( ! netjack_poll_deadline( input_fd, deadline ) )
-                break;
-
-            packet_cache_drain_socket(packcache, input_fd);
-
-            if (packet_cache_get_next_available_framecnt( packcache, framecnt - latency, &got_frame ))
-                if( got_frame == (framecnt - latency) )
-                    break;
-        }
-    } else {
-        // normally:
-        // only drain socket.
-        packet_cache_drain_socket(packcache, input_fd);
-    }
-
-    size = packet_cache_retreive_packet_pointer( packcache, framecnt - latency, (char**)&rx_packet_ptr, rx_bufsize, &packet_recv_timestamp );
-    /* First alternative : we received what we expected. Render the data
-     * to the JACK ports so it can be played. */
-    if (size == rx_bufsize) {
-        uint32_t *packet_buf_rx = rx_packet_ptr;
-        jacknet_packet_header *pkthdr_rx = (jacknet_packet_header *) packet_buf_rx;
-        packet_bufX = packet_buf_rx + sizeof (jacknet_packet_header) / sizeof (jack_default_audio_sample_t);
-        // calculate how much time there would have been, if this packet was sent at the deadline.
-
-        int recv_time_offset = (int) (jack_get_time() - packet_recv_timestamp);
-        packet_header_ntoh (pkthdr_rx);
-        deadline_goodness = recv_time_offset - (int)pkthdr_rx->latency;
-        //printf( "deadline goodness = %d ---> off: %d\n", deadline_goodness, recv_time_offset );
-
-        if (cont_miss) {
-            //printf("Frame %d  \tRecovered from dropouts\n", framecnt);
-            cont_miss = 0;
-        }
-        render_payload_to_jack_ports (bitdepth, packet_bufX, net_period,
-                                      capture_ports, capture_srcs, nframes, dont_htonl_floats);
-
-        state_currentframe = framecnt;
-        state_recv_packet_queue_time = recv_time_offset;
-        state_connected = 1;
-        sync_state = pkthdr_rx->sync_state;
-        packet_cache_release_packet( packcache, framecnt - latency );
-    }
-    /* Second alternative : we've received something that's not
-     * as big as expected or we missed a packet. We render silence
-     * to the output ports */
-    else {
-        jack_nframes_t latency_estimate;
-        if( packet_cache_find_latency( packcache, framecnt, &latency_estimate ) )
-            //if( (state_latency == 0) || (latency_estimate < state_latency) )
-            state_latency = latency_estimate;
-
-        // Set the counters up.
-        state_currentframe = framecnt;
-        //state_latency = framecnt - pkthdr->framecnt;
-        state_netxruns += 1;
-
-        //printf ("Frame %d  \tPacket missed or incomplete (expected: %d bytes, got: %d bytes)\n", framecnt, rx_bufsize, size);
-        //printf ("Frame %d  \tPacket missed or incomplete\n", framecnt);
-        cont_miss += 1;
-        chn = 0;
-        node = capture_ports;
-        while (node != NULL) {
-            port = (jack_port_t *) node->data;
-            buf = jack_port_get_buffer (port, nframes);
-            porttype = jack_port_type (port);
-            if (strncmp (porttype, JACK_DEFAULT_AUDIO_TYPE, jack_port_type_size ()) == 0)
-                for (i = 0; i < nframes; i++)
-                    buf[i] = 0.0;
-            else if (strncmp (porttype, JACK_DEFAULT_MIDI_TYPE, jack_port_type_size ()) == 0)
-                jack_midi_clear_buffer (buf);
-            node = jack_slist_next (node);
-            chn++;
-        }
-    }
-    if (latency != 0) {
-        /* reset packet_bufX... */
-        packet_bufX = packet_buf_tx + sizeof (jacknet_packet_header) / sizeof (jack_default_audio_sample_t);
-
-        /* ---------- Send ---------- */
-        render_jack_ports_to_payload (bitdepth, playback_ports, playback_srcs, nframes,
-                                      packet_bufX, net_period, dont_htonl_floats);
-
-        /* fill in packet hdr */
-        pkthdr_tx->transport_state = jack_transport_query (client, &local_trans_pos);
-        pkthdr_tx->transport_frame = local_trans_pos.frame;
-        pkthdr_tx->framecnt = framecnt;
-        pkthdr_tx->latency = latency;
-        pkthdr_tx->reply_port = reply_port;
-        pkthdr_tx->sample_rate = jack_get_sample_rate (client);
-        pkthdr_tx->period_size = nframes;
-
-        /* playback for us is capture on the other side */
-        pkthdr_tx->capture_channels_audio = playback_channels_audio;
-        pkthdr_tx->playback_channels_audio = capture_channels_audio;
-        pkthdr_tx->capture_channels_midi = playback_channels_midi;
-        pkthdr_tx->playback_channels_midi = capture_channels_midi;
-        pkthdr_tx->mtu = mtu;
-        if( freewheeling != 0 )
-            pkthdr_tx->sync_state = (jack_nframes_t)MASTER_FREEWHEELS;
-        else
-            pkthdr_tx->sync_state = (jack_nframes_t)deadline_goodness;
-        //printf("goodness=%d\n", deadline_goodness );
-
-        packet_header_hton (pkthdr_tx);
-        if (cont_miss < 3 * latency + 5) {
-            int r;
-            for( r = 0; r < redundancy; r++ )
-                netjack_sendto (outsockfd, (char *) packet_buf_tx, tx_bufsize, 0, &destaddr, sizeof (destaddr), mtu);
-        } else if (cont_miss > 50 + 5 * latency) {
-            state_connected = 0;
-            packet_cache_reset_master_address( packcache );
-            //printf ("Frame %d  \tRealy too many packets missed (%d). Let's reset the counter\n", framecnt, cont_miss);
-            cont_miss = 0;
-        }
-    }
-
-    framecnt++;
-    return 0;
-}
-
-/**
- * This is the shutdown callback for this JACK application.
- * It is called by JACK if the server ever shuts down or
- * decides to disconnect the client.
- */
-
-void
-jack_shutdown (void *arg)
-{
-    fprintf(stderr, "JACK shut down, exiting ...\n");
-    exit (1);
-}
-
-void
-init_sockaddr_in (struct sockaddr_in *name , const char *hostname , uint16_t port)
-{
-    name->sin_family = AF_INET ;
-    name->sin_port = htons (port);
-    if (hostname) {
-        struct hostent *hostinfo = gethostbyname (hostname);
-        if (hostinfo == NULL) {
-            fprintf (stderr, "init_sockaddr_in: unknown host: %s.\n", hostname);
-            fflush( stderr );
-        }
-#ifdef WIN32
-        name->sin_addr.s_addr = inet_addr( hostname );
-#else
-        name->sin_addr = *(struct in_addr *) hostinfo->h_addr ;
-#endif
-    } else
-        name->sin_addr.s_addr = htonl (INADDR_ANY) ;
-
-}
-
-void
-printUsage ()
-{
-    fprintf (stderr, "usage: jack_netsource [options]\n"
-             "\n"
-             "  -h this help text\n"
-             "  -H <slave host> - Host name of the slave JACK\n"
-             "  -o <num channels> - Number of audio playback channels\n"
-             "  -i <num channels> - Number of audio capture channels\n"
-             "  -O <num channels> - Number of midi playback channels\n"
-             "  -I <num channels> - Number of midi capture channels\n"
-             "  -n <periods> - Network latency in JACK periods\n"
-             "  -p <port> - UDP port that the slave is listening on\n"
-             "  -r <reply port> - UDP port that we are listening on\n"
-             "  -B <bind port> - reply port, for use in NAT environments\n"
-             "  -b <bitdepth> - Set transport to use 16bit or 8bit\n"
-             "  -c <kbits> - Use CELT encoding with <kbits> kbits per channel\n"
-             "  -P <kbits> - Use Opus encoding with <kbits> kbits per channel\n"
-             "  -m <mtu> - Assume this mtu for the link\n"
-             "  -R <N> - Redundancy: send out packets N times.\n"
-             "  -e - skip host-to-network endianness conversion\n"
-             "  -N <jack name> - Reports a different name to jack\n"
-             "  -s <server name> - The name of the local jack server\n"
-             "\n");
-}
-
-void
-sigterm_handler( int signal )
-{
-    quit = 1;
-}
-
-int
-main (int argc, char *argv[])
-{
-    /* Some startup related basics */
-    char *client_name, *server_name = NULL, *peer_ip;
-    int peer_port = 3000;
-    jack_options_t options = JackNullOption;
-    jack_status_t status;
-#ifdef WIN32
-    WSADATA wsa;
-    int rc = WSAStartup(MAKEWORD(2, 0), &wsa);
-#endif
-    /* Torben's famous state variables, aka "the reporting API" ! */
-    /* heh ? these are only the copies of them ;)                 */
-    int statecopy_connected, statecopy_latency, statecopy_netxruns;
-    jack_nframes_t net_period;
-    /* Argument parsing stuff */
-    extern char *optarg;
-    extern int optind, optopt;
-    int errflg = 0, c;
-
-    if (argc < 3) {
-        printUsage ();
-        return 1;
-    }
-
-    client_name = (char *) malloc (sizeof (char) * 10);
-    peer_ip = (char *) malloc (sizeof (char) * 10);
-    sprintf(client_name, "netjack");
-    sprintf(peer_ip, "localhost");
-
-    while ((c = getopt (argc, argv, ":h:H:o:i:O:I:n:p:r:B:b:c:m:R:e:N:s:P:")) != -1) {
-        switch (c) {
-            case 'h':
-                printUsage();
-                exit (0);
-                break;
-            case 'H':
-                free(peer_ip);
-                peer_ip = (char *) malloc (sizeof (char) * strlen (optarg) + 1);
-                strcpy (peer_ip, optarg);
-                break;
-            case 'o':
-                playback_channels_audio = atoi (optarg);
-                break;
-            case 'i':
-                capture_channels_audio = atoi (optarg);
-                break;
-            case 'O':
-                playback_channels_midi = atoi (optarg);
-                break;
-            case 'I':
-                capture_channels_midi = atoi (optarg);
-                break;
-            case 'n':
-                latency = atoi (optarg);
-                break;
-            case 'p':
-                peer_port = atoi (optarg);
-                break;
-            case 'r':
-                reply_port = atoi (optarg);
-                break;
-            case 'B':
-                bind_port = atoi (optarg);
-                break;
-            case 'f':
-                factor = atoi (optarg);
-                printf("This feature is deprecated and will be removed in future netjack versions. CELT offers a superiour way to conserve bandwidth");
-                break;
-            case 'b':
-                bitdepth = atoi (optarg);
-                break;
-            case 'c':
-#if HAVE_CELT
-                bitdepth = 1000;
-                factor = atoi (optarg);
-#else
-                printf( "not built with celt support\n" );
-                exit(10);
-#endif
-                break;
-            case 'P':
-#if HAVE_OPUS
-                bitdepth = 999;
-                factor = atoi (optarg);
-#else
-                printf( "not built with opus support\n" );
-                exit(10);
-#endif
-                break;
-            case 'm':
-                mtu = atoi (optarg);
-                break;
-            case 'R':
-                redundancy = atoi (optarg);
-                break;
-            case 'e':
-                dont_htonl_floats = 1;
-                break;
-            case 'N':
-                free(client_name);
-                client_name = (char *) malloc (sizeof (char) * strlen (optarg) + 1);
-                strcpy (client_name, optarg);
-                break;
-            case 's':
-                server_name = (char *) malloc (sizeof (char) * strlen (optarg) + 1);
-                strcpy (server_name, optarg);
-                options |= JackServerName;
-                break;
-            case ':':
-                fprintf (stderr, "Option -%c requires an operand\n", optopt);
-                errflg++;
-                break;
-            case '?':
-                fprintf (stderr, "Unrecognized option: -%c\n", optopt);
-                errflg++;
-        }
-    }
-    if (errflg) {
-        printUsage ();
-        exit (2);
-    }
-
-    capture_channels = capture_channels_audio + capture_channels_midi;
-    playback_channels = playback_channels_audio + playback_channels_midi;
-
-    outsockfd = socket (AF_INET, SOCK_DGRAM, 0);
-    insockfd = socket (AF_INET, SOCK_DGRAM, 0);
-
-    if ((outsockfd == -1) || (insockfd == -1)) {
-        fprintf (stderr, "can not open sockets\n" );
-        return 1;
-    }
-
-    init_sockaddr_in ((struct sockaddr_in *) &destaddr, peer_ip, peer_port);
-    if (bind_port) {
-        init_sockaddr_in ((struct sockaddr_in *) &bindaddr, NULL, bind_port);
-        if( bind (outsockfd, &bindaddr, sizeof (bindaddr)) ) {
-            fprintf (stderr, "bind failure\n" );
-        }
-    }
-    if (reply_port) {
-        init_sockaddr_in ((struct sockaddr_in *) &bindaddr, NULL, reply_port);
-        if( bind (insockfd, &bindaddr, sizeof (bindaddr)) ) {
-            fprintf (stderr, "bind failure\n" );
-        }
-    }
-
-    /* try to become a client of the JACK server */
-    client = jack_client_open (client_name, options, &status, server_name);
-    if (client == NULL) {
-        fprintf (stderr, "jack_client_open() failed, status = 0x%2.0x\n"
-                 "Is the JACK server running ?\n", status);
-        return 1;
-    }
-
-    /* Set up jack callbacks */
-    jack_set_process_callback (client, process, 0);
-    jack_set_sync_callback (client, sync_cb, 0);
-    jack_set_freewheel_callback (client, freewheel_cb, 0);
-    jack_on_shutdown (client, jack_shutdown, 0);
-
-    alloc_ports (capture_channels_audio, playback_channels_audio, capture_channels_midi, playback_channels_midi);
-
-    if( bitdepth == 1000 || bitdepth == 999)
-        net_period = (factor * jack_get_buffer_size(client) * 1024 / jack_get_sample_rate(client) / 8) & (~1) ;
-    else
-        net_period = ceilf((float) jack_get_buffer_size (client) / (float) factor);
-
-    int rx_bufsize =  get_sample_size (bitdepth) * capture_channels * net_period + sizeof (jacknet_packet_header);
-    packcache = packet_cache_new (latency + 50, rx_bufsize, mtu);
-
-    /* tell the JACK server that we are ready to roll */
-    if (jack_activate (client)) {
-        fprintf (stderr, "Cannot activate client");
-        return 1;
-    }
-
-    /* Now sleep forever... and evaluate the state_ vars */
-
-    signal( SIGTERM, sigterm_handler );
-    signal( SIGINT, sigterm_handler );
-
-    statecopy_connected = 2; // make it report unconnected on start.
-    statecopy_latency = state_latency;
-    statecopy_netxruns = state_netxruns;
-
-    while ( !quit ) {
-#ifdef WIN32
-        Sleep (1000);
-#else
-        sleep(1);
-#endif
-        if (statecopy_connected != state_connected) {
-            statecopy_connected = state_connected;
-            if (statecopy_connected) {
-                state_netxruns = 1; // We want to reset the netxrun count on each new connection
-                printf ("Connected :-)\n");
-            } else
-                printf ("Not Connected\n");
-
-            fflush(stdout);
-        }
-
-        if (statecopy_connected) {
-            if (statecopy_netxruns != state_netxruns) {
-                statecopy_netxruns = state_netxruns;
-                printf ("%s: at frame %06d -> total netxruns %d  (%d%%) queue time= %d\n",
-                        client_name,
-                        state_currentframe,
-                        statecopy_netxruns,
-                        100 * statecopy_netxruns / state_currentframe,
-                        state_recv_packet_queue_time);
-
-                fflush(stdout);
-            }
-        } else {
-            if (statecopy_latency != state_latency) {
-                statecopy_latency = state_latency;
-                if (statecopy_latency > 1)
-                    printf ("current latency %d\n", statecopy_latency);
-                fflush(stdout);
-            }
-        }
-    }
-
-    jack_client_close (client);
-    packet_cache_free (packcache);
-    exit (0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/property.c 1.9.16~dfsg-1/example-clients/property.c
--- 1.9.14~dfsg-1/example-clients/property.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/property.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,327 +0,0 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <getopt.h>
-
-#include <jack/jack.h>
-#include <jack/metadata.h>
-#include <jack/uuid.h>
-#include <jack/session.h>
-
-static int subject_is_client = 0;
-static int subject_is_port = 0;
-static jack_uuid_t uuid = JACK_UUID_EMPTY_INITIALIZER;
-static char* subject = NULL;
-
-static void
-show_usage (void)
-{
-	fprintf (stderr, "\nUsage: jack_property [options] UUID [ key [ value [ type  ] ] ]\n");
-	fprintf (stderr, "Set/Display JACK properties (metadata).\n\n");
-	fprintf (stderr, "Set options:\n");
-	fprintf (stderr, "        -s, --set		Set property \"key\" to \"value\" for \"UUID\" with optional MIME type \"type\"\n");
-	fprintf (stderr, "        -d, --delete		Remove/delete property \"key\" for \"UUID\"\n");
-	fprintf (stderr, "        -d, --delete UUID	Remove/delete all properties for \"UUID\"\n");
-	fprintf (stderr, "        -D, --delete-all	Remove/delete all properties\n");
-        fprintf (stderr, "        --client		Interpret UUID as a client name, not a UUID\n");
-        fprintf (stderr, "        --port		\tInterpret UUID as a port name, not a UUID\n");
-	fprintf (stderr, "\nDisplay options:\n");
-	fprintf (stderr, "        -l			Show all properties\n");
-	fprintf (stderr, "        -l, --list UUID	\tShow value all properties of UUID\n");
-	fprintf (stderr, "        -l, --list UUID key	Show value for key of UUID\n");
-	fprintf (stderr, "\nFor more information see http://jackaudio.org/\n");
-}
-
-static int
-get_subject (jack_client_t* client, char* argv[], int* optind)
-{
-        if (subject_is_client) {
-                char* cstr = argv[(*optind)++];
-                char* ustr;
-
-                if ((ustr = jack_get_uuid_for_client_name (client, cstr)) == NULL) {
-                        fprintf (stderr, "cannot get UUID for client named %s\n", cstr);
-                        return -1;
-                }
-
-                if (jack_uuid_parse (ustr, &uuid)) {
-                        fprintf (stderr, "cannot parse client UUID as UUID '%s' '%s'\n", cstr, ustr);
-                        return -1;
-                }
-
-                subject = cstr;
-
-        } else if (subject_is_port) {
-
-                char* pstr = argv[(*optind)++];
-                jack_port_t* port;
-
-                if ((port = jack_port_by_name (client, pstr)) == NULL) {
-                        fprintf (stderr, "cannot find port name %s\n", pstr);
-                        return -1;
-                }
-
-                uuid = jack_port_uuid (port);
-                subject = pstr;
-
-        } else {
-                char* str = argv[(*optind)++];
-
-                if (jack_uuid_parse (str, &uuid)) {
-                        fprintf (stderr, "cannot parse subject as UUID\n");
-                        return -1;
-                }
-
-                subject = str;
-        }
-
-        return 0;
-}
-
-int main (int argc, char* argv[])
-{
-        jack_client_t* client = NULL;
-	jack_options_t options = JackNoStartServer;
-        char* key = NULL;
-        char* value = NULL;
-        char* type = NULL;
-        int set = 1;
-        int delete = 0;
-        int delete_all = 0;
-        int c;
-	int option_index;
-	extern int optind;
-	struct option long_options[] = {
-		{ "set", 0, 0, 's' },
-		{ "delete", 0, 0, 'd' },
-		{ "delete-all", 0, 0, 'D' },
-		{ "list", 0, 0, 'l' },
-                { "client", 0, 0, 'c' },
-                { "port", 0, 0, 'p' },
-		{ 0, 0, 0, 0 }
-	};
-
-        if (argc < 2) {
-                show_usage ();
-                exit (1);
-        }
-
-	while ((c = getopt_long (argc, argv, "sdDlaApc", long_options, &option_index)) >= 0) {
-		switch (c) {
-		case 's':
-                        if (argc < 5) {
-                                show_usage ();
-                                exit (1);
-                        }
-			set = 1;
-			break;
-                case 'd':
-                        if (argc < 3) {
-                                show_usage ();
-                                return 1;
-                        }
-                        set = 0;
-                        delete = 1;
-                        break;
-
-                case 'D':
-                        delete = 0;
-                        set = 0;
-                        delete_all = 1;
-                        break;
-
-                case 'l':
-                        set = 0;
-                        delete = 0;
-                        delete_all = 0;
-                        break;
-
-                case 'p':
-                        subject_is_port = 1;
-                        break;
-
-                case 'c':
-                        subject_is_client = 1;
-                        break;
-
-                case '?':
-                default:
-                        show_usage ();
-                        exit (1);
-                }
-        }
-
-        if ((client = jack_client_open ("jack-property", options, NULL)) == 0) {
-                fprintf (stderr, "Cannot connect to JACK server\n");
-                exit (1);
-        }
-
-        if (delete_all) {
-
-                if (jack_remove_all_properties (client) == 0) {
-                        printf ("JACK metadata successfully delete\n");
-                        exit (0);
-                }
-                exit (1);
-        }
-
-        if (delete) {
-
-                int args_left = argc - optind;
-
-                if (args_left < 1) {
-                        show_usage ();
-                        exit (1);
-                }
-
-                /* argc == 3: delete all properties for a subject
-                   argc == 4: delete value of key for subject
-                */
-
-                if (args_left >= 2) {
-
-                        if (get_subject (client, argv, &optind)) {
-                                return 1;
-                        }
-
-                        key = argv[optind++];
-
-                        if (jack_remove_property (client, uuid, key)) {
-                                fprintf (stderr, "\"%s\" property not removed for %s\n", key, subject);
-                                exit (1);
-                        }
-
-                } else {
-
-                        if (get_subject (client, argv, &optind)) {
-                                return 1;
-                        }
-
-                        if (jack_remove_properties (client, uuid) < 0) {
-                                fprintf (stderr, "cannot remove properties for UUID %s\n", subject);
-                                exit (1);
-                        }
-                }
-
-        }  else if (set) {
-
-                int args_left = argc - optind;
-
-                if (get_subject (client, argv, &optind)) {
-                        return -1;
-                }
-
-                key = argv[optind++];
-                value = argv[optind++];
-
-                if (args_left >= 3) {
-                        type = argv[optind++];
-                } else {
-                        type = "";
-                }
-
-                if (jack_set_property (client, uuid, key, value, type)) {
-                        fprintf (stderr, "cannot set value for key %s of %s\n", value, subject);
-                        exit (1);
-                }
-
-        } else {
-
-                /* list properties */
-
-                int args_left = argc - optind;
-
-                if (args_left >= 2) {
-
-                        /* list properties for a UUID/key pair */
-
-                        if (get_subject (client, argv, &optind)) {
-                                return -1;
-                        }
-
-                        key = argv[optind++];
-
-                        if (jack_get_property (uuid, key, &value, &type) == 0) {
-                                printf ("%s\n", value);
-                                free (value);
-                                if (type) {
-                                        free (type);
-                                }
-                        } else {
-                                fprintf (stderr, "Value not found for %s of %s\n", key, subject);
-                                exit (1);
-                        }
-
-                } else if (args_left == 1) {
-
-                        /* list all properties for a given UUID */
-
-                        jack_description_t description;
-                        size_t cnt, n;
-
-                        if (get_subject (client, argv, &optind)) {
-                                return -1;
-                        }
-
-                        if ((cnt = jack_get_properties (uuid, &description)) < 0) {
-                                fprintf (stderr, "could not retrieve properties for %s\n", subject);
-                                exit (1);
-                        }
-
-                        for (n = 0; n < cnt; ++n) {
-                                if (description.properties[n].type) {
-                                        printf ("key: %s value: %s type: %s\n",
-                                                description.properties[n].key,
-                                                description.properties[n].data,
-                                                description.properties[n].type);
-                                } else {
-                                        printf ("key: %s value: %s\n",
-                                                description.properties[n].key,
-                                                description.properties[n].data);
-                                }
-                        }
-
-                        jack_free_description (&description, 0);
-
-                } else {
-
-                        /* list all properties */
-
-                        jack_description_t* description;
-                        int cnt;
-                        size_t p;
-                        int n;
-                        char buf[JACK_UUID_STRING_SIZE];
-
-                        if ((cnt = jack_get_all_properties (&description)) < 0) {
-                                fprintf (stderr, "could not retrieve all properties\n");
-                                exit (1);
-                        }
-
-                        for (n = 0; n < cnt; ++n) {
-                                jack_uuid_unparse (description[n].subject, buf);
-                                printf ("%s\n", buf);
-                                for (p = 0; p < description[n].property_cnt; ++p) {
-                                        if (description[n].properties[p].type) {
-                                                printf ("key: %s value: %s type: %s\n",
-                                                        description[n].properties[p].key,
-                                                        description[n].properties[p].data,
-                                                        description[n].properties[p].type);
-                                        } else {
-                                                printf ("key: %s value: %s\n",
-                                                        description[n].properties[p].key,
-                                                        description[n].properties[p].data);
-                                        }
-                                }
-                                jack_free_description (&description[n], 0);
-                        }
-
-                        free (description);
-                }
-        }
-
-
-        (void) jack_client_close (client);
-        return 0;
-}
diff -pruN 1.9.14~dfsg-1/example-clients/samplerate.c 1.9.16~dfsg-1/example-clients/samplerate.c
--- 1.9.14~dfsg-1/example-clients/samplerate.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/samplerate.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,87 +0,0 @@
-/*
- *  smaplerate.c -- get current samplerate
- *
- *  Copyright (C) 2003 Jack O'Quin.
- *  
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <string.h>
-#include <jack/jack.h>
-#include <jack/transport.h>
-
-char *package;				/* program name */
-jack_client_t *client;
-
-void jack_shutdown(void *arg)
-{
-	fprintf(stderr, "JACK shut down, exiting ...\n");
-	exit(1);
-}
-
-void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-void parse_arguments(int argc, char *argv[])
-{
-
-	/* basename $0 */
-	package = strrchr(argv[0], '/');
-	if (package == 0)
-		package = argv[0];
-	else
-		package++;
-
-	if (argc==1) {
-		return;
-	}
-	fprintf(stderr, "usage: %s\n", package);
-	exit(9);
-}
-
-int main(int argc, char *argv[])
-{
-	parse_arguments(argc, argv);
-
-	/* become a JACK client */
-	if ((client = jack_client_open(package, JackNullOption, NULL)) == 0) {
-		fprintf(stderr, "JACK server not running?\n");
-		exit(1);
-	}
-
-#ifndef WIN32
-	signal(SIGQUIT, signal_handler);
-	signal(SIGHUP, signal_handler);
-#endif
-	signal(SIGTERM, signal_handler);
-	signal(SIGINT, signal_handler);
-
-	jack_on_shutdown(client, jack_shutdown, 0);
-
-	fprintf(stdout, "%d\n", jack_get_sample_rate( client ) );
-
-	jack_client_close(client);
-
-	return 0;
-}
diff -pruN 1.9.14~dfsg-1/example-clients/session_notify.c 1.9.16~dfsg-1/example-clients/session_notify.c
--- 1.9.14~dfsg-1/example-clients/session_notify.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/session_notify.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,186 +0,0 @@
-/*
- *  session_notify.c -- ultra minimal session manager
- *
- *  Copyright (C) 2018 Karl Linden <karl.j.linden@gmail.com>
- *  Copyright (C) 2010 Torben Hohn.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-#include <alloca.h>
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <string.h>
-#include <jack/jack.h>
-#include <jack/jslist.h>
-#include <jack/transport.h>
-#include <jack/session.h>
-
-char *package;				/* program name */
-jack_client_t *client;
-
-jack_session_event_type_t notify_type;
-char *save_path = NULL;
-
-void jack_shutdown(void *arg)
-{
-	fprintf(stderr, "JACK shut down, exiting ...\n");
-	exit(1);
-}
-
-void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-void parse_arguments(int argc, char *argv[])
-{
-
-	/* basename $0 */
-	package = strrchr(argv[0], '/');
-	if (package == 0)
-		package = argv[0];
-	else
-		package++;
-
-	if (argc==2) {
-		if( !strcmp( argv[1], "quit" ) ) {
-			notify_type = JackSessionSaveAndQuit;
-			return;
-		}
-	}
-	if (argc==3) {
-		if( !strcmp( argv[1], "save" ) ) {
-			notify_type = JackSessionSave;
-			save_path = argv[2];
-			return;
-		}
-
-	}
-	fprintf(stderr, "usage: %s quit|save [path]\n", package);
-	exit(9);
-}
-
-typedef struct {
-	char name[32];
-	char uuid[16];
-} uuid_map_t;
-
-JSList *uuid_map = NULL;
-
-void add_uuid_mapping( const char *uuid ) {
-	char *clientname = jack_get_client_name_by_uuid( client, uuid );
-	if( !clientname ) {
-		printf( "error... can not find client for uuid" );
-		return;
-	}
-
-	uuid_map_t *mapping = malloc( sizeof(uuid_map_t) );
-	snprintf( mapping->uuid, sizeof(mapping->uuid), "%s", uuid );
-	snprintf( mapping->name, sizeof(mapping->name), "%s", clientname );
-	uuid_map = jack_slist_append( uuid_map, mapping );
-}
-
-char *map_port_name_to_uuid_port( const char *port_name )
-{
-	JSList *node;
-	char retval[300];
-	char *port_component = strchr( port_name,':' );
-	char *client_component = strdup( port_name );
-	strchr( client_component, ':' )[0] = '\0';
-
-	sprintf( retval, "%s", port_name );
-
-	for( node=uuid_map; node; node=jack_slist_next(node) ) {
-		uuid_map_t *mapping = node->data;
-		if( !strcmp( mapping->name, client_component ) ) {
-			sprintf( retval, "%s%s", mapping->uuid, port_component );
-			break;
-		}
-	}
-
-	return strdup(retval);
-}
-
-int main(int argc, char *argv[])
-{
-	parse_arguments(argc, argv);
-	jack_session_command_t *retval;
-	int k,i,j;
-
-
-	/* become a JACK client */
-	if ((client = jack_client_open(package, JackNullOption, NULL)) == 0) {
-		fprintf(stderr, "JACK server not running?\n");
-		exit(1);
-	}
-
-#ifndef WIN32
-	signal(SIGQUIT, signal_handler);
-	signal(SIGHUP, signal_handler);
-#endif
-
-	signal(SIGTERM, signal_handler);
-	signal(SIGINT, signal_handler);
-
-	jack_on_shutdown(client, jack_shutdown, 0);
-
-	jack_activate(client);
-
-
-	retval = jack_session_notify( client, NULL, notify_type, save_path );
-	for (i = 0; retval[i].uuid; i++) {
-		printf( "export SESSION_DIR=\"%s%s/\"\n", save_path, retval[i].client_name );
-		printf( "%s &\n", retval[i].command );
-		add_uuid_mapping(retval[i].uuid);
-	}
-
-	printf( "sleep 10\n" );
-
-	for (k = 0; retval[k].uuid; k++) {
-
-		char* port_regexp = alloca( jack_client_name_size()+3 );
-		char* client_name = jack_get_client_name_by_uuid( client, retval[k].uuid );
-		snprintf( port_regexp, jack_client_name_size()+3, "%s:.*", client_name );
-		jack_free(client_name);
-		const char **ports = jack_get_ports( client, port_regexp, NULL, 0 );
-		if( !ports ) {
-			continue;
-		}
-		for (i = 0; ports[i]; ++i) {
-			const char **connections;
-			if ((connections = jack_port_get_all_connections (client, jack_port_by_name(client, ports[i]))) != 0) {
-				for (j = 0; connections[j]; j++) {
-					char *src = map_port_name_to_uuid_port( ports[i] );
-					char *dst = map_port_name_to_uuid_port( connections[j] );
-					printf( "jack_connect -u \"%s\" \"%s\"\n", src, dst );
-				}
-				jack_free (connections);
-			}
-		}
-		jack_free(ports);
-
-	}
-	jack_session_commands_free(retval);
-
-	jack_client_close(client);
-
-	return 0;
-}
diff -pruN 1.9.14~dfsg-1/example-clients/transport.c 1.9.16~dfsg-1/example-clients/transport.c
--- 1.9.14~dfsg-1/example-clients/transport.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/transport.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,508 +0,0 @@
-/*
- *  transport.c -- JACK transport master example client.
- *
- *  Copyright (C) 2003 Jack O'Quin.
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <signal.h>
-#include <stdlib.h>
-#include <string.h>
-#if HAVE_READLINE
-#include <readline/readline.h>
-#include <readline/history.h>
-#endif
-#include <jack/jack.h>
-#include <jack/transport.h>
-
-/* Use a copy of the readline macro whitespace if it does not exist.
- * Not all readline compatible libraries supply the whitespace macro
- * (libedit for example), so pull in the copy in those cases too. */
-#if !HAVE_READLINE || !defined(whitespace)
-#define whitespace(c) (((c) == ' ') || ((c) == '\t'))
-#endif
-
-char *package;				/* program name */
-int done = 0;
-jack_client_t *client;
-
-/* Time and tempo variables.  These are global to the entire,
- * transport timeline.  There is no attempt to keep a true tempo map.
- * The default time signature is: "march time", 4/4, 120bpm
- */
-float time_beats_per_bar = 4.0;
-float time_beat_type = 4.0;
-double time_ticks_per_beat = 1920.0;
-double time_beats_per_minute = 120.0;
-volatile int time_reset = 1;		/* true when time values change */
-
-/* JACK timebase callback.
- *
- * Runs in the process thread.  Realtime, must not wait.
- */
-static void timebase(jack_transport_state_t state, jack_nframes_t nframes,
-	      jack_position_t *pos, int new_pos, void *arg)
-{
-	double min;			/* minutes since frame 0 */
-	long abs_tick;			/* ticks since frame 0 */
-	long abs_beat;			/* beats since frame 0 */
-
-	if (new_pos || time_reset) {
-
-		pos->valid = JackPositionBBT;
-		pos->beats_per_bar = time_beats_per_bar;
-		pos->beat_type = time_beat_type;
-		pos->ticks_per_beat = time_ticks_per_beat;
-		pos->beats_per_minute = time_beats_per_minute;
-
-		time_reset = 0;		/* time change complete */
-
-		/* Compute BBT info from frame number.  This is relatively
-		 * simple here, but would become complex if we supported tempo
-		 * or time signature changes at specific locations in the
-		 * transport timeline. */
-
-		min = pos->frame / ((double) pos->frame_rate * 60.0);
-		abs_tick = min * pos->beats_per_minute * pos->ticks_per_beat;
-		abs_beat = abs_tick / pos->ticks_per_beat;
-
-		pos->bar = abs_beat / pos->beats_per_bar;
-		pos->beat = abs_beat - (pos->bar * pos->beats_per_bar) + 1;
-		pos->tick = abs_tick - (abs_beat * pos->ticks_per_beat);
-		pos->bar_start_tick = pos->bar * pos->beats_per_bar *
-			pos->ticks_per_beat;
-		pos->bar++;		/* adjust start to bar 1 */
-
-#if 0
-		/* some debug code... */
-		fprintf(stderr, "\nnew position: %" PRIu32 "\tBBT: %3"
-			PRIi32 "|%" PRIi32 "|%04" PRIi32 "\n",
-			pos->frame, pos->bar, pos->beat, pos->tick);
-#endif
-
-	} else {
-
-		/* Compute BBT info based on previous period. */
-		pos->tick +=
-			nframes * pos->ticks_per_beat * pos->beats_per_minute
-			/ (pos->frame_rate * 60);
-
-		while (pos->tick >= pos->ticks_per_beat) {
-			pos->tick -= pos->ticks_per_beat;
-			if (++pos->beat > pos->beats_per_bar) {
-				pos->beat = 1;
-				++pos->bar;
-				pos->bar_start_tick +=
-					pos->beats_per_bar
-					* pos->ticks_per_beat;
-			}
-		}
-	}
-}
-
-static void jack_shutdown(void *arg)
-{
-#if defined(RL_READLINE_VERSION) && RL_READLINE_VERSION >= 0x0400
-	rl_cleanup_after_signal();
-#endif
-	fprintf(stderr, "JACK shut down, exiting ...\n");
-	exit(1);
-}
-
-static void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-/* Command functions: see commands[] table following. */
-
-static void com_activate(char *arg)
-{
-	if (jack_activate(client)) {
-		fprintf(stderr, "cannot activate client");
-	}
-}
-
-static void com_deactivate(char *arg)
-{
-	if (jack_deactivate(client)) {
-		fprintf(stderr, "cannot deactivate client");
-	}
-}
-
-static void com_exit(char *arg)
-{
-	done = 1;
-}
-
-static void com_help(char *);			/* forward declaration */
-
-static void com_locate(char *arg)
-{
-	jack_nframes_t frame = 0;
-
-	if (*arg != '\0')
-		frame = atoi(arg);
-
-	jack_transport_locate(client, frame);
-}
-
-static void com_master(char *arg)
-{
-	int cond = (*arg != '\0');
-	if (jack_set_timebase_callback(client, cond, timebase, NULL) != 0)
-		fprintf(stderr, "Unable to take over timebase.\n");
-}
-
-static void com_play(char *arg)
-{
-	jack_transport_start(client);
-}
-
-static void com_release(char *arg)
-{
-	jack_release_timebase(client);
-}
-
-static void com_stop(char *arg)
-{
-	jack_transport_stop(client);
-}
-
-/* Change the tempo for the entire timeline, not just from the current
- * location. */
-static void com_tempo(char *arg)
-{
-	float tempo = 120.0;
-
-	if (*arg != '\0')
-		tempo = atof(arg);
-
-	time_beats_per_minute = tempo;
-	time_reset = 1;
-}
-
-/* Set sync timeout in seconds. */
-static void com_timeout(char *arg)
-{
-	double timeout = 2.0;
-
-	if (*arg != '\0')
-		timeout = atof(arg);
-
-	jack_set_sync_timeout(client, (jack_time_t) (timeout*1000000));
-}
-
-/* Toggle between play and stop state */
-static void com_toggle(char *arg)
-{
-	jack_position_t current;
-	jack_transport_state_t transport_state;
-
-	transport_state = jack_transport_query (client, &current);
-
-	switch (transport_state) {
-	case JackTransportStopped:
-		com_play( arg );
-		break;
-	case JackTransportRolling:
-		com_stop( arg );
-		break;
-	case JackTransportStarting:
-		fprintf(stderr, "state: Starting - no transport toggling");
-		break;
-	default:
-		fprintf(stderr, "unexpected state: no transport toggling");
-	}
-}
-
-
-/* Command parsing based on GNU readline info examples. */
-
-typedef void cmd_function_t(char *);	/* command function type */
-
-/* Transport command table. */
-typedef struct {
-	char *name;			/* user printable name */
-	cmd_function_t *func;		/* function to call */
-	char *doc;			/* documentation  */
-} command_t;
-
-/* command table must be in alphabetical order */
-command_t commands[] = {
-	{"activate",	com_activate,	"Call jack_activate()"},
-	{"exit",	com_exit,	"Exit transport program"},
-	{"deactivate",	com_deactivate,	"Call jack_deactivate()"},
-	{"help",	com_help,	"Display help text [<command>]"},
-	{"locate",	com_locate,	"Locate to frame <position>"},
-	{"master",	com_master,	"Become timebase master "
-					"[<conditionally>]"},
-	{"play",	com_play,	"Start transport rolling"},
-	{"quit",	com_exit,	"Synonym for `exit'"},
-	{"release",	com_release,	"Release timebase"},
-	{"stop",	com_stop,	"Stop transport"},
-	{"tempo",	com_tempo,	"Set beat tempo <beats_per_min>"},
-	{"timeout",	com_timeout,	"Set sync timeout in <seconds>"},
-	{"toggle",	com_toggle,	"Toggle transport rolling"},
-	{"?",		com_help,	"Synonym for `help'" },
-	{(char *)NULL, (cmd_function_t *)NULL, (char *)NULL }
-};
-
-static command_t *find_command(char *name)
-{
-	register int i;
-	size_t namelen;
-
-	if ((name == NULL) || (*name == '\0'))
-		return ((command_t *)NULL);
-
-	namelen = strlen(name);
-	for (i = 0; commands[i].name; i++)
-		if (strncmp(name, commands[i].name, namelen) == 0) {
-
-			/* make sure the match is unique */
-			if ((commands[i+1].name) &&
-			    (strncmp(name, commands[i+1].name, namelen) == 0))
-				return ((command_t *)NULL);
-			else
-				return (&commands[i]);
-		}
-
-	return ((command_t *)NULL);
-}
-
-static void com_help(char *arg)
-{
-	register int i;
-	command_t *cmd;
-
-	if (!*arg) {
-		/* print help for all commands */
-		for (i = 0; commands[i].name; i++) {
-			printf("%s\t\t%s.\n", commands[i].name,
-			       commands[i].doc);
-		}
-
-	} else if ((cmd = find_command(arg))) {
-		printf("%s\t\t%s.\n", cmd->name, cmd->doc);
-
-	} else {
-		int printed = 0;
-
-		printf("No `%s' command.  Valid command names are:\n", arg);
-
-		for (i = 0; commands[i].name; i++) {
-			/* Print in six columns. */
-			if (printed == 6) {
-				printed = 0;
-				printf ("\n");
-			}
-
-			printf ("%s\t", commands[i].name);
-			printed++;
-		}
-
-		printf("\n\nTry `help [command]\' for more information.\n");
-	}
-}
-
-static void execute_command(char *line)
-{
-	register int i;
-	command_t *command;
-	char *word;
-
-	/* Isolate the command word. */
-	i = 0;
-	while (line[i] && whitespace(line[i]))
-		i++;
-	word = line + i;
-
-	while (line[i] && !whitespace(line[i]))
-		i++;
-
-	if (line[i])
-		line[i++] = '\0';
-
-	command = find_command(word);
-
-	if (!command) {
-		fprintf(stderr, "%s: No such command.  There is `help\'.\n",
-			word);
-		return;
-	}
-
-	/* Get argument to command, if any. */
-	while (whitespace(line[i]))
-		i++;
-
-	word = line + i;
-
-	/* invoke the command function. */
-	(*command->func)(word);
-}
-
-
-/* Strip whitespace from the start and end of string. */
-static char *stripwhite(char *string)
-{
-	register char *s, *t;
-
-	s = string;
-	while (whitespace(*s))
-		s++;
-
-	if (*s == '\0')
-		return s;
-
-	t = s + strlen (s) - 1;
-	while (t > s && whitespace(*t))
-		t--;
-	*++t = '\0';
-
-	return s;
-}
-
-static char *dupstr(char *s)
-{
-	char *r = malloc(strlen(s) + 1);
-	strcpy(r, s);
-	return r;
-}
-
-/* Readline generator function for command completion. */
-static char *command_generator (const char *text, int state)
-{
-	static int list_index, len;
-	char *name;
-
-	/* If this is a new word to complete, initialize now.  This
-	   includes saving the length of TEXT for efficiency, and
-	   initializing the index variable to 0. */
-	if (!state) {
-		list_index = 0;
-		len = strlen (text);
-	}
-
-	/* Return the next name which partially matches from the
-	   command list. */
-	while ((name = commands[list_index].name)) {
-		list_index++;
-
-		if (strncmp(name, text, len) == 0)
-			return dupstr(name);
-	}
-
-	return (char *) NULL;		/* No names matched. */
-}
-
-static void command_loop()
-{
-#if HAVE_READLINE
-	char *line, *cmd;
-	char prompt[32];
-
-	snprintf(prompt, sizeof(prompt), "%s> ", package);
-
-	/* Allow conditional parsing of the ~/.inputrc file. */
-	rl_readline_name = package;
-
-	/* Define a custom completion function. */
-	rl_completion_entry_function = command_generator;
-#else
-	char line[64] = {0,};
-	char *cmd = NULL;
-#endif
-
-	/* Read and execute commands until the user quits. */
-	while (!done) {
-
-#if HAVE_READLINE
-		line = readline(prompt);
-
-		if (line == NULL) {	/* EOF? */
-			printf("\n");	/* close out prompt */
-			done = 1;
-			break;
-		}
-#else
-		printf("%s> ", package);
-		fgets(line, sizeof(line), stdin);
-		line[strlen(line)-1] = '\0';
-#endif
-
-		/* Remove leading and trailing whitespace from the line. */
-		cmd = stripwhite(line);
-
-		/* If anything left, add to history and execute it. */
-		if (*cmd)
-		{
-#if HAVE_READLINE
-			add_history(cmd);
-#endif
-			execute_command(cmd);
-		}
-
-#if HAVE_READLINE
-		free(line);		/* realine() called malloc() */
-#endif
-	}
-}
-
-int main(int argc, char *argv[])
-{
-	jack_status_t status;
-
-	/* basename $0 */
-	package = strrchr(argv[0], '/');
-	if (package == 0)
-		package = argv[0];
-	else
-		package++;
-
-	/* open a connection to the JACK server */
-	client = jack_client_open (package, JackNullOption, &status);
-	if (client == NULL) {
-		fprintf (stderr, "jack_client_open() failed, "
-			 "status = 0x%2.0x\n", status);
-		return 1;
-	}
-
-#if !WIN32
-	signal(SIGQUIT, signal_handler);
-	signal(SIGHUP, signal_handler);
-#endif
-	signal(SIGTERM, signal_handler);
-	signal(SIGINT, signal_handler);
-
-	jack_on_shutdown(client, jack_shutdown, 0);
-
-	if (jack_activate(client)) {
-		fprintf(stderr, "cannot activate client");
-		return 1;
-	}
-
-	/* execute commands until done */
-	command_loop();
-
-	jack_client_close(client);
-	exit(0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/tw.c 1.9.16~dfsg-1/example-clients/tw.c
--- 1.9.14~dfsg-1/example-clients/tw.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/tw.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,264 +0,0 @@
-/** @file tw.c
- *
- * @brief This simple client demonstrates the basic features of JACK
- * as they would be used by many applications.
- */
-
-#include <stdio.h>
-#include <errno.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <string.h>
-#include <signal.h>
-
-#include <jack/jack.h>
-
-jack_port_t *input_port;
-jack_port_t *output_port;
-jack_client_t *client;
-
-/* a simple state machine for this client */
-volatile enum {
-	Init,
-	Run,
-	Exit
-} client_state = Init;
-
-static void signal_handler(int sig)
-{
-	jack_client_close(client);
-	fprintf(stderr, "signal received, exiting ...\n");
-	exit(0);
-}
-
-/**
- * The process callback for this JACK application is called in a
- * special realtime thread once for each audio cycle.
- *
- * This client follows a simple rule: when the JACK transport is
- * running, copy the input port to the output.  When it stops, exit.
- */
-static int
-_process (jack_nframes_t nframes)
-{
-	jack_default_audio_sample_t *in, *out;
-	jack_transport_state_t ts = jack_transport_query(client, NULL);
-
-	if (ts == JackTransportRolling) {
-
-		if (client_state == Init)
-			client_state = Run;
-
-		in = jack_port_get_buffer (input_port, nframes);
-		out = jack_port_get_buffer (output_port, nframes);
-		memcpy (out, in,
-			sizeof (jack_default_audio_sample_t) * nframes);
-
-	} else if (ts == JackTransportStopped) {
-
-		if (client_state == Run) {
-			client_state = Exit;
-			return -1;  // to stop the thread
-		}
-	}
-
-	return 0;
-}
-
-static void* jack_thread(void *arg)
-{
-	jack_client_t* client = (jack_client_t*) arg;
-
-	while (1) {
-
-		jack_nframes_t frames = jack_cycle_wait (client);
-		int status = _process(frames);
-		jack_cycle_signal (client, status);
-
-        /*
-            Possibly do something else after signaling next clients in the graph
-        */
-
-        /* End condition */
-        if (status != 0)
-            return 0;
-	}
-
-    /* not reached*/
-	return 0;
-}
-
-/*
-static void* jack_thread(void *arg)
-{
-	jack_client_t* client = (jack_client_t*) arg;
-
-	while (1) {
-		jack_nframes_t frames;
-		int status;
-		// cycle 1
-		frames = jack_cycle_wait (client);
-		status = _process(frames);
-		jack_cycle_signal (client, status);
-		// cycle 2
-		frames = jack_cycle_wait (client);
-		status = _process(frames);
-		jack_cycle_signal (client, status);
-		// cycle 3
-		frames = jack_cycle_wait (client);
-		status = _process(frames);
-		jack_cycle_signal (client, status);
-		// cycle 4
-		frames = jack_cycle_wait (client);
-		status = _process(frames);
-		jack_cycle_signal (client, status);
-	}
-
-	return 0;
-}
-*/
-
-/**
- * JACK calls this shutdown_callback if the server ever shuts down or
- * decides to disconnect the client.
- */
-static void
-jack_shutdown (void *arg)
-{
-    fprintf(stderr, "JACK shut down, exiting ...\n");
-	exit (1);
-}
-
-int
-main (int argc, char *argv[])
-{
-	const char **ports;
-	const char *client_name;
-	const char *server_name = NULL;
-	jack_options_t options = JackNullOption;
-	jack_status_t status;
-
-	if (argc >= 2) {		/* client name specified? */
-		client_name = argv[1];
-		if (argc >= 3) {	/* server name specified? */
-			server_name = argv[2];
-			options |= JackServerName;
-		}
-	} else {			/* use basename of argv[0] */
-		client_name = strrchr(argv[0], '/');
-		if (client_name == 0) {
-			client_name = argv[0];
-		} else {
-			client_name++;
-		}
-	}
-
-	/* open a client connection to the JACK server */
-
-	client = jack_client_open (client_name, options, &status, server_name);
-	if (client == NULL) {
-		fprintf (stderr, "jack_client_open() failed, "
-			 "status = 0x%2.0x\n", status);
-		if (status & JackServerFailed) {
-			fprintf (stderr, "Unable to connect to JACK server\n");
-		}
-		exit (1);
-	}
-	if (status & JackServerStarted) {
-		fprintf (stderr, "JACK server started\n");
-	}
-	if (status & JackNameNotUnique) {
-		client_name = jack_get_client_name(client);
-		fprintf (stderr, "unique name `%s' assigned\n", client_name);
-	}
-
-	/* tell the JACK server to call `process()' whenever
-	   there is work to be done.
-	*/
-    if (jack_set_process_thread(client, jack_thread, client) < 0)
-		exit(1);
-
-	/* tell the JACK server to call `jack_shutdown()' if
-	   it ever shuts down, either entirely, or if it
-	   just decides to stop calling us.
-	*/
-
-	jack_on_shutdown (client, jack_shutdown, 0);
-
-	/* display the current sample rate.
-	 */
-
-	printf ("engine sample rate: %" PRIu32 "\n",
-		jack_get_sample_rate (client));
-
-	/* create two ports */
-
-	input_port = jack_port_register (client, "input",
-					 JACK_DEFAULT_AUDIO_TYPE,
-					 JackPortIsInput, 0);
-	output_port = jack_port_register (client, "output",
-					  JACK_DEFAULT_AUDIO_TYPE,
-					  JackPortIsOutput, 0);
-
-	if ((input_port == NULL) || (output_port == NULL)) {
-		fprintf(stderr, "no more JACK ports available\n");
-		exit (1);
-	}
-
-	/* Tell the JACK server that we are ready to roll.  Our
-	 * process() callback will start running now. */
-
-	if (jack_activate (client)) {
-		fprintf (stderr, "cannot activate client");
-		exit (1);
-	}
-
-	/* Connect the ports.  You can't do this before the client is
-	 * activated, because we can't make connections to clients
-	 * that aren't running.  Note the confusing (but necessary)
-	 * orientation of the driver backend ports: playback ports are
-	 * "input" to the backend, and capture ports are "output" from
-	 * it.
-	 */
-
-	ports = jack_get_ports (client, NULL, NULL,
-				JackPortIsPhysical|JackPortIsOutput);
-	if (ports == NULL) {
-		fprintf(stderr, "no physical capture ports\n");
-		exit (1);
-	}
-
-	if (jack_connect (client, ports[0], jack_port_name (input_port))) {
-		fprintf (stderr, "cannot connect input ports\n");
-	}
-
-	jack_free (ports);
-
-	ports = jack_get_ports (client, NULL, NULL,
-				JackPortIsPhysical|JackPortIsInput);
-	if (ports == NULL) {
-		fprintf(stderr, "no physical playback ports\n");
-		exit (1);
-	}
-
-	if (jack_connect (client, jack_port_name (output_port), ports[0])) {
-		fprintf (stderr, "cannot connect output ports\n");
-	}
-
-	jack_free (ports);
-
-    /* install a signal handler to properly quits jack client */
-    signal(SIGQUIT, signal_handler);
-	signal(SIGTERM, signal_handler);
-	signal(SIGHUP, signal_handler);
-	signal(SIGINT, signal_handler);
-
-	/* keep running until the transport stops */
-
-	while (client_state != Exit) {
-		sleep (1);
-	}
-
-	jack_client_close (client);
-	exit (0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/wait.c 1.9.16~dfsg-1/example-clients/wait.c
--- 1.9.14~dfsg-1/example-clients/wait.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/wait.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,140 +0,0 @@
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <string.h>
-#include <getopt.h>
-
-#include <time.h>
-
-#include <jack/jack.h>
-
-char * my_name;
-
-void
-show_usage(void)
-{
-	fprintf(stderr, "\nUsage: %s [options]\n", my_name);
-	fprintf(stderr, "Check for jack existence, or wait, until it either quits, or gets started\n");
-	fprintf(stderr, "options:\n");
-	fprintf(stderr, "        -s, --server <name>   Connect to the jack server named <name>\n");
-	fprintf(stderr, "        -w, --wait            Wait for server to become available\n");
-	fprintf(stderr, "        -q, --quit            Wait until server is quit\n");
-	fprintf(stderr, "        -c, --check           Check whether server is running\n");
-	fprintf(stderr, "        -t, --timeout         Wait timeout in seconds\n");
-	fprintf(stderr, "        -h, --help            Display this help message\n");
-	fprintf(stderr, "For more information see http://jackaudio.org/\n");
-}
-
-int
-main(int argc, char *argv[])
-{
-	jack_client_t *client;
-	jack_status_t status;
-	jack_options_t options = JackNoStartServer;
-	int c;
-	int option_index;
-	char *server_name = NULL;
-	int wait_for_start = 0;
-	int wait_for_quit = 0;
-	int just_check = 0;
-	int wait_timeout = 0;
-	time_t start_timestamp;
-
-
-	struct option long_options[] = {
-		{ "server", 1, 0, 's' },
-		{ "wait", 0, 0, 'w' },
-		{ "quit", 0, 0, 'q' },
-		{ "check", 0, 0, 'c' },
-		{ "timeout", 1, 0, 't' },
-		{ "help", 0, 0, 'h' },
-		{ 0, 0, 0, 0 }
-	};
-
-	my_name = strrchr(argv[0], '/');
-	if (my_name == 0) {
-		my_name = argv[0];
-	} else {
-		my_name ++;
-	}
-
-	while ((c = getopt_long (argc, argv, "s:wqct:hv", long_options, &option_index)) >= 0) {
-		switch (c) {
-		case 's':
-			server_name = (char *) malloc (sizeof (char) * strlen(optarg));
-			strcpy (server_name, optarg);
-			options |= JackServerName;
-			break;
-		case 'w':
-			wait_for_start = 1;
-			break;
-		case 'q':
-			wait_for_quit = 1;
-			break;
-		case 'c':
-			just_check = 1;
-			break;
-		case 't':
-			wait_timeout = atoi(optarg);
-			break;
-		case 'h':
-			show_usage();
-			return 1;
-			break;
-		default:
-			show_usage();
-			return 1;
-			break;
-		}
-	}
-
-	/* try to open server in a loop. breaking under certein conditions */
-
-	start_timestamp = time(NULL);
-
-	while (1) {
-		client = jack_client_open ("wait", options, &status, server_name);
-		/* check for some real error and bail out */
-		if ((client == NULL) && !(status & JackServerFailed)) {
-			fprintf (stderr, "jack_client_open() failed, "
-					"status = 0x%2.0x\n", status);
-			return 1;
-		}
-
-		if (client == NULL) {
-			if (wait_for_quit) {
-				fprintf(stdout, "server is gone\n");
-				break;
-			}
-			if (just_check) {
-				fprintf(stdout, "not running\n");
-				break;
-			}
-		} else {
-			jack_client_close(client);
-			if (wait_for_start) {
-				fprintf(stdout, "server is available\n");
-				break;
-			}
-			if (just_check) {
-				fprintf(stdout, "running\n");
-				break;
-			}
-		}
-		if (wait_timeout) {
-			if ((time(NULL) - start_timestamp) > wait_timeout) {
-				fprintf(stdout, "timeout\n");
-				exit(EXIT_FAILURE);
-			}
-		}
-
-		// Wait a second, and repeat
-#ifdef WIN32
-		Sleep(1*1000);
-#else
-		sleep(1);
-#endif
-	}
-
-	exit(0);
-}
diff -pruN 1.9.14~dfsg-1/example-clients/wscript 1.9.16~dfsg-1/example-clients/wscript
--- 1.9.14~dfsg-1/example-clients/wscript	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/example-clients/wscript	2020-10-16 19:10:40.000000000 +0000
@@ -2,35 +2,21 @@
 # encoding: utf-8
 
 example_programs = {
-    'jack_freewheel' : 'freewheel.c',
-    'jack_connect' : 'connect.c',
-    'jack_lsp' : 'lsp.c',
+    'jack_cpu_load' : 'cpu_load.c',
+    'jack_latent_client' : 'latent_client.c',
     'jack_metro' : 'metro.c',
+    'jack_midi_latency_test' : 'midi_latency_test.c',
     'jack_midiseq' : 'midiseq.c',
     'jack_midisine' : 'midisine.c',
+    'jack_net_master' : 'netmaster.c',
+    'jack_net_slave' : 'netslave.c',
+    'jack_server_control' : 'server_control.cpp',
     'jack_showtime' : 'showtime.c',
+    'jack_simdtests' : 'simdtests.cpp',
     'jack_simple_client' : 'simple_client.c',
-    'jack_zombie' : 'zombie.c',
-    'jack_load' : 'ipload.c',
-    'jack_unload' : 'ipunload.c',
-    'jack_alias' : 'alias.c',
-    'jack_bufsize' : 'bufsize.c',
-    'jack_wait' : 'wait.c',
-    'jack_samplerate' : 'samplerate.c',
-    'jack_evmon' : 'evmon.c',
-    'jack_monitor_client' : 'monitor_client.c',
-    'jack_thru' : 'thru_client.c',
-    'jack_cpu_load' : 'cpu_load.c',
     'jack_simple_session_client' : 'simple_session_client.c',
-    'jack_session_notify' : 'session_notify.c',
-    'jack_server_control' : 'server_control.cpp',
-    'jack_net_slave' : 'netslave.c',
-    'jack_net_master' : 'netmaster.c',
-    'jack_latent_client' : 'latent_client.c',
-    'jack_midi_dump' : 'midi_dump.c',
-    'jack_midi_latency_test' : 'midi_latency_test.c',
-    'jack_simdtests' : 'simdtests.cpp',
-    'jack_property' : 'property.c',
+    'jack_thru' : 'thru_client.c',
+    'jack_zombie' : 'zombie.c',
     }
 
 example_libs = {
@@ -38,12 +24,8 @@ example_libs = {
     }
 
 def configure(conf):
-    conf.env['BUILD_EXAMPLE_CLIENT_TRANSPORT'] = conf.env['READLINE']
-
     conf.env['BUILD_EXAMPLE_CLIENT_REC'] = conf.env['SNDFILE']
 
-    conf.env['BUILD_EXAMPLE_ALSA_IO'] = conf.env['SAMPLERATE'] and conf.env['BUILD_DRIVER_ALSA']
-
 def build(bld):
     if bld.env['IS_LINUX']:
         os_incdir = ['../linux', '../posix']
@@ -78,24 +60,13 @@ def build(bld):
             prog.use += ['RT', 'M']
         if bld.env['IS_SUN']:
             prog.use += ['M']
+        if bld.env['IS_WINDOWS'] and bld.env['BUILD_STATIC']:
+            prog.env['LIB_PTHREAD'] = [':libwinpthread.a']
         #prog.cflags = ['-Wno-deprecated-declarations', '-Wno-misleading-indentation']
         #prog.cxxflags = ['-Wno-deprecated-declarations', '-Wno-misleading-indentation']
 
         prog.target = example_program
 
-    if bld.env['BUILD_EXAMPLE_CLIENT_TRANSPORT']:
-        prog = bld(features = 'c cprogram')
-        prog.includes = os_incdir + ['../common/jack', '../common']
-        prog.source = 'transport.c'
-        prog.use = ['clientlib']
-        if bld.env['IS_LINUX']:
-            prog.use += ['RT', 'READLINE']
-        if bld.env['IS_MACOSX']:
-            prog.use += ['READLINE']
-        if bld.env['IS_WINDOWS']:
-            prog.use += ['READLINE']
-        prog.target = 'jack_transport'
-
     if bld.env['BUILD_EXAMPLE_CLIENT_REC']:
         prog = bld(features = 'c cprogram')
         prog.includes = os_incdir + ['../common/jack', '../common']
@@ -109,32 +80,10 @@ def build(bld):
             prog.use += ['RT', 'SNDFILE']
         if bld.env['IS_WINDOWS']:
             prog.uselib = ['SNDFILE']
+            if bld.env['BUILD_STATIC']:
+                prog.env['LIB_PTHREAD'] = [':libwinpthread.a']
         prog.target = 'jack_rec'
 
-    if bld.env['IS_LINUX'] or bld.env['IS_MACOSX']:
-        prog = bld(features = 'c cprogram')
-        prog.includes = os_incdir + ['.', '..', '../common/jack', '../common']
-        prog.source = ['netsource.c', '../common/netjack_packet.c']
-        prog.env.append_value('CFLAGS', '-DNO_JACK_ERROR')
-        prog.use = ['CELT', 'SAMPLERATE', 'OPUS', 'M', 'clientlib']
-        prog.target = 'jack_netsource'
-        prog.defines = ['HAVE_CONFIG_H']
-
-    if bld.env['IS_LINUX'] and bld.env['BUILD_EXAMPLE_ALSA_IO']:
-        prog = bld(features = 'c cprogram')
-        prog.includes = os_incdir + ['../common/jack', '../common']
-        prog.source = ['alsa_in.c', '../common/memops.c']
-        prog.env.append_value('CFLAGS', '-DNO_JACK_ERROR')
-        prog.use = ['clientlib', 'ALSA', 'SAMPLERATE', 'M']
-        prog.target = 'alsa_in'
-
-        prog = bld(features = 'c cprogram')
-        prog.includes = os_incdir + ['../common/jack', '../common']
-        prog.source = ['alsa_out.c', '../common/memops.c']
-        prog.env.append_value('CFLAGS', '-DNO_JACK_ERROR')
-        prog.use = ['clientlib', 'ALSA', 'SAMPLERATE', 'M']
-        prog.target = 'alsa_out'
-
     for example_lib, example_lib_source in list(example_libs.items()):
         lib = bld(features = 'c cshlib')
         if not bld.env['IS_WINDOWS']:
@@ -144,9 +93,7 @@ def build(bld):
         lib.source = example_lib_source
         if bld.env['IS_SUN']:
             lib.env.append_value('LINKFLAGS', '-lm')
+        if bld.env['IS_WINDOWS'] and bld.env['BUILD_STATIC']:
+            prog.env['LIB_PTHREAD'] = [':libwinpthread.a']
         lib.use = 'serverlib'
         lib.install_path = '${ADDON_DIR}/'
-
-    if not bld.env['IS_WINDOWS']:
-        bld.symlink_as('${PREFIX}/bin/jack_disconnect', 'jack_connect')
-        bld.install_files('${PREFIX}/bin', 'jack_control', chmod=0o755)
diff -pruN 1.9.14~dfsg-1/.gitignore 1.9.16~dfsg-1/.gitignore
--- 1.9.14~dfsg-1/.gitignore	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/.gitignore	2020-10-16 19:10:40.000000000 +0000
@@ -1,8 +1,21 @@
 build/
 man/*.1
 .lock*
+.stamp_*
+.DS_Store
 __pycache__
+*.dll
 *.pyc
+*.pkg
 android/.server/
 android/.client/
 codeBlocks
+
+# macos release files
+macos/package.xml
+macos/package-welcome.txt
+
+# windows release files
+windows/inno/version.iss
+windows/inno/win32
+windows/inno/win64
diff -pruN 1.9.14~dfsg-1/jack.pc.in 1.9.16~dfsg-1/jack.pc.in
--- 1.9.14~dfsg-1/jack.pc.in	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/jack.pc.in	2020-10-16 19:10:40.000000000 +0000
@@ -7,5 +7,5 @@ server_libs=-L@LIBDIR@ -l@SERVERLIB@
 Name: jack
 Description: the Jack Audio Connection Kit: a low-latency synchronous callback-based media server
 Version: @JACK_VERSION@
-Libs: -L@LIBDIR@ -ljack
+Libs: -L@LIBDIR@ -l@CLIENTLIB@
 Cflags: -I@INCLUDEDIR@
diff -pruN 1.9.14~dfsg-1/linux/alsa/alsa_driver.c 1.9.16~dfsg-1/linux/alsa/alsa_driver.c
--- 1.9.14~dfsg-1/linux/alsa/alsa_driver.c	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/linux/alsa/alsa_driver.c	2020-10-16 19:10:40.000000000 +0000
@@ -755,8 +755,8 @@ alsa_driver_set_parameters (alsa_driver_
 		if (c_period_size != driver->frames_per_cycle) {
 			jack_error ("alsa_pcm: requested an interrupt every %"
 				    PRIu32
-				    " frames but got %uc frames for capture",
-				    driver->frames_per_cycle, p_period_size);
+				    " frames but got %u frames for capture",
+				    driver->frames_per_cycle, c_period_size);
 			return -1;
 		}
 	}
@@ -837,10 +837,8 @@ alsa_driver_set_parameters (alsa_driver_
 
 	if (driver->playback_nchannels > driver->capture_nchannels) {
 		driver->max_nchannels = driver->playback_nchannels;
-		driver->user_nchannels = driver->capture_nchannels;
 	} else {
 		driver->max_nchannels = driver->capture_nchannels;
-		driver->user_nchannels = driver->playback_nchannels;
 	}
 
 	alsa_driver_setup_io_function_pointers (driver);
@@ -1367,12 +1365,14 @@ alsa_driver_wait (alsa_driver_t *driver,
 		if (poll_result < 0) {
 
 			if (errno == EINTR) {
-				jack_info ("poll interrupt");
+				const char poll_log[] = "ALSA: poll interrupt";
 				// this happens mostly when run
 				// under gdb, or when exiting due to a signal
 				if (under_gdb) {
+					jack_info(poll_log);
 					goto again;
 				}
+				jack_error(poll_log);
 				*status = -2;
 				return 0;
 			}
@@ -1395,9 +1395,9 @@ alsa_driver_wait (alsa_driver_t *driver,
 				*status = -5;
 				return 0;
 			}
-			jack_log ("ALSA: poll time out, polled for %" PRIu64
-				  " usecs, Retrying with a recovery, retry cnt = %d",
-				  poll_ret - poll_enter, retry_cnt);
+			jack_error ("ALSA: poll time out, polled for %" PRIu64
+				    " usecs, Retrying with a recovery, retry cnt = %d",
+				    poll_ret - poll_enter, retry_cnt);
 			*status = alsa_driver_xrun_recovery (driver, delayed_usecs);
 			if(*status != 0) {
 				jack_error ("ALSA: poll time out, recovery failed with status = %d", *status);
@@ -2038,7 +2038,6 @@ alsa_driver_new (char *name, char *playb
 	driver->hw = 0;
 	driver->capture_and_playback_not_synced = FALSE;
 	driver->max_nchannels = 0;
-	driver->user_nchannels = 0;
 	driver->playback_nchannels = user_playback_nchnls;
 	driver->capture_nchannels = user_capture_nchnls;
 	driver->playback_sample_bytes = (shorts_first ? 2:4);
diff -pruN 1.9.14~dfsg-1/linux/alsa/alsa_driver.h 1.9.16~dfsg-1/linux/alsa/alsa_driver.h
--- 1.9.14~dfsg-1/linux/alsa/alsa_driver.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/linux/alsa/alsa_driver.h	2020-10-16 19:10:40.000000000 +0000
@@ -72,7 +72,6 @@ typedef struct _alsa_driver {
     unsigned long                *capture_interleave_skip;
     unsigned long                *playback_interleave_skip;
     channel_t                     max_nchannels;
-    channel_t                     user_nchannels;
     channel_t                     playback_nchannels;
     channel_t                     capture_nchannels;
     unsigned long                 playback_sample_bytes;
diff -pruN 1.9.14~dfsg-1/linux/alsa/JackAlsaAdapter.h 1.9.16~dfsg-1/linux/alsa/JackAlsaAdapter.h
--- 1.9.14~dfsg-1/linux/alsa/JackAlsaAdapter.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/linux/alsa/JackAlsaAdapter.h	2020-10-16 19:10:40.000000000 +0000
@@ -35,8 +35,8 @@ namespace Jack
 
     inline void* aligned_calloc ( size_t nmemb, size_t size ) { return ( void* ) calloc ( nmemb, size ); }
 
-#define max(x,y) (((x)>(y)) ? (x) : (y))
-#define min(x,y) (((x)<(y)) ? (x) : (y))
+#define jack_max(x,y) (((x)>(y)) ? (x) : (y))
+#define jack_min(x,y) (((x)<(y)) ? (x) : (y))
 
 #define check_error(err) if (err) { jack_error("%s:%d, alsa error %d : %s", __FILE__, __LINE__, err, snd_strerror(err)); return err; }
 #define check_error_msg(err,msg) if (err) { jack_error("%s:%d, %s : %s(%d)", __FILE__, __LINE__, msg, snd_strerror(err), err); return err; }
@@ -259,9 +259,9 @@ namespace Jack
                 }
 
                 //set floating point buffers needed by the dsp code
-                fSoftInputs = max ( fSoftInputs, fCardInputs );
+                fSoftInputs = jack_max ( fSoftInputs, fCardInputs );
                 assert ( fSoftInputs < 256 );
-                fSoftOutputs = max ( fSoftOutputs, fCardOutputs );
+                fSoftOutputs = jack_max ( fSoftOutputs, fCardOutputs );
                 assert ( fSoftOutputs < 256 );
 
                 for ( unsigned int i = 0; i < fSoftInputs; i++ )
@@ -447,7 +447,7 @@ namespace Jack
                                 for ( unsigned int c = 0; c < fCardOutputs; c++ )
                                 {
                                     jack_default_audio_sample_t x = fOutputSoftChannels[c][f];
-                                    buffer16b[c + f * fCardOutputs] = short(max(min (x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(SHRT_MAX));
+                                    buffer16b[c + f * fCardOutputs] = short(jack_max(jack_min (x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(SHRT_MAX));
                                 }
                             }
                         }
@@ -459,7 +459,7 @@ namespace Jack
                                 for ( unsigned int c = 0; c < fCardOutputs; c++ )
                                 {
                                     jack_default_audio_sample_t x = fOutputSoftChannels[c][f];
-                                    buffer32b[c + f * fCardOutputs] = int32_t(max(min(x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(INT_MAX));
+                                    buffer32b[c + f * fCardOutputs] = int32_t(jack_max(jack_min(x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(INT_MAX));
                                 }
                             }
                         }
@@ -481,7 +481,7 @@ namespace Jack
                                 for ( f = 0; f < fBuffering; f++ )
                                 {
                                     jack_default_audio_sample_t x = fOutputSoftChannels[c][f];
-                                    chan16b[f] = short(max(min (x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(SHRT_MAX));
+                                    chan16b[f] = short(jack_max(jack_min (x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(SHRT_MAX));
                                 }
                             }
                         }
@@ -493,7 +493,7 @@ namespace Jack
                                 for ( f = 0; f < fBuffering; f++ )
                                 {
                                     jack_default_audio_sample_t x = fOutputSoftChannels[c][f];
-                                    chan32b[f] = int32_t(max(min(x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(INT_MAX));
+                                    chan32b[f] = int32_t(jack_max(jack_min(x, jack_default_audio_sample_t(1.0)), jack_default_audio_sample_t(-1.0)) * jack_default_audio_sample_t(INT_MAX));
                                 }
                             }
                         }
diff -pruN 1.9.14~dfsg-1/linux/alsa/JackAlsaDriver.cpp 1.9.16~dfsg-1/linux/alsa/JackAlsaDriver.cpp
--- 1.9.14~dfsg-1/linux/alsa/JackAlsaDriver.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/linux/alsa/JackAlsaDriver.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -352,21 +352,22 @@ int JackAlsaDriver::Open(jack_nframes_t
                                capture_latency,
                                playback_latency,
                                midi);
-    if (fDriver) {
-        // ALSA driver may have changed the in/out values
-        fCaptureChannels = ((alsa_driver_t *)fDriver)->capture_nchannels;
-        fPlaybackChannels = ((alsa_driver_t *)fDriver)->playback_nchannels;
-        if (JackServerGlobals::on_device_reservation_loop != NULL) {
-            device_reservation_loop_running = true;
-            if (JackPosixThread::StartImp(&fReservationLoopThread, 0, 0, on_device_reservation_loop, NULL) != 0) {
-                device_reservation_loop_running = false;
-            }
-        }
-        return 0;
-    } else {
+    if (!fDriver) {
         Close();
         return -1;
     }
+
+    // ALSA driver may have changed the in/out values
+    fCaptureChannels = ((alsa_driver_t *)fDriver)->capture_nchannels;
+    fPlaybackChannels = ((alsa_driver_t *)fDriver)->playback_nchannels;
+    if (JackServerGlobals::on_device_reservation_loop != NULL) {
+        device_reservation_loop_running = true;
+        if (JackPosixThread::StartImp(&fReservationLoopThread, 0, 0, on_device_reservation_loop, NULL) != 0) {
+            device_reservation_loop_running = false;
+        }
+    }
+
+    return 0;
 }
 
 int JackAlsaDriver::Close()
diff -pruN 1.9.14~dfsg-1/macosx/coremidi/JackCoreMidiDriver.mm 1.9.16~dfsg-1/macosx/coremidi/JackCoreMidiDriver.mm
--- 1.9.14~dfsg-1/macosx/coremidi/JackCoreMidiDriver.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/coremidi/JackCoreMidiDriver.mm	2020-10-16 19:10:40.000000000 +0000
@@ -633,7 +633,7 @@ JackCoreMidiDriver::Start()
     jack_info("JackCoreMidiDriver::Start - Enabling physical input ports.");
 
     for (; pi_count < num_physical_inputs; pi_count++) {
-        if (physical_input_ports[pi_count]->Start() < 0) {
+        if (!physical_input_ports[pi_count]->Start()) {
             jack_error("JackCoreMidiDriver::Start - Failed to enable physical "
                        "input port.");
             goto stop_physical_input_ports;
@@ -643,7 +643,7 @@ JackCoreMidiDriver::Start()
     jack_info("JackCoreMidiDriver::Start - Enabling physical output ports.");
 
     for (; po_count < num_physical_outputs; po_count++) {
-        if (physical_output_ports[po_count]->Start() < 0) {
+        if (!physical_output_ports[po_count]->Start()) {
             jack_error("JackCoreMidiDriver::Start - Failed to enable physical "
                        "output port.");
             goto stop_physical_output_ports;
@@ -653,7 +653,7 @@ JackCoreMidiDriver::Start()
     jack_info("JackCoreMidiDriver::Start - Enabling virtual input ports.");
 
     for (; vi_count < num_virtual_inputs; vi_count++) {
-        if (virtual_input_ports[vi_count]->Start() < 0) {
+        if (!virtual_input_ports[vi_count]->Start()) {
             jack_error("JackCoreMidiDriver::Start - Failed to enable virtual "
                        "input port.");
             goto stop_virtual_input_ports;
@@ -663,7 +663,7 @@ JackCoreMidiDriver::Start()
     jack_info("JackCoreMidiDriver::Start - Enabling virtual output ports.");
 
     for (; vo_count < num_virtual_outputs; vo_count++) {
-        if (virtual_output_ports[vo_count]->Start() < 0) {
+        if (!virtual_output_ports[vo_count]->Start()) {
             jack_error("JackCoreMidiDriver::Start - Failed to enable virtual "
                        "output port.");
             goto stop_virtual_output_ports;
@@ -676,28 +676,28 @@ JackCoreMidiDriver::Start()
 
  stop_virtual_output_ports:
     for (int i = 0; i < vo_count; i++) {
-        if (virtual_output_ports[i]->Stop() < 0) {
+        if (!virtual_output_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Start - Failed to disable virtual "
                        "output port.");
         }
     }
  stop_virtual_input_ports:
     for (int i = 0; i < vi_count; i++) {
-        if (virtual_input_ports[i]->Stop() < 0) {
+        if (!virtual_input_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Start - Failed to disable virtual "
                        "input port.");
         }
     }
  stop_physical_output_ports:
     for (int i = 0; i < po_count; i++) {
-        if (physical_output_ports[i]->Stop() < 0) {
+        if (!physical_output_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Start - Failed to disable "
                        "physical output port.");
         }
     }
  stop_physical_input_ports:
     for (int i = 0; i < pi_count; i++) {
-        if (physical_input_ports[i]->Stop() < 0) {
+        if (!physical_input_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Start - Failed to disable "
                        "physical input port.");
         }
@@ -716,7 +716,7 @@ JackCoreMidiDriver::Stop()
     jack_info("JackCoreMidiDriver::Stop - disabling physical input ports.");
 
     for (int i = 0; i < num_physical_inputs; i++) {
-        if (physical_input_ports[i]->Stop() < 0) {
+        if (!physical_input_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Stop - Failed to disable physical "
                        "input port.");
             result = -1;
@@ -726,7 +726,7 @@ JackCoreMidiDriver::Stop()
     jack_info("JackCoreMidiDriver::Stop - disabling physical output ports.");
 
     for (int i = 0; i < num_physical_outputs; i++) {
-        if (physical_output_ports[i]->Stop() < 0) {
+        if (!physical_output_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Stop - Failed to disable physical "
                        "output port.");
             result = -1;
@@ -736,7 +736,7 @@ JackCoreMidiDriver::Stop()
     jack_info("JackCoreMidiDriver::Stop - disabling virtual input ports.");
 
     for (int i = 0; i < num_virtual_inputs; i++) {
-        if (virtual_input_ports[i]->Stop() < 0) {
+        if (!virtual_input_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Stop - Failed to disable virtual "
                        "input port.");
             result = -1;
@@ -746,7 +746,7 @@ JackCoreMidiDriver::Stop()
     jack_info("JackCoreMidiDriver::Stop - disabling virtual output ports.");
 
     for (int i = 0; i < num_virtual_outputs; i++) {
-        if (virtual_output_ports[i]->Stop() < 0) {
+        if (!virtual_output_ports[i]->Stop()) {
             jack_error("JackCoreMidiDriver::Stop - Failed to disable virtual "
                        "output port.");
             result = -1;
@@ -825,7 +825,7 @@ extern "C" {
 
         desc = jack_driver_descriptor_construct("coremidi", JackDriverSlave, "Apple CoreMIDI API based MIDI backend", &filler);
 
-        value.ui  = 0;
+        value.ui = 0;
         jack_driver_descriptor_add_parameter(desc, &filler, "inchannels", 'i', JackDriverParamUInt, &value, NULL, "CoreMIDI virtual bus", NULL);
         jack_driver_descriptor_add_parameter(desc, &filler, "outchannels", 'o', JackDriverParamUInt, &value, NULL, "CoreMIDI virtual bus", NULL);
 
diff -pruN 1.9.14~dfsg-1/macosx/generate-pkg.sh 1.9.16~dfsg-1/macosx/generate-pkg.sh
--- 1.9.14~dfsg-1/macosx/generate-pkg.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/generate-pkg.sh	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,54 @@
+#!/bin/bash
+
+set -e
+
+cd $(dirname ${0})
+
+# ---------------------------------------------------------------------------------------------------------------------
+
+installed_prefix="${1}"
+
+if [ -z "${installed_prefix}" ]; then
+    echo "usage: ${0} <installed_prefix>"
+    exit 1
+fi
+
+# ---------------------------------------------------------------------------------------------------------------------
+
+VERSION=$(cat ../wscript | awk 'sub("VERSION=","")' | tr -d "'")
+
+rm -f jack2-osx-root.pkg
+rm -f jack2-osx-${VERSION}.pkg
+rm -f package.xml
+
+# ---------------------------------------------------------------------------------------------------------------------
+
+pkgbuild \
+    --identifier org.jackaudio.jack2 \
+    --install-location "/usr/local/" \
+    --root "${installed_prefix}/" \
+    jack2-osx-root.pkg
+
+# ---------------------------------------------------------------------------------------------------------------------
+
+# https://developer.apple.com/library/content/documentation/DeveloperTools/Reference/DistributionDefinitionRef/Chapters/Distribution_XML_Ref.html
+
+pushd "${installed_prefix}"
+mkdir -p share/jack2
+touch share/jack2/jack2-osx-files.txt
+find -sL . -type f | awk 'sub("./","/usr/local/")' > share/jack2/jack2-osx-files.txt
+popd
+
+sed -e "s|@CURDIR@|${PWD}|" package.xml.in > package.xml
+cat package-welcome.txt.in "${installed_prefix}/share/jack2/jack2-osx-files.txt" > package-welcome.txt
+
+productbuild \
+    --distribution package.xml \
+    --identifier org.jackaudio.jack2 \
+    --package-path "${PWD}" \
+    --version ${VERSION} \
+    jack2-osx-${VERSION}.pkg
+
+rm jack2-osx-root.pkg package.xml package-welcome.txt
+
+# ---------------------------------------------------------------------------------------------------------------------
diff -pruN 1.9.14~dfsg-1/macosx/iphone/audio_thru.mm 1.9.16~dfsg-1/macosx/iphone/audio_thru.mm
--- 1.9.14~dfsg-1/macosx/iphone/audio_thru.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/audio_thru.mm	1970-01-01 00:00:00.000000000 +0000
@@ -1,35 +0,0 @@
-
-#include "JackAudioQueueAdapter.h"
-
-#define CHANNELS 2
-
-static void DSPcompute(int count, float** input, float** output)
-{
-    for (int i = 0; i < CHANNELS; i++) {
-        memcpy(output[i], input[i], count * sizeof(float));
-    }
-}
-
-int main(int argc, char *argv[]) {
-    
-    NSAutoreleasePool * pool = [[NSAutoreleasePool alloc] init];
-    
-    Jack::JackAudioQueueAdapter audio(2, 2, 512, 44100, DSPcompute);
-    
-    if (audio.Open() < 0) {
-        fprintf(stderr, "Cannot open audio\n");
-	    return 1;
-	}
-    
-    // Hang around forever...
-	while(1) CFRunLoopRunInMode(kCFRunLoopDefaultMode, 0.25, false);
-   
-    int retVal = UIApplicationMain(argc, argv, nil, nil);
-    [pool release];
-     
-    if (audio.Close() < 0) {
-        fprintf(stderr, "Cannot close audio\n");
-	}
-    
-    return retVal;
-}
diff -pruN 1.9.14~dfsg-1/macosx/iphone/freeverb.mm 1.9.16~dfsg-1/macosx/iphone/freeverb.mm
--- 1.9.14~dfsg-1/macosx/iphone/freeverb.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/freeverb.mm	1970-01-01 00:00:00.000000000 +0000
@@ -1,750 +0,0 @@
-//-----------------------------------------------------
-// name: "freeverb"
-// version: "1.0"
-// author: "Grame"
-// license: "BSD"
-// copyright: "(c)GRAME 2006"
-//
-// Code generated with Faust 0.9.9.5b2 (http://faust.grame.fr)
-//-----------------------------------------------------
-/* link with  */
-
-/* link with  */
-#include <math.h>
-/* link with  */
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <limits.h>
-#include <math.h>
-#include <errno.h>
-#include <time.h>
-#include <sys/ioctl.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <pwd.h>
-#include <sys/types.h>
-#include <assert.h>
-#include <pthread.h>
-#include <sys/wait.h>
-#include <libgen.h>
-#include <jack/net.h>
-
-#include <list>
-#include <vector>
-#include <iostream>
-#include <fstream>
-#include <stack>
-#include <list>
-#include <map>
-
-#include "JackAudioQueueAdapter.h"
-
-using namespace std;
-
-// On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
-// flags to avoid costly denormals
-#ifdef __SSE__
-    #include <xmmintrin.h>
-    #ifdef __SSE2__
-        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8040)
-    #else
-        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8000)
-    #endif
-#else
-    #define AVOIDDENORMALS
-#endif
-
-//#define BENCHMARKMODE
-
-struct Meta : map<const char*, const char*>
-{
-    void declare (const char* key, const char* value) { (*this)[key]=value; }
-};
-
-
-#define max(x,y) (((x)>(y)) ? (x) : (y))
-#define min(x,y) (((x)<(y)) ? (x) : (y))
-
-inline int		lsr (int x, int n)	{ return int(((unsigned int)x) >> n); }
-inline int 		int2pow2 (int x)	{ int r = 0; while ((1<<r)<x) r++; return r; }
-
-
-/******************************************************************************
-*******************************************************************************
-
-							       VECTOR INTRINSICS
-
-*******************************************************************************
-*******************************************************************************/
-
-
-/******************************************************************************
-*******************************************************************************
-
-								USER INTERFACE
-
-*******************************************************************************
-*******************************************************************************/
-
-class UI
-{
-	bool	fStopped;
-public:
-
-	UI() : fStopped(false) {}
-	virtual ~UI() {}
-
-	// -- active widgets
-
-	virtual void addButton(const char* label, float* zone) = 0;
-	virtual void addToggleButton(const char* label, float* zone) = 0;
-	virtual void addCheckButton(const char* label, float* zone) = 0;
-	virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step) = 0;
-	virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step) = 0;
-	virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step) = 0;
-
-	// -- passive widgets
-
-	virtual void addNumDisplay(const char* label, float* zone, int precision) = 0;
-	virtual void addTextDisplay(const char* label, float* zone, char* names[], float min, float max) = 0;
-	virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max) = 0;
-	virtual void addVerticalBargraph(const char* label, float* zone, float min, float max) = 0;
-
-	// -- frames and labels
-
-	virtual void openFrameBox(const char* label) = 0;
-	virtual void openTabBox(const char* label) = 0;
-	virtual void openHorizontalBox(const char* label) = 0;
-	virtual void openVerticalBox(const char* label) = 0;
-	virtual void closeBox() = 0;
-
-	virtual void show() = 0;
-	virtual void run() = 0;
-
-	void stop()		{ fStopped = true; }
-	bool stopped() 	{ return fStopped; }
-
-    virtual void declare(float* zone, const char* key, const char* value) {}
-};
-
-struct param {
-	float* fZone; float fMin; float fMax;
-	param(float* z, float a, float b) : fZone(z), fMin(a), fMax(b) {}
-};
-
-class CMDUI : public UI
-{
-	int					fArgc;
-	char**				fArgv;
-	stack<string>		fPrefix;
-	map<string, param>	fKeyParam;
-
-	void addOption(const char* label, float* zone, float min, float max)
-	{
-		string fullname = fPrefix.top() + label;
-		fKeyParam.insert(make_pair(fullname, param(zone, min, max)));
-	}
-
-	void openAnyBox(const char* label)
-	{
-		string prefix;
-
-		if (label && label[0]) {
-			prefix = fPrefix.top() + "-" + label;
-		} else {
-			prefix = fPrefix.top();
-		}
-		fPrefix.push(prefix);
-	}
-
-public:
-
-	CMDUI(int argc, char *argv[]) : UI(), fArgc(argc), fArgv(argv) { fPrefix.push("--"); }
-	virtual ~CMDUI() {}
-
-	virtual void addButton(const char* label, float* zone) 		{};
-	virtual void addToggleButton(const char* label, float* zone) 	{};
-	virtual void addCheckButton(const char* label, float* zone) 	{};
-
-	virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step)
-	{
-		addOption(label,zone,min,max);
-	}
-
-	virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step)
-	{
-		addOption(label,zone,min,max);
-	}
-
-	virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step)
-	{
-		addOption(label,zone,min,max);
-	}
-
-	// -- passive widgets
-
-	virtual void addNumDisplay(const char* label, float* zone, int precision) 						{}
-	virtual void addTextDisplay(const char* label, float* zone, char* names[], float min, float max) 	{}
-	virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max) 			{}
-	virtual void addVerticalBargraph(const char* label, float* zone, float min, float max) 			{}
-
-	virtual void openFrameBox(const char* label)		{ openAnyBox(label); }
-	virtual void openTabBox(const char* label)		{ openAnyBox(label); }
-	virtual void openHorizontalBox(const char* label)	{ openAnyBox(label); }
-	virtual void openVerticalBox(const char* label)	{ openAnyBox(label); }
-
-	virtual void closeBox() 					{ fPrefix.pop(); }
-
-	virtual void show() {}
-	virtual void run()
-	{
-		char c;
-		printf("Type 'q' to quit\n");
-		while ((c = getchar()) != 'q') {
-			sleep(1);
-		}
-	}
-
-	void print()
-	{
-		map<string, param>::iterator i;
-		cout << fArgc << "\n";
-		cout << fArgv[0] << " option list : ";
-		for (i = fKeyParam.begin(); i != fKeyParam.end(); i++) {
-			cout << "[ " << i->first << " " << i->second.fMin << ".." << i->second.fMax <<" ] ";
-		}
-	}
-
-	void process_command()
-	{
-		map<string, param>::iterator p;
-		for (int i = 1; i < fArgc; i++) {
-			if (fArgv[i][0] == '-') {
-				p = fKeyParam.find(fArgv[i]);
-				if (p == fKeyParam.end()) {
-					cout << fArgv[0] << " : unrecognized option " << fArgv[i] << "\n";
-					print();
-					exit(1);
-				}
-				char*	end;
-				*(p->second.fZone) = float(strtod(fArgv[i+1], &end));
-				i++;
-			}
-		}
-	}
-
-	void process_init()
-	{
-		map<string, param>::iterator p;
-		for (int i = 1; i < fArgc; i++) {
-			if (fArgv[i][0] == '-') {
-				p = fKeyParam.find(fArgv[i]);
-				if (p == fKeyParam.end()) {
-					cout << fArgv[0] << " : unrecognized option " << fArgv[i] << "\n";
-					exit(1);
-				}
-				char*	end;
-				*(p->second.fZone) = float(strtod(fArgv[i+1], &end));
-				i++;
-			}
-		}
-	}
-};
-
-
-//----------------------------------------------------------------
-//  Signal processor definition
-//----------------------------------------------------------------
-
-class dsp {
- protected:
-	int fSamplingFreq;
- public:
-	dsp() {}
-	virtual ~dsp() {}
-
-	virtual int getNumInputs() 										= 0;
-	virtual int getNumOutputs() 									= 0;
-	virtual void buildUserInterface(UI* interface) 					= 0;
-	virtual void init(int samplingRate) 							= 0;
- 	virtual void compute(int len, float** inputs, float** outputs) 	= 0;
- 	virtual void conclude() 										{}
-};
-
-
-//----------------------------------------------------------------------------
-// 	FAUST generated code
-//----------------------------------------------------------------------------
-
-
-class mydsp : public dsp {
-  private:
-	float 	fslider0;
-	float 	fRec9[2];
-	float 	fslider1;
-	int 	IOTA;
-	float 	fVec0[2048];
-	float 	fRec8[2];
-	float 	fRec11[2];
-	float 	fVec1[2048];
-	float 	fRec10[2];
-	float 	fRec13[2];
-	float 	fVec2[2048];
-	float 	fRec12[2];
-	float 	fRec15[2];
-	float 	fVec3[2048];
-	float 	fRec14[2];
-	float 	fRec17[2];
-	float 	fVec4[2048];
-	float 	fRec16[2];
-	float 	fRec19[2];
-	float 	fVec5[2048];
-	float 	fRec18[2];
-	float 	fRec21[2];
-	float 	fVec6[2048];
-	float 	fRec20[2];
-	float 	fRec23[2];
-	float 	fVec7[2048];
-	float 	fRec22[2];
-	float 	fVec8[1024];
-	float 	fRec6[2];
-	float 	fVec9[512];
-	float 	fRec4[2];
-	float 	fVec10[512];
-	float 	fRec2[2];
-	float 	fVec11[256];
-	float 	fRec0[2];
-	float 	fslider2;
-	float 	fRec33[2];
-	float 	fVec12[2048];
-	float 	fRec32[2];
-	float 	fRec35[2];
-	float 	fVec13[2048];
-	float 	fRec34[2];
-	float 	fRec37[2];
-	float 	fVec14[2048];
-	float 	fRec36[2];
-	float 	fRec39[2];
-	float 	fVec15[2048];
-	float 	fRec38[2];
-	float 	fRec41[2];
-	float 	fVec16[2048];
-	float 	fRec40[2];
-	float 	fRec43[2];
-	float 	fVec17[2048];
-	float 	fRec42[2];
-	float 	fRec45[2];
-	float 	fVec18[2048];
-	float 	fRec44[2];
-	float 	fRec47[2];
-	float 	fVec19[2048];
-	float 	fRec46[2];
-	float 	fVec20[1024];
-	float 	fRec30[2];
-	float 	fVec21[512];
-	float 	fRec28[2];
-	float 	fVec22[512];
-	float 	fRec26[2];
-	float 	fVec23[256];
-	float 	fRec24[2];
-  public:
-	static void metadata(Meta* m) 	{
-		m->declare("name", "freeverb");
-		m->declare("version", "1.0");
-		m->declare("author", "Grame");
-		m->declare("license", "BSD");
-		m->declare("copyright", "(c)GRAME 2006");
-	}
-
-	virtual int getNumInputs() 	{ return 2; }
-	virtual int getNumOutputs() 	{ return 2; }
-	static void classInit(int samplingFreq) {
-	}
-	virtual void instanceInit(int samplingFreq) {
-		fSamplingFreq = samplingFreq;
-		fslider0 = 0.5f;
-		for (int i=0; i<2; i++) fRec9[i] = 0;
-		fslider1 = 0.8f;
-		IOTA = 0;
-		for (int i=0; i<2048; i++) fVec0[i] = 0;
-		for (int i=0; i<2; i++) fRec8[i] = 0;
-		for (int i=0; i<2; i++) fRec11[i] = 0;
-		for (int i=0; i<2048; i++) fVec1[i] = 0;
-		for (int i=0; i<2; i++) fRec10[i] = 0;
-		for (int i=0; i<2; i++) fRec13[i] = 0;
-		for (int i=0; i<2048; i++) fVec2[i] = 0;
-		for (int i=0; i<2; i++) fRec12[i] = 0;
-		for (int i=0; i<2; i++) fRec15[i] = 0;
-		for (int i=0; i<2048; i++) fVec3[i] = 0;
-		for (int i=0; i<2; i++) fRec14[i] = 0;
-		for (int i=0; i<2; i++) fRec17[i] = 0;
-		for (int i=0; i<2048; i++) fVec4[i] = 0;
-		for (int i=0; i<2; i++) fRec16[i] = 0;
-		for (int i=0; i<2; i++) fRec19[i] = 0;
-		for (int i=0; i<2048; i++) fVec5[i] = 0;
-		for (int i=0; i<2; i++) fRec18[i] = 0;
-		for (int i=0; i<2; i++) fRec21[i] = 0;
-		for (int i=0; i<2048; i++) fVec6[i] = 0;
-		for (int i=0; i<2; i++) fRec20[i] = 0;
-		for (int i=0; i<2; i++) fRec23[i] = 0;
-		for (int i=0; i<2048; i++) fVec7[i] = 0;
-		for (int i=0; i<2; i++) fRec22[i] = 0;
-		for (int i=0; i<1024; i++) fVec8[i] = 0;
-		for (int i=0; i<2; i++) fRec6[i] = 0;
-		for (int i=0; i<512; i++) fVec9[i] = 0;
-		for (int i=0; i<2; i++) fRec4[i] = 0;
-		for (int i=0; i<512; i++) fVec10[i] = 0;
-		for (int i=0; i<2; i++) fRec2[i] = 0;
-		for (int i=0; i<256; i++) fVec11[i] = 0;
-		for (int i=0; i<2; i++) fRec0[i] = 0;
-		fslider2 = 0.8f;
-		for (int i=0; i<2; i++) fRec33[i] = 0;
-		for (int i=0; i<2048; i++) fVec12[i] = 0;
-		for (int i=0; i<2; i++) fRec32[i] = 0;
-		for (int i=0; i<2; i++) fRec35[i] = 0;
-		for (int i=0; i<2048; i++) fVec13[i] = 0;
-		for (int i=0; i<2; i++) fRec34[i] = 0;
-		for (int i=0; i<2; i++) fRec37[i] = 0;
-		for (int i=0; i<2048; i++) fVec14[i] = 0;
-		for (int i=0; i<2; i++) fRec36[i] = 0;
-		for (int i=0; i<2; i++) fRec39[i] = 0;
-		for (int i=0; i<2048; i++) fVec15[i] = 0;
-		for (int i=0; i<2; i++) fRec38[i] = 0;
-		for (int i=0; i<2; i++) fRec41[i] = 0;
-		for (int i=0; i<2048; i++) fVec16[i] = 0;
-		for (int i=0; i<2; i++) fRec40[i] = 0;
-		for (int i=0; i<2; i++) fRec43[i] = 0;
-		for (int i=0; i<2048; i++) fVec17[i] = 0;
-		for (int i=0; i<2; i++) fRec42[i] = 0;
-		for (int i=0; i<2; i++) fRec45[i] = 0;
-		for (int i=0; i<2048; i++) fVec18[i] = 0;
-		for (int i=0; i<2; i++) fRec44[i] = 0;
-		for (int i=0; i<2; i++) fRec47[i] = 0;
-		for (int i=0; i<2048; i++) fVec19[i] = 0;
-		for (int i=0; i<2; i++) fRec46[i] = 0;
-		for (int i=0; i<1024; i++) fVec20[i] = 0;
-		for (int i=0; i<2; i++) fRec30[i] = 0;
-		for (int i=0; i<512; i++) fVec21[i] = 0;
-		for (int i=0; i<2; i++) fRec28[i] = 0;
-		for (int i=0; i<512; i++) fVec22[i] = 0;
-		for (int i=0; i<2; i++) fRec26[i] = 0;
-		for (int i=0; i<256; i++) fVec23[i] = 0;
-		for (int i=0; i<2; i++) fRec24[i] = 0;
-	}
-	virtual void init(int samplingFreq) {
-		classInit(samplingFreq);
-		instanceInit(samplingFreq);
-	}
-	virtual void buildUserInterface(UI* interface) {
-		interface->openVerticalBox("Freeverb");
-		interface->addHorizontalSlider("Damp", &fslider0, 0.5f, 0.0f, 1.0f, 2.500000e-02f);
-		interface->addHorizontalSlider("RoomSize", &fslider1, 0.8f, 0.0f, 1.0f, 2.500000e-02f);
-		interface->addHorizontalSlider("Wet", &fslider2, 0.8f, 0.0f, 1.0f, 2.500000e-02f);
-		interface->closeBox();
-	}
-	virtual void compute (int count, float** input, float** output) {
-		float 	fSlow0 = (0.4f * fslider0);
-		float 	fSlow1 = (1 - fSlow0);
-		float 	fSlow2 = (0.7f + (0.28f * fslider1));
-		float 	fSlow3 = fslider2;
-		float 	fSlow4 = (1 - fSlow3);
-		float* input0 = input[0];
-		float* input1 = input[1];
-		float* output0 = output[0];
-		float* output1 = output[1];
-		for (int i=0; i<count; i++) {
-			fRec9[0] = ((fSlow1 * fRec8[1]) + (fSlow0 * fRec9[1]));
-			float fTemp0 = input1[i];
-			float fTemp1 = input0[i];
-			float fTemp2 = (1.500000e-02f * (fTemp1 + fTemp0));
-			fVec0[IOTA&2047] = (fTemp2 + (fSlow2 * fRec9[0]));
-			fRec8[0] = fVec0[(IOTA-1617)&2047];
-			fRec11[0] = ((fSlow1 * fRec10[1]) + (fSlow0 * fRec11[1]));
-			fVec1[IOTA&2047] = (fTemp2 + (fSlow2 * fRec11[0]));
-			fRec10[0] = fVec1[(IOTA-1557)&2047];
-			fRec13[0] = ((fSlow1 * fRec12[1]) + (fSlow0 * fRec13[1]));
-			fVec2[IOTA&2047] = (fTemp2 + (fSlow2 * fRec13[0]));
-			fRec12[0] = fVec2[(IOTA-1491)&2047];
-			fRec15[0] = ((fSlow1 * fRec14[1]) + (fSlow0 * fRec15[1]));
-			fVec3[IOTA&2047] = (fTemp2 + (fSlow2 * fRec15[0]));
-			fRec14[0] = fVec3[(IOTA-1422)&2047];
-			fRec17[0] = ((fSlow1 * fRec16[1]) + (fSlow0 * fRec17[1]));
-			fVec4[IOTA&2047] = (fTemp2 + (fSlow2 * fRec17[0]));
-			fRec16[0] = fVec4[(IOTA-1356)&2047];
-			fRec19[0] = ((fSlow1 * fRec18[1]) + (fSlow0 * fRec19[1]));
-			fVec5[IOTA&2047] = (fTemp2 + (fSlow2 * fRec19[0]));
-			fRec18[0] = fVec5[(IOTA-1277)&2047];
-			fRec21[0] = ((fSlow1 * fRec20[1]) + (fSlow0 * fRec21[1]));
-			fVec6[IOTA&2047] = (fTemp2 + (fSlow2 * fRec21[0]));
-			fRec20[0] = fVec6[(IOTA-1188)&2047];
-			fRec23[0] = ((fSlow1 * fRec22[1]) + (fSlow0 * fRec23[1]));
-			fVec7[IOTA&2047] = (fTemp2 + (fSlow2 * fRec23[0]));
-			fRec22[0] = fVec7[(IOTA-1116)&2047];
-			float fTemp3 = (((((((fRec22[0] + fRec20[0]) + fRec18[0]) + fRec16[0]) + fRec14[0]) + fRec12[0]) + fRec10[0]) + fRec8[0]);
-			fVec8[IOTA&1023] = (fTemp3 + (0.5f * fRec6[1]));
-			fRec6[0] = fVec8[(IOTA-556)&1023];
-			float 	fRec7 = (0 - (fTemp3 - fRec6[1]));
-			fVec9[IOTA&511] = (fRec7 + (0.5f * fRec4[1]));
-			fRec4[0] = fVec9[(IOTA-441)&511];
-			float 	fRec5 = (fRec4[1] - fRec7);
-			fVec10[IOTA&511] = (fRec5 + (0.5f * fRec2[1]));
-			fRec2[0] = fVec10[(IOTA-341)&511];
-			float 	fRec3 = (fRec2[1] - fRec5);
-			fVec11[IOTA&255] = (fRec3 + (0.5f * fRec0[1]));
-			fRec0[0] = fVec11[(IOTA-225)&255];
-			float 	fRec1 = (fRec0[1] - fRec3);
-			output0[i] = ((fSlow4 * fTemp1) + (fSlow3 * fRec1));
-			fRec33[0] = ((fSlow1 * fRec32[1]) + (fSlow0 * fRec33[1]));
-			fVec12[IOTA&2047] = (fTemp2 + (fSlow2 * fRec33[0]));
-			fRec32[0] = fVec12[(IOTA-1640)&2047];
-			fRec35[0] = ((fSlow1 * fRec34[1]) + (fSlow0 * fRec35[1]));
-			fVec13[IOTA&2047] = (fTemp2 + (fSlow2 * fRec35[0]));
-			fRec34[0] = fVec13[(IOTA-1580)&2047];
-			fRec37[0] = ((fSlow1 * fRec36[1]) + (fSlow0 * fRec37[1]));
-			fVec14[IOTA&2047] = (fTemp2 + (fSlow2 * fRec37[0]));
-			fRec36[0] = fVec14[(IOTA-1514)&2047];
-			fRec39[0] = ((fSlow1 * fRec38[1]) + (fSlow0 * fRec39[1]));
-			fVec15[IOTA&2047] = (fTemp2 + (fSlow2 * fRec39[0]));
-			fRec38[0] = fVec15[(IOTA-1445)&2047];
-			fRec41[0] = ((fSlow1 * fRec40[1]) + (fSlow0 * fRec41[1]));
-			fVec16[IOTA&2047] = (fTemp2 + (fSlow2 * fRec41[0]));
-			fRec40[0] = fVec16[(IOTA-1379)&2047];
-			fRec43[0] = ((fSlow1 * fRec42[1]) + (fSlow0 * fRec43[1]));
-			fVec17[IOTA&2047] = (fTemp2 + (fSlow2 * fRec43[0]));
-			fRec42[0] = fVec17[(IOTA-1300)&2047];
-			fRec45[0] = ((fSlow1 * fRec44[1]) + (fSlow0 * fRec45[1]));
-			fVec18[IOTA&2047] = (fTemp2 + (fSlow2 * fRec45[0]));
-			fRec44[0] = fVec18[(IOTA-1211)&2047];
-			fRec47[0] = ((fSlow1 * fRec46[1]) + (fSlow0 * fRec47[1]));
-			fVec19[IOTA&2047] = (fTemp2 + (fSlow2 * fRec47[0]));
-			fRec46[0] = fVec19[(IOTA-1139)&2047];
-			float fTemp4 = (((((((fRec46[0] + fRec44[0]) + fRec42[0]) + fRec40[0]) + fRec38[0]) + fRec36[0]) + fRec34[0]) + fRec32[0]);
-			fVec20[IOTA&1023] = (fTemp4 + (0.5f * fRec30[1]));
-			fRec30[0] = fVec20[(IOTA-579)&1023];
-			float 	fRec31 = (0 - (fTemp4 - fRec30[1]));
-			fVec21[IOTA&511] = (fRec31 + (0.5f * fRec28[1]));
-			fRec28[0] = fVec21[(IOTA-464)&511];
-			float 	fRec29 = (fRec28[1] - fRec31);
-			fVec22[IOTA&511] = (fRec29 + (0.5f * fRec26[1]));
-			fRec26[0] = fVec22[(IOTA-364)&511];
-			float 	fRec27 = (fRec26[1] - fRec29);
-			fVec23[IOTA&255] = (fRec27 + (0.5f * fRec24[1]));
-			fRec24[0] = fVec23[(IOTA-248)&255];
-			float 	fRec25 = (fRec24[1] - fRec27);
-			output1[i] = ((fSlow4 * fTemp0) + (fSlow3 * fRec25));
-			// post processing
-			fRec24[1] = fRec24[0];
-			fRec26[1] = fRec26[0];
-			fRec28[1] = fRec28[0];
-			fRec30[1] = fRec30[0];
-			fRec46[1] = fRec46[0];
-			fRec47[1] = fRec47[0];
-			fRec44[1] = fRec44[0];
-			fRec45[1] = fRec45[0];
-			fRec42[1] = fRec42[0];
-			fRec43[1] = fRec43[0];
-			fRec40[1] = fRec40[0];
-			fRec41[1] = fRec41[0];
-			fRec38[1] = fRec38[0];
-			fRec39[1] = fRec39[0];
-			fRec36[1] = fRec36[0];
-			fRec37[1] = fRec37[0];
-			fRec34[1] = fRec34[0];
-			fRec35[1] = fRec35[0];
-			fRec32[1] = fRec32[0];
-			fRec33[1] = fRec33[0];
-			fRec0[1] = fRec0[0];
-			fRec2[1] = fRec2[0];
-			fRec4[1] = fRec4[0];
-			fRec6[1] = fRec6[0];
-			fRec22[1] = fRec22[0];
-			fRec23[1] = fRec23[0];
-			fRec20[1] = fRec20[0];
-			fRec21[1] = fRec21[0];
-			fRec18[1] = fRec18[0];
-			fRec19[1] = fRec19[0];
-			fRec16[1] = fRec16[0];
-			fRec17[1] = fRec17[0];
-			fRec14[1] = fRec14[0];
-			fRec15[1] = fRec15[0];
-			fRec12[1] = fRec12[0];
-			fRec13[1] = fRec13[0];
-			fRec10[1] = fRec10[0];
-			fRec11[1] = fRec11[0];
-			fRec8[1] = fRec8[0];
-			IOTA = IOTA+1;
-			fRec9[1] = fRec9[0];
-		}
-	}
-};
-
-mydsp	DSP;
-
-/******************************************************************************
-*******************************************************************************
-
-							NETJACK AUDIO INTERFACE
-
-*******************************************************************************
-*******************************************************************************/
-
-//----------------------------------------------------------------------------
-// 	number of input and output channels
-//----------------------------------------------------------------------------
-
-int		gNumInChans;
-int		gNumOutChans;
-
-//----------------------------------------------------------------------------
-// Jack Callbacks
-//----------------------------------------------------------------------------
-
-static void net_shutdown(void *)
-{
-	exit(1);
-}
-
-#ifdef BENCHMARKMODE
-// measuring jack performances
-static __inline__ unsigned long long int rdtsc(void)
-{
-  unsigned long long int x;
-     __asm__ volatile (".byte 0x0f, 0x31" : "=A" (x));
-     return x;
-}
-
-#define KSKIP 10
-#define KMESURE 1024
-int mesure = 0;
-unsigned long long int starts[KMESURE];
-unsigned long long int stops [KMESURE];
-
-#define STARTMESURE starts[mesure%KMESURE] = rdtsc();
-#define STOPMESURE stops[mesure%KMESURE] = rdtsc(); mesure = mesure+1;
-
-void printstats()
-{
-    unsigned long long int low, hi, tot;
-    low = hi = tot = (stops[KSKIP] - starts[KSKIP]);
-
-    if (mesure < KMESURE) {
-
-        for (int i = KSKIP+1; i<mesure; i++) {
-            unsigned long long int m = stops[i] - starts[i];
-            if (m<low) low = m;
-            if (m>hi) hi = m;
-            tot += m;
-        }
-        cout << low << ' ' << tot/(mesure-KSKIP) << ' ' << hi << endl;
-
-    } else {
-
-        for (int i = KSKIP+1; i<KMESURE; i++) {
-            unsigned long long int m = stops[i] - starts[i];
-            if (m<low) low = m;
-            if (m>hi) hi = m;
-            tot += m;
-        }
-        cout << low << ' ' << tot/(KMESURE-KSKIP) << ' ' << hi << endl;
-
-    }
-}
-
-#else
-
-#define STARTMESURE
-#define STOPMESURE
-
-#endif
-
-static int net_process(jack_nframes_t buffer_size,
-            int audio_input,
-            float** audio_input_buffer,
-            int midi_input,
-            void** midi_input_buffer,
-            int audio_output,
-            float** audio_output_buffer,
-            int midi_output,
-            void** midi_output_buffer,
-            void* data)
-{
-    AVOIDDENORMALS;
-    STARTMESURE
-    DSP.compute(buffer_size, audio_input_buffer, audio_output_buffer);
-    STOPMESURE
-	return 0;
-}
-
-/******************************************************************************
-*******************************************************************************
-
-								MAIN PLAY THREAD
-
-*******************************************************************************
-*******************************************************************************/
-
-//-------------------------------------------------------------------------
-// 									MAIN
-//-------------------------------------------------------------------------
-
-
-#define TEST_MASTER "194.5.49.5"
-
-int main(int argc, char *argv[]) {
-
-    UI* interface = new CMDUI(argc, argv);
-    jack_net_slave_t* net;
-    NSAutoreleasePool * pool = [[NSAutoreleasePool alloc] init];
-
-    //Jack::JackAudioQueueAdapter audio(2, 2, 1024, 44100, NULL);
-
-    gNumInChans = DSP.getNumInputs();
-	gNumOutChans = DSP.getNumOutputs();
-
-    jack_slave_t request = { gNumInChans, gNumOutChans, 0, 0, DEFAULT_MTU, -1, 2 };
-    jack_master_t result;
-
-    printf("Network\n");
-
-    //if (audio.Open() < 0) {
-    //    fprintf(stderr, "Cannot open audio\n");
-    //    return 1;
-    //}
-
-     //audio.Start();
-
-    // Hang around forever...
-	 //while(1) CFRunLoopRunInMode(kCFRunLoopDefaultMode, 0.25, false);
-
-    if ((net = jack_net_slave_open(TEST_MASTER, DEFAULT_PORT, "iPhone", &request, &result)) == 0) {
-	    fprintf(stderr, "jack remote server not running ?\n");
-	    return 1;
-	}
-
-    jack_set_net_slave_process_callback(net, net_process, NULL);
-
-    // We want to restart (that is "wait for available master" again)
-    //jack_set_net_shutdown_callback(net, net_shutdown, 0);
-
-    DSP.init(result.sample_rate);
-	DSP.buildUserInterface(interface);
-
-    if (jack_net_slave_activate(net) != 0) {
-	    fprintf(stderr, "cannot activate net");
-	    return 1;
-	}
-
-    int retVal = UIApplicationMain(argc, argv, nil, nil);
-    [pool release];
-
-    // Wait for application end
-    jack_net_slave_deactivate(net);
-    jack_net_slave_close(net);
-
-    //if (audio.Close() < 0) {
-    //    fprintf(stderr, "Cannot close audio\n");
-    //}
-
-    return retVal;
-}
Binary files 1.9.14~dfsg-1/macosx/iphone/icon.png and 1.9.16~dfsg-1/macosx/iphone/icon.png differ
diff -pruN 1.9.14~dfsg-1/macosx/iphone/Info.plist 1.9.16~dfsg-1/macosx/iphone/Info.plist
--- 1.9.14~dfsg-1/macosx/iphone/Info.plist	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/Info.plist	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
-<plist version="1.0">
-<dict>
-	<key>CFBundleDevelopmentRegion</key>
-	<string>English</string>
-	<key>CFBundleDisplayName</key>
-	<string>${PRODUCT_NAME}</string>
-	<key>CFBundleExecutable</key>
-	<string>${EXECUTABLE_NAME}</string>
-	<key>CFBundleIconFile</key>
-	<string></string>
-	<key>CFBundleIdentifier</key>
-	<string>fr.grame.iGrame.iPhoneFaustNet</string>
-	<key>CFBundleInfoDictionaryVersion</key>
-	<string>6.0</string>
-	<key>CFBundleName</key>
-	<string>${PRODUCT_NAME}</string>
-	<key>CFBundlePackageType</key>
-	<string>APPL</string>
-	<key>CFBundleSignature</key>
-	<string>????</string>
-	<key>CFBundleVersion</key>
-	<string>1.0</string>
-	<key>LSRequiresIPhoneOS</key>
-	<true/>
-	<key>NSMainNibFile</key>
-	<string>MainWindow</string>
-</dict>
-</plist>
diff -pruN 1.9.14~dfsg-1/macosx/iphone/iphone-faust.mm 1.9.16~dfsg-1/macosx/iphone/iphone-faust.mm
--- 1.9.14~dfsg-1/macosx/iphone/iphone-faust.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/iphone-faust.mm	1970-01-01 00:00:00.000000000 +0000
@@ -1,3127 +0,0 @@
-//-----------------------------------------------------
-// name: "freeverb"
-// version: "1.0"
-// author: "Grame"
-// license: "BSD"
-// copyright: "(c)GRAME 2006"
-//
-// Code generated with Faust 0.9.10 (http://faust.grame.fr)
-//-----------------------------------------------------
-/* link with  */
-/* link with  */
-#include <math.h>
-/* link with  */
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <limits.h>
-#include <math.h>
-#include <errno.h>
-#include <time.h>
-#include <sys/ioctl.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <pwd.h>
-#include <sys/types.h>
-#include <assert.h>
-#include <pthread.h> 
-#include <sys/wait.h>
-
-#include <list>
-#include <vector>
-#include <iostream>
-#include <fstream>
-#include <stack>
-#include <list>
-#include <map>
-#include <libgen.h>
-
-#include <AudioToolbox/AudioConverter.h>
-#include <AudioToolbox/AudioServices.h>
-#include <AudioUnit/AudioUnit.h>
-
-#include "HardwareClock.h"
-
-using namespace std;
-
-// On Intel set FZ (Flush to Zero) and DAZ (Denormals Are Zero)
-// flags to avoid costly denormals
-#ifdef __SSE__
-    #include <xmmintrin.h>
-    #ifdef __SSE2__
-        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8040)
-    #else
-        #define AVOIDDENORMALS _mm_setcsr(_mm_getcsr() | 0x8000)
-    #endif
-#else
-    #define AVOIDDENORMALS 
-#endif
-
-//#define BENCHMARKMODE
-
-struct Meta : map<const char*, const char*>
-{
-    void declare (const char* key, const char* value) { (*this)[key] = value; }
-};
-
-//inline void *aligned_calloc(size_t nmemb, size_t size) { return (void*)((unsigned)(calloc((nmemb*size)+15,sizeof(char)))+15 & 0xfffffff0); }
-
-// g++ -O3 -lm -ljack `gtk-config --cflags --libs` ex2.cpp
- 
-	
-#define max(x,y) (((x)>(y)) ? (x) : (y))
-#define min(x,y) (((x)<(y)) ? (x) : (y))
-
-inline int	lsr(int x, int n)	{ return int(((unsigned int)x) >> n); }
-inline int 	int2pow2(int x)     { int r=0; while ((1<<r)<x) r++; return r; }
-
-/******************************************************************************
-*******************************************************************************
-
-							       VECTOR INTRINSICS
-
-*******************************************************************************
-*******************************************************************************/
-
-
-/******************************************************************************
-*******************************************************************************
-
-								USER INTERFACE
-
-*******************************************************************************
-*******************************************************************************/
-
-class UI
-{
-        bool fStopped;
-        
-    public:
-            
-        UI() : fStopped(false) {}
-        virtual ~UI() {}
-        
-        // -- active widgets
-        
-        virtual void addButton(const char* label, float* zone) = 0;
-        virtual void addToggleButton(const char* label, float* zone) = 0;
-        virtual void addCheckButton(const char* label, float* zone) = 0;
-        virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step) = 0;
-        virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step) = 0;
-        virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step) = 0;
-        
-        // -- passive widgets
-        
-        virtual void addNumDisplay(const char* label, float* zone, int precision) = 0;
-        virtual void addTextDisplay(const char* label, float* zone, char* names[], float min, float max) = 0;
-        virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max) = 0;
-        virtual void addVerticalBargraph(const char* label, float* zone, float min, float max) = 0;
-        
-        // -- frames and labels
-        
-        virtual void openFrameBox(const char* label) = 0;
-        virtual void openTabBox(const char* label) = 0;
-        virtual void openHorizontalBox(const char* label) = 0;
-        virtual void openVerticalBox(const char* label) = 0;
-        virtual void closeBox() = 0;
-        
-        virtual void show() = 0;
-        virtual void run() = 0;
-        
-        void stop()		{ fStopped = true; }
-        bool stopped() 	{ return fStopped; }
-
-        virtual void declare(float* zone, const char* key, const char* value) {}
-};
-
-struct param {
-	float* fZone; float fMin; float fMax;
-	param(float* z, float a, float b) : fZone(z), fMin(a), fMax(b) {}
-};
-	
-class CMDUI : public UI
-{
-	int					fArgc;
-	char**				fArgv;
-	stack<string>		fPrefix;
-	map<string, param>	fKeyParam;
-	
-	void addOption(const char* label, float* zone, float init, float min, float max)
-	{
-		string fullname = fPrefix.top() + label;
-		fKeyParam.insert(make_pair(fullname, param(zone, min, max)));
-        *zone = init;
-	}
-	
-	void openAnyBox(const char* label)
-	{
-		string prefix;
-		
-		if (label && label[0]) {
-			prefix = fPrefix.top() + "-" + label;
-		} else {
-			prefix = fPrefix.top();
-		}
-		fPrefix.push(prefix);
-	}
-	
-public:
-		
-	CMDUI(int argc, char *argv[]) : UI(), fArgc(argc), fArgv(argv) { fPrefix.push("--"); }
-	virtual ~CMDUI() {}
-	
-	virtual void addButton(const char* label, float* zone) 		{};
-	virtual void addToggleButton(const char* label, float* zone) 	{};
-	virtual void addCheckButton(const char* label, float* zone) 	{};
-		
-	virtual void addVerticalSlider(const char* label, float* zone, float init, float min, float max, float step)
-	{
-		addOption(label,zone,init, min,max);
-	}
-		
-	virtual void addHorizontalSlider(const char* label, float* zone, float init, float min, float max, float step)
-	{
-		addOption(label,zone,init, min,max);
-	}
-
-	virtual void addNumEntry(const char* label, float* zone, float init, float min, float max, float step)
-	{
-		addOption(label,zone,init, min,max);
-	}
-		
-	// -- passive widgets
-	
-	virtual void addNumDisplay(const char* label, float* zone, int precision)                           {}
-	virtual void addTextDisplay(const char* label, float* zone, char* names[], float min, float max) 	{}
-	virtual void addHorizontalBargraph(const char* label, float* zone, float min, float max) 			{}
-	virtual void addVerticalBargraph(const char* label, float* zone, float min, float max)              {}
-
-	virtual void openFrameBox(const char* label)		{ openAnyBox(label); }
-	virtual void openTabBox(const char* label)          { openAnyBox(label); }
-	virtual void openHorizontalBox(const char* label)	{ openAnyBox(label); }
-	virtual void openVerticalBox(const char* label)     { openAnyBox(label); }
-	
-	virtual void closeBox() 					{ fPrefix.pop(); }
-	
-	virtual void show() {}
-	virtual void run() 	
-	{
-		char c;
-		printf("Type 'q' to quit\n");
-		while ((c = getchar()) != 'q') {
-			sleep(1);
-		}
-	}
-	
-	void print() 
-	{
-		map<string, param>::iterator i;
-		cout << fArgc << "\n";
-		cout << fArgv[0] << " option list : ";
-		for (i = fKeyParam.begin(); i != fKeyParam.end(); i++) {
-			cout << "[ " << i->first << " " << i->second.fMin << ".." << i->second.fMax <<" ] ";
-		}
-	}
-		
-	void process_command()
-	{
-		map<string, param>::iterator p;
-		for (int i = 1; i < fArgc; i++) {
-			if (fArgv[i][0] == '-') {
-				p = fKeyParam.find(fArgv[i]); 
-				if (p == fKeyParam.end()) {
-					cout << fArgv[0] << " : unrecognized option " << fArgv[i] << "\n";
-					print();
-					exit(1);
-				}
-				char*	end;
-				*(p->second.fZone) = float(strtod(fArgv[i+1], &end));
-				i++;
-			}
-		}
-	}
-		
-	void process_init()
-	{
-		map<string, param>::iterator p;
-		for (int i = 1; i < fArgc; i++) {
-			if (fArgv[i][0] == '-') {
-				p = fKeyParam.find(fArgv[i]); 
-				if (p == fKeyParam.end()) {
-					cout << fArgv[0] << " : unrecognized option " << fArgv[i] << "\n";
-					exit(1);
-				}
-				char*	end;
-				*(p->second.fZone) = float(strtod(fArgv[i+1], &end));
-				i++;
-			}
-		}
-	}
-};
-
-/******************************************************************************
-*******************************************************************************
-
-			    FAUST DSP
-
-*******************************************************************************
-*******************************************************************************/
-
-
-//----------------------------------------------------------------
-//  abstract definition of a signal processor
-//----------------------------------------------------------------
-			
-class dsp {
- protected:
-	int fSamplingFreq;
- public:
-	dsp() {}
-	virtual ~dsp() {}
-
-	virtual int getNumInputs() 						= 0;
-	virtual int getNumOutputs() 					= 0;
-	virtual void buildUserInterface(UI* interface) 	= 0;
-	virtual void init(int samplingRate) 			= 0;
- 	virtual void compute(int len, float** inputs, float** outputs) 	= 0;
-};
-		
-//----------------------------------------------------------------------------
-//  FAUST generated signal processor
-//----------------------------------------------------------------------------
-		
-#ifndef FAUSTFLOAT
-#define FAUSTFLOAT float
-#endif  
-
-typedef long double quad;
-
-class mydsp : public dsp{
-  private:
-	FAUSTFLOAT 	fslider0;
-	float 	fRec9_perm[4];
-	FAUSTFLOAT 	fslider1;
-	float 	fRec19_perm[4];
-	float 	fYec0[4096];
-	int 	fYec0_idx;
-	int 	fYec0_idx_save;
-	float 	fRec18_perm[4];
-	float 	fRec21_perm[4];
-	float 	fYec1[4096];
-	int 	fYec1_idx;
-	int 	fYec1_idx_save;
-	float 	fRec20_perm[4];
-	float 	fRec23_perm[4];
-	float 	fYec2[4096];
-	int 	fYec2_idx;
-	int 	fYec2_idx_save;
-	float 	fRec22_perm[4];
-	float 	fRec25_perm[4];
-	float 	fYec3[4096];
-	int 	fYec3_idx;
-	int 	fYec3_idx_save;
-	float 	fRec24_perm[4];
-	float 	fRec27_perm[4];
-	float 	fYec4[4096];
-	int 	fYec4_idx;
-	int 	fYec4_idx_save;
-	float 	fRec26_perm[4];
-	float 	fRec29_perm[4];
-	float 	fYec5[4096];
-	int 	fYec5_idx;
-	int 	fYec5_idx_save;
-	float 	fRec28_perm[4];
-	float 	fRec31_perm[4];
-	float 	fYec6[4096];
-	int 	fYec6_idx;
-	int 	fYec6_idx_save;
-	float 	fRec30_perm[4];
-	float 	fRec33_perm[4];
-	float 	fYec7[4096];
-	int 	fYec7_idx;
-	int 	fYec7_idx_save;
-	float 	fRec32_perm[4];
-	float 	fYec8[2048];
-	int 	fYec8_idx;
-	int 	fYec8_idx_save;
-	float 	fRec16_perm[4];
-	float 	fYec9[2048];
-	int 	fYec9_idx;
-	int 	fYec9_idx_save;
-	float 	fRec14_perm[4];
-	float 	fYec10[2048];
-	int 	fYec10_idx;
-	int 	fYec10_idx_save;
-	float 	fRec12_perm[4];
-	float 	fYec11[2048];
-	int 	fYec11_idx;
-	int 	fYec11_idx_save;
-	float 	fRec10_perm[4];
-	FAUSTFLOAT 	fslider2;
-	float 	fRec43_perm[4];
-	float 	fYec12[4096];
-	int 	fYec12_idx;
-	int 	fYec12_idx_save;
-	float 	fRec42_perm[4];
-	float 	fRec45_perm[4];
-	float 	fYec13[4096];
-	int 	fYec13_idx;
-	int 	fYec13_idx_save;
-	float 	fRec44_perm[4];
-	float 	fRec47_perm[4];
-	float 	fYec14[4096];
-	int 	fYec14_idx;
-	int 	fYec14_idx_save;
-	float 	fRec46_perm[4];
-	float 	fRec49_perm[4];
-	float 	fYec15[4096];
-	int 	fYec15_idx;
-	int 	fYec15_idx_save;
-	float 	fRec48_perm[4];
-	float 	fRec51_perm[4];
-	float 	fYec16[4096];
-	int 	fYec16_idx;
-	int 	fYec16_idx_save;
-	float 	fRec50_perm[4];
-	float 	fRec53_perm[4];
-	float 	fYec17[4096];
-	int 	fYec17_idx;
-	int 	fYec17_idx_save;
-	float 	fRec52_perm[4];
-	float 	fRec55_perm[4];
-	float 	fYec18[4096];
-	int 	fYec18_idx;
-	int 	fYec18_idx_save;
-	float 	fRec54_perm[4];
-	float 	fRec57_perm[4];
-	float 	fYec19[4096];
-	int 	fYec19_idx;
-	int 	fYec19_idx_save;
-	float 	fRec56_perm[4];
-	float 	fYec20[2048];
-	int 	fYec20_idx;
-	int 	fYec20_idx_save;
-	float 	fRec40_perm[4];
-	float 	fYec21[2048];
-	int 	fYec21_idx;
-	int 	fYec21_idx_save;
-	float 	fRec38_perm[4];
-	float 	fYec22[2048];
-	int 	fYec22_idx;
-	int 	fYec22_idx_save;
-	float 	fRec36_perm[4];
-	float 	fYec23[2048];
-	int 	fYec23_idx;
-	int 	fYec23_idx_save;
-	float 	fRec34_perm[4];
-	float 	fYec24[4096];
-	int 	fYec24_idx;
-	int 	fYec24_idx_save;
-	float 	fRec8_perm[4];
-	float 	fRec59_perm[4];
-	float 	fYec25[4096];
-	int 	fYec25_idx;
-	int 	fYec25_idx_save;
-	float 	fRec58_perm[4];
-	float 	fRec61_perm[4];
-	float 	fYec26[4096];
-	int 	fYec26_idx;
-	int 	fYec26_idx_save;
-	float 	fRec60_perm[4];
-	float 	fRec63_perm[4];
-	float 	fYec27[4096];
-	int 	fYec27_idx;
-	int 	fYec27_idx_save;
-	float 	fRec62_perm[4];
-	float 	fRec65_perm[4];
-	float 	fYec28[4096];
-	int 	fYec28_idx;
-	int 	fYec28_idx_save;
-	float 	fRec64_perm[4];
-	float 	fRec67_perm[4];
-	float 	fYec29[4096];
-	int 	fYec29_idx;
-	int 	fYec29_idx_save;
-	float 	fRec66_perm[4];
-	float 	fRec69_perm[4];
-	float 	fYec30[4096];
-	int 	fYec30_idx;
-	int 	fYec30_idx_save;
-	float 	fRec68_perm[4];
-	float 	fRec71_perm[4];
-	float 	fYec31[4096];
-	int 	fYec31_idx;
-	int 	fYec31_idx_save;
-	float 	fRec70_perm[4];
-	float 	fYec32[2048];
-	int 	fYec32_idx;
-	int 	fYec32_idx_save;
-	float 	fRec6_perm[4];
-	float 	fYec33[2048];
-	int 	fYec33_idx;
-	int 	fYec33_idx_save;
-	float 	fRec4_perm[4];
-	float 	fYec34[2048];
-	int 	fYec34_idx;
-	int 	fYec34_idx_save;
-	float 	fRec2_perm[4];
-	float 	fYec35[2048];
-	int 	fYec35_idx;
-	int 	fYec35_idx_save;
-	float 	fRec0_perm[4];
-	float 	fRec81_perm[4];
-	float 	fYec36[4096];
-	int 	fYec36_idx;
-	int 	fYec36_idx_save;
-	float 	fRec80_perm[4];
-	float 	fRec83_perm[4];
-	float 	fYec37[4096];
-	int 	fYec37_idx;
-	int 	fYec37_idx_save;
-	float 	fRec82_perm[4];
-	float 	fRec85_perm[4];
-	float 	fYec38[4096];
-	int 	fYec38_idx;
-	int 	fYec38_idx_save;
-	float 	fRec84_perm[4];
-	float 	fRec87_perm[4];
-	float 	fYec39[4096];
-	int 	fYec39_idx;
-	int 	fYec39_idx_save;
-	float 	fRec86_perm[4];
-	float 	fRec89_perm[4];
-	float 	fYec40[4096];
-	int 	fYec40_idx;
-	int 	fYec40_idx_save;
-	float 	fRec88_perm[4];
-	float 	fRec91_perm[4];
-	float 	fYec41[4096];
-	int 	fYec41_idx;
-	int 	fYec41_idx_save;
-	float 	fRec90_perm[4];
-	float 	fRec93_perm[4];
-	float 	fYec42[4096];
-	int 	fYec42_idx;
-	int 	fYec42_idx_save;
-	float 	fRec92_perm[4];
-	float 	fRec95_perm[4];
-	float 	fYec43[4096];
-	int 	fYec43_idx;
-	int 	fYec43_idx_save;
-	float 	fRec94_perm[4];
-	float 	fYec44[2048];
-	int 	fYec44_idx;
-	int 	fYec44_idx_save;
-	float 	fRec78_perm[4];
-	float 	fYec45[2048];
-	int 	fYec45_idx;
-	int 	fYec45_idx_save;
-	float 	fRec76_perm[4];
-	float 	fYec46[2048];
-	int 	fYec46_idx;
-	int 	fYec46_idx_save;
-	float 	fRec74_perm[4];
-	float 	fYec47[2048];
-	int 	fYec47_idx;
-	int 	fYec47_idx_save;
-	float 	fRec72_perm[4];
-  public:
-	static void metadata(Meta* m) 	{ 
-		m->declare("name", "freeverb");
-		m->declare("version", "1.0");
-		m->declare("author", "Grame");
-		m->declare("license", "BSD");
-		m->declare("copyright", "(c)GRAME 2006");
-	}
-
-	virtual int getNumInputs() 	{ return 2; }
-	virtual int getNumOutputs() 	{ return 2; }
-	static void classInit(int samplingFreq) {
-	}
-	virtual void instanceInit(int samplingFreq) {
-		fSamplingFreq = samplingFreq;
-		fslider0 = 0.5f;
-		for (int i=0; i<4; i++) fRec9_perm[i]=0;
-		fslider1 = 0.5f;
-		for (int i=0; i<4; i++) fRec19_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec0[i]=0;
-		fYec0_idx = 0;
-		fYec0_idx_save = 0;
-		for (int i=0; i<4; i++) fRec18_perm[i]=0;
-		for (int i=0; i<4; i++) fRec21_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec1[i]=0;
-		fYec1_idx = 0;
-		fYec1_idx_save = 0;
-		for (int i=0; i<4; i++) fRec20_perm[i]=0;
-		for (int i=0; i<4; i++) fRec23_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec2[i]=0;
-		fYec2_idx = 0;
-		fYec2_idx_save = 0;
-		for (int i=0; i<4; i++) fRec22_perm[i]=0;
-		for (int i=0; i<4; i++) fRec25_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec3[i]=0;
-		fYec3_idx = 0;
-		fYec3_idx_save = 0;
-		for (int i=0; i<4; i++) fRec24_perm[i]=0;
-		for (int i=0; i<4; i++) fRec27_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec4[i]=0;
-		fYec4_idx = 0;
-		fYec4_idx_save = 0;
-		for (int i=0; i<4; i++) fRec26_perm[i]=0;
-		for (int i=0; i<4; i++) fRec29_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec5[i]=0;
-		fYec5_idx = 0;
-		fYec5_idx_save = 0;
-		for (int i=0; i<4; i++) fRec28_perm[i]=0;
-		for (int i=0; i<4; i++) fRec31_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec6[i]=0;
-		fYec6_idx = 0;
-		fYec6_idx_save = 0;
-		for (int i=0; i<4; i++) fRec30_perm[i]=0;
-		for (int i=0; i<4; i++) fRec33_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec7[i]=0;
-		fYec7_idx = 0;
-		fYec7_idx_save = 0;
-		for (int i=0; i<4; i++) fRec32_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec8[i]=0;
-		fYec8_idx = 0;
-		fYec8_idx_save = 0;
-		for (int i=0; i<4; i++) fRec16_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec9[i]=0;
-		fYec9_idx = 0;
-		fYec9_idx_save = 0;
-		for (int i=0; i<4; i++) fRec14_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec10[i]=0;
-		fYec10_idx = 0;
-		fYec10_idx_save = 0;
-		for (int i=0; i<4; i++) fRec12_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec11[i]=0;
-		fYec11_idx = 0;
-		fYec11_idx_save = 0;
-		for (int i=0; i<4; i++) fRec10_perm[i]=0;
-		fslider2 = 0.3333f;
-		for (int i=0; i<4; i++) fRec43_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec12[i]=0;
-		fYec12_idx = 0;
-		fYec12_idx_save = 0;
-		for (int i=0; i<4; i++) fRec42_perm[i]=0;
-		for (int i=0; i<4; i++) fRec45_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec13[i]=0;
-		fYec13_idx = 0;
-		fYec13_idx_save = 0;
-		for (int i=0; i<4; i++) fRec44_perm[i]=0;
-		for (int i=0; i<4; i++) fRec47_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec14[i]=0;
-		fYec14_idx = 0;
-		fYec14_idx_save = 0;
-		for (int i=0; i<4; i++) fRec46_perm[i]=0;
-		for (int i=0; i<4; i++) fRec49_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec15[i]=0;
-		fYec15_idx = 0;
-		fYec15_idx_save = 0;
-		for (int i=0; i<4; i++) fRec48_perm[i]=0;
-		for (int i=0; i<4; i++) fRec51_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec16[i]=0;
-		fYec16_idx = 0;
-		fYec16_idx_save = 0;
-		for (int i=0; i<4; i++) fRec50_perm[i]=0;
-		for (int i=0; i<4; i++) fRec53_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec17[i]=0;
-		fYec17_idx = 0;
-		fYec17_idx_save = 0;
-		for (int i=0; i<4; i++) fRec52_perm[i]=0;
-		for (int i=0; i<4; i++) fRec55_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec18[i]=0;
-		fYec18_idx = 0;
-		fYec18_idx_save = 0;
-		for (int i=0; i<4; i++) fRec54_perm[i]=0;
-		for (int i=0; i<4; i++) fRec57_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec19[i]=0;
-		fYec19_idx = 0;
-		fYec19_idx_save = 0;
-		for (int i=0; i<4; i++) fRec56_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec20[i]=0;
-		fYec20_idx = 0;
-		fYec20_idx_save = 0;
-		for (int i=0; i<4; i++) fRec40_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec21[i]=0;
-		fYec21_idx = 0;
-		fYec21_idx_save = 0;
-		for (int i=0; i<4; i++) fRec38_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec22[i]=0;
-		fYec22_idx = 0;
-		fYec22_idx_save = 0;
-		for (int i=0; i<4; i++) fRec36_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec23[i]=0;
-		fYec23_idx = 0;
-		fYec23_idx_save = 0;
-		for (int i=0; i<4; i++) fRec34_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec24[i]=0;
-		fYec24_idx = 0;
-		fYec24_idx_save = 0;
-		for (int i=0; i<4; i++) fRec8_perm[i]=0;
-		for (int i=0; i<4; i++) fRec59_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec25[i]=0;
-		fYec25_idx = 0;
-		fYec25_idx_save = 0;
-		for (int i=0; i<4; i++) fRec58_perm[i]=0;
-		for (int i=0; i<4; i++) fRec61_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec26[i]=0;
-		fYec26_idx = 0;
-		fYec26_idx_save = 0;
-		for (int i=0; i<4; i++) fRec60_perm[i]=0;
-		for (int i=0; i<4; i++) fRec63_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec27[i]=0;
-		fYec27_idx = 0;
-		fYec27_idx_save = 0;
-		for (int i=0; i<4; i++) fRec62_perm[i]=0;
-		for (int i=0; i<4; i++) fRec65_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec28[i]=0;
-		fYec28_idx = 0;
-		fYec28_idx_save = 0;
-		for (int i=0; i<4; i++) fRec64_perm[i]=0;
-		for (int i=0; i<4; i++) fRec67_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec29[i]=0;
-		fYec29_idx = 0;
-		fYec29_idx_save = 0;
-		for (int i=0; i<4; i++) fRec66_perm[i]=0;
-		for (int i=0; i<4; i++) fRec69_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec30[i]=0;
-		fYec30_idx = 0;
-		fYec30_idx_save = 0;
-		for (int i=0; i<4; i++) fRec68_perm[i]=0;
-		for (int i=0; i<4; i++) fRec71_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec31[i]=0;
-		fYec31_idx = 0;
-		fYec31_idx_save = 0;
-		for (int i=0; i<4; i++) fRec70_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec32[i]=0;
-		fYec32_idx = 0;
-		fYec32_idx_save = 0;
-		for (int i=0; i<4; i++) fRec6_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec33[i]=0;
-		fYec33_idx = 0;
-		fYec33_idx_save = 0;
-		for (int i=0; i<4; i++) fRec4_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec34[i]=0;
-		fYec34_idx = 0;
-		fYec34_idx_save = 0;
-		for (int i=0; i<4; i++) fRec2_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec35[i]=0;
-		fYec35_idx = 0;
-		fYec35_idx_save = 0;
-		for (int i=0; i<4; i++) fRec0_perm[i]=0;
-		for (int i=0; i<4; i++) fRec81_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec36[i]=0;
-		fYec36_idx = 0;
-		fYec36_idx_save = 0;
-		for (int i=0; i<4; i++) fRec80_perm[i]=0;
-		for (int i=0; i<4; i++) fRec83_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec37[i]=0;
-		fYec37_idx = 0;
-		fYec37_idx_save = 0;
-		for (int i=0; i<4; i++) fRec82_perm[i]=0;
-		for (int i=0; i<4; i++) fRec85_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec38[i]=0;
-		fYec38_idx = 0;
-		fYec38_idx_save = 0;
-		for (int i=0; i<4; i++) fRec84_perm[i]=0;
-		for (int i=0; i<4; i++) fRec87_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec39[i]=0;
-		fYec39_idx = 0;
-		fYec39_idx_save = 0;
-		for (int i=0; i<4; i++) fRec86_perm[i]=0;
-		for (int i=0; i<4; i++) fRec89_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec40[i]=0;
-		fYec40_idx = 0;
-		fYec40_idx_save = 0;
-		for (int i=0; i<4; i++) fRec88_perm[i]=0;
-		for (int i=0; i<4; i++) fRec91_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec41[i]=0;
-		fYec41_idx = 0;
-		fYec41_idx_save = 0;
-		for (int i=0; i<4; i++) fRec90_perm[i]=0;
-		for (int i=0; i<4; i++) fRec93_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec42[i]=0;
-		fYec42_idx = 0;
-		fYec42_idx_save = 0;
-		for (int i=0; i<4; i++) fRec92_perm[i]=0;
-		for (int i=0; i<4; i++) fRec95_perm[i]=0;
-		for (int i=0; i<4096; i++) fYec43[i]=0;
-		fYec43_idx = 0;
-		fYec43_idx_save = 0;
-		for (int i=0; i<4; i++) fRec94_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec44[i]=0;
-		fYec44_idx = 0;
-		fYec44_idx_save = 0;
-		for (int i=0; i<4; i++) fRec78_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec45[i]=0;
-		fYec45_idx = 0;
-		fYec45_idx_save = 0;
-		for (int i=0; i<4; i++) fRec76_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec46[i]=0;
-		fYec46_idx = 0;
-		fYec46_idx_save = 0;
-		for (int i=0; i<4; i++) fRec74_perm[i]=0;
-		for (int i=0; i<2048; i++) fYec47[i]=0;
-		fYec47_idx = 0;
-		fYec47_idx_save = 0;
-		for (int i=0; i<4; i++) fRec72_perm[i]=0;
-	}
-	virtual void init(int samplingFreq) {
-		classInit(samplingFreq);
-		instanceInit(samplingFreq);
-	}
-	virtual void buildUserInterface(UI* interface) {
-		interface->openVerticalBox("Freeverb");
-		interface->addHorizontalSlider("Damp", &fslider0, 0.5f, 0.0f, 1.0f, 2.500000e-02f);
-		interface->addHorizontalSlider("RoomSize", &fslider1, 0.5f, 0.0f, 1.0f, 2.500000e-02f);
-		interface->addHorizontalSlider("Wet", &fslider2, 0.3333f, 0.0f, 1.0f, 2.500000e-02f);
-		interface->closeBox();
-	}
-	virtual void compute (int fullcount, FAUSTFLOAT** input, FAUSTFLOAT** output) {
-		float 	fRec9_tmp[1024+4];
-		float 	fRec19_tmp[1024+4];
-		float 	fZec0[1024];
-		float 	fRec18_tmp[1024+4];
-		float 	fRec21_tmp[1024+4];
-		float 	fRec20_tmp[1024+4];
-		float 	fRec23_tmp[1024+4];
-		float 	fRec22_tmp[1024+4];
-		float 	fRec25_tmp[1024+4];
-		float 	fRec24_tmp[1024+4];
-		float 	fRec27_tmp[1024+4];
-		float 	fRec26_tmp[1024+4];
-		float 	fRec29_tmp[1024+4];
-		float 	fRec28_tmp[1024+4];
-		float 	fRec31_tmp[1024+4];
-		float 	fRec30_tmp[1024+4];
-		float 	fRec33_tmp[1024+4];
-		float 	fRec32_tmp[1024+4];
-		float 	fZec1[1024];
-		float 	fRec16_tmp[1024+4];
-		float 	fRec17[1024];
-		float 	fRec14_tmp[1024+4];
-		float 	fRec15[1024];
-		float 	fRec12_tmp[1024+4];
-		float 	fRec13[1024];
-		float 	fRec10_tmp[1024+4];
-		float 	fRec11[1024];
-		float 	fZec2[1024];
-		float 	fRec43_tmp[1024+4];
-		float 	fRec42_tmp[1024+4];
-		float 	fRec45_tmp[1024+4];
-		float 	fRec44_tmp[1024+4];
-		float 	fRec47_tmp[1024+4];
-		float 	fRec46_tmp[1024+4];
-		float 	fRec49_tmp[1024+4];
-		float 	fRec48_tmp[1024+4];
-		float 	fRec51_tmp[1024+4];
-		float 	fRec50_tmp[1024+4];
-		float 	fRec53_tmp[1024+4];
-		float 	fRec52_tmp[1024+4];
-		float 	fRec55_tmp[1024+4];
-		float 	fRec54_tmp[1024+4];
-		float 	fRec57_tmp[1024+4];
-		float 	fRec56_tmp[1024+4];
-		float 	fZec3[1024];
-		float 	fRec40_tmp[1024+4];
-		float 	fRec41[1024];
-		float 	fRec38_tmp[1024+4];
-		float 	fRec39[1024];
-		float 	fRec36_tmp[1024+4];
-		float 	fRec37[1024];
-		float 	fRec34_tmp[1024+4];
-		float 	fRec35[1024];
-		float 	fZec4[1024];
-		float 	fZec5[1024];
-		float 	fRec8_tmp[1024+4];
-		float 	fRec59_tmp[1024+4];
-		float 	fRec58_tmp[1024+4];
-		float 	fRec61_tmp[1024+4];
-		float 	fRec60_tmp[1024+4];
-		float 	fRec63_tmp[1024+4];
-		float 	fRec62_tmp[1024+4];
-		float 	fRec65_tmp[1024+4];
-		float 	fRec64_tmp[1024+4];
-		float 	fRec67_tmp[1024+4];
-		float 	fRec66_tmp[1024+4];
-		float 	fRec69_tmp[1024+4];
-		float 	fRec68_tmp[1024+4];
-		float 	fRec71_tmp[1024+4];
-		float 	fRec70_tmp[1024+4];
-		float 	fZec6[1024];
-		float 	fRec6_tmp[1024+4];
-		float 	fRec7[1024];
-		float 	fRec4_tmp[1024+4];
-		float 	fRec5[1024];
-		float 	fRec2_tmp[1024+4];
-		float 	fRec3[1024];
-		float 	fRec0_tmp[1024+4];
-		float 	fRec1[1024];
-		float 	fRec81_tmp[1024+4];
-		float 	fRec80_tmp[1024+4];
-		float 	fRec83_tmp[1024+4];
-		float 	fRec82_tmp[1024+4];
-		float 	fRec85_tmp[1024+4];
-		float 	fRec84_tmp[1024+4];
-		float 	fRec87_tmp[1024+4];
-		float 	fRec86_tmp[1024+4];
-		float 	fRec89_tmp[1024+4];
-		float 	fRec88_tmp[1024+4];
-		float 	fRec91_tmp[1024+4];
-		float 	fRec90_tmp[1024+4];
-		float 	fRec93_tmp[1024+4];
-		float 	fRec92_tmp[1024+4];
-		float 	fRec95_tmp[1024+4];
-		float 	fRec94_tmp[1024+4];
-		float 	fZec7[1024];
-		float 	fRec78_tmp[1024+4];
-		float 	fRec79[1024];
-		float 	fRec76_tmp[1024+4];
-		float 	fRec77[1024];
-		float 	fRec74_tmp[1024+4];
-		float 	fRec75[1024];
-		float 	fRec72_tmp[1024+4];
-		float 	fRec73[1024];
-		float 	fSlow0 = (0.4f * fslider0);
-		float 	fSlow1 = (1 - fSlow0);
-		float* 	fRec9 = &fRec9_tmp[4];
-		float 	fSlow2 = (0.7f + (0.28f * fslider1));
-		float* 	fRec19 = &fRec19_tmp[4];
-		float* 	fRec18 = &fRec18_tmp[4];
-		float* 	fRec21 = &fRec21_tmp[4];
-		float* 	fRec20 = &fRec20_tmp[4];
-		float* 	fRec23 = &fRec23_tmp[4];
-		float* 	fRec22 = &fRec22_tmp[4];
-		float* 	fRec25 = &fRec25_tmp[4];
-		float* 	fRec24 = &fRec24_tmp[4];
-		float* 	fRec27 = &fRec27_tmp[4];
-		float* 	fRec26 = &fRec26_tmp[4];
-		float* 	fRec29 = &fRec29_tmp[4];
-		float* 	fRec28 = &fRec28_tmp[4];
-		float* 	fRec31 = &fRec31_tmp[4];
-		float* 	fRec30 = &fRec30_tmp[4];
-		float* 	fRec33 = &fRec33_tmp[4];
-		float* 	fRec32 = &fRec32_tmp[4];
-		float* 	fRec16 = &fRec16_tmp[4];
-		float* 	fRec14 = &fRec14_tmp[4];
-		float* 	fRec12 = &fRec12_tmp[4];
-		float* 	fRec10 = &fRec10_tmp[4];
-		float 	fSlow3 = fslider2;
-		float 	fSlow4 = (1 - fSlow3);
-		float* 	fRec43 = &fRec43_tmp[4];
-		float* 	fRec42 = &fRec42_tmp[4];
-		float* 	fRec45 = &fRec45_tmp[4];
-		float* 	fRec44 = &fRec44_tmp[4];
-		float* 	fRec47 = &fRec47_tmp[4];
-		float* 	fRec46 = &fRec46_tmp[4];
-		float* 	fRec49 = &fRec49_tmp[4];
-		float* 	fRec48 = &fRec48_tmp[4];
-		float* 	fRec51 = &fRec51_tmp[4];
-		float* 	fRec50 = &fRec50_tmp[4];
-		float* 	fRec53 = &fRec53_tmp[4];
-		float* 	fRec52 = &fRec52_tmp[4];
-		float* 	fRec55 = &fRec55_tmp[4];
-		float* 	fRec54 = &fRec54_tmp[4];
-		float* 	fRec57 = &fRec57_tmp[4];
-		float* 	fRec56 = &fRec56_tmp[4];
-		float* 	fRec40 = &fRec40_tmp[4];
-		float* 	fRec38 = &fRec38_tmp[4];
-		float* 	fRec36 = &fRec36_tmp[4];
-		float* 	fRec34 = &fRec34_tmp[4];
-		float* 	fRec8 = &fRec8_tmp[4];
-		float* 	fRec59 = &fRec59_tmp[4];
-		float* 	fRec58 = &fRec58_tmp[4];
-		float* 	fRec61 = &fRec61_tmp[4];
-		float* 	fRec60 = &fRec60_tmp[4];
-		float* 	fRec63 = &fRec63_tmp[4];
-		float* 	fRec62 = &fRec62_tmp[4];
-		float* 	fRec65 = &fRec65_tmp[4];
-		float* 	fRec64 = &fRec64_tmp[4];
-		float* 	fRec67 = &fRec67_tmp[4];
-		float* 	fRec66 = &fRec66_tmp[4];
-		float* 	fRec69 = &fRec69_tmp[4];
-		float* 	fRec68 = &fRec68_tmp[4];
-		float* 	fRec71 = &fRec71_tmp[4];
-		float* 	fRec70 = &fRec70_tmp[4];
-		float* 	fRec6 = &fRec6_tmp[4];
-		float* 	fRec4 = &fRec4_tmp[4];
-		float* 	fRec2 = &fRec2_tmp[4];
-		float* 	fRec0 = &fRec0_tmp[4];
-		float* 	fRec81 = &fRec81_tmp[4];
-		float* 	fRec80 = &fRec80_tmp[4];
-		float* 	fRec83 = &fRec83_tmp[4];
-		float* 	fRec82 = &fRec82_tmp[4];
-		float* 	fRec85 = &fRec85_tmp[4];
-		float* 	fRec84 = &fRec84_tmp[4];
-		float* 	fRec87 = &fRec87_tmp[4];
-		float* 	fRec86 = &fRec86_tmp[4];
-		float* 	fRec89 = &fRec89_tmp[4];
-		float* 	fRec88 = &fRec88_tmp[4];
-		float* 	fRec91 = &fRec91_tmp[4];
-		float* 	fRec90 = &fRec90_tmp[4];
-		float* 	fRec93 = &fRec93_tmp[4];
-		float* 	fRec92 = &fRec92_tmp[4];
-		float* 	fRec95 = &fRec95_tmp[4];
-		float* 	fRec94 = &fRec94_tmp[4];
-		float* 	fRec78 = &fRec78_tmp[4];
-		float* 	fRec76 = &fRec76_tmp[4];
-		float* 	fRec74 = &fRec74_tmp[4];
-		float* 	fRec72 = &fRec72_tmp[4];
-		int index;
-		for (index = 0; index <= fullcount - 1024; index += 1024) {
-			// compute by blocks of 1024 samples
-			const int count = 1024;
-			FAUSTFLOAT* input0 = &input[0][index];
-			FAUSTFLOAT* input1 = &input[1][index];
-			FAUSTFLOAT* output0 = &output[0][index];
-			FAUSTFLOAT* output1 = &output[1][index];
-			// SECTION : 1
-			// LOOP 0x101350bc0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec0[i] = (1.500000e-02f * ((float)input0[i] + (float)input1[i]));
-			}
-			
-			// SECTION : 2
-			// LOOP 0x10134f970
-			// pre processing
-			for (int i=0; i<4; i++) fRec19_tmp[i]=fRec19_perm[i];
-			fYec0_idx = (fYec0_idx+fYec0_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec18_tmp[i]=fRec18_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec19[i] = ((fSlow1 * fRec18[i-1]) + (fSlow0 * fRec19[i-1]));
-				fYec0[(fYec0_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec19[i]));
-				fRec18[i] = fYec0[(fYec0_idx+i-1617)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec18_perm[i]=fRec18_tmp[count+i];
-			fYec0_idx_save = count;
-			for (int i=0; i<4; i++) fRec19_perm[i]=fRec19_tmp[count+i];
-			
-			// LOOP 0x101351ed0
-			// pre processing
-			for (int i=0; i<4; i++) fRec21_tmp[i]=fRec21_perm[i];
-			fYec1_idx = (fYec1_idx+fYec1_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec20_tmp[i]=fRec20_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec21[i] = ((fSlow1 * fRec20[i-1]) + (fSlow0 * fRec21[i-1]));
-				fYec1[(fYec1_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec21[i]));
-				fRec20[i] = fYec1[(fYec1_idx+i-1557)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec20_perm[i]=fRec20_tmp[count+i];
-			fYec1_idx_save = count;
-			for (int i=0; i<4; i++) fRec21_perm[i]=fRec21_tmp[count+i];
-			
-			// LOOP 0x101353a50
-			// pre processing
-			for (int i=0; i<4; i++) fRec23_tmp[i]=fRec23_perm[i];
-			fYec2_idx = (fYec2_idx+fYec2_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec22_tmp[i]=fRec22_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec23[i] = ((fSlow1 * fRec22[i-1]) + (fSlow0 * fRec23[i-1]));
-				fYec2[(fYec2_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec23[i]));
-				fRec22[i] = fYec2[(fYec2_idx+i-1491)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec22_perm[i]=fRec22_tmp[count+i];
-			fYec2_idx_save = count;
-			for (int i=0; i<4; i++) fRec23_perm[i]=fRec23_tmp[count+i];
-			
-			// LOOP 0x1013555d0
-			// pre processing
-			for (int i=0; i<4; i++) fRec25_tmp[i]=fRec25_perm[i];
-			fYec3_idx = (fYec3_idx+fYec3_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec24_tmp[i]=fRec24_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec25[i] = ((fSlow1 * fRec24[i-1]) + (fSlow0 * fRec25[i-1]));
-				fYec3[(fYec3_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec25[i]));
-				fRec24[i] = fYec3[(fYec3_idx+i-1422)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec24_perm[i]=fRec24_tmp[count+i];
-			fYec3_idx_save = count;
-			for (int i=0; i<4; i++) fRec25_perm[i]=fRec25_tmp[count+i];
-			
-			// LOOP 0x101357120
-			// pre processing
-			for (int i=0; i<4; i++) fRec27_tmp[i]=fRec27_perm[i];
-			fYec4_idx = (fYec4_idx+fYec4_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec26_tmp[i]=fRec26_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec27[i] = ((fSlow1 * fRec26[i-1]) + (fSlow0 * fRec27[i-1]));
-				fYec4[(fYec4_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec27[i]));
-				fRec26[i] = fYec4[(fYec4_idx+i-1356)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec26_perm[i]=fRec26_tmp[count+i];
-			fYec4_idx_save = count;
-			for (int i=0; i<4; i++) fRec27_perm[i]=fRec27_tmp[count+i];
-			
-			// LOOP 0x101358c70
-			// pre processing
-			for (int i=0; i<4; i++) fRec29_tmp[i]=fRec29_perm[i];
-			fYec5_idx = (fYec5_idx+fYec5_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec28_tmp[i]=fRec28_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec29[i] = ((fSlow1 * fRec28[i-1]) + (fSlow0 * fRec29[i-1]));
-				fYec5[(fYec5_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec29[i]));
-				fRec28[i] = fYec5[(fYec5_idx+i-1277)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec28_perm[i]=fRec28_tmp[count+i];
-			fYec5_idx_save = count;
-			for (int i=0; i<4; i++) fRec29_perm[i]=fRec29_tmp[count+i];
-			
-			// LOOP 0x10135a7e0
-			// pre processing
-			for (int i=0; i<4; i++) fRec31_tmp[i]=fRec31_perm[i];
-			fYec6_idx = (fYec6_idx+fYec6_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec30_tmp[i]=fRec30_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec31[i] = ((fSlow1 * fRec30[i-1]) + (fSlow0 * fRec31[i-1]));
-				fYec6[(fYec6_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec31[i]));
-				fRec30[i] = fYec6[(fYec6_idx+i-1188)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec30_perm[i]=fRec30_tmp[count+i];
-			fYec6_idx_save = count;
-			for (int i=0; i<4; i++) fRec31_perm[i]=fRec31_tmp[count+i];
-			
-			// LOOP 0x10135c330
-			// pre processing
-			for (int i=0; i<4; i++) fRec33_tmp[i]=fRec33_perm[i];
-			fYec7_idx = (fYec7_idx+fYec7_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec32_tmp[i]=fRec32_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec33[i] = ((fSlow1 * fRec32[i-1]) + (fSlow0 * fRec33[i-1]));
-				fYec7[(fYec7_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec33[i]));
-				fRec32[i] = fYec7[(fYec7_idx+i-1116)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec32_perm[i]=fRec32_tmp[count+i];
-			fYec7_idx_save = count;
-			for (int i=0; i<4; i++) fRec33_perm[i]=fRec33_tmp[count+i];
-			
-			// LOOP 0x101364b70
-			// pre processing
-			for (int i=0; i<4; i++) fRec43_tmp[i]=fRec43_perm[i];
-			fYec12_idx = (fYec12_idx+fYec12_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec42_tmp[i]=fRec42_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec43[i] = ((fSlow1 * fRec42[i-1]) + (fSlow0 * fRec43[i-1]));
-				fYec12[(fYec12_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec43[i]));
-				fRec42[i] = fYec12[(fYec12_idx+i-1640)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec42_perm[i]=fRec42_tmp[count+i];
-			fYec12_idx_save = count;
-			for (int i=0; i<4; i++) fRec43_perm[i]=fRec43_tmp[count+i];
-			
-			// LOOP 0x1013667b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec45_tmp[i]=fRec45_perm[i];
-			fYec13_idx = (fYec13_idx+fYec13_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec44_tmp[i]=fRec44_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec45[i] = ((fSlow1 * fRec44[i-1]) + (fSlow0 * fRec45[i-1]));
-				fYec13[(fYec13_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec45[i]));
-				fRec44[i] = fYec13[(fYec13_idx+i-1580)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec44_perm[i]=fRec44_tmp[count+i];
-			fYec13_idx_save = count;
-			for (int i=0; i<4; i++) fRec45_perm[i]=fRec45_tmp[count+i];
-			
-			// LOOP 0x101368330
-			// pre processing
-			for (int i=0; i<4; i++) fRec47_tmp[i]=fRec47_perm[i];
-			fYec14_idx = (fYec14_idx+fYec14_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec46_tmp[i]=fRec46_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec47[i] = ((fSlow1 * fRec46[i-1]) + (fSlow0 * fRec47[i-1]));
-				fYec14[(fYec14_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec47[i]));
-				fRec46[i] = fYec14[(fYec14_idx+i-1514)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec46_perm[i]=fRec46_tmp[count+i];
-			fYec14_idx_save = count;
-			for (int i=0; i<4; i++) fRec47_perm[i]=fRec47_tmp[count+i];
-			
-			// LOOP 0x101369f40
-			// pre processing
-			for (int i=0; i<4; i++) fRec49_tmp[i]=fRec49_perm[i];
-			fYec15_idx = (fYec15_idx+fYec15_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec48_tmp[i]=fRec48_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec49[i] = ((fSlow1 * fRec48[i-1]) + (fSlow0 * fRec49[i-1]));
-				fYec15[(fYec15_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec49[i]));
-				fRec48[i] = fYec15[(fYec15_idx+i-1445)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec48_perm[i]=fRec48_tmp[count+i];
-			fYec15_idx_save = count;
-			for (int i=0; i<4; i++) fRec49_perm[i]=fRec49_tmp[count+i];
-			
-			// LOOP 0x10136bae0
-			// pre processing
-			for (int i=0; i<4; i++) fRec51_tmp[i]=fRec51_perm[i];
-			fYec16_idx = (fYec16_idx+fYec16_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec50_tmp[i]=fRec50_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec51[i] = ((fSlow1 * fRec50[i-1]) + (fSlow0 * fRec51[i-1]));
-				fYec16[(fYec16_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec51[i]));
-				fRec50[i] = fYec16[(fYec16_idx+i-1379)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec50_perm[i]=fRec50_tmp[count+i];
-			fYec16_idx_save = count;
-			for (int i=0; i<4; i++) fRec51_perm[i]=fRec51_tmp[count+i];
-			
-			// LOOP 0x10136d660
-			// pre processing
-			for (int i=0; i<4; i++) fRec53_tmp[i]=fRec53_perm[i];
-			fYec17_idx = (fYec17_idx+fYec17_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec52_tmp[i]=fRec52_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec53[i] = ((fSlow1 * fRec52[i-1]) + (fSlow0 * fRec53[i-1]));
-				fYec17[(fYec17_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec53[i]));
-				fRec52[i] = fYec17[(fYec17_idx+i-1300)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec52_perm[i]=fRec52_tmp[count+i];
-			fYec17_idx_save = count;
-			for (int i=0; i<4; i++) fRec53_perm[i]=fRec53_tmp[count+i];
-			
-			// LOOP 0x10136f1e0
-			// pre processing
-			for (int i=0; i<4; i++) fRec55_tmp[i]=fRec55_perm[i];
-			fYec18_idx = (fYec18_idx+fYec18_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec54_tmp[i]=fRec54_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec55[i] = ((fSlow1 * fRec54[i-1]) + (fSlow0 * fRec55[i-1]));
-				fYec18[(fYec18_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec55[i]));
-				fRec54[i] = fYec18[(fYec18_idx+i-1211)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec54_perm[i]=fRec54_tmp[count+i];
-			fYec18_idx_save = count;
-			for (int i=0; i<4; i++) fRec55_perm[i]=fRec55_tmp[count+i];
-			
-			// LOOP 0x101370d60
-			// pre processing
-			for (int i=0; i<4; i++) fRec57_tmp[i]=fRec57_perm[i];
-			fYec19_idx = (fYec19_idx+fYec19_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec56_tmp[i]=fRec56_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec57[i] = ((fSlow1 * fRec56[i-1]) + (fSlow0 * fRec57[i-1]));
-				fYec19[(fYec19_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec57[i]));
-				fRec56[i] = fYec19[(fYec19_idx+i-1139)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec56_perm[i]=fRec56_tmp[count+i];
-			fYec19_idx_save = count;
-			for (int i=0; i<4; i++) fRec57_perm[i]=fRec57_tmp[count+i];
-			
-			// SECTION : 3
-			// LOOP 0x10134f870
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec1[i] = (((((((fRec32[i] + fRec30[i]) + fRec28[i]) + fRec26[i]) + fRec24[i]) + fRec22[i]) + fRec20[i]) + fRec18[i]);
-			}
-			
-			// LOOP 0x101364a70
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec3[i] = (((((((fRec56[i] + fRec54[i]) + fRec52[i]) + fRec50[i]) + fRec48[i]) + fRec46[i]) + fRec44[i]) + fRec42[i]);
-			}
-			
-			// SECTION : 4
-			// LOOP 0x10134f120
-			// pre processing
-			fYec8_idx = (fYec8_idx+fYec8_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec16_tmp[i]=fRec16_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec8[(fYec8_idx+i)&2047] = (fZec1[i] + (0.5f * fRec16[i-1]));
-				fRec16[i] = fYec8[(fYec8_idx+i-556)&2047];
-				fRec17[i] = (0 - (fZec1[i] - fRec16[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec16_perm[i]=fRec16_tmp[count+i];
-			fYec8_idx_save = count;
-			
-			// LOOP 0x101364320
-			// pre processing
-			fYec20_idx = (fYec20_idx+fYec20_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec40_tmp[i]=fRec40_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec20[(fYec20_idx+i)&2047] = (fZec3[i] + (0.5f * fRec40[i-1]));
-				fRec40[i] = fYec20[(fYec20_idx+i-579)&2047];
-				fRec41[i] = (0 - (fZec3[i] - fRec40[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec40_perm[i]=fRec40_tmp[count+i];
-			fYec20_idx_save = count;
-			
-			// SECTION : 5
-			// LOOP 0x10134e9d0
-			// pre processing
-			fYec9_idx = (fYec9_idx+fYec9_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec14_tmp[i]=fRec14_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec9[(fYec9_idx+i)&2047] = (fRec17[i] + (0.5f * fRec14[i-1]));
-				fRec14[i] = fYec9[(fYec9_idx+i-441)&2047];
-				fRec15[i] = (fRec14[i-1] - fRec17[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec14_perm[i]=fRec14_tmp[count+i];
-			fYec9_idx_save = count;
-			
-			// LOOP 0x101363bd0
-			// pre processing
-			fYec21_idx = (fYec21_idx+fYec21_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec38_tmp[i]=fRec38_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec21[(fYec21_idx+i)&2047] = (fRec41[i] + (0.5f * fRec38[i-1]));
-				fRec38[i] = fYec21[(fYec21_idx+i-464)&2047];
-				fRec39[i] = (fRec38[i-1] - fRec41[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec38_perm[i]=fRec38_tmp[count+i];
-			fYec21_idx_save = count;
-			
-			// SECTION : 6
-			// LOOP 0x10134e2a0
-			// pre processing
-			fYec10_idx = (fYec10_idx+fYec10_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec12_tmp[i]=fRec12_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec10[(fYec10_idx+i)&2047] = (fRec15[i] + (0.5f * fRec12[i-1]));
-				fRec12[i] = fYec10[(fYec10_idx+i-341)&2047];
-				fRec13[i] = (fRec12[i-1] - fRec15[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec12_perm[i]=fRec12_tmp[count+i];
-			fYec10_idx_save = count;
-			
-			// LOOP 0x1013634a0
-			// pre processing
-			fYec22_idx = (fYec22_idx+fYec22_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec36_tmp[i]=fRec36_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec22[(fYec22_idx+i)&2047] = (fRec39[i] + (0.5f * fRec36[i-1]));
-				fRec36[i] = fYec22[(fYec22_idx+i-364)&2047];
-				fRec37[i] = (fRec36[i-1] - fRec39[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec36_perm[i]=fRec36_tmp[count+i];
-			fYec22_idx_save = count;
-			
-			// SECTION : 7
-			// LOOP 0x10134dba0
-			// pre processing
-			fYec11_idx = (fYec11_idx+fYec11_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec10_tmp[i]=fRec10_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec11[(fYec11_idx+i)&2047] = (fRec13[i] + (0.5f * fRec10[i-1]));
-				fRec10[i] = fYec11[(fYec11_idx+i-225)&2047];
-				fRec11[i] = (fRec10[i-1] - fRec13[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec10_perm[i]=fRec10_tmp[count+i];
-			fYec11_idx_save = count;
-			
-			// LOOP 0x101362e30
-			// pre processing
-			fYec23_idx = (fYec23_idx+fYec23_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec34_tmp[i]=fRec34_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec23[(fYec23_idx+i)&2047] = (fRec37[i] + (0.5f * fRec34[i-1]));
-				fRec34[i] = fYec23[(fYec23_idx+i-248)&2047];
-				fRec35[i] = (fRec34[i-1] - fRec37[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec34_perm[i]=fRec34_tmp[count+i];
-			fYec23_idx_save = count;
-			
-			// SECTION : 8
-			// LOOP 0x10134daa0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec2[i] = ((fSlow4 * (float)input0[i]) + (fSlow3 * fRec11[i]));
-			}
-			
-			// LOOP 0x101362d30
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec4[i] = ((fSlow4 * (float)input1[i]) + (fSlow3 * fRec35[i]));
-			}
-			
-			// SECTION : 9
-			// LOOP 0x10134d9a0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec5[i] = (1.500000e-02f * (fZec4[i] + fZec2[i]));
-			}
-			
-			// SECTION : 10
-			// LOOP 0x10134b4b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec9_tmp[i]=fRec9_perm[i];
-			fYec24_idx = (fYec24_idx+fYec24_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec8_tmp[i]=fRec8_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec9[i] = ((fSlow1 * fRec8[i-1]) + (fSlow0 * fRec9[i-1]));
-				fYec24[(fYec24_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec9[i]));
-				fRec8[i] = fYec24[(fYec24_idx+i-1617)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec8_perm[i]=fRec8_tmp[count+i];
-			fYec24_idx_save = count;
-			for (int i=0; i<4; i++) fRec9_perm[i]=fRec9_tmp[count+i];
-			
-			// LOOP 0x101377dc0
-			// pre processing
-			for (int i=0; i<4; i++) fRec59_tmp[i]=fRec59_perm[i];
-			fYec25_idx = (fYec25_idx+fYec25_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec58_tmp[i]=fRec58_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec59[i] = ((fSlow1 * fRec58[i-1]) + (fSlow0 * fRec59[i-1]));
-				fYec25[(fYec25_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec59[i]));
-				fRec58[i] = fYec25[(fYec25_idx+i-1557)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec58_perm[i]=fRec58_tmp[count+i];
-			fYec25_idx_save = count;
-			for (int i=0; i<4; i++) fRec59_perm[i]=fRec59_tmp[count+i];
-			
-			// LOOP 0x101379900
-			// pre processing
-			for (int i=0; i<4; i++) fRec61_tmp[i]=fRec61_perm[i];
-			fYec26_idx = (fYec26_idx+fYec26_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec60_tmp[i]=fRec60_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec61[i] = ((fSlow1 * fRec60[i-1]) + (fSlow0 * fRec61[i-1]));
-				fYec26[(fYec26_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec61[i]));
-				fRec60[i] = fYec26[(fYec26_idx+i-1491)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec60_perm[i]=fRec60_tmp[count+i];
-			fYec26_idx_save = count;
-			for (int i=0; i<4; i++) fRec61_perm[i]=fRec61_tmp[count+i];
-			
-			// LOOP 0x10137b480
-			// pre processing
-			for (int i=0; i<4; i++) fRec63_tmp[i]=fRec63_perm[i];
-			fYec27_idx = (fYec27_idx+fYec27_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec62_tmp[i]=fRec62_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec63[i] = ((fSlow1 * fRec62[i-1]) + (fSlow0 * fRec63[i-1]));
-				fYec27[(fYec27_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec63[i]));
-				fRec62[i] = fYec27[(fYec27_idx+i-1422)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec62_perm[i]=fRec62_tmp[count+i];
-			fYec27_idx_save = count;
-			for (int i=0; i<4; i++) fRec63_perm[i]=fRec63_tmp[count+i];
-			
-			// LOOP 0x10137d000
-			// pre processing
-			for (int i=0; i<4; i++) fRec65_tmp[i]=fRec65_perm[i];
-			fYec28_idx = (fYec28_idx+fYec28_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec64_tmp[i]=fRec64_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec65[i] = ((fSlow1 * fRec64[i-1]) + (fSlow0 * fRec65[i-1]));
-				fYec28[(fYec28_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec65[i]));
-				fRec64[i] = fYec28[(fYec28_idx+i-1356)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec64_perm[i]=fRec64_tmp[count+i];
-			fYec28_idx_save = count;
-			for (int i=0; i<4; i++) fRec65_perm[i]=fRec65_tmp[count+i];
-			
-			// LOOP 0x10137eb80
-			// pre processing
-			for (int i=0; i<4; i++) fRec67_tmp[i]=fRec67_perm[i];
-			fYec29_idx = (fYec29_idx+fYec29_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec66_tmp[i]=fRec66_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec67[i] = ((fSlow1 * fRec66[i-1]) + (fSlow0 * fRec67[i-1]));
-				fYec29[(fYec29_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec67[i]));
-				fRec66[i] = fYec29[(fYec29_idx+i-1277)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec66_perm[i]=fRec66_tmp[count+i];
-			fYec29_idx_save = count;
-			for (int i=0; i<4; i++) fRec67_perm[i]=fRec67_tmp[count+i];
-			
-			// LOOP 0x101380700
-			// pre processing
-			for (int i=0; i<4; i++) fRec69_tmp[i]=fRec69_perm[i];
-			fYec30_idx = (fYec30_idx+fYec30_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec68_tmp[i]=fRec68_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec69[i] = ((fSlow1 * fRec68[i-1]) + (fSlow0 * fRec69[i-1]));
-				fYec30[(fYec30_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec69[i]));
-				fRec68[i] = fYec30[(fYec30_idx+i-1188)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec68_perm[i]=fRec68_tmp[count+i];
-			fYec30_idx_save = count;
-			for (int i=0; i<4; i++) fRec69_perm[i]=fRec69_tmp[count+i];
-			
-			// LOOP 0x101382280
-			// pre processing
-			for (int i=0; i<4; i++) fRec71_tmp[i]=fRec71_perm[i];
-			fYec31_idx = (fYec31_idx+fYec31_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec70_tmp[i]=fRec70_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec71[i] = ((fSlow1 * fRec70[i-1]) + (fSlow0 * fRec71[i-1]));
-				fYec31[(fYec31_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec71[i]));
-				fRec70[i] = fYec31[(fYec31_idx+i-1116)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec70_perm[i]=fRec70_tmp[count+i];
-			fYec31_idx_save = count;
-			for (int i=0; i<4; i++) fRec71_perm[i]=fRec71_tmp[count+i];
-			
-			// LOOP 0x101389fc0
-			// pre processing
-			for (int i=0; i<4; i++) fRec81_tmp[i]=fRec81_perm[i];
-			fYec36_idx = (fYec36_idx+fYec36_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec80_tmp[i]=fRec80_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec81[i] = ((fSlow1 * fRec80[i-1]) + (fSlow0 * fRec81[i-1]));
-				fYec36[(fYec36_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec81[i]));
-				fRec80[i] = fYec36[(fYec36_idx+i-1640)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec80_perm[i]=fRec80_tmp[count+i];
-			fYec36_idx_save = count;
-			for (int i=0; i<4; i++) fRec81_perm[i]=fRec81_tmp[count+i];
-			
-			// LOOP 0x10138bc10
-			// pre processing
-			for (int i=0; i<4; i++) fRec83_tmp[i]=fRec83_perm[i];
-			fYec37_idx = (fYec37_idx+fYec37_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec82_tmp[i]=fRec82_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec83[i] = ((fSlow1 * fRec82[i-1]) + (fSlow0 * fRec83[i-1]));
-				fYec37[(fYec37_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec83[i]));
-				fRec82[i] = fYec37[(fYec37_idx+i-1580)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec82_perm[i]=fRec82_tmp[count+i];
-			fYec37_idx_save = count;
-			for (int i=0; i<4; i++) fRec83_perm[i]=fRec83_tmp[count+i];
-			
-			// LOOP 0x10138d7b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec85_tmp[i]=fRec85_perm[i];
-			fYec38_idx = (fYec38_idx+fYec38_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec84_tmp[i]=fRec84_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec85[i] = ((fSlow1 * fRec84[i-1]) + (fSlow0 * fRec85[i-1]));
-				fYec38[(fYec38_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec85[i]));
-				fRec84[i] = fYec38[(fYec38_idx+i-1514)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec84_perm[i]=fRec84_tmp[count+i];
-			fYec38_idx_save = count;
-			for (int i=0; i<4; i++) fRec85_perm[i]=fRec85_tmp[count+i];
-			
-			// LOOP 0x10138f330
-			// pre processing
-			for (int i=0; i<4; i++) fRec87_tmp[i]=fRec87_perm[i];
-			fYec39_idx = (fYec39_idx+fYec39_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec86_tmp[i]=fRec86_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec87[i] = ((fSlow1 * fRec86[i-1]) + (fSlow0 * fRec87[i-1]));
-				fYec39[(fYec39_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec87[i]));
-				fRec86[i] = fYec39[(fYec39_idx+i-1445)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec86_perm[i]=fRec86_tmp[count+i];
-			fYec39_idx_save = count;
-			for (int i=0; i<4; i++) fRec87_perm[i]=fRec87_tmp[count+i];
-			
-			// LOOP 0x101390eb0
-			// pre processing
-			for (int i=0; i<4; i++) fRec89_tmp[i]=fRec89_perm[i];
-			fYec40_idx = (fYec40_idx+fYec40_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec88_tmp[i]=fRec88_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec89[i] = ((fSlow1 * fRec88[i-1]) + (fSlow0 * fRec89[i-1]));
-				fYec40[(fYec40_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec89[i]));
-				fRec88[i] = fYec40[(fYec40_idx+i-1379)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec88_perm[i]=fRec88_tmp[count+i];
-			fYec40_idx_save = count;
-			for (int i=0; i<4; i++) fRec89_perm[i]=fRec89_tmp[count+i];
-			
-			// LOOP 0x101392a30
-			// pre processing
-			for (int i=0; i<4; i++) fRec91_tmp[i]=fRec91_perm[i];
-			fYec41_idx = (fYec41_idx+fYec41_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec90_tmp[i]=fRec90_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec91[i] = ((fSlow1 * fRec90[i-1]) + (fSlow0 * fRec91[i-1]));
-				fYec41[(fYec41_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec91[i]));
-				fRec90[i] = fYec41[(fYec41_idx+i-1300)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec90_perm[i]=fRec90_tmp[count+i];
-			fYec41_idx_save = count;
-			for (int i=0; i<4; i++) fRec91_perm[i]=fRec91_tmp[count+i];
-			
-			// LOOP 0x1013945b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec93_tmp[i]=fRec93_perm[i];
-			fYec42_idx = (fYec42_idx+fYec42_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec92_tmp[i]=fRec92_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec93[i] = ((fSlow1 * fRec92[i-1]) + (fSlow0 * fRec93[i-1]));
-				fYec42[(fYec42_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec93[i]));
-				fRec92[i] = fYec42[(fYec42_idx+i-1211)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec92_perm[i]=fRec92_tmp[count+i];
-			fYec42_idx_save = count;
-			for (int i=0; i<4; i++) fRec93_perm[i]=fRec93_tmp[count+i];
-			
-			// LOOP 0x101396130
-			// pre processing
-			for (int i=0; i<4; i++) fRec95_tmp[i]=fRec95_perm[i];
-			fYec43_idx = (fYec43_idx+fYec43_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec94_tmp[i]=fRec94_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec95[i] = ((fSlow1 * fRec94[i-1]) + (fSlow0 * fRec95[i-1]));
-				fYec43[(fYec43_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec95[i]));
-				fRec94[i] = fYec43[(fYec43_idx+i-1139)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec94_perm[i]=fRec94_tmp[count+i];
-			fYec43_idx_save = count;
-			for (int i=0; i<4; i++) fRec95_perm[i]=fRec95_tmp[count+i];
-			
-			// SECTION : 11
-			// LOOP 0x10134b3b0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec6[i] = (((((((fRec70[i] + fRec68[i]) + fRec66[i]) + fRec64[i]) + fRec62[i]) + fRec60[i]) + fRec58[i]) + fRec8[i]);
-			}
-			
-			// LOOP 0x101389ec0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec7[i] = (((((((fRec94[i] + fRec92[i]) + fRec90[i]) + fRec88[i]) + fRec86[i]) + fRec84[i]) + fRec82[i]) + fRec80[i]);
-			}
-			
-			// SECTION : 12
-			// LOOP 0x10134acd0
-			// pre processing
-			fYec32_idx = (fYec32_idx+fYec32_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec6_tmp[i]=fRec6_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec32[(fYec32_idx+i)&2047] = (fZec6[i] + (0.5f * fRec6[i-1]));
-				fRec6[i] = fYec32[(fYec32_idx+i-556)&2047];
-				fRec7[i] = (0 - (fZec6[i] - fRec6[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec6_perm[i]=fRec6_tmp[count+i];
-			fYec32_idx_save = count;
-			
-			// LOOP 0x1013897e0
-			// pre processing
-			fYec44_idx = (fYec44_idx+fYec44_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec78_tmp[i]=fRec78_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec44[(fYec44_idx+i)&2047] = (fZec7[i] + (0.5f * fRec78[i-1]));
-				fRec78[i] = fYec44[(fYec44_idx+i-579)&2047];
-				fRec79[i] = (0 - (fZec7[i] - fRec78[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec78_perm[i]=fRec78_tmp[count+i];
-			fYec44_idx_save = count;
-			
-			// SECTION : 13
-			// LOOP 0x10134a5f0
-			// pre processing
-			fYec33_idx = (fYec33_idx+fYec33_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec4_tmp[i]=fRec4_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec33[(fYec33_idx+i)&2047] = (fRec7[i] + (0.5f * fRec4[i-1]));
-				fRec4[i] = fYec33[(fYec33_idx+i-441)&2047];
-				fRec5[i] = (fRec4[i-1] - fRec7[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec4_perm[i]=fRec4_tmp[count+i];
-			fYec33_idx_save = count;
-			
-			// LOOP 0x101389100
-			// pre processing
-			fYec45_idx = (fYec45_idx+fYec45_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec76_tmp[i]=fRec76_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec45[(fYec45_idx+i)&2047] = (fRec79[i] + (0.5f * fRec76[i-1]));
-				fRec76[i] = fYec45[(fYec45_idx+i-464)&2047];
-				fRec77[i] = (fRec76[i-1] - fRec79[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec76_perm[i]=fRec76_tmp[count+i];
-			fYec45_idx_save = count;
-			
-			// SECTION : 14
-			// LOOP 0x101349f10
-			// pre processing
-			fYec34_idx = (fYec34_idx+fYec34_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec2_tmp[i]=fRec2_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec34[(fYec34_idx+i)&2047] = (fRec5[i] + (0.5f * fRec2[i-1]));
-				fRec2[i] = fYec34[(fYec34_idx+i-341)&2047];
-				fRec3[i] = (fRec2[i-1] - fRec5[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec2_perm[i]=fRec2_tmp[count+i];
-			fYec34_idx_save = count;
-			
-			// LOOP 0x101388a20
-			// pre processing
-			fYec46_idx = (fYec46_idx+fYec46_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec74_tmp[i]=fRec74_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec46[(fYec46_idx+i)&2047] = (fRec77[i] + (0.5f * fRec74[i-1]));
-				fRec74[i] = fYec46[(fYec46_idx+i-364)&2047];
-				fRec75[i] = (fRec74[i-1] - fRec77[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec74_perm[i]=fRec74_tmp[count+i];
-			fYec46_idx_save = count;
-			
-			// SECTION : 15
-			// LOOP 0x101349700
-			// pre processing
-			fYec35_idx = (fYec35_idx+fYec35_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec0_tmp[i]=fRec0_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec35[(fYec35_idx+i)&2047] = (fRec3[i] + (0.5f * fRec0[i-1]));
-				fRec0[i] = fYec35[(fYec35_idx+i-225)&2047];
-				fRec1[i] = (fRec0[i-1] - fRec3[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec0_perm[i]=fRec0_tmp[count+i];
-			fYec35_idx_save = count;
-			
-			// LOOP 0x1013883a0
-			// pre processing
-			fYec47_idx = (fYec47_idx+fYec47_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec72_tmp[i]=fRec72_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec47[(fYec47_idx+i)&2047] = (fRec75[i] + (0.5f * fRec72[i-1]));
-				fRec72[i] = fYec47[(fYec47_idx+i-248)&2047];
-				fRec73[i] = (fRec72[i-1] - fRec75[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec72_perm[i]=fRec72_tmp[count+i];
-			fYec47_idx_save = count;
-			
-			// SECTION : 16
-			// LOOP 0x101349600
-			// exec code
-			for (int i=0; i<count; i++) {
-				output0[i] = (FAUSTFLOAT)((fSlow4 * fZec2[i]) + (fSlow3 * fRec1[i]));
-			}
-			
-			// LOOP 0x1013881d0
-			// exec code
-			for (int i=0; i<count; i++) {
-				output1[i] = (FAUSTFLOAT)((fSlow4 * fZec4[i]) + (fSlow3 * fRec73[i]));
-			}
-			
-		}
-		if (index < fullcount) {
-			// compute the remaining samples if any
-			int count = fullcount-index;
-			FAUSTFLOAT* input0 = &input[0][index];
-			FAUSTFLOAT* input1 = &input[1][index];
-			FAUSTFLOAT* output0 = &output[0][index];
-			FAUSTFLOAT* output1 = &output[1][index];
-			// SECTION : 1
-			// LOOP 0x101350bc0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec0[i] = (1.500000e-02f * ((float)input0[i] + (float)input1[i]));
-			}
-			
-			// SECTION : 2
-			// LOOP 0x10134f970
-			// pre processing
-			for (int i=0; i<4; i++) fRec19_tmp[i]=fRec19_perm[i];
-			fYec0_idx = (fYec0_idx+fYec0_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec18_tmp[i]=fRec18_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec19[i] = ((fSlow1 * fRec18[i-1]) + (fSlow0 * fRec19[i-1]));
-				fYec0[(fYec0_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec19[i]));
-				fRec18[i] = fYec0[(fYec0_idx+i-1617)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec18_perm[i]=fRec18_tmp[count+i];
-			fYec0_idx_save = count;
-			for (int i=0; i<4; i++) fRec19_perm[i]=fRec19_tmp[count+i];
-			
-			// LOOP 0x101351ed0
-			// pre processing
-			for (int i=0; i<4; i++) fRec21_tmp[i]=fRec21_perm[i];
-			fYec1_idx = (fYec1_idx+fYec1_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec20_tmp[i]=fRec20_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec21[i] = ((fSlow1 * fRec20[i-1]) + (fSlow0 * fRec21[i-1]));
-				fYec1[(fYec1_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec21[i]));
-				fRec20[i] = fYec1[(fYec1_idx+i-1557)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec20_perm[i]=fRec20_tmp[count+i];
-			fYec1_idx_save = count;
-			for (int i=0; i<4; i++) fRec21_perm[i]=fRec21_tmp[count+i];
-			
-			// LOOP 0x101353a50
-			// pre processing
-			for (int i=0; i<4; i++) fRec23_tmp[i]=fRec23_perm[i];
-			fYec2_idx = (fYec2_idx+fYec2_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec22_tmp[i]=fRec22_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec23[i] = ((fSlow1 * fRec22[i-1]) + (fSlow0 * fRec23[i-1]));
-				fYec2[(fYec2_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec23[i]));
-				fRec22[i] = fYec2[(fYec2_idx+i-1491)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec22_perm[i]=fRec22_tmp[count+i];
-			fYec2_idx_save = count;
-			for (int i=0; i<4; i++) fRec23_perm[i]=fRec23_tmp[count+i];
-			
-			// LOOP 0x1013555d0
-			// pre processing
-			for (int i=0; i<4; i++) fRec25_tmp[i]=fRec25_perm[i];
-			fYec3_idx = (fYec3_idx+fYec3_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec24_tmp[i]=fRec24_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec25[i] = ((fSlow1 * fRec24[i-1]) + (fSlow0 * fRec25[i-1]));
-				fYec3[(fYec3_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec25[i]));
-				fRec24[i] = fYec3[(fYec3_idx+i-1422)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec24_perm[i]=fRec24_tmp[count+i];
-			fYec3_idx_save = count;
-			for (int i=0; i<4; i++) fRec25_perm[i]=fRec25_tmp[count+i];
-			
-			// LOOP 0x101357120
-			// pre processing
-			for (int i=0; i<4; i++) fRec27_tmp[i]=fRec27_perm[i];
-			fYec4_idx = (fYec4_idx+fYec4_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec26_tmp[i]=fRec26_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec27[i] = ((fSlow1 * fRec26[i-1]) + (fSlow0 * fRec27[i-1]));
-				fYec4[(fYec4_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec27[i]));
-				fRec26[i] = fYec4[(fYec4_idx+i-1356)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec26_perm[i]=fRec26_tmp[count+i];
-			fYec4_idx_save = count;
-			for (int i=0; i<4; i++) fRec27_perm[i]=fRec27_tmp[count+i];
-			
-			// LOOP 0x101358c70
-			// pre processing
-			for (int i=0; i<4; i++) fRec29_tmp[i]=fRec29_perm[i];
-			fYec5_idx = (fYec5_idx+fYec5_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec28_tmp[i]=fRec28_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec29[i] = ((fSlow1 * fRec28[i-1]) + (fSlow0 * fRec29[i-1]));
-				fYec5[(fYec5_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec29[i]));
-				fRec28[i] = fYec5[(fYec5_idx+i-1277)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec28_perm[i]=fRec28_tmp[count+i];
-			fYec5_idx_save = count;
-			for (int i=0; i<4; i++) fRec29_perm[i]=fRec29_tmp[count+i];
-			
-			// LOOP 0x10135a7e0
-			// pre processing
-			for (int i=0; i<4; i++) fRec31_tmp[i]=fRec31_perm[i];
-			fYec6_idx = (fYec6_idx+fYec6_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec30_tmp[i]=fRec30_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec31[i] = ((fSlow1 * fRec30[i-1]) + (fSlow0 * fRec31[i-1]));
-				fYec6[(fYec6_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec31[i]));
-				fRec30[i] = fYec6[(fYec6_idx+i-1188)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec30_perm[i]=fRec30_tmp[count+i];
-			fYec6_idx_save = count;
-			for (int i=0; i<4; i++) fRec31_perm[i]=fRec31_tmp[count+i];
-			
-			// LOOP 0x10135c330
-			// pre processing
-			for (int i=0; i<4; i++) fRec33_tmp[i]=fRec33_perm[i];
-			fYec7_idx = (fYec7_idx+fYec7_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec32_tmp[i]=fRec32_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec33[i] = ((fSlow1 * fRec32[i-1]) + (fSlow0 * fRec33[i-1]));
-				fYec7[(fYec7_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec33[i]));
-				fRec32[i] = fYec7[(fYec7_idx+i-1116)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec32_perm[i]=fRec32_tmp[count+i];
-			fYec7_idx_save = count;
-			for (int i=0; i<4; i++) fRec33_perm[i]=fRec33_tmp[count+i];
-			
-			// LOOP 0x101364b70
-			// pre processing
-			for (int i=0; i<4; i++) fRec43_tmp[i]=fRec43_perm[i];
-			fYec12_idx = (fYec12_idx+fYec12_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec42_tmp[i]=fRec42_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec43[i] = ((fSlow1 * fRec42[i-1]) + (fSlow0 * fRec43[i-1]));
-				fYec12[(fYec12_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec43[i]));
-				fRec42[i] = fYec12[(fYec12_idx+i-1640)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec42_perm[i]=fRec42_tmp[count+i];
-			fYec12_idx_save = count;
-			for (int i=0; i<4; i++) fRec43_perm[i]=fRec43_tmp[count+i];
-			
-			// LOOP 0x1013667b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec45_tmp[i]=fRec45_perm[i];
-			fYec13_idx = (fYec13_idx+fYec13_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec44_tmp[i]=fRec44_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec45[i] = ((fSlow1 * fRec44[i-1]) + (fSlow0 * fRec45[i-1]));
-				fYec13[(fYec13_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec45[i]));
-				fRec44[i] = fYec13[(fYec13_idx+i-1580)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec44_perm[i]=fRec44_tmp[count+i];
-			fYec13_idx_save = count;
-			for (int i=0; i<4; i++) fRec45_perm[i]=fRec45_tmp[count+i];
-			
-			// LOOP 0x101368330
-			// pre processing
-			for (int i=0; i<4; i++) fRec47_tmp[i]=fRec47_perm[i];
-			fYec14_idx = (fYec14_idx+fYec14_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec46_tmp[i]=fRec46_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec47[i] = ((fSlow1 * fRec46[i-1]) + (fSlow0 * fRec47[i-1]));
-				fYec14[(fYec14_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec47[i]));
-				fRec46[i] = fYec14[(fYec14_idx+i-1514)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec46_perm[i]=fRec46_tmp[count+i];
-			fYec14_idx_save = count;
-			for (int i=0; i<4; i++) fRec47_perm[i]=fRec47_tmp[count+i];
-			
-			// LOOP 0x101369f40
-			// pre processing
-			for (int i=0; i<4; i++) fRec49_tmp[i]=fRec49_perm[i];
-			fYec15_idx = (fYec15_idx+fYec15_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec48_tmp[i]=fRec48_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec49[i] = ((fSlow1 * fRec48[i-1]) + (fSlow0 * fRec49[i-1]));
-				fYec15[(fYec15_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec49[i]));
-				fRec48[i] = fYec15[(fYec15_idx+i-1445)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec48_perm[i]=fRec48_tmp[count+i];
-			fYec15_idx_save = count;
-			for (int i=0; i<4; i++) fRec49_perm[i]=fRec49_tmp[count+i];
-			
-			// LOOP 0x10136bae0
-			// pre processing
-			for (int i=0; i<4; i++) fRec51_tmp[i]=fRec51_perm[i];
-			fYec16_idx = (fYec16_idx+fYec16_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec50_tmp[i]=fRec50_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec51[i] = ((fSlow1 * fRec50[i-1]) + (fSlow0 * fRec51[i-1]));
-				fYec16[(fYec16_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec51[i]));
-				fRec50[i] = fYec16[(fYec16_idx+i-1379)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec50_perm[i]=fRec50_tmp[count+i];
-			fYec16_idx_save = count;
-			for (int i=0; i<4; i++) fRec51_perm[i]=fRec51_tmp[count+i];
-			
-			// LOOP 0x10136d660
-			// pre processing
-			for (int i=0; i<4; i++) fRec53_tmp[i]=fRec53_perm[i];
-			fYec17_idx = (fYec17_idx+fYec17_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec52_tmp[i]=fRec52_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec53[i] = ((fSlow1 * fRec52[i-1]) + (fSlow0 * fRec53[i-1]));
-				fYec17[(fYec17_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec53[i]));
-				fRec52[i] = fYec17[(fYec17_idx+i-1300)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec52_perm[i]=fRec52_tmp[count+i];
-			fYec17_idx_save = count;
-			for (int i=0; i<4; i++) fRec53_perm[i]=fRec53_tmp[count+i];
-			
-			// LOOP 0x10136f1e0
-			// pre processing
-			for (int i=0; i<4; i++) fRec55_tmp[i]=fRec55_perm[i];
-			fYec18_idx = (fYec18_idx+fYec18_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec54_tmp[i]=fRec54_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec55[i] = ((fSlow1 * fRec54[i-1]) + (fSlow0 * fRec55[i-1]));
-				fYec18[(fYec18_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec55[i]));
-				fRec54[i] = fYec18[(fYec18_idx+i-1211)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec54_perm[i]=fRec54_tmp[count+i];
-			fYec18_idx_save = count;
-			for (int i=0; i<4; i++) fRec55_perm[i]=fRec55_tmp[count+i];
-			
-			// LOOP 0x101370d60
-			// pre processing
-			for (int i=0; i<4; i++) fRec57_tmp[i]=fRec57_perm[i];
-			fYec19_idx = (fYec19_idx+fYec19_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec56_tmp[i]=fRec56_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec57[i] = ((fSlow1 * fRec56[i-1]) + (fSlow0 * fRec57[i-1]));
-				fYec19[(fYec19_idx+i)&4095] = (fZec0[i] + (fSlow2 * fRec57[i]));
-				fRec56[i] = fYec19[(fYec19_idx+i-1139)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec56_perm[i]=fRec56_tmp[count+i];
-			fYec19_idx_save = count;
-			for (int i=0; i<4; i++) fRec57_perm[i]=fRec57_tmp[count+i];
-			
-			// SECTION : 3
-			// LOOP 0x10134f870
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec1[i] = (((((((fRec32[i] + fRec30[i]) + fRec28[i]) + fRec26[i]) + fRec24[i]) + fRec22[i]) + fRec20[i]) + fRec18[i]);
-			}
-			
-			// LOOP 0x101364a70
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec3[i] = (((((((fRec56[i] + fRec54[i]) + fRec52[i]) + fRec50[i]) + fRec48[i]) + fRec46[i]) + fRec44[i]) + fRec42[i]);
-			}
-			
-			// SECTION : 4
-			// LOOP 0x10134f120
-			// pre processing
-			fYec8_idx = (fYec8_idx+fYec8_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec16_tmp[i]=fRec16_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec8[(fYec8_idx+i)&2047] = (fZec1[i] + (0.5f * fRec16[i-1]));
-				fRec16[i] = fYec8[(fYec8_idx+i-556)&2047];
-				fRec17[i] = (0 - (fZec1[i] - fRec16[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec16_perm[i]=fRec16_tmp[count+i];
-			fYec8_idx_save = count;
-			
-			// LOOP 0x101364320
-			// pre processing
-			fYec20_idx = (fYec20_idx+fYec20_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec40_tmp[i]=fRec40_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec20[(fYec20_idx+i)&2047] = (fZec3[i] + (0.5f * fRec40[i-1]));
-				fRec40[i] = fYec20[(fYec20_idx+i-579)&2047];
-				fRec41[i] = (0 - (fZec3[i] - fRec40[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec40_perm[i]=fRec40_tmp[count+i];
-			fYec20_idx_save = count;
-			
-			// SECTION : 5
-			// LOOP 0x10134e9d0
-			// pre processing
-			fYec9_idx = (fYec9_idx+fYec9_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec14_tmp[i]=fRec14_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec9[(fYec9_idx+i)&2047] = (fRec17[i] + (0.5f * fRec14[i-1]));
-				fRec14[i] = fYec9[(fYec9_idx+i-441)&2047];
-				fRec15[i] = (fRec14[i-1] - fRec17[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec14_perm[i]=fRec14_tmp[count+i];
-			fYec9_idx_save = count;
-			
-			// LOOP 0x101363bd0
-			// pre processing
-			fYec21_idx = (fYec21_idx+fYec21_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec38_tmp[i]=fRec38_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec21[(fYec21_idx+i)&2047] = (fRec41[i] + (0.5f * fRec38[i-1]));
-				fRec38[i] = fYec21[(fYec21_idx+i-464)&2047];
-				fRec39[i] = (fRec38[i-1] - fRec41[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec38_perm[i]=fRec38_tmp[count+i];
-			fYec21_idx_save = count;
-			
-			// SECTION : 6
-			// LOOP 0x10134e2a0
-			// pre processing
-			fYec10_idx = (fYec10_idx+fYec10_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec12_tmp[i]=fRec12_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec10[(fYec10_idx+i)&2047] = (fRec15[i] + (0.5f * fRec12[i-1]));
-				fRec12[i] = fYec10[(fYec10_idx+i-341)&2047];
-				fRec13[i] = (fRec12[i-1] - fRec15[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec12_perm[i]=fRec12_tmp[count+i];
-			fYec10_idx_save = count;
-			
-			// LOOP 0x1013634a0
-			// pre processing
-			fYec22_idx = (fYec22_idx+fYec22_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec36_tmp[i]=fRec36_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec22[(fYec22_idx+i)&2047] = (fRec39[i] + (0.5f * fRec36[i-1]));
-				fRec36[i] = fYec22[(fYec22_idx+i-364)&2047];
-				fRec37[i] = (fRec36[i-1] - fRec39[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec36_perm[i]=fRec36_tmp[count+i];
-			fYec22_idx_save = count;
-			
-			// SECTION : 7
-			// LOOP 0x10134dba0
-			// pre processing
-			fYec11_idx = (fYec11_idx+fYec11_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec10_tmp[i]=fRec10_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec11[(fYec11_idx+i)&2047] = (fRec13[i] + (0.5f * fRec10[i-1]));
-				fRec10[i] = fYec11[(fYec11_idx+i-225)&2047];
-				fRec11[i] = (fRec10[i-1] - fRec13[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec10_perm[i]=fRec10_tmp[count+i];
-			fYec11_idx_save = count;
-			
-			// LOOP 0x101362e30
-			// pre processing
-			fYec23_idx = (fYec23_idx+fYec23_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec34_tmp[i]=fRec34_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec23[(fYec23_idx+i)&2047] = (fRec37[i] + (0.5f * fRec34[i-1]));
-				fRec34[i] = fYec23[(fYec23_idx+i-248)&2047];
-				fRec35[i] = (fRec34[i-1] - fRec37[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec34_perm[i]=fRec34_tmp[count+i];
-			fYec23_idx_save = count;
-			
-			// SECTION : 8
-			// LOOP 0x10134daa0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec2[i] = ((fSlow4 * (float)input0[i]) + (fSlow3 * fRec11[i]));
-			}
-			
-			// LOOP 0x101362d30
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec4[i] = ((fSlow4 * (float)input1[i]) + (fSlow3 * fRec35[i]));
-			}
-			
-			// SECTION : 9
-			// LOOP 0x10134d9a0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec5[i] = (1.500000e-02f * (fZec4[i] + fZec2[i]));
-			}
-			
-			// SECTION : 10
-			// LOOP 0x10134b4b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec9_tmp[i]=fRec9_perm[i];
-			fYec24_idx = (fYec24_idx+fYec24_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec8_tmp[i]=fRec8_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec9[i] = ((fSlow1 * fRec8[i-1]) + (fSlow0 * fRec9[i-1]));
-				fYec24[(fYec24_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec9[i]));
-				fRec8[i] = fYec24[(fYec24_idx+i-1617)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec8_perm[i]=fRec8_tmp[count+i];
-			fYec24_idx_save = count;
-			for (int i=0; i<4; i++) fRec9_perm[i]=fRec9_tmp[count+i];
-			
-			// LOOP 0x101377dc0
-			// pre processing
-			for (int i=0; i<4; i++) fRec59_tmp[i]=fRec59_perm[i];
-			fYec25_idx = (fYec25_idx+fYec25_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec58_tmp[i]=fRec58_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec59[i] = ((fSlow1 * fRec58[i-1]) + (fSlow0 * fRec59[i-1]));
-				fYec25[(fYec25_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec59[i]));
-				fRec58[i] = fYec25[(fYec25_idx+i-1557)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec58_perm[i]=fRec58_tmp[count+i];
-			fYec25_idx_save = count;
-			for (int i=0; i<4; i++) fRec59_perm[i]=fRec59_tmp[count+i];
-			
-			// LOOP 0x101379900
-			// pre processing
-			for (int i=0; i<4; i++) fRec61_tmp[i]=fRec61_perm[i];
-			fYec26_idx = (fYec26_idx+fYec26_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec60_tmp[i]=fRec60_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec61[i] = ((fSlow1 * fRec60[i-1]) + (fSlow0 * fRec61[i-1]));
-				fYec26[(fYec26_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec61[i]));
-				fRec60[i] = fYec26[(fYec26_idx+i-1491)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec60_perm[i]=fRec60_tmp[count+i];
-			fYec26_idx_save = count;
-			for (int i=0; i<4; i++) fRec61_perm[i]=fRec61_tmp[count+i];
-			
-			// LOOP 0x10137b480
-			// pre processing
-			for (int i=0; i<4; i++) fRec63_tmp[i]=fRec63_perm[i];
-			fYec27_idx = (fYec27_idx+fYec27_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec62_tmp[i]=fRec62_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec63[i] = ((fSlow1 * fRec62[i-1]) + (fSlow0 * fRec63[i-1]));
-				fYec27[(fYec27_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec63[i]));
-				fRec62[i] = fYec27[(fYec27_idx+i-1422)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec62_perm[i]=fRec62_tmp[count+i];
-			fYec27_idx_save = count;
-			for (int i=0; i<4; i++) fRec63_perm[i]=fRec63_tmp[count+i];
-			
-			// LOOP 0x10137d000
-			// pre processing
-			for (int i=0; i<4; i++) fRec65_tmp[i]=fRec65_perm[i];
-			fYec28_idx = (fYec28_idx+fYec28_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec64_tmp[i]=fRec64_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec65[i] = ((fSlow1 * fRec64[i-1]) + (fSlow0 * fRec65[i-1]));
-				fYec28[(fYec28_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec65[i]));
-				fRec64[i] = fYec28[(fYec28_idx+i-1356)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec64_perm[i]=fRec64_tmp[count+i];
-			fYec28_idx_save = count;
-			for (int i=0; i<4; i++) fRec65_perm[i]=fRec65_tmp[count+i];
-			
-			// LOOP 0x10137eb80
-			// pre processing
-			for (int i=0; i<4; i++) fRec67_tmp[i]=fRec67_perm[i];
-			fYec29_idx = (fYec29_idx+fYec29_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec66_tmp[i]=fRec66_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec67[i] = ((fSlow1 * fRec66[i-1]) + (fSlow0 * fRec67[i-1]));
-				fYec29[(fYec29_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec67[i]));
-				fRec66[i] = fYec29[(fYec29_idx+i-1277)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec66_perm[i]=fRec66_tmp[count+i];
-			fYec29_idx_save = count;
-			for (int i=0; i<4; i++) fRec67_perm[i]=fRec67_tmp[count+i];
-			
-			// LOOP 0x101380700
-			// pre processing
-			for (int i=0; i<4; i++) fRec69_tmp[i]=fRec69_perm[i];
-			fYec30_idx = (fYec30_idx+fYec30_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec68_tmp[i]=fRec68_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec69[i] = ((fSlow1 * fRec68[i-1]) + (fSlow0 * fRec69[i-1]));
-				fYec30[(fYec30_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec69[i]));
-				fRec68[i] = fYec30[(fYec30_idx+i-1188)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec68_perm[i]=fRec68_tmp[count+i];
-			fYec30_idx_save = count;
-			for (int i=0; i<4; i++) fRec69_perm[i]=fRec69_tmp[count+i];
-			
-			// LOOP 0x101382280
-			// pre processing
-			for (int i=0; i<4; i++) fRec71_tmp[i]=fRec71_perm[i];
-			fYec31_idx = (fYec31_idx+fYec31_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec70_tmp[i]=fRec70_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec71[i] = ((fSlow1 * fRec70[i-1]) + (fSlow0 * fRec71[i-1]));
-				fYec31[(fYec31_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec71[i]));
-				fRec70[i] = fYec31[(fYec31_idx+i-1116)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec70_perm[i]=fRec70_tmp[count+i];
-			fYec31_idx_save = count;
-			for (int i=0; i<4; i++) fRec71_perm[i]=fRec71_tmp[count+i];
-			
-			// LOOP 0x101389fc0
-			// pre processing
-			for (int i=0; i<4; i++) fRec81_tmp[i]=fRec81_perm[i];
-			fYec36_idx = (fYec36_idx+fYec36_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec80_tmp[i]=fRec80_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec81[i] = ((fSlow1 * fRec80[i-1]) + (fSlow0 * fRec81[i-1]));
-				fYec36[(fYec36_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec81[i]));
-				fRec80[i] = fYec36[(fYec36_idx+i-1640)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec80_perm[i]=fRec80_tmp[count+i];
-			fYec36_idx_save = count;
-			for (int i=0; i<4; i++) fRec81_perm[i]=fRec81_tmp[count+i];
-			
-			// LOOP 0x10138bc10
-			// pre processing
-			for (int i=0; i<4; i++) fRec83_tmp[i]=fRec83_perm[i];
-			fYec37_idx = (fYec37_idx+fYec37_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec82_tmp[i]=fRec82_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec83[i] = ((fSlow1 * fRec82[i-1]) + (fSlow0 * fRec83[i-1]));
-				fYec37[(fYec37_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec83[i]));
-				fRec82[i] = fYec37[(fYec37_idx+i-1580)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec82_perm[i]=fRec82_tmp[count+i];
-			fYec37_idx_save = count;
-			for (int i=0; i<4; i++) fRec83_perm[i]=fRec83_tmp[count+i];
-			
-			// LOOP 0x10138d7b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec85_tmp[i]=fRec85_perm[i];
-			fYec38_idx = (fYec38_idx+fYec38_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec84_tmp[i]=fRec84_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec85[i] = ((fSlow1 * fRec84[i-1]) + (fSlow0 * fRec85[i-1]));
-				fYec38[(fYec38_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec85[i]));
-				fRec84[i] = fYec38[(fYec38_idx+i-1514)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec84_perm[i]=fRec84_tmp[count+i];
-			fYec38_idx_save = count;
-			for (int i=0; i<4; i++) fRec85_perm[i]=fRec85_tmp[count+i];
-			
-			// LOOP 0x10138f330
-			// pre processing
-			for (int i=0; i<4; i++) fRec87_tmp[i]=fRec87_perm[i];
-			fYec39_idx = (fYec39_idx+fYec39_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec86_tmp[i]=fRec86_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec87[i] = ((fSlow1 * fRec86[i-1]) + (fSlow0 * fRec87[i-1]));
-				fYec39[(fYec39_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec87[i]));
-				fRec86[i] = fYec39[(fYec39_idx+i-1445)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec86_perm[i]=fRec86_tmp[count+i];
-			fYec39_idx_save = count;
-			for (int i=0; i<4; i++) fRec87_perm[i]=fRec87_tmp[count+i];
-			
-			// LOOP 0x101390eb0
-			// pre processing
-			for (int i=0; i<4; i++) fRec89_tmp[i]=fRec89_perm[i];
-			fYec40_idx = (fYec40_idx+fYec40_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec88_tmp[i]=fRec88_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec89[i] = ((fSlow1 * fRec88[i-1]) + (fSlow0 * fRec89[i-1]));
-				fYec40[(fYec40_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec89[i]));
-				fRec88[i] = fYec40[(fYec40_idx+i-1379)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec88_perm[i]=fRec88_tmp[count+i];
-			fYec40_idx_save = count;
-			for (int i=0; i<4; i++) fRec89_perm[i]=fRec89_tmp[count+i];
-			
-			// LOOP 0x101392a30
-			// pre processing
-			for (int i=0; i<4; i++) fRec91_tmp[i]=fRec91_perm[i];
-			fYec41_idx = (fYec41_idx+fYec41_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec90_tmp[i]=fRec90_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec91[i] = ((fSlow1 * fRec90[i-1]) + (fSlow0 * fRec91[i-1]));
-				fYec41[(fYec41_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec91[i]));
-				fRec90[i] = fYec41[(fYec41_idx+i-1300)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec90_perm[i]=fRec90_tmp[count+i];
-			fYec41_idx_save = count;
-			for (int i=0; i<4; i++) fRec91_perm[i]=fRec91_tmp[count+i];
-			
-			// LOOP 0x1013945b0
-			// pre processing
-			for (int i=0; i<4; i++) fRec93_tmp[i]=fRec93_perm[i];
-			fYec42_idx = (fYec42_idx+fYec42_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec92_tmp[i]=fRec92_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec93[i] = ((fSlow1 * fRec92[i-1]) + (fSlow0 * fRec93[i-1]));
-				fYec42[(fYec42_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec93[i]));
-				fRec92[i] = fYec42[(fYec42_idx+i-1211)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec92_perm[i]=fRec92_tmp[count+i];
-			fYec42_idx_save = count;
-			for (int i=0; i<4; i++) fRec93_perm[i]=fRec93_tmp[count+i];
-			
-			// LOOP 0x101396130
-			// pre processing
-			for (int i=0; i<4; i++) fRec95_tmp[i]=fRec95_perm[i];
-			fYec43_idx = (fYec43_idx+fYec43_idx_save)&4095;
-			for (int i=0; i<4; i++) fRec94_tmp[i]=fRec94_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fRec95[i] = ((fSlow1 * fRec94[i-1]) + (fSlow0 * fRec95[i-1]));
-				fYec43[(fYec43_idx+i)&4095] = (fZec5[i] + (fSlow2 * fRec95[i]));
-				fRec94[i] = fYec43[(fYec43_idx+i-1139)&4095];
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec94_perm[i]=fRec94_tmp[count+i];
-			fYec43_idx_save = count;
-			for (int i=0; i<4; i++) fRec95_perm[i]=fRec95_tmp[count+i];
-			
-			// SECTION : 11
-			// LOOP 0x10134b3b0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec6[i] = (((((((fRec70[i] + fRec68[i]) + fRec66[i]) + fRec64[i]) + fRec62[i]) + fRec60[i]) + fRec58[i]) + fRec8[i]);
-			}
-			
-			// LOOP 0x101389ec0
-			// exec code
-			for (int i=0; i<count; i++) {
-				fZec7[i] = (((((((fRec94[i] + fRec92[i]) + fRec90[i]) + fRec88[i]) + fRec86[i]) + fRec84[i]) + fRec82[i]) + fRec80[i]);
-			}
-			
-			// SECTION : 12
-			// LOOP 0x10134acd0
-			// pre processing
-			fYec32_idx = (fYec32_idx+fYec32_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec6_tmp[i]=fRec6_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec32[(fYec32_idx+i)&2047] = (fZec6[i] + (0.5f * fRec6[i-1]));
-				fRec6[i] = fYec32[(fYec32_idx+i-556)&2047];
-				fRec7[i] = (0 - (fZec6[i] - fRec6[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec6_perm[i]=fRec6_tmp[count+i];
-			fYec32_idx_save = count;
-			
-			// LOOP 0x1013897e0
-			// pre processing
-			fYec44_idx = (fYec44_idx+fYec44_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec78_tmp[i]=fRec78_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec44[(fYec44_idx+i)&2047] = (fZec7[i] + (0.5f * fRec78[i-1]));
-				fRec78[i] = fYec44[(fYec44_idx+i-579)&2047];
-				fRec79[i] = (0 - (fZec7[i] - fRec78[i-1]));
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec78_perm[i]=fRec78_tmp[count+i];
-			fYec44_idx_save = count;
-			
-			// SECTION : 13
-			// LOOP 0x10134a5f0
-			// pre processing
-			fYec33_idx = (fYec33_idx+fYec33_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec4_tmp[i]=fRec4_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec33[(fYec33_idx+i)&2047] = (fRec7[i] + (0.5f * fRec4[i-1]));
-				fRec4[i] = fYec33[(fYec33_idx+i-441)&2047];
-				fRec5[i] = (fRec4[i-1] - fRec7[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec4_perm[i]=fRec4_tmp[count+i];
-			fYec33_idx_save = count;
-			
-			// LOOP 0x101389100
-			// pre processing
-			fYec45_idx = (fYec45_idx+fYec45_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec76_tmp[i]=fRec76_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec45[(fYec45_idx+i)&2047] = (fRec79[i] + (0.5f * fRec76[i-1]));
-				fRec76[i] = fYec45[(fYec45_idx+i-464)&2047];
-				fRec77[i] = (fRec76[i-1] - fRec79[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec76_perm[i]=fRec76_tmp[count+i];
-			fYec45_idx_save = count;
-			
-			// SECTION : 14
-			// LOOP 0x101349f10
-			// pre processing
-			fYec34_idx = (fYec34_idx+fYec34_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec2_tmp[i]=fRec2_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec34[(fYec34_idx+i)&2047] = (fRec5[i] + (0.5f * fRec2[i-1]));
-				fRec2[i] = fYec34[(fYec34_idx+i-341)&2047];
-				fRec3[i] = (fRec2[i-1] - fRec5[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec2_perm[i]=fRec2_tmp[count+i];
-			fYec34_idx_save = count;
-			
-			// LOOP 0x101388a20
-			// pre processing
-			fYec46_idx = (fYec46_idx+fYec46_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec74_tmp[i]=fRec74_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec46[(fYec46_idx+i)&2047] = (fRec77[i] + (0.5f * fRec74[i-1]));
-				fRec74[i] = fYec46[(fYec46_idx+i-364)&2047];
-				fRec75[i] = (fRec74[i-1] - fRec77[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec74_perm[i]=fRec74_tmp[count+i];
-			fYec46_idx_save = count;
-			
-			// SECTION : 15
-			// LOOP 0x101349700
-			// pre processing
-			fYec35_idx = (fYec35_idx+fYec35_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec0_tmp[i]=fRec0_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec35[(fYec35_idx+i)&2047] = (fRec3[i] + (0.5f * fRec0[i-1]));
-				fRec0[i] = fYec35[(fYec35_idx+i-225)&2047];
-				fRec1[i] = (fRec0[i-1] - fRec3[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec0_perm[i]=fRec0_tmp[count+i];
-			fYec35_idx_save = count;
-			
-			// LOOP 0x1013883a0
-			// pre processing
-			fYec47_idx = (fYec47_idx+fYec47_idx_save)&2047;
-			for (int i=0; i<4; i++) fRec72_tmp[i]=fRec72_perm[i];
-			// exec code
-			for (int i=0; i<count; i++) {
-				fYec47[(fYec47_idx+i)&2047] = (fRec75[i] + (0.5f * fRec72[i-1]));
-				fRec72[i] = fYec47[(fYec47_idx+i-248)&2047];
-				fRec73[i] = (fRec72[i-1] - fRec75[i]);
-			}
-			// post processing
-			for (int i=0; i<4; i++) fRec72_perm[i]=fRec72_tmp[count+i];
-			fYec47_idx_save = count;
-			
-			// SECTION : 16
-			// LOOP 0x101349600
-			// exec code
-			for (int i=0; i<count; i++) {
-				output0[i] = (FAUSTFLOAT)((fSlow4 * fZec2[i]) + (fSlow3 * fRec1[i]));
-			}
-			
-			// LOOP 0x1013881d0
-			// exec code
-			for (int i=0; i<count; i++) {
-				output1[i] = (FAUSTFLOAT)((fSlow4 * fZec4[i]) + (fSlow3 * fRec73[i]));
-			}
-			
-		}
-	}
-};
-				
-mydsp	DSP;
-
-/******************************************************************************
-*******************************************************************************
-
-							COREAUDIO INTERFACE
-
-*******************************************************************************
-*******************************************************************************/
-
-#define MAX_CHANNELS 256
-#define OPEN_ERR -1
-#define NO_ERR 0
-
-class TiPhoneCoreAudioRenderer
-{
-
-    private:
-
-		AudioUnit fAUHAL;
-        
-        int	fDevNumInChans;
-        int	fDevNumOutChans;
-     
-        float* fInChannel[MAX_CHANNELS];
-        float* fOutChannel[MAX_CHANNELS];
-	
-		static OSStatus Render(void *inRefCon,
-                               AudioUnitRenderActionFlags *ioActionFlags,
-                               const AudioTimeStamp *inTimeStamp,
-                               UInt32 inBusNumber,
-                               UInt32 inNumberFrames,
-                               AudioBufferList *ioData);
-                               
-        static void InterruptionListener(void *inClientData, UInt32 inInterruption);
-
-    public:
-
-        TiPhoneCoreAudioRenderer(int input, int output)
-            :fDevNumInChans(input), fDevNumOutChans(output)
-        {
-            for (int i = 0; i < fDevNumInChans; i++) {
-                fInChannel[i] = new float[8192];
-            }
-    
-            for (int i = 0; i < fDevNumOutChans; i++) {
-                fOutChannel[i] = new float[8192];
-            }
-        }
-        virtual ~TiPhoneCoreAudioRenderer()
-        {
-            for (int i = 0; i < fDevNumInChans; i++) {
-                delete[] fInChannel[i];
-            }
-    
-            for (int i = 0; i < fDevNumOutChans; i++) {
-                delete[] fOutChannel[i]; 
-            }
-        }
-
-        long Open(long bufferSize, long sampleRate);
-        long Close();
-
-        long Start();
-        long Stop();
-
-};
-
-typedef TiPhoneCoreAudioRenderer * TiPhoneCoreAudioRendererPtr;
-
-static void PrintStreamDesc(AudioStreamBasicDescription *inDesc)
-{
-    printf("- - - - - - - - - - - - - - - - - - - -\n");
-    printf("  Sample Rate:%f\n", inDesc->mSampleRate);
-    printf("  Format ID:%.*s\n", (int) sizeof(inDesc->mFormatID), (char*)&inDesc->mFormatID);
-    printf("  Format Flags:%lX\n", inDesc->mFormatFlags);
-    printf("  Bytes per Packet:%ld\n", inDesc->mBytesPerPacket);
-    printf("  Frames per Packet:%ld\n", inDesc->mFramesPerPacket);
-    printf("  Bytes per Frame:%ld\n", inDesc->mBytesPerFrame);
-    printf("  Channels per Frame:%ld\n", inDesc->mChannelsPerFrame);
-    printf("  Bits per Channel:%ld\n", inDesc->mBitsPerChannel);
-    printf("- - - - - - - - - - - - - - - - - - - -\n");
-}
-
-static void printError(OSStatus err)
-{
-    switch (err) {
-      	case kAudioConverterErr_FormatNotSupported:
-            printf("error code : kAudioConverterErr_FormatNotSupported\n");
-            break;
-        case kAudioConverterErr_OperationNotSupported:
-            printf("error code : kAudioConverterErr_OperationNotSupported\n");
-            break;
-        case kAudioConverterErr_PropertyNotSupported:
-            printf("error code : kAudioConverterErr_PropertyNotSupported\n");
-            break;
-        case kAudioConverterErr_InvalidInputSize:
-            printf("error code : kAudioConverterErr_InvalidInputSize\n");
-            break;
-        case kAudioConverterErr_InvalidOutputSize:
-            printf("error code : kAudioConverterErr_InvalidOutputSize\n");
-            break;
-        case kAudioConverterErr_UnspecifiedError:
-            printf("error code : kAudioConverterErr_UnspecifiedError\n");
-            break;
-        case kAudioConverterErr_BadPropertySizeError:
-            printf("error code : kAudioConverterErr_BadPropertySizeError\n");
-            break;
-        case kAudioConverterErr_RequiresPacketDescriptionsError:
-            printf("error code : kAudioConverterErr_RequiresPacketDescriptionsError\n");
-            break;
-        case kAudioConverterErr_InputSampleRateOutOfRange:
-            printf("error code : kAudioConverterErr_InputSampleRateOutOfRange\n");
-            break;
-        case kAudioConverterErr_OutputSampleRateOutOfRange:
-            printf("error code : kAudioConverterErr_OutputSampleRateOutOfRange\n");
-            break;
-        default:
-            printf("error code : unknown\n");
-            break;
-    }
-}
-
-st::HardwareClock my_clock;
-
-OSStatus TiPhoneCoreAudioRenderer::Render(void *inRefCon,
-                                         AudioUnitRenderActionFlags *ioActionFlags,
-                                         const AudioTimeStamp *inTimeStamp,
-                                         UInt32,
-                                         UInt32 inNumberFrames,
-                                         AudioBufferList *ioData)
-{
-    TiPhoneCoreAudioRendererPtr renderer = (TiPhoneCoreAudioRendererPtr)inRefCon;
-    my_clock.Update();
-    //printf("TiPhoneCoreAudioRenderer::Render 0 %d\n", inNumberFrames);
-    
-    AudioUnitRender(renderer->fAUHAL, ioActionFlags, inTimeStamp, 1, inNumberFrames, ioData);
-    
-    float coef = 1.f/32768.f;
-    /*
-    for (int chan = 0; chan < fDevNumInChans; chan++) {
-        for (int frame = 0; frame < inNumberFrames; frame++) {
-            fInChannel[chan][frame] = float(((long*)ioData->mBuffers[chan].mData)[frame]) / 32768.f;
-            fInChannel[chan][frame] = float(((long*)ioData->mBuffers[chan].mData)[frame]) / 32768.f;
-        }
-    }
-    */
-    
-    for (int frame = 0; frame < inNumberFrames; frame++) {
-        float sample = float(((long*)ioData->mBuffers[0].mData)[frame]) * coef;
-        renderer->fInChannel[0][frame] = sample;
-        renderer->fInChannel[1][frame] = sample;
-    }
-    
-    //printf("TiPhoneCoreAudioRenderer::Render 1  %d\n", inNumberFrames);
-       
-    DSP.compute((int)inNumberFrames, renderer->fInChannel, renderer->fOutChannel);
-    
-    for (int chan = 0; chan < renderer->fDevNumOutChans; chan++) {
-        for (int frame = 0; frame < inNumberFrames; frame++) {
-           ((long*)ioData->mBuffers[chan].mData)[frame] = long(renderer->fOutChannel[chan][frame] * 32768.f); 
-        }
-    }
-    
-    my_clock.Update();
-    const float dt = my_clock.GetDeltaTime();
-    printf("Normal: %f s\n", dt);
-    
-    //printf("TiPhoneCoreAudioRenderer::Render 3  %d\n", inNumberFrames);
-	return 0;
-}
-
-void TiPhoneCoreAudioRenderer::InterruptionListener(void *inClientData, UInt32 inInterruption)
-{
-	printf("Session interrupted! --- %s ---", inInterruption == kAudioSessionBeginInterruption ? "Begin Interruption" : "End Interruption");
-	
-	TiPhoneCoreAudioRenderer *obj = (TiPhoneCoreAudioRenderer*)inClientData;
-	
-	if (inInterruption == kAudioSessionEndInterruption) {
-		// make sure we are again the active session
-		AudioSessionSetActive(true);
-		AudioOutputUnitStart(obj->fAUHAL);
-	}
-	
-	if (inInterruption == kAudioSessionBeginInterruption) {
-		AudioOutputUnitStop(obj->fAUHAL);
-    }
-}
-
-long TiPhoneCoreAudioRenderer::Open(long bufferSize, long samplerate)
-{
-    OSStatus err1;
-    UInt32 outSize;
-    UInt32 enableIO;
-	Boolean isWritable;
-	AudioStreamBasicDescription srcFormat, dstFormat;
-    
-    printf("Open fDevNumInChans = %ld fDevNumOutChans = %ld bufferSize = %ld samplerate = %ld\n", fDevNumInChans, fDevNumOutChans, bufferSize, samplerate);
-	  
-    // Initialize and configure the audio session
-    err1 = AudioSessionInitialize(NULL, NULL, InterruptionListener, this);
-    if (err1 != noErr) {
-        printf("Couldn't initialize audio session\n");
-        printError(err1);
-        return OPEN_ERR;
-    }
-    
-    err1 = AudioSessionSetActive(true);
-    if (err1 != noErr) {
-        printf("Couldn't set audio session active\n");
-        printError(err1);
-        return OPEN_ERR;
-    }
-  			
-    UInt32 audioCategory = kAudioSessionCategory_PlayAndRecord;
-	err1 = AudioSessionSetProperty(kAudioSessionProperty_AudioCategory, sizeof(audioCategory), &audioCategory);
-    if (err1 != noErr) {
-        printf("Couldn't set audio category\n");
-        printError(err1);
-        return OPEN_ERR;
-    }
-    
-   	//err1 = AudioSessionAddPropertyListener(kAudioSessionProperty_AudioRouteChange, propListener, self), "couldn't set property listener");
-    
-    Float64 hwSampleRate;
-    outSize = sizeof(hwSampleRate);
-	err1 = AudioSessionGetProperty(kAudioSessionProperty_CurrentHardwareSampleRate, &outSize, &hwSampleRate);
-    if (err1 != noErr) {
-        printf("Couldn't get hw sample rate\n");
-        printError(err1);
-        return OPEN_ERR;
-    } else {
-         printf("Get hw sample rate %f\n", hwSampleRate);
-    }
-    
-    Float32 hwBufferSize;
-    outSize = sizeof(hwBufferSize);
-	err1 = AudioSessionGetProperty(kAudioSessionProperty_CurrentHardwareIOBufferDuration, &outSize, &hwBufferSize);
-    if (err1 != noErr) {
-        printf("Couldn't get hw buffer duration\n");
-        printError(err1);
-        return OPEN_ERR;
-    } else {
-         printf("Get hw buffer duration %f\n", hwBufferSize);
-    }
-
-    UInt32 hwInput;
-    outSize = sizeof(hwInput);
-	err1 = AudioSessionGetProperty(kAudioSessionProperty_CurrentHardwareInputNumberChannels, &outSize, &hwInput);
-    if (err1 != noErr) {
-        printf("Couldn't get hw input channels\n");
-        printError(err1);
-        return OPEN_ERR;
-    } else {
-        printf("Get hw input channels %d\n", hwInput);
-    }
-
-    UInt32 hwOutput;
-    outSize = sizeof(hwOutput);
-	err1 = AudioSessionGetProperty(kAudioSessionProperty_CurrentHardwareOutputNumberChannels, &outSize, &hwOutput);
-    if (err1 != noErr) {
-        printf("Couldn't get hw output channels\n");
-        printError(err1);
-        return OPEN_ERR;
-    } else {
-        printf("Get hw output channels %d\n", hwOutput);
-    }
-			
-    Float32 preferredBufferSize = float(bufferSize) / float(samplerate);
-    printf("preferredBufferSize %f \n", preferredBufferSize);
-    
-	err1 = AudioSessionSetProperty(kAudioSessionProperty_PreferredHardwareIOBufferDuration, sizeof(preferredBufferSize), &preferredBufferSize);
-    if (err1 != noErr) {
-        printf("Couldn't set i/o buffer duration\n");
-        printError(err1);
-        return OPEN_ERR;
-    }
-  	
-    Float64 preferredSamplerate = float(samplerate);
-	err1 = AudioSessionSetProperty(kAudioSessionProperty_PreferredHardwareSampleRate, sizeof(preferredSamplerate), &preferredSamplerate);
-    if (err1 != noErr) {
-        printf("Couldn't set i/o sample rate\n");
-        printError(err1);
-        return OPEN_ERR;
-    }
-  	
-    // AUHAL
-    AudioComponentDescription cd = {kAudioUnitType_Output, kAudioUnitSubType_RemoteIO, kAudioUnitManufacturer_Apple, 0, 0};
-    AudioComponent HALOutput = AudioComponentFindNext(NULL, &cd);
-
-    err1 = AudioComponentInstanceNew(HALOutput, &fAUHAL);
-    if (err1 != noErr) {
-		printf("Error calling OpenAComponent\n");
-        printError(err1);
-        goto error;
-	}
-
-    enableIO = 1;
-    err1 = AudioUnitSetProperty(fAUHAL, kAudioOutputUnitProperty_EnableIO, kAudioUnitScope_Output, 0, &enableIO, sizeof(enableIO));
-    if (err1 != noErr) {
-        printf("Error calling AudioUnitSetProperty - kAudioOutputUnitProperty_EnableIO, kAudioUnitScope_Output\n");
-        printError(err1);
-        goto error;
-    }
-    
-    enableIO = 1;
-    err1 = AudioUnitSetProperty(fAUHAL, kAudioOutputUnitProperty_EnableIO, kAudioUnitScope_Input, 1, &enableIO, sizeof(enableIO));
-    if (err1 != noErr) {
-        printf("Error calling AudioUnitSetProperty - kAudioOutputUnitProperty_EnableIO, kAudioUnitScope_Input\n");
-        printError(err1);
-        goto error;
-    }
-    
-      
-    UInt32 maxFPS;
-    outSize = sizeof(maxFPS);
-    err1 = AudioUnitGetProperty(fAUHAL, kAudioUnitProperty_MaximumFramesPerSlice, kAudioUnitScope_Global, 0, &maxFPS, &outSize);
-    if (err1 != noErr) {
-        printf("Couldn't get kAudioUnitProperty_MaximumFramesPerSlice\n");
-        printError(err1);
-        goto error;
-    } else {
-        printf("Get kAudioUnitProperty_MaximumFramesPerSlice %d\n", maxFPS);
-    }
-   
-    err1 = AudioUnitSetProperty(fAUHAL, kAudioUnitProperty_MaximumFramesPerSlice, kAudioUnitScope_Global, 1, (UInt32*)&bufferSize, sizeof(UInt32));
-    if (err1 != noErr) {
-        printf("Error calling AudioUnitSetProperty - kAudioUnitProperty_MaximumFramesPerSlice\n");
-        printError(err1);
-        goto error;
-    }
-
-    err1 = AudioUnitSetProperty(fAUHAL, kAudioUnitProperty_MaximumFramesPerSlice, kAudioUnitScope_Global, 0, (UInt32*)&bufferSize, sizeof(UInt32));
-    if (err1 != noErr) {
-        printf("Error calling AudioUnitSetProperty - kAudioUnitProperty_MaximumFramesPerSlice\n");
-        printError(err1);
-        goto error;
-    }
-
-
-    err1 = AudioUnitInitialize(fAUHAL);
-    if (err1 != noErr) {
-		printf("Cannot initialize AUHAL unit\n");
-		printError(err1);
-        goto error;
-	}
-
-    // Setting format
-  	
-    if (fDevNumInChans > 0) {
-        outSize = sizeof(AudioStreamBasicDescription);
-        err1 = AudioUnitGetProperty(fAUHAL, kAudioUnitProperty_StreamFormat, kAudioUnitScope_Output, 1, &srcFormat, &outSize);
-        if (err1 != noErr) {
-            printf("Error calling AudioUnitGetProperty - kAudioUnitProperty_StreamFormat kAudioUnitScope_Output\n");
-            printError(err1);
-        }
-        PrintStreamDesc(&srcFormat);
-        
-        srcFormat.mFormatID = kAudioFormatLinearPCM;
-        srcFormat.mFormatFlags = kAudioFormatFlagsCanonical | kLinearPCMFormatFlagIsNonInterleaved;
-        srcFormat.mBytesPerPacket = sizeof(AudioUnitSampleType);
-        srcFormat.mFramesPerPacket = 1;
-        srcFormat.mBytesPerFrame = sizeof(AudioUnitSampleType);
-        srcFormat.mChannelsPerFrame = fDevNumInChans;
-        srcFormat.mBitsPerChannel = 32;
-        
-        PrintStreamDesc(&srcFormat);
-        
-        err1 = AudioUnitSetProperty(fAUHAL, kAudioUnitProperty_StreamFormat, kAudioUnitScope_Output, 1, &srcFormat, sizeof(AudioStreamBasicDescription));
-        if (err1 != noErr) {
-            printf("Error calling AudioUnitSetProperty - kAudioUnitProperty_StreamFormat kAudioUnitScope_Output\n");
-            printError(err1);
-        }    
-        
-    }
-	
-    if (fDevNumOutChans > 0) {
-        outSize = sizeof(AudioStreamBasicDescription);
-        err1 = AudioUnitGetProperty(fAUHAL, kAudioUnitProperty_StreamFormat, kAudioUnitScope_Input, 0, &dstFormat, &outSize);
-        if (err1 != noErr) {
-            printf("Error calling AudioUnitGetProperty - kAudioUnitProperty_StreamFormat kAudioUnitScope_Input\n");
-            printError(err1);
-        }
-        PrintStreamDesc(&dstFormat);
-        
-        dstFormat.mFormatID = kAudioFormatLinearPCM;
-        dstFormat.mFormatFlags = kAudioFormatFlagsCanonical | kLinearPCMFormatFlagIsNonInterleaved;
-        dstFormat.mBytesPerPacket = sizeof(AudioUnitSampleType);
-        dstFormat.mFramesPerPacket = 1;
-        dstFormat.mBytesPerFrame = sizeof(AudioUnitSampleType);
-        dstFormat.mChannelsPerFrame = fDevNumOutChans;
-        dstFormat.mBitsPerChannel = 32;
-        
-        PrintStreamDesc(&dstFormat);
-
-        err1 = AudioUnitSetProperty(fAUHAL, kAudioUnitProperty_StreamFormat, kAudioUnitScope_Input, 0, &dstFormat, sizeof(AudioStreamBasicDescription));
-        if (err1 != noErr) {
-            printf("Error calling AudioUnitSetProperty - kAudioUnitProperty_StreamFormat kAudioUnitScope_Input\n");
-            printError(err1);
-        }
-    }
-
-    if (fDevNumInChans > 0 && fDevNumOutChans == 0) {
-        AURenderCallbackStruct output;
-        output.inputProc = Render;
-        output.inputProcRefCon = this;
-        err1 = AudioUnitSetProperty(fAUHAL, kAudioOutputUnitProperty_SetInputCallback, kAudioUnitScope_Global, 0, &output, sizeof(output));
-        if (err1 != noErr) {
-            printf("Error calling AudioUnitSetProperty - kAudioUnitProperty_SetRenderCallback 1\n");
-            printError(err1);
-            goto error;
-        }
-    } else {
-        AURenderCallbackStruct output;
-        output.inputProc = Render;
-        output.inputProcRefCon = this;
-        err1 = AudioUnitSetProperty(fAUHAL, kAudioUnitProperty_SetRenderCallback, kAudioUnitScope_Input, 0, &output, sizeof(output));
-        if (err1 != noErr) {
-            printf("Error calling AudioUnitSetProperty - kAudioUnitProperty_SetRenderCallback 0\n");
-            printError(err1);
-            goto error;
-        }
-    }
-
-    return NO_ERR;
-
-error:
-    AudioUnitUninitialize(fAUHAL);
-    AudioComponentInstanceDispose(fAUHAL);
-    return OPEN_ERR;
-}
-
-long TiPhoneCoreAudioRenderer::Close()
-{
- 	AudioUnitUninitialize(fAUHAL);
-    AudioComponentInstanceDispose(fAUHAL);
-    return NO_ERR;
-}
-
-long TiPhoneCoreAudioRenderer::Start()
-{
-    AudioSessionSetActive(true);
-	OSStatus err = AudioOutputUnitStart(fAUHAL);
-  
-    if (err != noErr) {
-        printf("Error while opening device : device open error \n");
-        return OPEN_ERR;
-    } else {
-        return NO_ERR;
-	}
-}
-
-long TiPhoneCoreAudioRenderer::Stop()
-{
-    OSStatus err = AudioOutputUnitStop(fAUHAL);
-
-    if (err != noErr) {
-        printf("Error while closing device : device close error \n");
-        return OPEN_ERR;
-    } else {
-        return NO_ERR;
-	}
-}
-
-/******************************************************************************
-*******************************************************************************
-
-								MAIN PLAY THREAD
-
-*******************************************************************************
-*******************************************************************************/
-
-long lopt(char *argv[], const char *name, long def) 
-{
-	int	i;
-	for (i = 0; argv[i]; i++) if (!strcmp(argv[i], name)) return atoi(argv[i + 1]);
-	return def;
-}
-	
-//-------------------------------------------------------------------------
-// 									MAIN
-//-------------------------------------------------------------------------
-
-int main(int argc, char *argv[])
-{
-	UI* interface = new CMDUI(argc, argv);
-    TiPhoneCoreAudioRenderer audio_device(DSP.getNumInputs(), DSP.getNumOutputs());
-		
-    long srate = (long)lopt(argv, "--frequency", 44100);
-    int	fpb = lopt(argv, "--buffer", 512);
- 		
-	DSP.init(long(srate));
-	DSP.buildUserInterface(interface);
-	
-    if (audio_device.Open(fpb, srate) < 0) {
-        printf("Cannot open CoreAudio device\n");
-        return 0;
-    }
-    
-    if (audio_device.Start() < 0) {
-        printf("Cannot start CoreAudio device\n");
-        return 0;
-    }
-    
-    printf("inchan = %d, outchan = %d, freq = %ld\n", DSP.getNumInputs(), DSP.getNumOutputs(), srate);
-	interface->run();
-    
-    audio_device.Stop();
-    audio_device.Close();
-  	return 0;
-}
-
diff -pruN 1.9.14~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.h 1.9.16~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.h
--- 1.9.14~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-//
-//  iPhoneNetAppDelegate.h
-//  iPhoneNet
-//
-//  Created by Stéphane  LETZ on 16/02/09.
-//  Copyright Grame 2009. All rights reserved.
-//
-
-#import <UIKit/UIKit.h>
-
-@interface iPhoneNetAppDelegate : NSObject <UIApplicationDelegate> {
-   // UIWindow *window;
-    
-    IBOutlet UIWindow				*window;
-	IBOutlet UINavigationController	*navigationController;
-}
-
-//@property (nonatomic, retain) IBOutlet UIWindow *window;
-@property (nonatomic, retain) UIWindow *window;
-@property (nonatomic, retain) UINavigationController *navigationController;
-
-@end
-
diff -pruN 1.9.14~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.m 1.9.16~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.m
--- 1.9.14~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.m	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/iPhoneNetAppDelegate.m	1970-01-01 00:00:00.000000000 +0000
@@ -1,32 +0,0 @@
-//
-//  iPhoneNetAppDelegate.m
-//  iPhoneNet
-//
-//  Created by Stéphane  LETZ on 16/02/09.
-//  Copyright Grame 2009. All rights reserved.
-//
-
-#import "iPhoneNetAppDelegate.h"
-
-@implementation iPhoneNetAppDelegate
-
-@synthesize window, navigationController;
-
-
-- (void)applicationDidFinishLaunching:(UIApplication *)application {    
-
-    // Override point for customization after application launch
-    // add the navigation controller's view to the window
-	[window addSubview: navigationController.view];
-    [window makeKeyAndVisible];
-}
-
-
-- (void)dealloc {
-    [navigationController release];
-    [window release];
-    [super dealloc];
-}
-
-
-@end
diff -pruN 1.9.14~dfsg-1/macosx/iphone/iPhoneNet_Prefix.pch 1.9.16~dfsg-1/macosx/iphone/iPhoneNet_Prefix.pch
--- 1.9.14~dfsg-1/macosx/iphone/iPhoneNet_Prefix.pch	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/iPhoneNet_Prefix.pch	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-//
-// Prefix header for all source files of the 'iPhoneNet' target in the 'iPhoneNet' project
-//
-
-#ifdef __OBJC__
-    #import <Foundation/Foundation.h>
-    #import <UIKit/UIKit.h>
-#endif
-
-#define MY_TARGET_OS_IPHONE 1
diff -pruN 1.9.14~dfsg-1/macosx/iphone/iPhoneNet.xcodeproj/project.pbxproj 1.9.16~dfsg-1/macosx/iphone/iPhoneNet.xcodeproj/project.pbxproj
--- 1.9.14~dfsg-1/macosx/iphone/iPhoneNet.xcodeproj/project.pbxproj	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/iPhoneNet.xcodeproj/project.pbxproj	1970-01-01 00:00:00.000000000 +0000
@@ -1,1298 +0,0 @@
-// !$*UTF8*$!
-{
-	archiveVersion = 1;
-	classes = {
-	};
-	objectVersion = 45;
-	objects = {
-
-/* Begin PBXBuildFile section */
-		1D60589F0D05DD5A006BFB54 /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		1DF5F4E00D08C38300B7A737 /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		288765FD0DF74451002DB57D /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		28AD733F0D9D9553002E5188 /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4B0772210F54018C000DC657 /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4B0772240F54018C000DC657 /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */; };
-		4B0772250F54018C000DC657 /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93870F49B0E300D3626B /* JackMachTime.c */; };
-		4B0772260F54018C000DC657 /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */; };
-		4B0772270F54018C000DC657 /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */; };
-		4B0772280F54018C000DC657 /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93110F49AB3400D3626B /* JackNetTool.cpp */; };
-		4B0772290F54018C000DC657 /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */; };
-		4B07722A0F54018C000DC657 /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */; };
-		4B07722C0F54018C000DC657 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */; };
-		4B07722D0F54018C000DC657 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */; };
-		4B07722E0F54018C000DC657 /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF136540F4B0F9F00218A3F /* ringbuffer.c */; };
-		4B0772310F54018C000DC657 /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		4B0772320F54018C000DC657 /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		4B0772330F54018C000DC657 /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		4B0772340F54018C000DC657 /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-		4B07724A0F54021B000DC657 /* main_slave.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4B0772490F54021B000DC657 /* main_slave.mm */; };
-		4B0773860F541EE2000DC657 /* iPhoneNetAppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */; };
-		4B0773870F541EE2000DC657 /* iPhoneNetAppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */; };
-		4B0773880F541EE2000DC657 /* iPhoneNetAppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */; };
-		4B1A94140F49BE2C00D3626B /* iPhoneNet_Prefix.pch in Headers */ = {isa = PBXBuildFile; fileRef = 32CA4F630368D1EE00C91783 /* iPhoneNet_Prefix.pch */; };
-		4B1A94150F49BE2F00D3626B /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */; };
-		4B1A94160F49BE3000D3626B /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1A93540F49ACFC00D3626B /* JackMachThread.h */; };
-		4B1A94170F49BE3100D3626B /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93870F49B0E300D3626B /* JackMachTime.c */; };
-		4B1A94180F49BE3100D3626B /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */; };
-		4B1A94190F49BE3300D3626B /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */; };
-		4B1A941A0F49BE3300D3626B /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93110F49AB3400D3626B /* JackNetTool.cpp */; };
-		4B1A941B0F49BE3400D3626B /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */; };
-		4B1A941C0F49BE3500D3626B /* JackNetUnixSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1A93520F49ACF300D3626B /* JackNetUnixSocket.h */; };
-		4B1A941D0F49BE3500D3626B /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */; };
-		4B1A941E0F49BE3600D3626B /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1A933C0F49AC4500D3626B /* JackPosixThread.h */; };
-		4B1A94540F49C03300D3626B /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */; };
-		4B1A94550F49C03300D3626B /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93870F49B0E300D3626B /* JackMachTime.c */; };
-		4B1A94560F49C03400D3626B /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */; };
-		4B1A94570F49C03500D3626B /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */; };
-		4B1A94580F49C03600D3626B /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93110F49AB3400D3626B /* JackNetTool.cpp */; };
-		4B1A94590F49C03600D3626B /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */; };
-		4B1A945A0F49C03600D3626B /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */; };
-		4B1A95760F49CEAB00D3626B /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-		4B2791880F72570C000536B7 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2791870F72570C000536B7 /* JackGlobals.cpp */; };
-		4B2791890F72570C000536B7 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2791870F72570C000536B7 /* JackGlobals.cpp */; };
-		4B27918A0F72570C000536B7 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2791870F72570C000536B7 /* JackGlobals.cpp */; };
-		4B27918B0F72570C000536B7 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2791870F72570C000536B7 /* JackGlobals.cpp */; };
-		4B41469810BD3C4300C12F0C /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4B41469A10BD3C4300C12F0C /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */; };
-		4B41469B10BD3C4300C12F0C /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93870F49B0E300D3626B /* JackMachTime.c */; };
-		4B41469C10BD3C4300C12F0C /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */; };
-		4B41469D10BD3C4300C12F0C /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */; };
-		4B41469E10BD3C4300C12F0C /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93110F49AB3400D3626B /* JackNetTool.cpp */; };
-		4B41469F10BD3C4300C12F0C /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */; };
-		4B4146A010BD3C4300C12F0C /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */; };
-		4B4146A210BD3C4300C12F0C /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */; };
-		4B4146A310BD3C4300C12F0C /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */; };
-		4B4146A410BD3C4300C12F0C /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF136540F4B0F9F00218A3F /* ringbuffer.c */; };
-		4B4146A510BD3C4300C12F0C /* iPhoneNetAppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */; };
-		4B4146A610BD3C4300C12F0C /* freeverb.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4BBDC8F90F5420C000465F9C /* freeverb.mm */; };
-		4B4146A710BD3C4300C12F0C /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2791870F72570C000536B7 /* JackGlobals.cpp */; };
-		4B4146A910BD3C4300C12F0C /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		4B4146AA10BD3C4300C12F0C /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		4B4146AB10BD3C4300C12F0C /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		4B4146AC10BD3C4300C12F0C /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-		4B6B712C114BAE9A00ED9788 /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4B9CB1371136CA99007DE01A /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4B9CB1381136CA99007DE01A /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4B9CB1391136CA99007DE01A /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4B9CB13A1136CA99007DE01A /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4B9CB13B1136CA99007DE01A /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4B9CB13C1136CA99007DE01A /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4BBDC8FA0F5420C000465F9C /* freeverb.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4BBDC8F90F5420C000465F9C /* freeverb.mm */; };
-		4BC9C1F71135AB2800D22670 /* main_master.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4B0772500F54022D000DC657 /* main_master.mm */; };
-		4BCB37B6112D647C008C7BC1 /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4BCB37C7112D647C008C7BC1 /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		4BCB37C8112D647C008C7BC1 /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		4BCB37C9112D647C008C7BC1 /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		4BCB37CA112D647C008C7BC1 /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-		4BCB37D9112D64D8008C7BC1 /* iphone-faust.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4BCB37D8112D64D8008C7BC1 /* iphone-faust.mm */; };
-		4BCF75DA10BC2FD90082C526 /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4BCF75DC10BC2FD90082C526 /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */; };
-		4BCF75DD10BC2FD90082C526 /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93870F49B0E300D3626B /* JackMachTime.c */; };
-		4BCF75DE10BC2FD90082C526 /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */; };
-		4BCF75DF10BC2FD90082C526 /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */; };
-		4BCF75E010BC2FD90082C526 /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93110F49AB3400D3626B /* JackNetTool.cpp */; };
-		4BCF75E110BC2FD90082C526 /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */; };
-		4BCF75E210BC2FD90082C526 /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */; };
-		4BCF75E410BC2FD90082C526 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */; };
-		4BCF75E510BC2FD90082C526 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */; };
-		4BCF75E610BC2FD90082C526 /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF136540F4B0F9F00218A3F /* ringbuffer.c */; };
-		4BCF75E710BC2FD90082C526 /* iPhoneNetAppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */; };
-		4BCF75E910BC2FD90082C526 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2791870F72570C000536B7 /* JackGlobals.cpp */; };
-		4BCF75EB10BC2FD90082C526 /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		4BCF75EC10BC2FD90082C526 /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		4BCF75ED10BC2FD90082C526 /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		4BCF75EE10BC2FD90082C526 /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-		4BCF75F710BC30140082C526 /* audio_thru.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4BCF75F610BC30140082C526 /* audio_thru.mm */; };
-		4BDFCD3D113DB6B700D77992 /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4BDFCD3E113DB6B700D77992 /* icon.png in Resources */ = {isa = PBXBuildFile; fileRef = 4B9CB1361136CA99007DE01A /* icon.png */; };
-		4BDFCD4A113DB6B700D77992 /* main_slave.mm in Sources */ = {isa = PBXBuildFile; fileRef = 4B0772490F54021B000DC657 /* main_slave.mm */; };
-		4BDFCD4B113DB6B700D77992 /* iPhoneNetAppDelegate.m in Sources */ = {isa = PBXBuildFile; fileRef = 4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */; };
-		4BDFCD4D113DB6B700D77992 /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BDFCD4E113DB6B700D77992 /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BDFCD50113DB6B700D77992 /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		4BDFCD51113DB6B700D77992 /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		4BDFCD52113DB6B700D77992 /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		4BDFCD53113DB6B700D77992 /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-		4BF1360F0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */; };
-		4BF136100F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */; };
-		4BF136130F4B0B5E00218A3F /* JackAudioAdapterInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF136120F4B0B5E00218A3F /* JackAudioAdapterInterface.h */; };
-		4BF1364D0F4B0F7700218A3F /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */; };
-		4BF1364E0F4B0F7700218A3F /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */; };
-		4BF1364F0F4B0F7700218A3F /* JackResampler.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF1364C0F4B0F7700218A3F /* JackResampler.h */; };
-		4BF136550F4B0F9F00218A3F /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF136540F4B0F9F00218A3F /* ringbuffer.c */; };
-		4BF136560F4B0F9F00218A3F /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF136540F4B0F9F00218A3F /* ringbuffer.c */; };
-		4BF15E2511356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BF15E2611356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BF15E2711356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BF15E2811356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BF15E2911356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BF15E2A11356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */; };
-		4BF15F7811357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BF15F7911357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BF15F7A11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BF15F7B11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BF15F7C11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BF15F7D11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */; };
-		4BFF45600F4D5D9700106083 /* MainWindow.xib in Resources */ = {isa = PBXBuildFile; fileRef = 28AD733E0D9D9553002E5188 /* MainWindow.xib */; };
-		4BFF45630F4D5D9700106083 /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */; };
-		4BFF45640F4D5D9700106083 /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93870F49B0E300D3626B /* JackMachTime.c */; };
-		4BFF45650F4D5D9700106083 /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */; };
-		4BFF45660F4D5D9700106083 /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */; };
-		4BFF45670F4D5D9700106083 /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93110F49AB3400D3626B /* JackNetTool.cpp */; };
-		4BFF45680F4D5D9700106083 /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */; };
-		4BFF45690F4D5D9700106083 /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */; };
-		4BFF456B0F4D5D9700106083 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */; };
-		4BFF456C0F4D5D9700106083 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */; };
-		4BFF456D0F4D5D9700106083 /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF136540F4B0F9F00218A3F /* ringbuffer.c */; };
-		4BFF45700F4D5D9700106083 /* Foundation.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1D30AB110D05D00D00671497 /* Foundation.framework */; };
-		4BFF45710F4D5D9700106083 /* UIKit.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 1DF5F4DF0D08C38300B7A737 /* UIKit.framework */; };
-		4BFF45720F4D5D9700106083 /* CoreGraphics.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 288765FC0DF74451002DB57D /* CoreGraphics.framework */; };
-		4BFF45730F4D5D9700106083 /* AudioToolbox.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */; };
-/* End PBXBuildFile section */
-
-/* Begin PBXFileReference section */
-		1D30AB110D05D00D00671497 /* Foundation.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = Foundation.framework; path = System/Library/Frameworks/Foundation.framework; sourceTree = SDKROOT; };
-		1D6058910D05DD3D006BFB54 /* NetJackSlave.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = NetJackSlave.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		1DF5F4DF0D08C38300B7A737 /* UIKit.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = UIKit.framework; path = System/Library/Frameworks/UIKit.framework; sourceTree = SDKROOT; };
-		288765FC0DF74451002DB57D /* CoreGraphics.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = CoreGraphics.framework; path = System/Library/Frameworks/CoreGraphics.framework; sourceTree = SDKROOT; };
-		28AD733E0D9D9553002E5188 /* MainWindow.xib */ = {isa = PBXFileReference; lastKnownFileType = file.xib; path = MainWindow.xib; sourceTree = "<group>"; };
-		32CA4F630368D1EE00C91783 /* iPhoneNet_Prefix.pch */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = iPhoneNet_Prefix.pch; sourceTree = "<group>"; };
-		4B0772380F54018C000DC657 /* NetJackMaster.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = NetJackMaster.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B0772490F54021B000DC657 /* main_slave.mm */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.objcpp; path = main_slave.mm; sourceTree = SOURCE_ROOT; };
-		4B0772500F54022D000DC657 /* main_master.mm */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.objcpp; path = main_master.mm; sourceTree = SOURCE_ROOT; };
-		4B0773840F541EE2000DC657 /* iPhoneNetAppDelegate.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = iPhoneNetAppDelegate.h; sourceTree = "<group>"; };
-		4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.objc; path = iPhoneNetAppDelegate.m; sourceTree = "<group>"; };
-		4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetAPI.cpp; path = ../../common/JackNetAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetInterface.cpp; path = ../../common/JackNetInterface.cpp; sourceTree = SOURCE_ROOT; };
-		4B1A93110F49AB3400D3626B /* JackNetTool.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetTool.cpp; path = ../../common/JackNetTool.cpp; sourceTree = SOURCE_ROOT; };
-		4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPosixThread.cpp; path = ../../posix/JackPosixThread.cpp; sourceTree = SOURCE_ROOT; };
-		4B1A933C0F49AC4500D3626B /* JackPosixThread.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPosixThread.h; path = ../../posix/JackPosixThread.h; sourceTree = SOURCE_ROOT; };
-		4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetUnixSocket.cpp; path = ../../posix/JackNetUnixSocket.cpp; sourceTree = SOURCE_ROOT; };
-		4B1A93520F49ACF300D3626B /* JackNetUnixSocket.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackNetUnixSocket.h; path = ../../posix/JackNetUnixSocket.h; sourceTree = SOURCE_ROOT; };
-		4B1A93540F49ACFC00D3626B /* JackMachThread.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMachThread.h; path = ../JackMachThread.h; sourceTree = SOURCE_ROOT; };
-		4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMachThread.cpp; path = ../JackMachThread.cpp; sourceTree = SOURCE_ROOT; };
-		4B1A93870F49B0E300D3626B /* JackMachTime.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = JackMachTime.c; path = ../JackMachTime.c; sourceTree = SOURCE_ROOT; };
-		4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = AudioToolbox.framework; path = /Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS2.2.1.sdk/System/Library/Frameworks/AudioToolbox.framework; sourceTree = "<absolute>"; };
-		4B2791870F72570C000536B7 /* JackGlobals.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackGlobals.cpp; path = ../../common/JackGlobals.cpp; sourceTree = SOURCE_ROOT; };
-		4B4146B010BD3C4300C12F0C /* iPhoneFaustNet.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = iPhoneFaustNet.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B9CB1361136CA99007DE01A /* icon.png */ = {isa = PBXFileReference; lastKnownFileType = image.png; path = icon.png; sourceTree = SOURCE_ROOT; };
-		4BBDC8F90F5420C000465F9C /* freeverb.mm */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.objcpp; path = freeverb.mm; sourceTree = SOURCE_ROOT; };
-		4BC9C1D31135AA1800D22670 /* iPhoneNetMasterAppl-Info.plist */ = {isa = PBXFileReference; lastKnownFileType = text.plist.xml; path = "iPhoneNetMasterAppl-Info.plist"; sourceTree = "<group>"; };
-		4BCB37CE112D647C008C7BC1 /* iPhoneFaust.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = iPhoneFaust.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BCB37D8112D64D8008C7BC1 /* iphone-faust.mm */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.objcpp; path = "iphone-faust.mm"; sourceTree = SOURCE_ROOT; };
-		4BCF75F210BC2FD90082C526 /* iPhoneThruNet.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = iPhoneThruNet.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BCF75F610BC30140082C526 /* audio_thru.mm */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.objcpp; path = audio_thru.mm; sourceTree = SOURCE_ROOT; };
-		4BDFCD57113DB6B700D77992 /* NetJackSlave.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = NetJackSlave.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackAudioAdapterInterface.cpp; path = ../../common/JackAudioAdapterInterface.cpp; sourceTree = SOURCE_ROOT; };
-		4BF136120F4B0B5E00218A3F /* JackAudioAdapterInterface.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackAudioAdapterInterface.h; path = ../../common/JackAudioAdapterInterface.h; sourceTree = SOURCE_ROOT; };
-		4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackResampler.cpp; path = ../../common/JackResampler.cpp; sourceTree = SOURCE_ROOT; };
-		4BF1364C0F4B0F7700218A3F /* JackResampler.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackResampler.h; path = ../../common/JackResampler.h; sourceTree = SOURCE_ROOT; };
-		4BF136540F4B0F9F00218A3F /* ringbuffer.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = ringbuffer.c; path = ../../common/ringbuffer.c; sourceTree = SOURCE_ROOT; };
-		4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = CAHostTimeBase.cpp; path = /Developer/Extras/CoreAudio/PublicUtility/CAHostTimeBase.cpp; sourceTree = "<absolute>"; };
-		4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = TiPhoneCoreAudioRenderer.cpp; path = ../coreaudio/TiPhoneCoreAudioRenderer.cpp; sourceTree = SOURCE_ROOT; };
-		4BFF45120F4D59DB00106083 /* libjacknet.a */ = {isa = PBXFileReference; explicitFileType = archive.ar; includeInIndex = 0; path = libjacknet.a; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFF45770F4D5D9700106083 /* iPhoneFaustNet.app */ = {isa = PBXFileReference; explicitFileType = wrapper.application; includeInIndex = 0; path = iPhoneFaustNet.app; sourceTree = BUILT_PRODUCTS_DIR; };
-		8D1107310486CEB800E47090 /* Info.plist */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = text.plist.xml; path = Info.plist; sourceTree = "<group>"; };
-/* End PBXFileReference section */
-
-/* Begin PBXFrameworksBuildPhase section */
-		1D60588F0D05DD3D006BFB54 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				1D60589F0D05DD5A006BFB54 /* Foundation.framework in Frameworks */,
-				1DF5F4E00D08C38300B7A737 /* UIKit.framework in Frameworks */,
-				288765FD0DF74451002DB57D /* CoreGraphics.framework in Frameworks */,
-				4B1A95760F49CEAB00D3626B /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0772300F54018C000DC657 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B0772310F54018C000DC657 /* Foundation.framework in Frameworks */,
-				4B0772320F54018C000DC657 /* UIKit.framework in Frameworks */,
-				4B0772330F54018C000DC657 /* CoreGraphics.framework in Frameworks */,
-				4B0772340F54018C000DC657 /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B1A940E0F49BDE000D3626B /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B4146A810BD3C4300C12F0C /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B4146A910BD3C4300C12F0C /* Foundation.framework in Frameworks */,
-				4B4146AA10BD3C4300C12F0C /* UIKit.framework in Frameworks */,
-				4B4146AB10BD3C4300C12F0C /* CoreGraphics.framework in Frameworks */,
-				4B4146AC10BD3C4300C12F0C /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BCB37C6112D647C008C7BC1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCB37C7112D647C008C7BC1 /* Foundation.framework in Frameworks */,
-				4BCB37C8112D647C008C7BC1 /* UIKit.framework in Frameworks */,
-				4BCB37C9112D647C008C7BC1 /* CoreGraphics.framework in Frameworks */,
-				4BCB37CA112D647C008C7BC1 /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BCF75EA10BC2FD90082C526 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCF75EB10BC2FD90082C526 /* Foundation.framework in Frameworks */,
-				4BCF75EC10BC2FD90082C526 /* UIKit.framework in Frameworks */,
-				4BCF75ED10BC2FD90082C526 /* CoreGraphics.framework in Frameworks */,
-				4BCF75EE10BC2FD90082C526 /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDFCD4F113DB6B700D77992 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDFCD50113DB6B700D77992 /* Foundation.framework in Frameworks */,
-				4BDFCD51113DB6B700D77992 /* UIKit.framework in Frameworks */,
-				4BDFCD52113DB6B700D77992 /* CoreGraphics.framework in Frameworks */,
-				4BDFCD53113DB6B700D77992 /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFF456F0F4D5D9700106083 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFF45700F4D5D9700106083 /* Foundation.framework in Frameworks */,
-				4BFF45710F4D5D9700106083 /* UIKit.framework in Frameworks */,
-				4BFF45720F4D5D9700106083 /* CoreGraphics.framework in Frameworks */,
-				4BFF45730F4D5D9700106083 /* AudioToolbox.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXFrameworksBuildPhase section */
-
-/* Begin PBXGroup section */
-		19C28FACFE9D520D11CA2CBB /* Products */ = {
-			isa = PBXGroup;
-			children = (
-				1D6058910D05DD3D006BFB54 /* NetJackSlave.app */,
-				4BFF45120F4D59DB00106083 /* libjacknet.a */,
-				4BFF45770F4D5D9700106083 /* iPhoneFaustNet.app */,
-				4B0772380F54018C000DC657 /* NetJackMaster.app */,
-				4BCF75F210BC2FD90082C526 /* iPhoneThruNet.app */,
-				4B4146B010BD3C4300C12F0C /* iPhoneFaustNet.app */,
-				4BCB37CE112D647C008C7BC1 /* iPhoneFaust.app */,
-				4BDFCD57113DB6B700D77992 /* NetJackSlave.app */,
-			);
-			name = Products;
-			sourceTree = "<group>";
-		};
-		29B97314FDCFA39411CA2CEA /* CustomTemplate */ = {
-			isa = PBXGroup;
-			children = (
-				4BCB37D8112D64D8008C7BC1 /* iphone-faust.mm */,
-				4BF15E2411356A3E00B36B9A /* CAHostTimeBase.cpp */,
-				4BF15F7711357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp */,
-				29B97315FDCFA39411CA2CEA /* Other Sources */,
-				29B97323FDCFA39411CA2CEA /* Frameworks */,
-				19C28FACFE9D520D11CA2CBB /* Products */,
-			);
-			name = CustomTemplate;
-			sourceTree = "<group>";
-		};
-		29B97315FDCFA39411CA2CEA /* Other Sources */ = {
-			isa = PBXGroup;
-			children = (
-				29B97317FDCFA39411CA2CEA /* Resources */,
-				4BCF75F610BC30140082C526 /* audio_thru.mm */,
-				4BBDC8F90F5420C000465F9C /* freeverb.mm */,
-				4B0773840F541EE2000DC657 /* iPhoneNetAppDelegate.h */,
-				4B0773850F541EE2000DC657 /* iPhoneNetAppDelegate.m */,
-				4BF136540F4B0F9F00218A3F /* ringbuffer.c */,
-				4BF1364B0F4B0F7700218A3F /* JackResampler.cpp */,
-				4BF1364C0F4B0F7700218A3F /* JackResampler.h */,
-				4BF1360E0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp */,
-				4BF136120F4B0B5E00218A3F /* JackAudioAdapterInterface.h */,
-				4B1A93870F49B0E300D3626B /* JackMachTime.c */,
-				4B1A93540F49ACFC00D3626B /* JackMachThread.h */,
-				4B1A93550F49ACFC00D3626B /* JackMachThread.cpp */,
-				4B1A93510F49ACF300D3626B /* JackNetUnixSocket.cpp */,
-				4B1A93520F49ACF300D3626B /* JackNetUnixSocket.h */,
-				4B1A933B0F49AC4500D3626B /* JackPosixThread.cpp */,
-				4B1A933C0F49AC4500D3626B /* JackPosixThread.h */,
-				4B1A93110F49AB3400D3626B /* JackNetTool.cpp */,
-				4B1A930F0F49AB2F00D3626B /* JackNetInterface.cpp */,
-				4B1A930D0F49AB2A00D3626B /* JackNetAPI.cpp */,
-				4B2791870F72570C000536B7 /* JackGlobals.cpp */,
-				32CA4F630368D1EE00C91783 /* iPhoneNet_Prefix.pch */,
-				4B0772490F54021B000DC657 /* main_slave.mm */,
-				4B0772500F54022D000DC657 /* main_master.mm */,
-			);
-			name = "Other Sources";
-			sourceTree = "<group>";
-		};
-		29B97317FDCFA39411CA2CEA /* Resources */ = {
-			isa = PBXGroup;
-			children = (
-				4B9CB1361136CA99007DE01A /* icon.png */,
-				28AD733E0D9D9553002E5188 /* MainWindow.xib */,
-				8D1107310486CEB800E47090 /* Info.plist */,
-				4BC9C1D31135AA1800D22670 /* iPhoneNetMasterAppl-Info.plist */,
-			);
-			name = Resources;
-			sourceTree = "<group>";
-		};
-		29B97323FDCFA39411CA2CEA /* Frameworks */ = {
-			isa = PBXGroup;
-			children = (
-				4B1A95750F49CEAB00D3626B /* AudioToolbox.framework */,
-				1DF5F4DF0D08C38300B7A737 /* UIKit.framework */,
-				1D30AB110D05D00D00671497 /* Foundation.framework */,
-				288765FC0DF74451002DB57D /* CoreGraphics.framework */,
-			);
-			name = Frameworks;
-			sourceTree = "<group>";
-		};
-/* End PBXGroup section */
-
-/* Begin PBXHeadersBuildPhase section */
-		4B1A940C0F49BDE000D3626B /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B1A94140F49BE2C00D3626B /* iPhoneNet_Prefix.pch in Headers */,
-				4B1A94160F49BE3000D3626B /* JackMachThread.h in Headers */,
-				4B1A941C0F49BE3500D3626B /* JackNetUnixSocket.h in Headers */,
-				4B1A941E0F49BE3600D3626B /* JackPosixThread.h in Headers */,
-				4BF136130F4B0B5E00218A3F /* JackAudioAdapterInterface.h in Headers */,
-				4BF1364F0F4B0F7700218A3F /* JackResampler.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXHeadersBuildPhase section */
-
-/* Begin PBXNativeTarget section */
-		1D6058900D05DD3D006BFB54 /* iPhoneNetSlave */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 1D6058960D05DD3E006BFB54 /* Build configuration list for PBXNativeTarget "iPhoneNetSlave" */;
-			buildPhases = (
-				1D60588D0D05DD3D006BFB54 /* Resources */,
-				1D60588E0D05DD3D006BFB54 /* Sources */,
-				1D60588F0D05DD3D006BFB54 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = iPhoneNetSlave;
-			productName = iPhoneNet;
-			productReference = 1D6058910D05DD3D006BFB54 /* NetJackSlave.app */;
-			productType = "com.apple.product-type.application";
-		};
-		4B07721F0F54018C000DC657 /* iPhoneNetMaster */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B0772350F54018C000DC657 /* Build configuration list for PBXNativeTarget "iPhoneNetMaster" */;
-			buildPhases = (
-				4B0772200F54018C000DC657 /* Resources */,
-				4B0772220F54018C000DC657 /* Sources */,
-				4B0772300F54018C000DC657 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = iPhoneNetMaster;
-			productName = iPhoneNet;
-			productReference = 4B0772380F54018C000DC657 /* NetJackMaster.app */;
-			productType = "com.apple.product-type.application";
-		};
-		4B1A940F0F49BDE000D3626B /* libjacknet */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B1A94130F49BDFF00D3626B /* Build configuration list for PBXNativeTarget "libjacknet" */;
-			buildPhases = (
-				4B1A940C0F49BDE000D3626B /* Headers */,
-				4B1A940D0F49BDE000D3626B /* Sources */,
-				4B1A940E0F49BDE000D3626B /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = libjacknet;
-			productName = jacknet;
-			productReference = 4BFF45120F4D59DB00106083 /* libjacknet.a */;
-			productType = "com.apple.product-type.library.static";
-		};
-		4B41469610BD3C4300C12F0C /* iPhoneFaustNet Distribution */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B4146AD10BD3C4300C12F0C /* Build configuration list for PBXNativeTarget "iPhoneFaustNet Distribution" */;
-			buildPhases = (
-				4B41469710BD3C4300C12F0C /* Resources */,
-				4B41469910BD3C4300C12F0C /* Sources */,
-				4B4146A810BD3C4300C12F0C /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "iPhoneFaustNet Distribution";
-			productName = iPhoneNet;
-			productReference = 4B4146B010BD3C4300C12F0C /* iPhoneFaustNet.app */;
-			productType = "com.apple.product-type.application";
-		};
-		4BCB37B4112D647C008C7BC1 /* iPhoneFaust */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BCB37CB112D647C008C7BC1 /* Build configuration list for PBXNativeTarget "iPhoneFaust" */;
-			buildPhases = (
-				4BCB37B5112D647C008C7BC1 /* Resources */,
-				4BCB37B7112D647C008C7BC1 /* Sources */,
-				4BCB37C6112D647C008C7BC1 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = iPhoneFaust;
-			productName = iPhoneNet;
-			productReference = 4BCB37CE112D647C008C7BC1 /* iPhoneFaust.app */;
-			productType = "com.apple.product-type.application";
-		};
-		4BCF75D810BC2FD90082C526 /* iPhoneThruNet */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BCF75EF10BC2FD90082C526 /* Build configuration list for PBXNativeTarget "iPhoneThruNet" */;
-			buildPhases = (
-				4BCF75D910BC2FD90082C526 /* Resources */,
-				4BCF75DB10BC2FD90082C526 /* Sources */,
-				4BCF75EA10BC2FD90082C526 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = iPhoneThruNet;
-			productName = iPhoneNet;
-			productReference = 4BCF75F210BC2FD90082C526 /* iPhoneThruNet.app */;
-			productType = "com.apple.product-type.application";
-		};
-		4BDFCD3B113DB6B700D77992 /* iPhoneNetSlaveLib */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BDFCD54113DB6B700D77992 /* Build configuration list for PBXNativeTarget "iPhoneNetSlaveLib" */;
-			buildPhases = (
-				4BDFCD3C113DB6B700D77992 /* Resources */,
-				4BDFCD3F113DB6B700D77992 /* Sources */,
-				4BDFCD4F113DB6B700D77992 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = iPhoneNetSlaveLib;
-			productName = iPhoneNet;
-			productReference = 4BDFCD57113DB6B700D77992 /* NetJackSlave.app */;
-			productType = "com.apple.product-type.application";
-		};
-		4BFF455E0F4D5D9700106083 /* iPhoneFaustNet */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFF45740F4D5D9700106083 /* Build configuration list for PBXNativeTarget "iPhoneFaustNet" */;
-			buildPhases = (
-				4BFF455F0F4D5D9700106083 /* Resources */,
-				4BFF45610F4D5D9700106083 /* Sources */,
-				4BFF456F0F4D5D9700106083 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = iPhoneFaustNet;
-			productName = iPhoneNet;
-			productReference = 4BFF45770F4D5D9700106083 /* iPhoneFaustNet.app */;
-			productType = "com.apple.product-type.application";
-		};
-/* End PBXNativeTarget section */
-
-/* Begin PBXProject section */
-		29B97313FDCFA39411CA2CEA /* Project object */ = {
-			isa = PBXProject;
-			buildConfigurationList = C01FCF4E08A954540054247B /* Build configuration list for PBXProject "iPhoneNet" */;
-			compatibilityVersion = "Xcode 3.1";
-			developmentRegion = English;
-			hasScannedForEncodings = 1;
-			knownRegions = (
-				English,
-				Japanese,
-				French,
-				German,
-			);
-			mainGroup = 29B97314FDCFA39411CA2CEA /* CustomTemplate */;
-			projectDirPath = "";
-			projectRoot = "";
-			targets = (
-				4B07721F0F54018C000DC657 /* iPhoneNetMaster */,
-				1D6058900D05DD3D006BFB54 /* iPhoneNetSlave */,
-				4BDFCD3B113DB6B700D77992 /* iPhoneNetSlaveLib */,
-				4BFF455E0F4D5D9700106083 /* iPhoneFaustNet */,
-				4BCF75D810BC2FD90082C526 /* iPhoneThruNet */,
-				4B41469610BD3C4300C12F0C /* iPhoneFaustNet Distribution */,
-				4BCB37B4112D647C008C7BC1 /* iPhoneFaust */,
-				4B1A940F0F49BDE000D3626B /* libjacknet */,
-			);
-		};
-/* End PBXProject section */
-
-/* Begin PBXResourcesBuildPhase section */
-		1D60588D0D05DD3D006BFB54 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				28AD733F0D9D9553002E5188 /* MainWindow.xib in Resources */,
-				4B9CB1381136CA99007DE01A /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0772200F54018C000DC657 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B0772210F54018C000DC657 /* MainWindow.xib in Resources */,
-				4B9CB1371136CA99007DE01A /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B41469710BD3C4300C12F0C /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B41469810BD3C4300C12F0C /* MainWindow.xib in Resources */,
-				4B9CB13B1136CA99007DE01A /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BCB37B5112D647C008C7BC1 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCB37B6112D647C008C7BC1 /* MainWindow.xib in Resources */,
-				4B9CB13C1136CA99007DE01A /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BCF75D910BC2FD90082C526 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCF75DA10BC2FD90082C526 /* MainWindow.xib in Resources */,
-				4B9CB13A1136CA99007DE01A /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDFCD3C113DB6B700D77992 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDFCD3D113DB6B700D77992 /* MainWindow.xib in Resources */,
-				4BDFCD3E113DB6B700D77992 /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFF455F0F4D5D9700106083 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFF45600F4D5D9700106083 /* MainWindow.xib in Resources */,
-				4B9CB1391136CA99007DE01A /* icon.png in Resources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXResourcesBuildPhase section */
-
-/* Begin PBXSourcesBuildPhase section */
-		1D60588E0D05DD3D006BFB54 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B1A94540F49C03300D3626B /* JackMachThread.cpp in Sources */,
-				4B1A94550F49C03300D3626B /* JackMachTime.c in Sources */,
-				4B1A94560F49C03400D3626B /* JackNetAPI.cpp in Sources */,
-				4B1A94570F49C03500D3626B /* JackNetInterface.cpp in Sources */,
-				4B1A94580F49C03600D3626B /* JackNetTool.cpp in Sources */,
-				4B1A94590F49C03600D3626B /* JackNetUnixSocket.cpp in Sources */,
-				4B1A945A0F49C03600D3626B /* JackPosixThread.cpp in Sources */,
-				4BF1360F0F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp in Sources */,
-				4BF1364D0F4B0F7700218A3F /* JackResampler.cpp in Sources */,
-				4BF136550F4B0F9F00218A3F /* ringbuffer.c in Sources */,
-				4B07724A0F54021B000DC657 /* main_slave.mm in Sources */,
-				4B0773870F541EE2000DC657 /* iPhoneNetAppDelegate.m in Sources */,
-				4B27918A0F72570C000536B7 /* JackGlobals.cpp in Sources */,
-				4BF15E2611356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */,
-				4BF15F7911357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0772220F54018C000DC657 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B0772240F54018C000DC657 /* JackMachThread.cpp in Sources */,
-				4B0772250F54018C000DC657 /* JackMachTime.c in Sources */,
-				4B0772260F54018C000DC657 /* JackNetAPI.cpp in Sources */,
-				4B0772270F54018C000DC657 /* JackNetInterface.cpp in Sources */,
-				4B0772280F54018C000DC657 /* JackNetTool.cpp in Sources */,
-				4B0772290F54018C000DC657 /* JackNetUnixSocket.cpp in Sources */,
-				4B07722A0F54018C000DC657 /* JackPosixThread.cpp in Sources */,
-				4B07722C0F54018C000DC657 /* JackAudioAdapterInterface.cpp in Sources */,
-				4B07722D0F54018C000DC657 /* JackResampler.cpp in Sources */,
-				4B07722E0F54018C000DC657 /* ringbuffer.c in Sources */,
-				4B0773860F541EE2000DC657 /* iPhoneNetAppDelegate.m in Sources */,
-				4B27918B0F72570C000536B7 /* JackGlobals.cpp in Sources */,
-				4BF15E2511356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */,
-				4BF15F7811357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-				4BC9C1F71135AB2800D22670 /* main_master.mm in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B1A940D0F49BDE000D3626B /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B1A94150F49BE2F00D3626B /* JackMachThread.cpp in Sources */,
-				4B1A94170F49BE3100D3626B /* JackMachTime.c in Sources */,
-				4B1A94180F49BE3100D3626B /* JackNetAPI.cpp in Sources */,
-				4B1A94190F49BE3300D3626B /* JackNetInterface.cpp in Sources */,
-				4B1A941A0F49BE3300D3626B /* JackNetTool.cpp in Sources */,
-				4B1A941B0F49BE3400D3626B /* JackNetUnixSocket.cpp in Sources */,
-				4B1A941D0F49BE3500D3626B /* JackPosixThread.cpp in Sources */,
-				4BF136100F4B0B4C00218A3F /* JackAudioAdapterInterface.cpp in Sources */,
-				4BF1364E0F4B0F7700218A3F /* JackResampler.cpp in Sources */,
-				4BF136560F4B0F9F00218A3F /* ringbuffer.c in Sources */,
-				4B2791890F72570C000536B7 /* JackGlobals.cpp in Sources */,
-				4B6B712C114BAE9A00ED9788 /* CAHostTimeBase.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B41469910BD3C4300C12F0C /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B41469A10BD3C4300C12F0C /* JackMachThread.cpp in Sources */,
-				4B41469B10BD3C4300C12F0C /* JackMachTime.c in Sources */,
-				4B41469C10BD3C4300C12F0C /* JackNetAPI.cpp in Sources */,
-				4B41469D10BD3C4300C12F0C /* JackNetInterface.cpp in Sources */,
-				4B41469E10BD3C4300C12F0C /* JackNetTool.cpp in Sources */,
-				4B41469F10BD3C4300C12F0C /* JackNetUnixSocket.cpp in Sources */,
-				4B4146A010BD3C4300C12F0C /* JackPosixThread.cpp in Sources */,
-				4B4146A210BD3C4300C12F0C /* JackAudioAdapterInterface.cpp in Sources */,
-				4B4146A310BD3C4300C12F0C /* JackResampler.cpp in Sources */,
-				4B4146A410BD3C4300C12F0C /* ringbuffer.c in Sources */,
-				4B4146A510BD3C4300C12F0C /* iPhoneNetAppDelegate.m in Sources */,
-				4B4146A610BD3C4300C12F0C /* freeverb.mm in Sources */,
-				4B4146A710BD3C4300C12F0C /* JackGlobals.cpp in Sources */,
-				4BF15E2911356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */,
-				4BF15F7C11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BCB37B7112D647C008C7BC1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCB37D9112D64D8008C7BC1 /* iphone-faust.mm in Sources */,
-				4BF15E2A11356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */,
-				4BF15F7D11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BCF75DB10BC2FD90082C526 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCF75DC10BC2FD90082C526 /* JackMachThread.cpp in Sources */,
-				4BCF75DD10BC2FD90082C526 /* JackMachTime.c in Sources */,
-				4BCF75DE10BC2FD90082C526 /* JackNetAPI.cpp in Sources */,
-				4BCF75DF10BC2FD90082C526 /* JackNetInterface.cpp in Sources */,
-				4BCF75E010BC2FD90082C526 /* JackNetTool.cpp in Sources */,
-				4BCF75E110BC2FD90082C526 /* JackNetUnixSocket.cpp in Sources */,
-				4BCF75E210BC2FD90082C526 /* JackPosixThread.cpp in Sources */,
-				4BCF75E410BC2FD90082C526 /* JackAudioAdapterInterface.cpp in Sources */,
-				4BCF75E510BC2FD90082C526 /* JackResampler.cpp in Sources */,
-				4BCF75E610BC2FD90082C526 /* ringbuffer.c in Sources */,
-				4BCF75E710BC2FD90082C526 /* iPhoneNetAppDelegate.m in Sources */,
-				4BCF75E910BC2FD90082C526 /* JackGlobals.cpp in Sources */,
-				4BCF75F710BC30140082C526 /* audio_thru.mm in Sources */,
-				4BF15E2811356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */,
-				4BF15F7B11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDFCD3F113DB6B700D77992 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDFCD4A113DB6B700D77992 /* main_slave.mm in Sources */,
-				4BDFCD4B113DB6B700D77992 /* iPhoneNetAppDelegate.m in Sources */,
-				4BDFCD4D113DB6B700D77992 /* CAHostTimeBase.cpp in Sources */,
-				4BDFCD4E113DB6B700D77992 /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFF45610F4D5D9700106083 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFF45630F4D5D9700106083 /* JackMachThread.cpp in Sources */,
-				4BFF45640F4D5D9700106083 /* JackMachTime.c in Sources */,
-				4BFF45650F4D5D9700106083 /* JackNetAPI.cpp in Sources */,
-				4BFF45660F4D5D9700106083 /* JackNetInterface.cpp in Sources */,
-				4BFF45670F4D5D9700106083 /* JackNetTool.cpp in Sources */,
-				4BFF45680F4D5D9700106083 /* JackNetUnixSocket.cpp in Sources */,
-				4BFF45690F4D5D9700106083 /* JackPosixThread.cpp in Sources */,
-				4BFF456B0F4D5D9700106083 /* JackAudioAdapterInterface.cpp in Sources */,
-				4BFF456C0F4D5D9700106083 /* JackResampler.cpp in Sources */,
-				4BFF456D0F4D5D9700106083 /* ringbuffer.c in Sources */,
-				4B0773880F541EE2000DC657 /* iPhoneNetAppDelegate.m in Sources */,
-				4BBDC8FA0F5420C000465F9C /* freeverb.mm in Sources */,
-				4B2791880F72570C000536B7 /* JackGlobals.cpp in Sources */,
-				4BF15E2711356A3E00B36B9A /* CAHostTimeBase.cpp in Sources */,
-				4BF15F7A11357A0E00B36B9A /* TiPhoneCoreAudioRenderer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXSourcesBuildPhase section */
-
-/* Begin XCBuildConfiguration section */
-		1D6058940D05DD3E006BFB54 /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					/usr/local/include,
-					../../macosx/coreaudio,
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\"$(SRCROOT)/build/Debug-iphonesimulator\"",
-				);
-				OTHER_LDFLAGS = libcelt.a;
-				PRODUCT_NAME = NetJackSlave;
-				SDKROOT = iphoneos3.1.3;
-			};
-			name = Debug;
-		};
-		1D6058950D05DD3E006BFB54 /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				GCC_THUMB_SUPPORT = NO;
-				HEADER_SEARCH_PATHS = (
-					.,
-					/usr/local/include,
-					../../macosx/coreaudio,
-					../../common/jack,
-					../../common,
-					../../posix,
-					../../macosx,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\"$(SRCROOT)/build/Debug-iphonesimulator\"",
-				);
-				OTHER_LDFLAGS = libcelt.a;
-				PRODUCT_NAME = NetJackSlave;
-				SDKROOT = iphoneos3.1.3;
-			};
-			name = Release;
-		};
-		4B0772360F54018C000DC657 /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					/usr/local/include,
-					../../macosx/coreaudio,
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\"",
-				);
-				OTHER_LDFLAGS = libcelt.a;
-				PRODUCT_NAME = NetJackMaster;
-				SDKROOT = iphoneos3.1.3;
-			};
-			name = Debug;
-		};
-		4B0772370F54018C000DC657 /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					/usr/local/include,
-					../../macosx/coreaudio,
-					../../common/jack,
-					../../common,
-					../../posix,
-					../../macosx,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\"",
-				);
-				OTHER_LDFLAGS = libcelt.a;
-				PRODUCT_NAME = NetJackMaster;
-			};
-			name = Release;
-		};
-		4B1A94110F49BDE100D3626B /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					/usr/local/include,
-					../../common/jack,
-					../../common,
-					../../posix,
-					../../macosx,
-				);
-				MACH_O_TYPE = staticlib;
-				PREBINDING = NO;
-				PRODUCT_NAME = jacknet;
-				SDKROOT = iphoneos3.1.3;
-				STANDARD_C_PLUS_PLUS_LIBRARY_TYPE = static;
-			};
-			name = Debug;
-		};
-		4B1A94120F49BDE100D3626B /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				DEBUG_INFORMATION_FORMAT = "dwarf-with-dsym";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					/usr/local/include,
-					../../macosx,
-					../../posix,
-					../../common,
-					../../common/jack,
-				);
-				PREBINDING = NO;
-				PRODUCT_NAME = jacknet;
-				SDKROOT = iphoneos3.1.3;
-				ZERO_LINK = NO;
-			};
-			name = Release;
-		};
-		4B4146AE10BD3C4300C12F0C /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				"CODE_SIGN_IDENTITY[sdk=iphoneos*]" = "iPhone Developer: Stéphane Letz (8LJEY2RN3N)";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = "Info copy 2.plist";
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\\\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\\\\\"",
-				);
-				OTHER_LDFLAGS = "";
-				PRODUCT_NAME = iPhoneFaustNet;
-				"PROVISIONING_PROFILE[sdk=iphoneos*]" = "CEF78041-8E2A-499D-BF7C-8A1B22B6C2AC";
-				SDKROOT = iphoneos2.2.1;
-			};
-			name = Debug;
-		};
-		4B4146AF10BD3C4300C12F0C /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../common/jack,
-					../../common,
-					../../posix,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\\\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\\\\\"",
-				);
-				ONLY_ACTIVE_ARCH = NO;
-				PRODUCT_NAME = iPhoneFaustNet;
-				SDKROOT = iphoneos3.1.2;
-			};
-			name = Release;
-		};
-		4BCB37CC112D647C008C7BC1 /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				GCC_THUMB_SUPPORT = NO;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = Info.plist;
-				IPHONEOS_DEPLOYMENT_TARGET = 3.1.3;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\\\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\\\\\"",
-				);
-				OTHER_LDFLAGS = "";
-				PRODUCT_NAME = iPhoneFaust;
-				SDKROOT = iphoneos3.1.3;
-			};
-			name = Debug;
-		};
-		4BCB37CD112D647C008C7BC1 /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				GCC_THUMB_SUPPORT = NO;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../common/jack,
-					../../common,
-					../../posix,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\\\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\\\\\"",
-				);
-				ONLY_ACTIVE_ARCH = NO;
-				PRODUCT_NAME = iPhoneFaust;
-				SDKROOT = iphoneos3.1.3;
-			};
-			name = Release;
-		};
-		4BCF75F010BC2FD90082C526 /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\\\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\\\\\"",
-				);
-				OTHER_LDFLAGS = "";
-				PRODUCT_NAME = iPhoneThruNet;
-				SDKROOT = iphoneos2.2.1;
-			};
-			name = Debug;
-		};
-		4BCF75F110BC2FD90082C526 /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				GCC_VERSION = "";
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../common/jack,
-					../../common,
-					../../posix,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\\\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\\\\\"",
-				);
-				ONLY_ACTIVE_ARCH = NO;
-				PRODUCT_NAME = iPhoneFaustNet;
-			};
-			name = Release;
-		};
-		4BDFCD55113DB6B700D77992 /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx/coreaudio,
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\"",
-				);
-				OTHER_LDFLAGS = "-ljacknet";
-				PRODUCT_NAME = NetJackSlave;
-				SDKROOT = iphoneos3.1.3;
-			};
-			name = Debug;
-		};
-		4BDFCD56113DB6B700D77992 /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx/coreaudio,
-					../../common/jack,
-					../../common,
-					../../posix,
-					../../macosx,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\"",
-				);
-				OTHER_LDFLAGS = "-ljacknet";
-				PRODUCT_NAME = NetJackSlave;
-			};
-			name = Release;
-		};
-		4BFF45750F4D5D9700106083 /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../posix,
-					../../common/jack,
-					../../common,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\"",
-				);
-				OTHER_LDFLAGS = "";
-				PRODUCT_NAME = iPhoneFaustNet;
-				SDKROOT = iphoneos2.2.1;
-			};
-			name = Debug;
-		};
-		4BFF45760F4D5D9700106083 /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ALWAYS_SEARCH_USER_PATHS = NO;
-				COPY_PHASE_STRIP = YES;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = iPhoneNet_Prefix.pch;
-				HEADER_SEARCH_PATHS = (
-					../../macosx,
-					../../common/jack,
-					../../common,
-					../../posix,
-				);
-				INFOPLIST_FILE = Info.plist;
-				LIBRARY_SEARCH_PATHS = (
-					"$(inherited)",
-					"\\\"$(SRCROOT)/build/Debug-iphonesimulator\\\"",
-				);
-				ONLY_ACTIVE_ARCH = NO;
-				PRODUCT_NAME = iPhoneFaustNet;
-			};
-			name = Release;
-		};
-		C01FCF4F08A954540054247B /* Debug */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_BIT)";
-				"CODE_SIGN_IDENTITY[sdk=iphoneos*]" = "iPhone Developer";
-				GCC_C_LANGUAGE_STANDARD = c99;
-				GCC_WARN_ABOUT_RETURN_TYPE = YES;
-				GCC_WARN_UNUSED_VARIABLE = YES;
-				ONLY_ACTIVE_ARCH = YES;
-				PREBINDING = NO;
-				SDKROOT = iphoneos2.2.1;
-			};
-			name = Debug;
-		};
-		C01FCF5008A954540054247B /* Release */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_BIT)";
-				"CODE_SIGN_IDENTITY[sdk=iphoneos*]" = "iPhone Developer";
-				GCC_C_LANGUAGE_STANDARD = c99;
-				GCC_WARN_ABOUT_RETURN_TYPE = YES;
-				GCC_WARN_UNUSED_VARIABLE = YES;
-				PREBINDING = NO;
-				SDKROOT = iphoneos2.2.1;
-			};
-			name = Release;
-		};
-/* End XCBuildConfiguration section */
-
-/* Begin XCConfigurationList section */
-		1D6058960D05DD3E006BFB54 /* Build configuration list for PBXNativeTarget "iPhoneNetSlave" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				1D6058940D05DD3E006BFB54 /* Debug */,
-				1D6058950D05DD3E006BFB54 /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4B0772350F54018C000DC657 /* Build configuration list for PBXNativeTarget "iPhoneNetMaster" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B0772360F54018C000DC657 /* Debug */,
-				4B0772370F54018C000DC657 /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4B1A94130F49BDFF00D3626B /* Build configuration list for PBXNativeTarget "libjacknet" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B1A94110F49BDE100D3626B /* Debug */,
-				4B1A94120F49BDE100D3626B /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4B4146AD10BD3C4300C12F0C /* Build configuration list for PBXNativeTarget "iPhoneFaustNet Distribution" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B4146AE10BD3C4300C12F0C /* Debug */,
-				4B4146AF10BD3C4300C12F0C /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4BCB37CB112D647C008C7BC1 /* Build configuration list for PBXNativeTarget "iPhoneFaust" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BCB37CC112D647C008C7BC1 /* Debug */,
-				4BCB37CD112D647C008C7BC1 /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4BCF75EF10BC2FD90082C526 /* Build configuration list for PBXNativeTarget "iPhoneThruNet" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BCF75F010BC2FD90082C526 /* Debug */,
-				4BCF75F110BC2FD90082C526 /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4BDFCD54113DB6B700D77992 /* Build configuration list for PBXNativeTarget "iPhoneNetSlaveLib" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BDFCD55113DB6B700D77992 /* Debug */,
-				4BDFCD56113DB6B700D77992 /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		4BFF45740F4D5D9700106083 /* Build configuration list for PBXNativeTarget "iPhoneFaustNet" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFF45750F4D5D9700106083 /* Debug */,
-				4BFF45760F4D5D9700106083 /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-		C01FCF4E08A954540054247B /* Build configuration list for PBXProject "iPhoneNet" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				C01FCF4F08A954540054247B /* Debug */,
-				C01FCF5008A954540054247B /* Release */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Release;
-		};
-/* End XCConfigurationList section */
-	};
-	rootObject = 29B97313FDCFA39411CA2CEA /* Project object */;
-}
diff -pruN 1.9.14~dfsg-1/macosx/iphone/main_master.mm 1.9.16~dfsg-1/macosx/iphone/main_master.mm
--- 1.9.14~dfsg-1/macosx/iphone/main_master.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/main_master.mm	1970-01-01 00:00:00.000000000 +0000
@@ -1,155 +0,0 @@
-//
-//  main.m
-//  iPhoneNet
-//
-//  Created by Stéphane  LETZ on 16/02/09.
-//  Copyright Grame 2009. All rights reserved.
-//
-
-#import <UIKit/UIKit.h>
-#include <jack/net.h>
-
-#include "TiPhoneCoreAudioRenderer.h"
-
-#define NUM_INPUT 2
-#define NUM_OUTPUT 2
-
-jack_net_master_t* net;
-jack_adapter_t* adapter;
-
-float** audio_input_buffer = NULL;
-float** audio_output_buffer = NULL;
-
-int buffer_size = 1024;
-int sample_rate = 22050;
-//int sample_rate = 32000;
-
-jack_master_t request = { -1, -1, -1, -1, buffer_size, sample_rate, "master" };
-jack_slave_t result;
-
-static void MixAudio(float** dst, float** src1, float** src2, int channels, int buffer_size)
-{
-    for (int chan = 0; chan < channels; chan++) {
-        for (int frame = 0; frame < buffer_size; frame++) {
-            dst[chan][frame] = src1[chan][frame] + src2[chan][frame];
-        }
-    }
-}
-
-static void MasterAudioCallback(int frames, float** inputs, float** outputs, void* arg)
-{
-    int i;
-
-    // Copy from iPod input to network buffers
-    for (i = 0; i < result.audio_input; i++) {
-        memcpy(audio_input_buffer[i], inputs[i], buffer_size * sizeof(float));
-    }
-
-    /*
-    // Copy from network out buffers to network in buffers (audio thru)
-    for (i = 0; i < result.audio_input; i++) {
-        memcpy(audio_input_buffer[i], audio_output_buffer[i], buffer_size * sizeof(float));
-    }
-    */
-
-    // Mix iPod input and network in buffers to network out buffers
-    //MixAudio(audio_input_buffer, inputs, audio_output_buffer, result.audio_input, buffer_size);
-
-    // Send network buffers
-    if (jack_net_master_send(net, result.audio_input, audio_input_buffer, 0, NULL) < 0) {
-        printf("jack_net_master_send error..\n");
-    }
-
-    // Recv network buffers
-    if (jack_net_master_recv(net, result.audio_output, audio_output_buffer, 0, NULL) < 0) {
-        printf("jack_net_master_recv error..\n");
-    }
-
-    // Copy from network buffers to iPod output
-    for (i = 0; i < result.audio_output; i++) {
-        memcpy(outputs[i], audio_output_buffer[i], buffer_size * sizeof(float));
-    }
-}
-
-int main(int argc, char *argv[]) {
-
-    NSAutoreleasePool * pool = [[NSAutoreleasePool alloc] init];
-    int i;
-
-    if ((net = jack_net_master_open(DEFAULT_MULTICAST_IP, DEFAULT_PORT, "iPhone", &request, &result))  == 0) {
-        printf("jack_net_master_open error..\n");
-        return -1;
-    }
-
-    TiPhoneCoreAudioRenderer audio_device(result.audio_input, result.audio_output);
-
-    // Allocate buffers
-    if (result.audio_input > 0) {
-        audio_input_buffer = (float**)calloc(result.audio_input, sizeof(float*));
-        for (i = 0; i < result.audio_input; i++) {
-            audio_input_buffer[i] = (float*)(calloc(buffer_size, sizeof(float)));
-        }
-    }
-
-    if (result.audio_output > 0) {
-        audio_output_buffer = (float**)calloc(result.audio_output, sizeof(float*));
-        for (i = 0; i < result.audio_output; i++) {
-            audio_output_buffer[i] = (float*)(calloc(buffer_size, sizeof(float)));
-        }
-    }
-
-    if (audio_device.Open(buffer_size, sample_rate) < 0) {
-        return -1;
-    }
-
-    audio_device.SetAudioCallback(MasterAudioCallback, NULL);
-
-    if (audio_device.Start() < 0) {
-        return -1;
-    }
-
-    /*
-    // Quite brutal way, the application actually does not start completely, the netjack audio processing loop is used instead...
-    // Run until interrupted
-
-    int wait_usec = (unsigned long)((((float)buffer_size) / ((float)sample_rate)) * 1000000.0f);
-
-  	while (1) {
-
-        // Copy input to output
-        for (i = 0; i < result.audio_input; i++) {
-            memcpy(audio_output_buffer[i], audio_input_buffer[i], buffer_size * sizeof(float));
-        }
-
-        if (jack_net_master_send(net, result.audio_output, audio_output_buffer, 0, NULL) < 0) {
-            printf("jack_net_master_send error..\n");
-        }
-
-        if (jack_net_master_recv(net, result.audio_input, audio_input_buffer, 0, NULL) < 0) {
-            printf("jack_net_master_recv error..\n");
-        }
-        usleep(wait_usec);
-	};
-    */
-
-    int retVal = UIApplicationMain(argc, argv, nil, nil);
-
-    audio_device.Stop();
-    audio_device.Close();
-
-    // Wait for application end
-    jack_net_master_close(net);
-
-    for (i = 0; i < result.audio_input; i++) {
-        free(audio_input_buffer[i]);
-    }
-    free(audio_input_buffer);
-
-    for (i = 0; i < result.audio_output; i++) {
-        free(audio_output_buffer[i]);
-    }
-    free(audio_output_buffer);
-
-    [pool release];
-    return retVal;
-}
diff -pruN 1.9.14~dfsg-1/macosx/iphone/main_slave.mm 1.9.16~dfsg-1/macosx/iphone/main_slave.mm
--- 1.9.14~dfsg-1/macosx/iphone/main_slave.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/main_slave.mm	1970-01-01 00:00:00.000000000 +0000
@@ -1,114 +0,0 @@
-//
-//  main.m
-//  iPhoneNet
-//
-//  Created by Stéphane  LETZ on 16/02/09.
-//  Copyright Grame 2009. All rights reserved.
-//
-
-#import <UIKit/UIKit.h>
-#include <jack/net.h>
-
-#include "TiPhoneCoreAudioRenderer.h"
-
-#define NUM_INPUT 0
-#define NUM_OUTPUT 2
-
-jack_net_slave_t* net = NULL;
-jack_adapter_t* adapter = NULL;
-
-int buffer_size;
-int sample_rate;
-
-static int net_process(jack_nframes_t buffer_size,
-                        int audio_input,
-                        float** audio_input_buffer,
-                        int midi_input,
-                        void** midi_input_buffer,
-                        int audio_output,
-                        float** audio_output_buffer,
-                        int midi_output,
-                        void** midi_output_buffer,
-                        void* data)
-{
-    jack_adapter_pull_and_push(adapter, audio_output_buffer, audio_input_buffer, buffer_size);
-
-    // Process input, produce output
-    if (audio_input == audio_output) {
-        // Copy net input to net output
-        for (int i = 0; i < audio_input; i++) {
-            memcpy(audio_output_buffer[i], audio_input_buffer[i], buffer_size * sizeof(float));
-        }
-    }
-    return 0;
-}
-
-static void net_shutdown(void *arg)
-{
-    if (adapter)
-        jack_flush_adapter(adapter);
-}
-
-static void SlaveAudioCallback(int frames, float** inputs, float** outputs, void* arg)
-{
-    jack_adapter_push_and_pull(adapter, inputs, outputs, frames);
-}
-
-//http://www.securityfocus.com/infocus/1884
-
-#define WIFI_MTU 1500
-
-int main(int argc, char *argv[]) {
-
-    NSAutoreleasePool* pool = [[NSAutoreleasePool alloc] init];
-
-    jack_slave_t request = { NUM_OUTPUT, NUM_INPUT, 0, 0, WIFI_MTU, -1, JackCeltEncoder, 128, 2 };
-    jack_master_t result;
-
-    //if ((net = jack_net_slave_open("169.254.112.119", DEFAULT_PORT, "iPhone", &request, &result))  == 0) {
-    if ((net = jack_net_slave_open(DEFAULT_MULTICAST_IP, DEFAULT_PORT, "iPod", &request, &result))  == 0) {
-        printf("jack_net_slave_open error...\n");
-        return -1;
-    }
-
-    if ((adapter = jack_create_adapter(NUM_INPUT,
-                                    NUM_OUTPUT,
-                                    result.buffer_size,
-                                    result.sample_rate,
-                                    result.buffer_size,
-                                    result.sample_rate)) == 0) {
-        return -1;
-    }
-
-    TiPhoneCoreAudioRenderer audio_device(NUM_INPUT, NUM_OUTPUT);
-
-    jack_set_net_slave_process_callback(net, net_process, NULL);
-    jack_set_net_slave_shutdown_callback(net, net_shutdown, NULL);
-
-    if (jack_net_slave_activate(net) != 0) {
-        printf("Cannot activate slave client\n");
-        return -1;
-    }
-
-    if (audio_device.Open(result.buffer_size, result.sample_rate) < 0) {
-        return -1;
-    }
-
-    audio_device.SetAudioCallback(SlaveAudioCallback, NULL);
-
-    if (audio_device.Start() < 0) {
-        return -1;
-    }
-
-    int retVal = UIApplicationMain(argc, argv, nil, nil);
-    [pool release];
-
-    audio_device.Stop();
-    audio_device.Close();
-
-    // Wait for application end
-    jack_net_slave_deactivate(net);
-    jack_net_slave_close(net);
-    jack_destroy_adapter(adapter);
-    return retVal;
-}
diff -pruN 1.9.14~dfsg-1/macosx/iphone/MainWindow.xib 1.9.16~dfsg-1/macosx/iphone/MainWindow.xib
--- 1.9.14~dfsg-1/macosx/iphone/MainWindow.xib	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/iphone/MainWindow.xib	1970-01-01 00:00:00.000000000 +0000
@@ -1,440 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<archive type="com.apple.InterfaceBuilder3.CocoaTouch.XIB" version="7.10">
-	<data>
-		<int key="IBDocument.SystemTarget">528</int>
-		<string key="IBDocument.SystemVersion">10C540</string>
-		<string key="IBDocument.InterfaceBuilderVersion">740</string>
-		<string key="IBDocument.AppKitVersion">1038.25</string>
-		<string key="IBDocument.HIToolboxVersion">458.00</string>
-		<object class="NSMutableDictionary" key="IBDocument.PluginVersions">
-			<string key="NS.key.0">com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
-			<string key="NS.object.0">62</string>
-		</object>
-		<object class="NSMutableArray" key="IBDocument.EditedObjectIDs">
-			<bool key="EncodedWithXMLCoder">YES</bool>
-			<integer value="2"/>
-		</object>
-		<object class="NSArray" key="IBDocument.PluginDependencies">
-			<bool key="EncodedWithXMLCoder">YES</bool>
-			<string>com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
-		</object>
-		<object class="NSMutableDictionary" key="IBDocument.Metadata">
-			<bool key="EncodedWithXMLCoder">YES</bool>
-			<object class="NSArray" key="dict.sortedKeys" id="0">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-			</object>
-			<object class="NSMutableArray" key="dict.values">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-			</object>
-		</object>
-		<object class="NSMutableArray" key="IBDocument.RootObjects" id="1000">
-			<bool key="EncodedWithXMLCoder">YES</bool>
-			<object class="IBProxyObject" id="841351856">
-				<string key="IBProxiedObjectIdentifier">IBFilesOwner</string>
-			</object>
-			<object class="IBProxyObject" id="427554174">
-				<string key="IBProxiedObjectIdentifier">IBFirstResponder</string>
-			</object>
-			<object class="IBUICustomObject" id="664661524"/>
-			<object class="IBUIWindow" id="380026005">
-				<reference key="NSNextResponder"/>
-				<int key="NSvFlags">1316</int>
-				<object class="NSMutableArray" key="NSSubviews">
-					<bool key="EncodedWithXMLCoder">YES</bool>
-					<object class="IBUILabel" id="622412730">
-						<reference key="NSNextResponder" ref="380026005"/>
-						<int key="NSvFlags">1316</int>
-						<string key="NSFrame">{{25, 40}, {267, 21}}</string>
-						<reference key="NSSuperview" ref="380026005"/>
-						<bool key="IBUIOpaque">NO</bool>
-						<bool key="IBUIClipsSubviews">YES</bool>
-						<bool key="IBUIUserInteractionEnabled">NO</bool>
-						<string key="IBUIText">NetJack : client on JACK server </string>
-						<object class="NSFont" key="IBUIFont">
-							<string key="NSName">Helvetica-Bold</string>
-							<double key="NSSize">17</double>
-							<int key="NSfFlags">16</int>
-						</object>
-						<object class="NSColor" key="IBUITextColor">
-							<int key="NSColorSpace">1</int>
-							<bytes key="NSRGB">MCAwIDAAA</bytes>
-						</object>
-						<nil key="IBUIHighlightedColor"/>
-						<int key="IBUIBaselineAdjustment">1</int>
-						<float key="IBUIMinimumFontSize">10</float>
-					</object>
-				</object>
-				<object class="NSPSMatrix" key="NSFrameMatrix"/>
-				<string key="NSFrameSize">{320, 480}</string>
-				<reference key="NSSuperview"/>
-				<object class="NSColor" key="IBUIBackgroundColor">
-					<int key="NSColorSpace">1</int>
-					<bytes key="NSRGB">MSAxIDEAA</bytes>
-				</object>
-				<bool key="IBUIOpaque">NO</bool>
-				<bool key="IBUIClearsContextBeforeDrawing">NO</bool>
-				<object class="IBUISimulatedStatusBarMetrics" key="IBUISimulatedStatusBarMetrics"/>
-			</object>
-		</object>
-		<object class="IBObjectContainer" key="IBDocument.Objects">
-			<object class="NSMutableArray" key="connectionRecords">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-				<object class="IBConnectionRecord">
-					<object class="IBCocoaTouchOutletConnection" key="connection">
-						<string key="label">delegate</string>
-						<reference key="source" ref="841351856"/>
-						<reference key="destination" ref="664661524"/>
-					</object>
-					<int key="connectionID">4</int>
-				</object>
-				<object class="IBConnectionRecord">
-					<object class="IBCocoaTouchOutletConnection" key="connection">
-						<string key="label">window</string>
-						<reference key="source" ref="664661524"/>
-						<reference key="destination" ref="380026005"/>
-					</object>
-					<int key="connectionID">5</int>
-				</object>
-			</object>
-			<object class="IBMutableOrderedSet" key="objectRecords">
-				<object class="NSArray" key="orderedObjects">
-					<bool key="EncodedWithXMLCoder">YES</bool>
-					<object class="IBObjectRecord">
-						<int key="objectID">0</int>
-						<reference key="object" ref="0"/>
-						<reference key="children" ref="1000"/>
-						<nil key="parent"/>
-					</object>
-					<object class="IBObjectRecord">
-						<int key="objectID">2</int>
-						<reference key="object" ref="380026005"/>
-						<object class="NSMutableArray" key="children">
-							<bool key="EncodedWithXMLCoder">YES</bool>
-							<reference ref="622412730"/>
-						</object>
-						<reference key="parent" ref="0"/>
-					</object>
-					<object class="IBObjectRecord">
-						<int key="objectID">-1</int>
-						<reference key="object" ref="841351856"/>
-						<reference key="parent" ref="0"/>
-						<string key="objectName">File's Owner</string>
-					</object>
-					<object class="IBObjectRecord">
-						<int key="objectID">3</int>
-						<reference key="object" ref="664661524"/>
-						<reference key="parent" ref="0"/>
-					</object>
-					<object class="IBObjectRecord">
-						<int key="objectID">-2</int>
-						<reference key="object" ref="427554174"/>
-						<reference key="parent" ref="0"/>
-					</object>
-					<object class="IBObjectRecord">
-						<int key="objectID">10</int>
-						<reference key="object" ref="622412730"/>
-						<reference key="parent" ref="380026005"/>
-					</object>
-				</object>
-			</object>
-			<object class="NSMutableDictionary" key="flattenedProperties">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-				<object class="NSArray" key="dict.sortedKeys">
-					<bool key="EncodedWithXMLCoder">YES</bool>
-					<string>-1.CustomClassName</string>
-					<string>-2.CustomClassName</string>
-					<string>10.IBPluginDependency</string>
-					<string>2.IBAttributePlaceholdersKey</string>
-					<string>2.IBEditorWindowLastContentRect</string>
-					<string>2.IBPluginDependency</string>
-					<string>2.IBUserGuides</string>
-					<string>3.CustomClassName</string>
-					<string>3.IBPluginDependency</string>
-				</object>
-				<object class="NSMutableArray" key="dict.values">
-					<bool key="EncodedWithXMLCoder">YES</bool>
-					<string>UIApplication</string>
-					<string>UIResponder</string>
-					<string>com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
-					<object class="NSMutableDictionary">
-						<bool key="EncodedWithXMLCoder">YES</bool>
-						<reference key="dict.sortedKeys" ref="0"/>
-						<object class="NSMutableArray" key="dict.values">
-							<bool key="EncodedWithXMLCoder">YES</bool>
-						</object>
-					</object>
-					<string>{{366, 320}, {320, 480}}</string>
-					<string>com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
-					<object class="NSMutableArray">
-						<bool key="EncodedWithXMLCoder">YES</bool>
-						<object class="IBUserGuide">
-							<reference key="view" ref="380026005"/>
-							<double key="location">153.5</double>
-							<int key="affinity">0</int>
-						</object>
-					</object>
-					<string>iPhoneNetAppDelegate</string>
-					<string>com.apple.InterfaceBuilder.IBCocoaTouchPlugin</string>
-				</object>
-			</object>
-			<object class="NSMutableDictionary" key="unlocalizedProperties">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-				<reference key="dict.sortedKeys" ref="0"/>
-				<object class="NSMutableArray" key="dict.values">
-					<bool key="EncodedWithXMLCoder">YES</bool>
-				</object>
-			</object>
-			<nil key="activeLocalization"/>
-			<object class="NSMutableDictionary" key="localizations">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-				<reference key="dict.sortedKeys" ref="0"/>
-				<object class="NSMutableArray" key="dict.values">
-					<bool key="EncodedWithXMLCoder">YES</bool>
-				</object>
-			</object>
-			<nil key="sourceID"/>
-			<int key="maxID">11</int>
-		</object>
-		<object class="IBClassDescriber" key="IBDocument.Classes">
-			<object class="NSMutableArray" key="referencedPartialClassDescriptions">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-				<object class="IBPartialClassDescription">
-					<string key="className">iPhoneNetAppDelegate</string>
-					<string key="superclassName">NSObject</string>
-					<object class="NSMutableDictionary" key="outlets">
-						<bool key="EncodedWithXMLCoder">YES</bool>
-						<object class="NSArray" key="dict.sortedKeys">
-							<bool key="EncodedWithXMLCoder">YES</bool>
-							<string>navigationController</string>
-							<string>window</string>
-						</object>
-						<object class="NSMutableArray" key="dict.values">
-							<bool key="EncodedWithXMLCoder">YES</bool>
-							<string>UINavigationController</string>
-							<string>UIWindow</string>
-						</object>
-					</object>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBProjectSource</string>
-						<string key="minorKey">iPhoneNetAppDelegate.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">iPhoneNetAppDelegate</string>
-					<string key="superclassName">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBUserSource</string>
-						<string key="minorKey"/>
-					</object>
-				</object>
-			</object>
-			<object class="NSMutableArray" key="referencedPartialClassDescriptionsV3.2+">
-				<bool key="EncodedWithXMLCoder">YES</bool>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSError.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSFileManager.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSKeyValueCoding.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSKeyValueObserving.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSKeyedArchiver.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSNetServices.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSObject.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSPort.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSRunLoop.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSStream.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSThread.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSURL.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSURLConnection.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">Foundation.framework/Headers/NSXMLParser.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UINibLoading.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIApplication</string>
-					<string key="superclassName">UIResponder</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UIApplication.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UILabel</string>
-					<string key="superclassName">UIView</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UILabel.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UINavigationController</string>
-					<string key="superclassName">UIViewController</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier" id="325457853">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UINavigationController.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIResponder</string>
-					<string key="superclassName">NSObject</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UIResponder.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UISearchBar</string>
-					<string key="superclassName">UIView</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UISearchBar.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIView</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UITextField.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIView</string>
-					<string key="superclassName">UIResponder</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UIView.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIViewController</string>
-					<reference key="sourceIdentifier" ref="325457853"/>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIViewController</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UITabBarController.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIViewController</string>
-					<string key="superclassName">UIResponder</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UIViewController.h</string>
-					</object>
-				</object>
-				<object class="IBPartialClassDescription">
-					<string key="className">UIWindow</string>
-					<string key="superclassName">UIView</string>
-					<object class="IBClassDescriptionSource" key="sourceIdentifier">
-						<string key="majorKey">IBFrameworkSource</string>
-						<string key="minorKey">UIKit.framework/Headers/UIWindow.h</string>
-					</object>
-				</object>
-			</object>
-		</object>
-		<int key="IBDocument.localizationMode">0</int>
-		<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDependencies">
-			<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaTouchPlugin.iPhoneOS</string>
-			<integer value="528" key="NS.object.0"/>
-		</object>
-		<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDependencyDefaults">
-			<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaTouchPlugin.iPhoneOS</string>
-			<integer value="544" key="NS.object.0"/>
-		</object>
-		<object class="NSMutableDictionary" key="IBDocument.PluginDeclaredDevelopmentDependencies">
-			<string key="NS.key.0">com.apple.InterfaceBuilder.CocoaTouchPlugin.InterfaceBuilder3</string>
-			<integer value="3000" key="NS.object.0"/>
-		</object>
-		<bool key="IBDocument.PluginDeclaredDependenciesTrackSystemTargetVersion">YES</bool>
-		<string key="IBDocument.LastKnownRelativeProjectPath">iPhoneNet.xcodeproj</string>
-		<int key="IBDocument.defaultPropertyAccessControl">3</int>
-		<string key="IBCocoaTouchPluginVersion">3.1</string>
-	</data>
-</archive>
diff -pruN 1.9.14~dfsg-1/macosx/Jackdmp.xcodeproj/project.pbxproj 1.9.16~dfsg-1/macosx/Jackdmp.xcodeproj/project.pbxproj
--- 1.9.14~dfsg-1/macosx/Jackdmp.xcodeproj/project.pbxproj	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/Jackdmp.xcodeproj/project.pbxproj	1970-01-01 00:00:00.000000000 +0000
@@ -1,20555 +0,0 @@
-// !$*UTF8*$!
-{
-	archiveVersion = 1;
-	classes = {
-	};
-	objectVersion = 42;
-	objects = {
-
-/* Begin PBXAggregateTarget section */
-		4B35C6420D47339B000DE7AE /* All Universal 32/64 bits */ = {
-			isa = PBXAggregateTarget;
-			buildConfigurationList = 4B35C6790D47339B000DE7AE /* Build configuration list for PBXAggregateTarget "All Universal 32/64 bits" */;
-			buildPhases = (
-			);
-			dependencies = (
-				4B35C6800D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6820D4733B9000DE7AE /* PBXTargetDependency */,
-				4BB492A71372A393005F2601 /* PBXTargetDependency */,
-				4B35C67E0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6AC0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6B00D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6B20D4733B9000DE7AE /* PBXTargetDependency */,
-				4BDCDC2C1002036100B15929 /* PBXTargetDependency */,
-				4BDCDC2E1002036100B15929 /* PBXTargetDependency */,
-				4B32259110A31ABA00838A8E /* PBXTargetDependency */,
-				4B43A8E91014618D00E52943 /* PBXTargetDependency */,
-				4BDCDC301002036100B15929 /* PBXTargetDependency */,
-				4BDCDC39100203D500B15929 /* PBXTargetDependency */,
-				4BDCDC3B100203D500B15929 /* PBXTargetDependency */,
-				4B35C6860D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6880D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C68A0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C68C0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C68E0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6900D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6920D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6940D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6960D4733B9000DE7AE /* PBXTargetDependency */,
-				4B0A29300D5210C4002EFF74 /* PBXTargetDependency */,
-				4B35C69C0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C69E0D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6A00D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6A20D4733B9000DE7AE /* PBXTargetDependency */,
-				4B35C6A40D4733B9000DE7AE /* PBXTargetDependency */,
-				4BFA83320DF6AB540087B4E1 /* PBXTargetDependency */,
-				4BFA83340DF6AB540087B4E1 /* PBXTargetDependency */,
-				4BFA83380DF6AB540087B4E1 /* PBXTargetDependency */,
-				4BFA833A0DF6AB540087B4E1 /* PBXTargetDependency */,
-				4BFA833C0DF6AB540087B4E1 /* PBXTargetDependency */,
-				4B32258F10A31AB400838A8E /* PBXTargetDependency */,
-				4B66550E127C356E00753A79 /* PBXTargetDependency */,
-				4B38120313269CCB00C61B14 /* PBXTargetDependency */,
-				4B8F16FC1329169F0002AD73 /* PBXTargetDependency */,
-				4B20220C133A9C370019E213 /* PBXTargetDependency */,
-			);
-			name = "All Universal 32/64 bits";
-			productName = All;
-		};
-		4B699B26097D421600A18468 /* All Universal 32 bits */ = {
-			isa = PBXAggregateTarget;
-			buildConfigurationList = 4B699B33097D421600A18468 /* Build configuration list for PBXAggregateTarget "All Universal 32 bits" */;
-			buildPhases = (
-			);
-			dependencies = (
-				4B699DB4097D421700A18468 /* PBXTargetDependency */,
-				4B699DB6097D421700A18468 /* PBXTargetDependency */,
-				4B699DB8097D421700A18468 /* PBXTargetDependency */,
-				4B699DBA097D421700A18468 /* PBXTargetDependency */,
-				4BF339280F8B87800080FB5B /* PBXTargetDependency */,
-				4B699DBC097D421700A18468 /* PBXTargetDependency */,
-				BA222AF20DC883F3001A17F4 /* PBXTargetDependency */,
-				4B32258D10A31A9D00838A8E /* PBXTargetDependency */,
-				4B43A8CD1014607100E52943 /* PBXTargetDependency */,
-				4BD624D30CBCF55700DE782F /* PBXTargetDependency */,
-				BA222AF00DC883EF001A17F4 /* PBXTargetDependency */,
-				4B19B32C0E23636E00DD4A82 /* PBXTargetDependency */,
-				4B224B340E65BA330066BE5B /* PBXTargetDependency */,
-				4B5A1BE20CD1CD730005BF74 /* PBXTargetDependency */,
-				4B5A1BCF0CD1CCC80005BF74 /* PBXTargetDependency */,
-				4BFA99440AAAED90009E916C /* PBXTargetDependency */,
-				4BFA99460AAAED90009E916C /* PBXTargetDependency */,
-				4BA7FECD0D8E76810017FF73 /* PBXTargetDependency */,
-				4BFA99480AAAED90009E916C /* PBXTargetDependency */,
-				4BFA994A0AAAED90009E916C /* PBXTargetDependency */,
-				4BFA994C0AAAED90009E916C /* PBXTargetDependency */,
-				4BFA994E0AAAED90009E916C /* PBXTargetDependency */,
-				4BFA99560AAAED90009E916C /* PBXTargetDependency */,
-				4BE99D630AD7A19100C59091 /* PBXTargetDependency */,
-				4BA693E90CBE5BBA00EAD520 /* PBXTargetDependency */,
-				4BA693EB0CBE5BBA00EAD520 /* PBXTargetDependency */,
-				4B0A28F40D520D11002EFF74 /* PBXTargetDependency */,
-				4B363DE50DEB037F001F72D9 /* PBXTargetDependency */,
-				4BFA99AC0AAAF41D009E916C /* PBXTargetDependency */,
-				4BFA99540AAAED90009E916C /* PBXTargetDependency */,
-				4B363E750DEB0838001F72D9 /* PBXTargetDependency */,
-				4B363E770DEB0838001F72D9 /* PBXTargetDependency */,
-				4B363F250DEB0ABE001F72D9 /* PBXTargetDependency */,
-				4B363F530DEB0CFE001F72D9 /* PBXTargetDependency */,
-				4B363F780DEB0D85001F72D9 /* PBXTargetDependency */,
-				4B32258B10A31A9000838A8E /* PBXTargetDependency */,
-				4B38120113269CB600C61B14 /* PBXTargetDependency */,
-				4B8F16FA132916910002AD73 /* PBXTargetDependency */,
-			);
-			name = "All Universal 32 bits";
-			productName = All;
-		};
-/* End PBXAggregateTarget section */
-
-/* Begin PBXBuildFile section */
-		4B0A28ED0D520852002EFF74 /* tw.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B0A28EC0D520852002EFF74 /* tw.c */; };
-		4B0A29260D52108E002EFF74 /* tw.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B0A28EC0D520852002EFF74 /* tw.c */; };
-		4B1499F014BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */; };
-		4B1499F114BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */; };
-		4B1499F214BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */; };
-		4B1499F314BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */; };
-		4B1499F414BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */; };
-		4B1499F514BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */; };
-		4B1499F614BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */; };
-		4B1499F714BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */; };
-		4B1499F814BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */; };
-		4B1499F914BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */; };
-		4B1499FA14BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */; };
-		4B1499FB14BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */; };
-		4B193991133F321500547810 /* JackFilters.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193990133F321500547810 /* JackFilters.h */; };
-		4B193992133F321500547810 /* JackFilters.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193990133F321500547810 /* JackFilters.h */; };
-		4B193993133F321500547810 /* JackFilters.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193990133F321500547810 /* JackFilters.h */; };
-		4B193994133F321500547810 /* JackFilters.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193990133F321500547810 /* JackFilters.h */; };
-		4B193995133F321500547810 /* JackFilters.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193990133F321500547810 /* JackFilters.h */; };
-		4B193996133F321500547810 /* JackFilters.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193990133F321500547810 /* JackFilters.h */; };
-		4B19B3130E2362E800DD4A82 /* JackAudioAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3060E2362E700DD4A82 /* JackAudioAdapter.cpp */; };
-		4B19B3140E2362E800DD4A82 /* JackAudioAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3070E2362E700DD4A82 /* JackAudioAdapter.h */; };
-		4B19B3150E2362E800DD4A82 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */; };
-		4B19B3160E2362E800DD4A82 /* JackAudioAdapterInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */; };
-		4B19B31B0E2362E800DD4A82 /* JackLibSampleRateResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */; };
-		4B19B31C0E2362E800DD4A82 /* JackLibSampleRateResampler.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */; };
-		4B19B31F0E2362E800DD4A82 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3120E2362E700DD4A82 /* JackResampler.cpp */; };
-		4B20220A133A9C1C0019E213 /* midi_latency_test.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B202209133A9C1C0019E213 /* midi_latency_test.c */; };
-		4B21794F13E2EEA60095B3E5 /* JackTimedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B21794D13E2EEA60095B3E5 /* JackTimedDriver.cpp */; };
-		4B21795013E2EEA60095B3E5 /* JackTimedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B21794E13E2EEA60095B3E5 /* JackTimedDriver.h */; };
-		4B21795113E2EEA60095B3E5 /* JackTimedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B21794D13E2EEA60095B3E5 /* JackTimedDriver.cpp */; };
-		4B21795213E2EEA60095B3E5 /* JackTimedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B21794E13E2EEA60095B3E5 /* JackTimedDriver.h */; };
-		4B21795313E2EEA60095B3E5 /* JackTimedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B21794D13E2EEA60095B3E5 /* JackTimedDriver.cpp */; };
-		4B21795413E2EEA60095B3E5 /* JackTimedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B21794E13E2EEA60095B3E5 /* JackTimedDriver.h */; };
-		4B2209E112F6BBF300E5DC26 /* JackSocketServerChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B30E703B8D0066E42F /* JackSocketServerChannel.cpp */; };
-		4B2209E212F6BBF400E5DC26 /* JackSocketServerChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B40E703B8D0066E42F /* JackSocketServerChannel.h */; };
-		4B2209E312F6BBF500E5DC26 /* JackSocketServerNotifyChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B50E703B8D0066E42F /* JackSocketServerNotifyChannel.cpp */; };
-		4B2209E412F6BBF600E5DC26 /* JackSocketServerNotifyChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B60E703B8D0066E42F /* JackSocketServerNotifyChannel.h */; };
-		4B2209E612F6BC0200E5DC26 /* JackSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */; };
-		4B2209E712F6BC0300E5DC26 /* JackSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6AE0E703B8D0066E42F /* JackSocket.h */; };
-		4B2209E912F6BC1500E5DC26 /* JackSocketNotifyChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B10E703B8D0066E42F /* JackSocketNotifyChannel.cpp */; };
-		4B2209EA12F6BC1600E5DC26 /* JackSocketNotifyChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B20E703B8D0066E42F /* JackSocketNotifyChannel.h */; };
-		4B2209EC12F6BC2100E5DC26 /* JackSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */; };
-		4B2209ED12F6BC2200E5DC26 /* JackSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6AE0E703B8D0066E42F /* JackSocket.h */; };
-		4B2209EE12F6BC2300E5DC26 /* JackSocketClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AF0E703B8D0066E42F /* JackSocketClientChannel.cpp */; };
-		4B2209EF12F6BC2500E5DC26 /* JackSocketClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B00E703B8D0066E42F /* JackSocketClientChannel.h */; };
-		4B3224EA10A315B100838A8E /* JackNetOneDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224E810A315B100838A8E /* JackNetOneDriver.cpp */; };
-		4B3224EB10A315B100838A8E /* JackNetOneDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224E910A315B100838A8E /* JackNetOneDriver.h */; };
-		4B3224F010A315C400838A8E /* netjack_packet.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224EC10A315C400838A8E /* netjack_packet.c */; };
-		4B3224F110A315C400838A8E /* netjack_packet.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224ED10A315C400838A8E /* netjack_packet.h */; };
-		4B3224F210A315C400838A8E /* netjack.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224EE10A315C400838A8E /* netjack.c */; };
-		4B3224F310A315C400838A8E /* netjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224EF10A315C400838A8E /* netjack.h */; };
-		4B32253110A3173900838A8E /* JackNetOneDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224E810A315B100838A8E /* JackNetOneDriver.cpp */; };
-		4B32253210A3173A00838A8E /* JackNetOneDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224E910A315B100838A8E /* JackNetOneDriver.h */; };
-		4B32253310A3173B00838A8E /* netjack.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224EE10A315C400838A8E /* netjack.c */; };
-		4B32253410A3173C00838A8E /* netjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224EF10A315C400838A8E /* netjack.h */; };
-		4B32253510A3173D00838A8E /* netjack_packet.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224EC10A315C400838A8E /* netjack_packet.c */; };
-		4B32253610A3173E00838A8E /* netjack_packet.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224ED10A315C400838A8E /* netjack_packet.h */; };
-		4B32256410A318E300838A8E /* netsource.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B32256310A318E300838A8E /* netsource.c */; };
-		4B32256D10A318FC00838A8E /* netjack_packet.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224EC10A315C400838A8E /* netjack_packet.c */; };
-		4B32256E10A318FD00838A8E /* netjack_packet.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224ED10A315C400838A8E /* netjack_packet.h */; };
-		4B32257F10A3195900838A8E /* netjack_packet.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3224EC10A315C400838A8E /* netjack_packet.c */; };
-		4B32258010A3195A00838A8E /* netjack_packet.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B3224ED10A315C400838A8E /* netjack_packet.h */; };
-		4B32258110A3195B00838A8E /* netsource.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B32256310A318E300838A8E /* netsource.c */; };
-		4B327BA714B4B50400976483 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4B327BA814B4B50400976483 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4B327BA914B4B50400976483 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4B327BAA14B4B50400976483 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4B327BAB14B4B50400976483 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4B327BAC14B4B50400976483 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4B327BD614B4B6E700976483 /* JackException.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B67AB8C14B4B03800B4AA9A /* JackException.cpp */; };
-		4B35C41E0D4731D1000DE7AE /* Jackdmp.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2250834F06A00C94B91 /* Jackdmp.cpp */; };
-		4B35C42A0D4731D1000DE7AE /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4B35C42B0D4731D1000DE7AE /* JackTime.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1830834EE5800C94B91 /* JackTime.h */; };
-		4B35C42C0D4731D1000DE7AE /* JackShmMem.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1870834EE7900C94B91 /* JackShmMem.h */; };
-		4B35C42D0D4731D1000DE7AE /* shm.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D18F0834EE8400C94B91 /* shm.h */; };
-		4B35C42F0D4731D1000DE7AE /* JackThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D19F0834EE9E00C94B91 /* JackThread.h */; };
-		4B35C4300D4731D1000DE7AE /* JackActivationCount.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */; };
-		4B35C4310D4731D1000DE7AE /* JackChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1AF0834EEC400C94B91 /* JackChannel.h */; };
-		4B35C4320D4731D1000DE7AE /* JackGraphManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */; };
-		4B35C4330D4731D1000DE7AE /* JackPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1CF0834EF2F00C94B91 /* JackPort.h */; };
-		4B35C4340D4731D1000DE7AE /* JackClientInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */; };
-		4B35C4350D4731D1000DE7AE /* JackClientControl.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */; };
-		4B35C4360D4731D1000DE7AE /* JackClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1E10834EF5500C94B91 /* JackClient.h */; };
-		4B35C4370D4731D1000DE7AE /* JackInternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */; };
-		4B35C4380D4731D1000DE7AE /* JackLibGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1FB0834EFD100C94B91 /* JackLibGlobals.h */; };
-		4B35C4390D4731D1000DE7AE /* JackLibClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1FC0834EFD100C94B91 /* JackLibClient.h */; };
-		4B35C43A0D4731D1000DE7AE /* JackConnectionManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */; };
-		4B35C43B0D4731D1000DE7AE /* JackFrameTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */; };
-		4B35C43D0D4731D1000DE7AE /* JackMachSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */; };
-		4B35C43E0D4731D1000DE7AE /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4B35C43F0D4731D1000DE7AE /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4B35C4460D4731D1000DE7AE /* JackSynchro.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD561C708EEB910006BBC2A /* JackSynchro.h */; };
-		4B35C4470D4731D1000DE7AE /* JackDebugClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B98AE010931D30C0091932A /* JackDebugClient.h */; };
-		4B35C4480D4731D1000DE7AE /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4B35C4490D4731D1000DE7AE /* JackTransportEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */; };
-		4B35C44A0D4731D1000DE7AE /* timestamps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF520580CB8D1010037470E /* timestamps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C44B0D4731D1000DE7AE /* intclient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C73790CC60A6D001AFFD4 /* intclient.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C44C0D4731D1000DE7AE /* jack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737A0CC60A6D001AFFD4 /* jack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C44D0D4731D1000DE7AE /* ringbuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C44E0D4731D1000DE7AE /* statistics.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737C0CC60A6D001AFFD4 /* statistics.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C44F0D4731D1000DE7AE /* thread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737D0CC60A6D001AFFD4 /* thread.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4500D4731D1000DE7AE /* transport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737E0CC60A6D001AFFD4 /* transport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4510D4731D1000DE7AE /* types.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737F0CC60A6D001AFFD4 /* types.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4520D4731D1000DE7AE /* JackPortType.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAB95B70B9E20B800A0C723 /* JackPortType.h */; };
-		4B35C4530D4731D1000DE7AE /* JackMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B80D7E50BA0D17400F035BB /* JackMidiPort.h */; };
-		4B35C4540D4731D1000DE7AE /* midiport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6B9EF50CD0958B0051EE5A /* midiport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4550D4731D1000DE7AE /* JackTools.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE4CC000CDA153400CCF5BB /* JackTools.h */; };
-		4B35C45B0D4731D1000DE7AE /* JackShmMem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */; };
-		4B35C45C0D4731D1000DE7AE /* shm.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1900834EE8400C94B91 /* shm.c */; };
-		4B35C45E0D4731D1000DE7AE /* JackActivationCount.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */; };
-		4B35C45F0D4731D1000DE7AE /* JackGraphManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */; };
-		4B35C4600D4731D1000DE7AE /* JackPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */; };
-		4B35C4610D4731D1000DE7AE /* JackClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E50834EF6700C94B91 /* JackClient.cpp */; };
-		4B35C4620D4731D1000DE7AE /* JackAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */; };
-		4B35C4630D4731D1000DE7AE /* JackLibClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1FD0834EFD100C94B91 /* JackLibClient.cpp */; };
-		4B35C4640D4731D1000DE7AE /* JackLibAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1FE0834EFD100C94B91 /* JackLibAPI.cpp */; };
-		4B35C4650D4731D1000DE7AE /* JackConnectionManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */; };
-		4B35C4660D4731D1000DE7AE /* JackFrameTimer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */; };
-		4B35C4680D4731D1000DE7AE /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4B35C4690D4731D1000DE7AE /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B35C4700D4731D1000DE7AE /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4B35C4720D4731D1000DE7AE /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4B35C4730D4731D1000DE7AE /* JackDebugClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B98AE000931D30C0091932A /* JackDebugClient.cpp */; };
-		4B35C4740D4731D1000DE7AE /* JackTransportEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */; };
-		4B35C4760D4731D1000DE7AE /* timestamps.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF520520CB8D0E80037470E /* timestamps.c */; };
-		4B35C4770D4731D1000DE7AE /* JackPortType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */; };
-		4B35C4780D4731D1000DE7AE /* JackAudioPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */; };
-		4B35C4790D4731D1000DE7AE /* JackMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */; };
-		4B35C47A0D4731D1000DE7AE /* JackMidiAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */; };
-		4B35C47B0D4731D1000DE7AE /* JackEngineControl.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */; };
-		4B35C47C0D4731D1000DE7AE /* JackTools.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */; };
-		4B35C4880D4731D1000DE7AE /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4B35C4890D4731D1000DE7AE /* JackTime.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1830834EE5800C94B91 /* JackTime.h */; };
-		4B35C48A0D4731D1000DE7AE /* JackShmMem.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1870834EE7900C94B91 /* JackShmMem.h */; };
-		4B35C48B0D4731D1000DE7AE /* shm.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D18F0834EE8400C94B91 /* shm.h */; };
-		4B35C48D0D4731D1000DE7AE /* JackThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D19F0834EE9E00C94B91 /* JackThread.h */; };
-		4B35C48E0D4731D1000DE7AE /* JackActivationCount.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */; };
-		4B35C48F0D4731D1000DE7AE /* JackChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1AF0834EEC400C94B91 /* JackChannel.h */; };
-		4B35C4900D4731D1000DE7AE /* JackGraphManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */; };
-		4B35C4910D4731D1000DE7AE /* JackPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1CF0834EF2F00C94B91 /* JackPort.h */; };
-		4B35C4920D4731D1000DE7AE /* JackClientInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */; };
-		4B35C4930D4731D1000DE7AE /* JackClientControl.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */; };
-		4B35C4940D4731D1000DE7AE /* JackClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1E10834EF5500C94B91 /* JackClient.h */; };
-		4B35C4950D4731D1000DE7AE /* JackInternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */; };
-		4B35C4960D4731D1000DE7AE /* JackConnectionManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */; };
-		4B35C4970D4731D1000DE7AE /* JackFrameTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */; };
-		4B35C4990D4731D1000DE7AE /* JackMachSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */; };
-		4B35C49A0D4731D1000DE7AE /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4B35C49B0D4731D1000DE7AE /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4B35C4A00D4731D1000DE7AE /* JackSynchro.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD561C708EEB910006BBC2A /* JackSynchro.h */; };
-		4B35C4A10D4731D1000DE7AE /* JackAudioDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2290834F07D00C94B91 /* JackAudioDriver.h */; };
-		4B35C4A20D4731D1000DE7AE /* JackFreewheelDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1B90834EEF100C94B91 /* JackFreewheelDriver.h */; };
-		4B35C4A30D4731D1000DE7AE /* JackThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1BD0834EEFC00C94B91 /* JackThreadedDriver.h */; };
-		4B35C4A40D4731D1000DE7AE /* JackDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1B50834EEE400C94B91 /* JackDriver.h */; };
-		4B35C4A50D4731D1000DE7AE /* driver_interface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B869B3D08C8D21C001CF041 /* driver_interface.h */; };
-		4B35C4A70D4731D1000DE7AE /* JackDriverLoader.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B869B4208C8D22F001CF041 /* JackDriverLoader.h */; };
-		4B35C4A90D4731D1000DE7AE /* JackEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2130834F02800C94B91 /* JackEngine.h */; };
-		4B35C4AA0D4731D1000DE7AE /* JackExternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1F70834EFBD00C94B91 /* JackExternalClient.h */; };
-		4B35C4AB0D4731D1000DE7AE /* JackServer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2220834F05C00C94B91 /* JackServer.h */; };
-		4B35C4B20D4731D1000DE7AE /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4B35C4B30D4731D1000DE7AE /* JackTransportEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */; };
-		4B35C4B40D4731D1000DE7AE /* JackServerGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC2168D0A444BED00BDA09F /* JackServerGlobals.h */; };
-		4B35C4B50D4731D1000DE7AE /* timestamps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF520580CB8D1010037470E /* timestamps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4B60D4731D1000DE7AE /* jack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737A0CC60A6D001AFFD4 /* jack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4B70D4731D1000DE7AE /* intclient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C73790CC60A6D001AFFD4 /* intclient.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4B80D4731D1000DE7AE /* ringbuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4B90D4731D1000DE7AE /* statistics.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737C0CC60A6D001AFFD4 /* statistics.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4BA0D4731D1000DE7AE /* thread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737D0CC60A6D001AFFD4 /* thread.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4BB0D4731D1000DE7AE /* transport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737E0CC60A6D001AFFD4 /* transport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4BC0D4731D1000DE7AE /* types.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737F0CC60A6D001AFFD4 /* types.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4BD0D4731D1000DE7AE /* JackPortType.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAB95B70B9E20B800A0C723 /* JackPortType.h */; };
-		4B35C4BE0D4731D1000DE7AE /* JackMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B80D7E50BA0D17400F035BB /* JackMidiPort.h */; };
-		4B35C4BF0D4731D1000DE7AE /* midiport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6B9EF50CD0958B0051EE5A /* midiport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B35C4C00D4731D1000DE7AE /* JackDebugClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B98AE010931D30C0091932A /* JackDebugClient.h */; };
-		4B35C4C10D4731D1000DE7AE /* JackTools.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE4CC000CDA153400CCF5BB /* JackTools.h */; };
-		4B35C4C50D4731D1000DE7AE /* JackShmMem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */; };
-		4B35C4C60D4731D1000DE7AE /* shm.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1900834EE8400C94B91 /* shm.c */; };
-		4B35C4C80D4731D1000DE7AE /* JackActivationCount.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */; };
-		4B35C4C90D4731D1000DE7AE /* JackGraphManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */; };
-		4B35C4CA0D4731D1000DE7AE /* JackPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */; };
-		4B35C4CB0D4731D1000DE7AE /* JackClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E50834EF6700C94B91 /* JackClient.cpp */; };
-		4B35C4CC0D4731D1000DE7AE /* JackAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */; };
-		4B35C4CD0D4731D1000DE7AE /* JackConnectionManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */; };
-		4B35C4CE0D4731D1000DE7AE /* JackFrameTimer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */; };
-		4B35C4D00D4731D1000DE7AE /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4B35C4D10D4731D1000DE7AE /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B35C4D50D4731D1000DE7AE /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4B35C4D70D4731D1000DE7AE /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4B35C4D80D4731D1000DE7AE /* JackAudioDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D22A0834F07D00C94B91 /* JackAudioDriver.cpp */; };
-		4B35C4D90D4731D1000DE7AE /* JackFreewheelDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1BA0834EEF100C94B91 /* JackFreewheelDriver.cpp */; };
-		4B35C4DA0D4731D1000DE7AE /* JackThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1BE0834EEFC00C94B91 /* JackThreadedDriver.cpp */; };
-		4B35C4DB0D4731D1000DE7AE /* JackDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1B60834EEE400C94B91 /* JackDriver.cpp */; };
-		4B35C4DC0D4731D1000DE7AE /* JackDriverLoader.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B869D7F08C9CB00001CF041 /* JackDriverLoader.cpp */; };
-		4B35C4DD0D4731D1000DE7AE /* JackEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2140834F02800C94B91 /* JackEngine.cpp */; };
-		4B35C4DE0D4731D1000DE7AE /* JackExternalClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1F80834EFBD00C94B91 /* JackExternalClient.cpp */; };
-		4B35C4DF0D4731D1000DE7AE /* JackInternalClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1ED0834EF9200C94B91 /* JackInternalClient.cpp */; };
-		4B35C4E20D4731D1000DE7AE /* JackServer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2210834F05C00C94B91 /* JackServer.cpp */; };
-		4B35C4EB0D4731D1000DE7AE /* JackTransportEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */; };
-		4B35C4EC0D4731D1000DE7AE /* JackServerAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1F50834EFB000C94B91 /* JackServerAPI.cpp */; };
-		4B35C4ED0D4731D1000DE7AE /* JackServerGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC216880A444BDE00BDA09F /* JackServerGlobals.cpp */; };
-		4B35C4EE0D4731D1000DE7AE /* timestamps.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF520520CB8D0E80037470E /* timestamps.c */; };
-		4B35C4EF0D4731D1000DE7AE /* JackPortType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */; };
-		4B35C4F00D4731D1000DE7AE /* JackAudioPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */; };
-		4B35C4F10D4731D1000DE7AE /* JackMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */; };
-		4B35C4F20D4731D1000DE7AE /* JackMidiAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */; };
-		4B35C4F30D4731D1000DE7AE /* JackEngineControl.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */; };
-		4B35C4F40D4731D1000DE7AE /* JackDebugClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B98AE000931D30C0091932A /* JackDebugClient.cpp */; };
-		4B35C4F50D4731D1000DE7AE /* JackTools.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */; };
-		4B35C50D0D4731D1000DE7AE /* midiseq.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B5A1BBD0CD1CC110005BF74 /* midiseq.c */; };
-		4B35C5190D4731D1000DE7AE /* midisine.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B5A1BDC0CD1CD420005BF74 /* midisine.c */; };
-		4B35C5250D4731D1000DE7AE /* metro.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D16B0834EDF000C94B91 /* metro.c */; };
-		4B35C5310D4731D1000DE7AE /* lsp.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1690834EDE600C94B91 /* lsp.c */; };
-		4B35C53D0D4731D1000DE7AE /* connect.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B60CE480AAABA31004956AA /* connect.c */; };
-		4B35C5490D4731D1000DE7AE /* connect.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B60CE480AAABA31004956AA /* connect.c */; };
-		4B35C5570D4731D2000DE7AE /* freewheel.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1710834EE0F00C94B91 /* freewheel.c */; };
-		4B35C57D0D4731D2000DE7AE /* testAtomic.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D23E0834F1C300C94B91 /* testAtomic.cpp */; };
-		4B35C58D0D4731D2000DE7AE /* testSem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2470834F20600C94B91 /* testSem.cpp */; };
-		4B35C59F0D4731D2000DE7AE /* zombie.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1670834EDD900C94B91 /* zombie.c */; };
-		4B35C5AB0D4731D2000DE7AE /* test.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE6C6AC0A3E0A65005A203A /* test.cpp */; };
-		4B35C5B70D4731D2000DE7AE /* cpu.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3F49070AD8503300491C6E /* cpu.c */; };
-		4B35C5C30D4731D2000DE7AE /* ipload.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BA692B20CBE4C2D00EAD520 /* ipload.c */; };
-		4B35C5CF0D4731D2000DE7AE /* ipunload.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BA692D60CBE4CC600EAD520 /* ipunload.c */; };
-		4B35C5DA0D4731D2000DE7AE /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4B35C5DB0D4731D2000DE7AE /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4B35C5DD0D4731D2000DE7AE /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4B35C5E00D4731D2000DE7AE /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B35C5E20D4731D2000DE7AE /* testSynchroServer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BA577FB08BF8E4600F82DE1 /* testSynchroServer.cpp */; };
-		4B35C5F60D4731D2000DE7AE /* testSynchroClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BA577BC08BF8BE200F82DE1 /* testSynchroClient.cpp */; };
-		4B35C60A0D4731D2000DE7AE /* testSynchroServerClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBD13CC08C71EB40079F7FF /* testSynchroServerClient.cpp */; };
-		4B35C62C0D4731D2000DE7AE /* JackDummyDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3988A08B3CF6C00B6F371 /* JackDummyDriver.h */; };
-		4B35C62E0D4731D2000DE7AE /* JackDummyDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3988908B3CF6C00B6F371 /* JackDummyDriver.cpp */; };
-		4B35C6380D4731D3000DE7AE /* inprocess.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BD6240C0CBCF16600DE782F /* inprocess.c */; };
-		4B363DDF0DEB034E001F72D9 /* alias.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363DDE0DEB034E001F72D9 /* alias.c */; };
-		4B363E210DEB0401001F72D9 /* evmon.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363E200DEB0401001F72D9 /* evmon.c */; };
-		4B363E720DEB0808001F72D9 /* bufsize.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363E710DEB0808001F72D9 /* bufsize.c */; };
-		4B363EEE0DEB094B001F72D9 /* capture_client.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363EED0DEB094B001F72D9 /* capture_client.c */; };
-		4B363F230DEB0AB0001F72D9 /* monitor_client.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363F220DEB0AB0001F72D9 /* monitor_client.c */; };
-		4B363F3E0DEB0C31001F72D9 /* showtime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363F3D0DEB0C31001F72D9 /* showtime.c */; };
-		4B363F760DEB0D7D001F72D9 /* impulse_grabber.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363F750DEB0D7D001F72D9 /* impulse_grabber.c */; };
-		4B370A24133DD7E300237B68 /* JackCoreMidiInputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A14133DD7E200237B68 /* JackCoreMidiInputPort.cpp */; };
-		4B370A25133DD7E300237B68 /* JackCoreMidiInputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A15133DD7E200237B68 /* JackCoreMidiInputPort.h */; };
-		4B370A26133DD7E300237B68 /* JackCoreMidiOutputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A16133DD7E200237B68 /* JackCoreMidiOutputPort.cpp */; };
-		4B370A27133DD7E300237B68 /* JackCoreMidiOutputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A17133DD7E200237B68 /* JackCoreMidiOutputPort.h */; };
-		4B370A28133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A18133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.cpp */; };
-		4B370A29133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A19133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.h */; };
-		4B370A2A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A1A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp */; };
-		4B370A2B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A1B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h */; };
-		4B370A2C133DD7E300237B68 /* JackCoreMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A1C133DD7E300237B68 /* JackCoreMidiPort.cpp */; };
-		4B370A2D133DD7E300237B68 /* JackCoreMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A1D133DD7E300237B68 /* JackCoreMidiPort.h */; };
-		4B370A2E133DD7E300237B68 /* JackCoreMidiUtil.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A1E133DD7E300237B68 /* JackCoreMidiUtil.cpp */; };
-		4B370A2F133DD7E300237B68 /* JackCoreMidiUtil.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A1F133DD7E300237B68 /* JackCoreMidiUtil.h */; };
-		4B370A30133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A20133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp */; };
-		4B370A31133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A21133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h */; };
-		4B370A32133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A22133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp */; };
-		4B370A33133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A23133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h */; };
-		4B370A34133DD7E300237B68 /* JackCoreMidiInputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A14133DD7E200237B68 /* JackCoreMidiInputPort.cpp */; };
-		4B370A35133DD7E300237B68 /* JackCoreMidiInputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A15133DD7E200237B68 /* JackCoreMidiInputPort.h */; };
-		4B370A36133DD7E300237B68 /* JackCoreMidiOutputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A16133DD7E200237B68 /* JackCoreMidiOutputPort.cpp */; };
-		4B370A37133DD7E300237B68 /* JackCoreMidiOutputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A17133DD7E200237B68 /* JackCoreMidiOutputPort.h */; };
-		4B370A38133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A18133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.cpp */; };
-		4B370A39133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A19133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.h */; };
-		4B370A3A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A1A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp */; };
-		4B370A3B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A1B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h */; };
-		4B370A3C133DD7E300237B68 /* JackCoreMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A1C133DD7E300237B68 /* JackCoreMidiPort.cpp */; };
-		4B370A3D133DD7E300237B68 /* JackCoreMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A1D133DD7E300237B68 /* JackCoreMidiPort.h */; };
-		4B370A3E133DD7E300237B68 /* JackCoreMidiUtil.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A1E133DD7E300237B68 /* JackCoreMidiUtil.cpp */; };
-		4B370A3F133DD7E300237B68 /* JackCoreMidiUtil.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A1F133DD7E300237B68 /* JackCoreMidiUtil.h */; };
-		4B370A40133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A20133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp */; };
-		4B370A41133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A21133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h */; };
-		4B370A42133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B370A22133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp */; };
-		4B370A43133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B370A23133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h */; };
-		4B3811FB13269C8300C61B14 /* latent_client.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3811FA13269C8300C61B14 /* latent_client.c */; };
-		4B3811FC13269C8300C61B14 /* latent_client.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3811FA13269C8300C61B14 /* latent_client.c */; };
-		4B3814201327AA6800C61B14 /* iodelay.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B38141F1327AA6800C61B14 /* iodelay.cpp */; };
-		4B3814211327AA6800C61B14 /* iodelay.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B38141F1327AA6800C61B14 /* iodelay.cpp */; };
-		4B3F49080AD8503300491C6E /* cpu.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B3F49070AD8503300491C6E /* cpu.c */; };
-		4B43A8CA1014605000E52943 /* JackLoopbackDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B43A8C81014605000E52943 /* JackLoopbackDriver.cpp */; };
-		4B43A8CB1014605000E52943 /* JackLoopbackDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B43A8C91014605000E52943 /* JackLoopbackDriver.h */; };
-		4B43A8DF1014615800E52943 /* JackLoopbackDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B43A8C91014605000E52943 /* JackLoopbackDriver.h */; };
-		4B43A8E11014615800E52943 /* JackLoopbackDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B43A8C81014605000E52943 /* JackLoopbackDriver.cpp */; };
-		4B47AC8310B5890100469C67 /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4B47AC8410B5890100469C67 /* JackTime.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1830834EE5800C94B91 /* JackTime.h */; };
-		4B47AC8510B5890100469C67 /* JackShmMem.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1870834EE7900C94B91 /* JackShmMem.h */; };
-		4B47AC8610B5890100469C67 /* shm.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D18F0834EE8400C94B91 /* shm.h */; };
-		4B47AC8710B5890100469C67 /* JackThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D19F0834EE9E00C94B91 /* JackThread.h */; };
-		4B47AC8810B5890100469C67 /* JackActivationCount.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */; };
-		4B47AC8910B5890100469C67 /* JackChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1AF0834EEC400C94B91 /* JackChannel.h */; };
-		4B47AC8A10B5890100469C67 /* JackGraphManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */; };
-		4B47AC8B10B5890100469C67 /* JackPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1CF0834EF2F00C94B91 /* JackPort.h */; };
-		4B47AC8C10B5890100469C67 /* JackClientInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */; };
-		4B47AC8D10B5890100469C67 /* JackClientControl.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */; };
-		4B47AC8E10B5890100469C67 /* JackClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1E10834EF5500C94B91 /* JackClient.h */; };
-		4B47AC8F10B5890100469C67 /* JackInternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */; };
-		4B47AC9010B5890100469C67 /* JackLibGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1FB0834EFD100C94B91 /* JackLibGlobals.h */; };
-		4B47AC9110B5890100469C67 /* JackLibClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1FC0834EFD100C94B91 /* JackLibClient.h */; };
-		4B47AC9210B5890100469C67 /* JackConnectionManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */; };
-		4B47AC9310B5890100469C67 /* JackFrameTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */; };
-		4B47AC9410B5890100469C67 /* JackMachSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */; };
-		4B47AC9510B5890100469C67 /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4B47AC9610B5890100469C67 /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4B47AC9810B5890100469C67 /* JackSynchro.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD561C708EEB910006BBC2A /* JackSynchro.h */; };
-		4B47AC9910B5890100469C67 /* JackDebugClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B98AE010931D30C0091932A /* JackDebugClient.h */; };
-		4B47AC9A10B5890100469C67 /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4B47AC9B10B5890100469C67 /* JackTransportEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */; };
-		4B47AC9C10B5890100469C67 /* timestamps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF520580CB8D1010037470E /* timestamps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47AC9D10B5890100469C67 /* intclient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C73790CC60A6D001AFFD4 /* intclient.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47AC9E10B5890100469C67 /* jack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737A0CC60A6D001AFFD4 /* jack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47AC9F10B5890100469C67 /* ringbuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA010B5890100469C67 /* statistics.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737C0CC60A6D001AFFD4 /* statistics.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA110B5890100469C67 /* thread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737D0CC60A6D001AFFD4 /* thread.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA210B5890100469C67 /* transport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737E0CC60A6D001AFFD4 /* transport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA310B5890100469C67 /* types.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737F0CC60A6D001AFFD4 /* types.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA410B5890100469C67 /* JackPortType.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAB95B70B9E20B800A0C723 /* JackPortType.h */; };
-		4B47ACA510B5890100469C67 /* JackMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B80D7E50BA0D17400F035BB /* JackMidiPort.h */; };
-		4B47ACA610B5890100469C67 /* midiport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6B9EF50CD0958B0051EE5A /* midiport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA710B5890100469C67 /* JackTools.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE4CC000CDA153400CCF5BB /* JackTools.h */; };
-		4B47ACA810B5890100469C67 /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B47ACA910B5890100469C67 /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4B47ACAA10B5890100469C67 /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */; };
-		4B47ACB110B5890100469C67 /* JackShmMem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */; };
-		4B47ACB210B5890100469C67 /* shm.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1900834EE8400C94B91 /* shm.c */; };
-		4B47ACB310B5890100469C67 /* JackActivationCount.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */; };
-		4B47ACB410B5890100469C67 /* JackGraphManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */; };
-		4B47ACB510B5890100469C67 /* JackPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */; };
-		4B47ACB610B5890100469C67 /* JackClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E50834EF6700C94B91 /* JackClient.cpp */; };
-		4B47ACB710B5890100469C67 /* JackAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */; };
-		4B47ACB810B5890100469C67 /* JackLibClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1FD0834EFD100C94B91 /* JackLibClient.cpp */; };
-		4B47ACB910B5890100469C67 /* JackLibAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1FE0834EFD100C94B91 /* JackLibAPI.cpp */; };
-		4B47ACBA10B5890100469C67 /* JackConnectionManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */; };
-		4B47ACBB10B5890100469C67 /* JackFrameTimer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */; };
-		4B47ACBC10B5890100469C67 /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4B47ACBD10B5890100469C67 /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B47ACBF10B5890100469C67 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4B47ACC010B5890100469C67 /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4B47ACC110B5890100469C67 /* JackDebugClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B98AE000931D30C0091932A /* JackDebugClient.cpp */; };
-		4B47ACC210B5890100469C67 /* JackTransportEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */; };
-		4B47ACC310B5890100469C67 /* timestamps.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF520520CB8D0E80037470E /* timestamps.c */; };
-		4B47ACC410B5890100469C67 /* JackPortType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */; };
-		4B47ACC510B5890100469C67 /* JackAudioPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */; };
-		4B47ACC610B5890100469C67 /* JackMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */; };
-		4B47ACC710B5890100469C67 /* JackMidiAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */; };
-		4B47ACC810B5890100469C67 /* JackEngineControl.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */; };
-		4B47ACC910B5890100469C67 /* JackTools.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */; };
-		4B47ACCA10B5890100469C67 /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4B47ACCB10B5890100469C67 /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4B47ACCC10B5890100469C67 /* JackPosixServerLaunch.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBBA0E878B9C003D2374 /* JackPosixServerLaunch.cpp */; };
-		4B47ACCD10B5890100469C67 /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4B47ACCE10B5890100469C67 /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4B47ACD210B5890100469C67 /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4B49D44214865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; };
-		4B49D44314865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44414865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; };
-		4B49D44514865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44614865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; };
-		4B49D44714865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44814865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; };
-		4B49D44914865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44A14865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; };
-		4B49D44B14865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44C14865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; };
-		4B49D44D14865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44E14865F22003390F8 /* net.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44014865F22003390F8 /* net.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B49D44F14865F22003390F8 /* session.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B49D44114865F22003390F8 /* session.h */; };
-		4B4C3B641BC2FF670004CC35 /* JackPosixSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B70E703BAA0066E42F /* JackPosixSemaphore.cpp */; };
-		4B4C3B651BC2FF6A0004CC35 /* JackPosixSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B80E703BAA0066E42F /* JackPosixSemaphore.h */; };
-		4B4C3B6A1BC2FFB30004CC35 /* JackPosixSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B70E703BAA0066E42F /* JackPosixSemaphore.cpp */; };
-		4B4C3B6B1BC2FFB50004CC35 /* JackPosixSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B80E703BAA0066E42F /* JackPosixSemaphore.h */; };
-		4B4C3B6C1BC2FFC40004CC35 /* JackPosixSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B70E703BAA0066E42F /* JackPosixSemaphore.cpp */; };
-		4B4C3B6D1BC2FFC70004CC35 /* JackPosixSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B80E703BAA0066E42F /* JackPosixSemaphore.h */; };
-		4B4C3B6E1BC2FFDD0004CC35 /* JackPosixSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B70E703BAA0066E42F /* JackPosixSemaphore.cpp */; };
-		4B4C3B6F1BC2FFE00004CC35 /* JackPosixSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B80E703BAA0066E42F /* JackPosixSemaphore.h */; };
-		4B4CA9750E02CF9600F4BFDA /* JackRestartThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4CA9730E02CF9600F4BFDA /* JackRestartThreadedDriver.h */; };
-		4B4CA9760E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4CA9740E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp */; };
-		4B4CA9770E02CF9600F4BFDA /* JackRestartThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4CA9730E02CF9600F4BFDA /* JackRestartThreadedDriver.h */; };
-		4B4CA9780E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4CA9740E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp */; };
-		4B4E9AFA0E5F1090000A3278 /* JackControlAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4E9AF80E5F1090000A3278 /* JackControlAPI.cpp */; };
-		4B4E9AFB0E5F1090000A3278 /* JackControlAPI.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4E9AF90E5F1090000A3278 /* JackControlAPI.h */; };
-		4B4E9AFC0E5F1090000A3278 /* JackControlAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4E9AF80E5F1090000A3278 /* JackControlAPI.cpp */; };
-		4B4E9AFD0E5F1090000A3278 /* JackControlAPI.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4E9AF90E5F1090000A3278 /* JackControlAPI.h */; };
-		4B4F9C8C0DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4B4F9C8D0DC20C0400706CB0 /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4B4F9C8E0DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4B4F9C8F0DC20C0400706CB0 /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4B4F9C900DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4B4F9C910DC20C0400706CB0 /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4B4F9C920DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4B4F9C930DC20C0400706CB0 /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4B4F9D820DC2178E00706CB0 /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4B4F9D830DC2178F00706CB0 /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4B5160A813215E8B00BB7DCB /* systemdeps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B94334910A5E666002A187F /* systemdeps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B5160A913215EBF00BB7DCB /* systemdeps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B94334910A5E666002A187F /* systemdeps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B5160AA13215ED900BB7DCB /* systemdeps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B94334910A5E666002A187F /* systemdeps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B5160AE13215EF900BB7DCB /* systemdeps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B94334910A5E666002A187F /* systemdeps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B5A1BBE0CD1CC110005BF74 /* midiseq.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B5A1BBD0CD1CC110005BF74 /* midiseq.c */; };
-		4B5A1BDD0CD1CD420005BF74 /* midisine.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B5A1BDC0CD1CD420005BF74 /* midisine.c */; };
-		4B5DB9830CD2429A00EBA5EE /* JackDebugClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B98AE000931D30C0091932A /* JackDebugClient.cpp */; };
-		4B5DB9840CD2429B00EBA5EE /* JackDebugClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B98AE010931D30C0091932A /* JackDebugClient.h */; };
-		4B5E08C30E5B66EE00BEE4E0 /* JackAudioAdapterInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */; };
-		4B5E08C60E5B66EE00BEE4E0 /* JackLibSampleRateResampler.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */; };
-		4B5E08CC0E5B66EE00BEE4E0 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */; };
-		4B5E08CD0E5B66EE00BEE4E0 /* JackLibSampleRateResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */; };
-		4B5E08CE0E5B66EE00BEE4E0 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3120E2362E700DD4A82 /* JackResampler.cpp */; };
-		4B5E08E10E5B676C00BEE4E0 /* JackNetAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B5E08DF0E5B676C00BEE4E0 /* JackNetAdapter.cpp */; };
-		4B5E08E20E5B676D00BEE4E0 /* JackNetAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B5E08E00E5B676C00BEE4E0 /* JackNetAdapter.h */; };
-		4B5E08EE0E5B680200BEE4E0 /* JackAudioAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3060E2362E700DD4A82 /* JackAudioAdapter.cpp */; };
-		4B5E08EF0E5B680200BEE4E0 /* JackAudioAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3070E2362E700DD4A82 /* JackAudioAdapter.h */; };
-		4B5F253E0DEE9B8F0041E486 /* JackLockedEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B5F253D0DEE9B8F0041E486 /* JackLockedEngine.h */; };
-		4B60CE490AAABA31004956AA /* connect.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B60CE480AAABA31004956AA /* connect.c */; };
-		4B60CE4A0AAABA31004956AA /* connect.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B60CE480AAABA31004956AA /* connect.c */; };
-		4B6654FC127C350100753A79 /* server_control.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6654FB127C350100753A79 /* server_control.cpp */; };
-		4B67AB8D14B4B03800B4AA9A /* JackException.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B67AB8C14B4B03800B4AA9A /* JackException.cpp */; };
-		4B67AB8E14B4B03800B4AA9A /* JackException.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B67AB8C14B4B03800B4AA9A /* JackException.cpp */; };
-		4B67AB8F14B4B03800B4AA9A /* JackException.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B67AB8C14B4B03800B4AA9A /* JackException.cpp */; };
-		4B699BAA097D421600A18468 /* Jackdmp.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2250834F06A00C94B91 /* Jackdmp.cpp */; };
-		4B699C03097D421600A18468 /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4B699C04097D421600A18468 /* JackTime.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1830834EE5800C94B91 /* JackTime.h */; };
-		4B699C05097D421600A18468 /* JackShmMem.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1870834EE7900C94B91 /* JackShmMem.h */; };
-		4B699C06097D421600A18468 /* shm.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D18F0834EE8400C94B91 /* shm.h */; };
-		4B699C08097D421600A18468 /* JackThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D19F0834EE9E00C94B91 /* JackThread.h */; };
-		4B699C09097D421600A18468 /* JackActivationCount.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */; };
-		4B699C0A097D421600A18468 /* JackChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1AF0834EEC400C94B91 /* JackChannel.h */; };
-		4B699C0B097D421600A18468 /* JackGraphManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */; };
-		4B699C0C097D421600A18468 /* JackPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1CF0834EF2F00C94B91 /* JackPort.h */; };
-		4B699C0D097D421600A18468 /* JackClientInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */; };
-		4B699C0E097D421600A18468 /* JackClientControl.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */; };
-		4B699C0F097D421600A18468 /* JackClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1E10834EF5500C94B91 /* JackClient.h */; };
-		4B699C10097D421600A18468 /* JackInternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */; };
-		4B699C11097D421600A18468 /* JackLibGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1FB0834EFD100C94B91 /* JackLibGlobals.h */; };
-		4B699C12097D421600A18468 /* JackLibClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1FC0834EFD100C94B91 /* JackLibClient.h */; };
-		4B699C13097D421600A18468 /* JackConnectionManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */; };
-		4B699C14097D421600A18468 /* JackFrameTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */; };
-		4B699C16097D421600A18468 /* JackMachSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */; };
-		4B699C17097D421600A18468 /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4B699C18097D421600A18468 /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4B699C20097D421600A18468 /* JackSynchro.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD561C708EEB910006BBC2A /* JackSynchro.h */; };
-		4B699C21097D421600A18468 /* JackDebugClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B98AE010931D30C0091932A /* JackDebugClient.h */; };
-		4B699C22097D421600A18468 /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4B699C28097D421600A18468 /* JackShmMem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */; };
-		4B699C29097D421600A18468 /* shm.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1900834EE8400C94B91 /* shm.c */; };
-		4B699C2B097D421600A18468 /* JackActivationCount.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */; };
-		4B699C2C097D421600A18468 /* JackGraphManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */; };
-		4B699C2D097D421600A18468 /* JackPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */; };
-		4B699C2E097D421600A18468 /* JackClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E50834EF6700C94B91 /* JackClient.cpp */; };
-		4B699C2F097D421600A18468 /* JackAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */; };
-		4B699C30097D421600A18468 /* JackLibClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1FD0834EFD100C94B91 /* JackLibClient.cpp */; };
-		4B699C31097D421600A18468 /* JackLibAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1FE0834EFD100C94B91 /* JackLibAPI.cpp */; };
-		4B699C32097D421600A18468 /* JackConnectionManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */; };
-		4B699C33097D421600A18468 /* JackFrameTimer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */; };
-		4B699C35097D421600A18468 /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4B699C36097D421600A18468 /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B699C3D097D421600A18468 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4B699C3F097D421600A18468 /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4B699C40097D421600A18468 /* JackDebugClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B98AE000931D30C0091932A /* JackDebugClient.cpp */; };
-		4B699C4F097D421600A18468 /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4B699C50097D421600A18468 /* JackTime.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1830834EE5800C94B91 /* JackTime.h */; };
-		4B699C51097D421600A18468 /* JackShmMem.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1870834EE7900C94B91 /* JackShmMem.h */; };
-		4B699C52097D421600A18468 /* shm.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D18F0834EE8400C94B91 /* shm.h */; };
-		4B699C54097D421600A18468 /* JackThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D19F0834EE9E00C94B91 /* JackThread.h */; };
-		4B699C55097D421600A18468 /* JackActivationCount.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */; };
-		4B699C56097D421600A18468 /* JackChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1AF0834EEC400C94B91 /* JackChannel.h */; };
-		4B699C57097D421600A18468 /* JackGraphManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */; };
-		4B699C58097D421600A18468 /* JackPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1CF0834EF2F00C94B91 /* JackPort.h */; };
-		4B699C59097D421600A18468 /* JackClientInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */; };
-		4B699C5A097D421600A18468 /* JackClientControl.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */; };
-		4B699C5B097D421600A18468 /* JackClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1E10834EF5500C94B91 /* JackClient.h */; };
-		4B699C5C097D421600A18468 /* JackInternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */; };
-		4B699C5D097D421600A18468 /* JackConnectionManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */; };
-		4B699C5E097D421600A18468 /* JackFrameTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */; };
-		4B699C60097D421600A18468 /* JackMachSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */; };
-		4B699C61097D421600A18468 /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4B699C62097D421600A18468 /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4B699C68097D421600A18468 /* JackSynchro.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD561C708EEB910006BBC2A /* JackSynchro.h */; };
-		4B699C69097D421600A18468 /* JackAudioDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2290834F07D00C94B91 /* JackAudioDriver.h */; };
-		4B699C6A097D421600A18468 /* JackFreewheelDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1B90834EEF100C94B91 /* JackFreewheelDriver.h */; };
-		4B699C6B097D421600A18468 /* JackThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1BD0834EEFC00C94B91 /* JackThreadedDriver.h */; };
-		4B699C6C097D421600A18468 /* JackDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1B50834EEE400C94B91 /* JackDriver.h */; };
-		4B699C6D097D421600A18468 /* driver_interface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B869B3D08C8D21C001CF041 /* driver_interface.h */; };
-		4B699C6F097D421600A18468 /* JackDriverLoader.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B869B4208C8D22F001CF041 /* JackDriverLoader.h */; };
-		4B699C71097D421600A18468 /* JackEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2130834F02800C94B91 /* JackEngine.h */; };
-		4B699C73097D421600A18468 /* JackExternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1F70834EFBD00C94B91 /* JackExternalClient.h */; };
-		4B699C74097D421600A18468 /* JackServer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2220834F05C00C94B91 /* JackServer.h */; };
-		4B699C7B097D421600A18468 /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4B699C7F097D421600A18468 /* JackShmMem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */; };
-		4B699C80097D421600A18468 /* shm.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1900834EE8400C94B91 /* shm.c */; };
-		4B699C82097D421600A18468 /* JackActivationCount.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */; };
-		4B699C83097D421600A18468 /* JackGraphManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */; };
-		4B699C84097D421600A18468 /* JackPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */; };
-		4B699C85097D421600A18468 /* JackClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E50834EF6700C94B91 /* JackClient.cpp */; };
-		4B699C86097D421600A18468 /* JackAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */; };
-		4B699C87097D421600A18468 /* JackConnectionManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */; };
-		4B699C88097D421600A18468 /* JackFrameTimer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */; };
-		4B699C8A097D421600A18468 /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4B699C8B097D421600A18468 /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B699C8F097D421600A18468 /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4B699C91097D421600A18468 /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4B699C92097D421600A18468 /* JackAudioDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D22A0834F07D00C94B91 /* JackAudioDriver.cpp */; };
-		4B699C93097D421600A18468 /* JackFreewheelDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1BA0834EEF100C94B91 /* JackFreewheelDriver.cpp */; };
-		4B699C94097D421600A18468 /* JackThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1BE0834EEFC00C94B91 /* JackThreadedDriver.cpp */; };
-		4B699C95097D421600A18468 /* JackDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1B60834EEE400C94B91 /* JackDriver.cpp */; };
-		4B699C96097D421600A18468 /* JackDriverLoader.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B869D7F08C9CB00001CF041 /* JackDriverLoader.cpp */; };
-		4B699C97097D421600A18468 /* JackEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2140834F02800C94B91 /* JackEngine.cpp */; };
-		4B699C99097D421600A18468 /* JackExternalClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1F80834EFBD00C94B91 /* JackExternalClient.cpp */; };
-		4B699C9A097D421600A18468 /* JackInternalClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1ED0834EF9200C94B91 /* JackInternalClient.cpp */; };
-		4B699C9D097D421600A18468 /* JackServer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2210834F05C00C94B91 /* JackServer.cpp */; };
-		4B699CB4097D421600A18468 /* metro.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D16B0834EDF000C94B91 /* metro.c */; };
-		4B699CC4097D421600A18468 /* lsp.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1690834EDE600C94B91 /* lsp.c */; };
-		4B699CF6097D421600A18468 /* freewheel.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1710834EE0F00C94B91 /* freewheel.c */; };
-		4B699D18097D421600A18468 /* testAtomic.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D23E0834F1C300C94B91 /* testAtomic.cpp */; };
-		4B699D2C097D421600A18468 /* testSem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2470834F20600C94B91 /* testSem.cpp */; };
-		4B699D42097D421600A18468 /* zombie.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1670834EDD900C94B91 /* zombie.c */; };
-		4B699D59097D421600A18468 /* testSynchroServer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BA577FB08BF8E4600F82DE1 /* testSynchroServer.cpp */; };
-		4B699D71097D421600A18468 /* testSynchroClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BA577BC08BF8BE200F82DE1 /* testSynchroClient.cpp */; };
-		4B699D89097D421700A18468 /* testSynchroServerClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBD13CC08C71EB40079F7FF /* testSynchroServerClient.cpp */; };
-		4B699DA8097D421700A18468 /* JackDummyDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3988A08B3CF6C00B6F371 /* JackDummyDriver.h */; };
-		4B699DAA097D421700A18468 /* JackDummyDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3988908B3CF6C00B6F371 /* JackDummyDriver.cpp */; };
-		4B6B9EF60CD095930051EE5A /* midiport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6B9EF50CD0958B0051EE5A /* midiport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6B9EF70CD095970051EE5A /* midiport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6B9EF50CD0958B0051EE5A /* midiport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73800CC60A7F001AFFD4 /* intclient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C73790CC60A6D001AFFD4 /* intclient.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73810CC60A7F001AFFD4 /* jack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737A0CC60A6D001AFFD4 /* jack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73820CC60A7F001AFFD4 /* ringbuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73830CC60A80001AFFD4 /* statistics.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737C0CC60A6D001AFFD4 /* statistics.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73840CC60A80001AFFD4 /* thread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737D0CC60A6D001AFFD4 /* thread.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73850CC60A81001AFFD4 /* transport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737E0CC60A6D001AFFD4 /* transport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73860CC60A83001AFFD4 /* jack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737A0CC60A6D001AFFD4 /* jack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73870CC60A84001AFFD4 /* intclient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C73790CC60A6D001AFFD4 /* intclient.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73880CC60A84001AFFD4 /* ringbuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C73890CC60A85001AFFD4 /* statistics.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737C0CC60A6D001AFFD4 /* statistics.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C738A0CC60A85001AFFD4 /* thread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737D0CC60A6D001AFFD4 /* thread.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6C738B0CC60A86001AFFD4 /* transport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737E0CC60A6D001AFFD4 /* transport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B6F7AEE0CD0CDBD00F48A9D /* JackEngineControl.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */; };
-		4B6FE13A13DDABE000B4B943 /* JackSocketServerNotifyChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B60E703B8D0066E42F /* JackSocketServerNotifyChannel.h */; };
-		4B6FE13B13DDABE700B4B943 /* JackSocketServerNotifyChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B50E703B8D0066E42F /* JackSocketServerNotifyChannel.cpp */; };
-		4B6FE13C13DDABF100B4B943 /* JackSocketServerChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B40E703B8D0066E42F /* JackSocketServerChannel.h */; };
-		4B6FE13D13DDABFA00B4B943 /* JackSocketServerChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B30E703B8D0066E42F /* JackSocketServerChannel.cpp */; };
-		4B6FE13E13DDAC0500B4B943 /* JackSocketNotifyChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B20E703B8D0066E42F /* JackSocketNotifyChannel.h */; };
-		4B6FE13F13DDAC0C00B4B943 /* JackSocketNotifyChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B10E703B8D0066E42F /* JackSocketNotifyChannel.cpp */; };
-		4B6FE14413DDAC4700B4B943 /* JackSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */; };
-		4B6FE14513DDAC4C00B4B943 /* JackSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6AE0E703B8D0066E42F /* JackSocket.h */; };
-		4B6FE14D13DDACCC00B4B943 /* JackMidiAsyncQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193931133F311400547810 /* JackMidiAsyncQueue.cpp */; };
-		4B6FE14E13DDACD200B4B943 /* JackMidiAsyncQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193932133F311400547810 /* JackMidiAsyncQueue.h */; };
-		4B6FE15313DDACEF00B4B943 /* JackMidiBufferWriteQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193968133F319000547810 /* JackMidiBufferWriteQueue.cpp */; };
-		4B6FE15413DDACF300B4B943 /* JackMidiBufferWriteQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193969133F319000547810 /* JackMidiBufferWriteQueue.h */; };
-		4B6FE15B13DDAD3D00B4B943 /* JackMidiWriteQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19397A133F31CB00547810 /* JackMidiWriteQueue.h */; };
-		4B6FE15C13DDAD4600B4B943 /* JackMidiWriteQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193979133F31CB00547810 /* JackMidiWriteQueue.cpp */; };
-		4B6FE15D13DDAD4E00B4B943 /* JackMidiUtil.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193978133F31CB00547810 /* JackMidiUtil.h */; };
-		4B6FE15E13DDAD5300B4B943 /* JackMidiUtil.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193977133F31CB00547810 /* JackMidiUtil.cpp */; };
-		4B6FE15F13DDAD5900B4B943 /* JackMidiSendQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193976133F31CB00547810 /* JackMidiSendQueue.h */; };
-		4B6FE16013DDAD5F00B4B943 /* JackMidiSendQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193975133F31CB00547810 /* JackMidiSendQueue.cpp */; };
-		4B6FE16113DDAD6600B4B943 /* JackMidiReceiveQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193974133F31CB00547810 /* JackMidiReceiveQueue.h */; };
-		4B6FE16213DDAD6F00B4B943 /* JackMidiReceiveQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193973133F31CB00547810 /* JackMidiReceiveQueue.cpp */; };
-		4B6FE16313DDAD7700B4B943 /* JackMidiReadQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193946133F315200547810 /* JackMidiReadQueue.h */; };
-		4B6FE16413DDAD7F00B4B943 /* JackMidiReadQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193945133F315200547810 /* JackMidiReadQueue.cpp */; };
-		4B6FE16513DDAD8800B4B943 /* JackMidiBufferReadQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19395E133F317300547810 /* JackMidiBufferReadQueue.h */; };
-		4B6FE16613DDAD8F00B4B943 /* JackMidiBufferReadQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19395D133F317300547810 /* JackMidiBufferReadQueue.cpp */; };
-		4B6FE16713DDAD9700B4B943 /* JackMidiAsyncWaitQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19393C133F313000547810 /* JackMidiAsyncWaitQueue.h */; };
-		4B6FE16813DDAD9F00B4B943 /* JackMidiAsyncWaitQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19393B133F313000547810 /* JackMidiAsyncWaitQueue.cpp */; };
-		4B80D7E80BA0D17400F035BB /* JackMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B80D7E50BA0D17400F035BB /* JackMidiPort.h */; };
-		4B80D7E90BA0D17400F035BB /* JackMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */; };
-		4B80D7EA0BA0D17400F035BB /* JackMidiAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */; };
-		4B80D7EB0BA0D17400F035BB /* JackMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B80D7E50BA0D17400F035BB /* JackMidiPort.h */; };
-		4B80D7EC0BA0D17400F035BB /* JackMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */; };
-		4B80D7ED0BA0D17400F035BB /* JackMidiAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */; };
-		4B8692D61371DB4700D2D11B /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4B8692F81371DC5200D2D11B /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */; };
-		4B8692FA1371DC6300D2D11B /* JackAudioAdapterInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */; };
-		4B8692FB1371DC7100D2D11B /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4B8692FD1371DC8A00D2D11B /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4B8692FE1371DC9700D2D11B /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4B86930D1371DCB000D2D11B /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4B8693141371DCCA00D2D11B /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4B8693161371DD0A00D2D11B /* JackNetAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B8693151371DD0A00D2D11B /* JackNetAPI.cpp */; };
-		4B8693171371DD2400D2D11B /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B76C7680E5AB2DB00E2AC21 /* JackNetInterface.cpp */; };
-		4B8693181371DD2A00D2D11B /* JackNetInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B76C7690E5AB2DB00E2AC21 /* JackNetInterface.h */; };
-		4B8693191371DD3B00D2D11B /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222AD60DC88268001A17F4 /* JackNetTool.cpp */; };
-		4B86931A1371DD4400D2D11B /* JackNetTool.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222AD70DC88268001A17F4 /* JackNetTool.h */; };
-		4B86931B1371DD4C00D2D11B /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B90E703BCC0066E42F /* JackNetUnixSocket.cpp */; };
-		4B8693231371DD6000D2D11B /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4B8693251371DD7E00D2D11B /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3120E2362E700DD4A82 /* JackResampler.cpp */; };
-		4B86932C1371DD9B00D2D11B /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4B86934D1371DEBA00D2D11B /* JackLibSampleRateResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */; };
-		4B86934E1371DEBD00D2D11B /* JackLibSampleRateResampler.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */; };
-		4B88D03B11298BEE007A87C1 /* weakjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03911298BEE007A87C1 /* weakjack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D03C11298BEE007A87C1 /* weakmacros.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03A11298BEE007A87C1 /* weakmacros.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D03D11298BEE007A87C1 /* weakjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03911298BEE007A87C1 /* weakjack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D03E11298BEE007A87C1 /* weakmacros.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03A11298BEE007A87C1 /* weakmacros.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D03F11298BEE007A87C1 /* weakjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03911298BEE007A87C1 /* weakjack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04011298BEE007A87C1 /* weakmacros.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03A11298BEE007A87C1 /* weakmacros.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04111298BEE007A87C1 /* weakjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03911298BEE007A87C1 /* weakjack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04211298BEE007A87C1 /* weakmacros.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03A11298BEE007A87C1 /* weakmacros.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04311298BEE007A87C1 /* weakjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03911298BEE007A87C1 /* weakjack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04411298BEE007A87C1 /* weakmacros.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03A11298BEE007A87C1 /* weakmacros.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04511298BEE007A87C1 /* weakjack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03911298BEE007A87C1 /* weakjack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B88D04611298BEE007A87C1 /* weakmacros.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B88D03A11298BEE007A87C1 /* weakmacros.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B8A38A7117B80D300664E07 /* JackSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */; };
-		4B8A38A8117B80DA00664E07 /* JackSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6AE0E703B8D0066E42F /* JackSocket.h */; };
-		4B8A38AD117B810A00664E07 /* JackSocketNotifyChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B20E703B8D0066E42F /* JackSocketNotifyChannel.h */; };
-		4B8A38AE117B811100664E07 /* JackSocketNotifyChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B10E703B8D0066E42F /* JackSocketNotifyChannel.cpp */; };
-		4B8A38B0117B812500664E07 /* JackSocketServerChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B40E703B8D0066E42F /* JackSocketServerChannel.h */; };
-		4B8A38B1117B812D00664E07 /* JackSocketServerChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B30E703B8D0066E42F /* JackSocketServerChannel.cpp */; };
-		4B8A38B2117B813400664E07 /* JackSocketServerNotifyChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B50E703B8D0066E42F /* JackSocketServerNotifyChannel.cpp */; };
-		4B8A38C4117B814000664E07 /* JackSocketServerNotifyChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B60E703B8D0066E42F /* JackSocketServerNotifyChannel.h */; };
-		4B8A38F0117B827900664E07 /* JackSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6AE0E703B8D0066E42F /* JackSocket.h */; };
-		4B8A38F1117B827E00664E07 /* JackSocketClientChannel.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AF0E703B8D0066E42F /* JackSocketClientChannel.cpp */; };
-		4B8A38F6117B82AB00664E07 /* JackSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */; };
-		4B8A38F7117B82B200664E07 /* JackSocketClientChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6B00E703B8D0066E42F /* JackSocketClientChannel.h */; };
-		4B8F16F51329161E0002AD73 /* midi_dump.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B8F16F41329161E0002AD73 /* midi_dump.c */; };
-		4B8F16F61329161E0002AD73 /* midi_dump.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B8F16F41329161E0002AD73 /* midi_dump.c */; };
-		4B90669A14BEE6D20074CD40 /* JackRequestDecoder.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B90669814BEE6D20074CD40 /* JackRequestDecoder.cpp */; };
-		4B90669B14BEE6D20074CD40 /* JackRequestDecoder.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B90669914BEE6D20074CD40 /* JackRequestDecoder.h */; };
-		4B90669C14BEE6D20074CD40 /* JackRequestDecoder.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B90669814BEE6D20074CD40 /* JackRequestDecoder.cpp */; };
-		4B90669D14BEE6D20074CD40 /* JackRequestDecoder.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B90669914BEE6D20074CD40 /* JackRequestDecoder.h */; };
-		4B90669E14BEE6D20074CD40 /* JackRequestDecoder.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B90669814BEE6D20074CD40 /* JackRequestDecoder.cpp */; };
-		4B90669F14BEE6D20074CD40 /* JackRequestDecoder.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B90669914BEE6D20074CD40 /* JackRequestDecoder.h */; };
-		4B93F1990E87992100E4ECCD /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4B93F19A0E87992200E4ECCD /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */; };
-		4B93F19C0E87998200E4ECCD /* JackPosixServerLaunch.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBBA0E878B9C003D2374 /* JackPosixServerLaunch.cpp */; };
-		4B93F19D0E87998400E4ECCD /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4B93F19E0E87998400E4ECCD /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */; };
-		4B93F1C00E87A35400E4ECCD /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4B93F22B0E87A72500E4ECCD /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4B94334A10A5E666002A187F /* systemdeps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B94334910A5E666002A187F /* systemdeps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B94334B10A5E666002A187F /* systemdeps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B94334910A5E666002A187F /* systemdeps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B95BCAE0D913073000F7695 /* control.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B95BCAD0D913073000F7695 /* control.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B97B6381344B3C100794F57 /* JackMidiAsyncQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193931133F311400547810 /* JackMidiAsyncQueue.cpp */; };
-		4B97B6391344B3C300794F57 /* JackMidiAsyncQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193932133F311400547810 /* JackMidiAsyncQueue.h */; };
-		4B97B63A1344B3C700794F57 /* JackMidiAsyncWaitQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19393B133F313000547810 /* JackMidiAsyncWaitQueue.cpp */; };
-		4B97B63D1344B3EC00794F57 /* JackMidiAsyncWaitQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19393C133F313000547810 /* JackMidiAsyncWaitQueue.h */; };
-		4B97B63E1344B3F100794F57 /* JackMidiBufferReadQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19395D133F317300547810 /* JackMidiBufferReadQueue.cpp */; };
-		4B97B6411344B40C00794F57 /* JackMidiBufferReadQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19395E133F317300547810 /* JackMidiBufferReadQueue.h */; };
-		4B97B6531344B41E00794F57 /* JackMidiBufferWriteQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193968133F319000547810 /* JackMidiBufferWriteQueue.cpp */; };
-		4B97B6541344B42400794F57 /* JackMidiBufferWriteQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193969133F319000547810 /* JackMidiBufferWriteQueue.h */; };
-		4B97B6561344B43600794F57 /* JackMidiReadQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193946133F315200547810 /* JackMidiReadQueue.h */; };
-		4B97B6571344B43A00794F57 /* JackMidiReadQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193945133F315200547810 /* JackMidiReadQueue.cpp */; };
-		4B97B6581344B43F00794F57 /* JackMidiReceiveQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193973133F31CB00547810 /* JackMidiReceiveQueue.cpp */; };
-		4B97B6591344B44800794F57 /* JackMidiReceiveQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193974133F31CB00547810 /* JackMidiReceiveQueue.h */; };
-		4B97B65A1344B44F00794F57 /* JackMidiSendQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193975133F31CB00547810 /* JackMidiSendQueue.cpp */; };
-		4B97B65B1344B45600794F57 /* JackMidiSendQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193976133F31CB00547810 /* JackMidiSendQueue.h */; };
-		4B97B65C1344B45D00794F57 /* JackMidiUtil.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193977133F31CB00547810 /* JackMidiUtil.cpp */; };
-		4B97B65D1344B46400794F57 /* JackMidiUtil.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193978133F31CB00547810 /* JackMidiUtil.h */; };
-		4B97B65E1344B46B00794F57 /* JackMidiWriteQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193979133F31CB00547810 /* JackMidiWriteQueue.cpp */; };
-		4B97B65F1344B47100794F57 /* JackMidiWriteQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19397A133F31CB00547810 /* JackMidiWriteQueue.h */; };
-		4B97B6601344B48F00794F57 /* JackMidiAsyncQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193931133F311400547810 /* JackMidiAsyncQueue.cpp */; };
-		4B97B6611344B49500794F57 /* JackMidiAsyncQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193932133F311400547810 /* JackMidiAsyncQueue.h */; };
-		4B97B6621344B49C00794F57 /* JackMidiAsyncWaitQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19393B133F313000547810 /* JackMidiAsyncWaitQueue.cpp */; };
-		4B97B6631344B4A800794F57 /* JackMidiAsyncWaitQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19393C133F313000547810 /* JackMidiAsyncWaitQueue.h */; };
-		4B97B6641344B4AE00794F57 /* JackMidiBufferReadQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19395D133F317300547810 /* JackMidiBufferReadQueue.cpp */; };
-		4B97B6651344B4B500794F57 /* JackMidiBufferReadQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19395E133F317300547810 /* JackMidiBufferReadQueue.h */; };
-		4B97B6671344B4C700794F57 /* JackMidiBufferWriteQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193969133F319000547810 /* JackMidiBufferWriteQueue.h */; };
-		4B97B6691344B4CE00794F57 /* JackMidiBufferWriteQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193968133F319000547810 /* JackMidiBufferWriteQueue.cpp */; };
-		4B97B66E1344B4D500794F57 /* JackMidiReadQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193945133F315200547810 /* JackMidiReadQueue.cpp */; };
-		4B97B66F1344B4DC00794F57 /* JackMidiReadQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193946133F315200547810 /* JackMidiReadQueue.h */; };
-		4B97B6701344B4E300794F57 /* JackMidiReceiveQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193973133F31CB00547810 /* JackMidiReceiveQueue.cpp */; };
-		4B97B6711344B4EA00794F57 /* JackMidiReceiveQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193974133F31CB00547810 /* JackMidiReceiveQueue.h */; };
-		4B97B6721344B4F000794F57 /* JackMidiSendQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193975133F31CB00547810 /* JackMidiSendQueue.cpp */; };
-		4B97B6781344B50800794F57 /* JackMidiSendQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193976133F31CB00547810 /* JackMidiSendQueue.h */; };
-		4B97B6791344B50F00794F57 /* JackMidiUtil.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193977133F31CB00547810 /* JackMidiUtil.cpp */; };
-		4B97B67A1344B51600794F57 /* JackMidiUtil.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B193978133F31CB00547810 /* JackMidiUtil.h */; };
-		4B97B67B1344B51D00794F57 /* JackMidiWriteQueue.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B193979133F31CB00547810 /* JackMidiWriteQueue.cpp */; };
-		4B97B67C1344B52800794F57 /* JackMidiWriteQueue.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19397A133F31CB00547810 /* JackMidiWriteQueue.h */; };
-		4B9A25B50DBF8330006E9FBC /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4B9A25B60DBF8330006E9FBC /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4B9A26010DBF8584006E9FBC /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B9A26020DBF8584006E9FBC /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B9A26040DBF8584006E9FBC /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (); }; };
-		4B9A26050DBF8584006E9FBC /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B9A26060DBF8584006E9FBC /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4B9A26610DBF8ADD006E9FBC /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4B9A26640DBF8B14006E9FBC /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4B9A26790DBF8B88006E9FBC /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4BA3393610B2E36800190E3B /* JackError.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1770834EE4800C94B91 /* JackError.h */; };
-		4BA3393710B2E36800190E3B /* JackTime.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1830834EE5800C94B91 /* JackTime.h */; };
-		4BA3393810B2E36800190E3B /* JackShmMem.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1870834EE7900C94B91 /* JackShmMem.h */; };
-		4BA3393910B2E36800190E3B /* shm.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D18F0834EE8400C94B91 /* shm.h */; };
-		4BA3393A10B2E36800190E3B /* JackThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D19F0834EE9E00C94B91 /* JackThread.h */; };
-		4BA3393B10B2E36800190E3B /* JackActivationCount.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */; };
-		4BA3393C10B2E36800190E3B /* JackChannel.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1AF0834EEC400C94B91 /* JackChannel.h */; };
-		4BA3393D10B2E36800190E3B /* JackGraphManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */; };
-		4BA3393E10B2E36800190E3B /* JackPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1CF0834EF2F00C94B91 /* JackPort.h */; };
-		4BA3393F10B2E36800190E3B /* JackClientInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */; };
-		4BA3394010B2E36800190E3B /* JackClientControl.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */; };
-		4BA3394110B2E36800190E3B /* JackClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1E10834EF5500C94B91 /* JackClient.h */; };
-		4BA3394210B2E36800190E3B /* JackInternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */; };
-		4BA3394310B2E36800190E3B /* JackConnectionManager.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */; };
-		4BA3394410B2E36800190E3B /* JackFrameTimer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */; };
-		4BA3394510B2E36800190E3B /* JackMachSemaphore.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */; };
-		4BA3394610B2E36800190E3B /* JackGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB73F608AD291A00DB99B8 /* JackGlobals.h */; };
-		4BA3394710B2E36800190E3B /* JackMachThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */; };
-		4BA3394810B2E36800190E3B /* JackSynchro.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD561C708EEB910006BBC2A /* JackSynchro.h */; };
-		4BA3394910B2E36800190E3B /* JackAudioDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2290834F07D00C94B91 /* JackAudioDriver.h */; };
-		4BA3394A10B2E36800190E3B /* JackFreewheelDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1B90834EEF100C94B91 /* JackFreewheelDriver.h */; };
-		4BA3394B10B2E36800190E3B /* JackThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1BD0834EEFC00C94B91 /* JackThreadedDriver.h */; };
-		4BA3394C10B2E36800190E3B /* JackDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1B50834EEE400C94B91 /* JackDriver.h */; };
-		4BA3394D10B2E36800190E3B /* driver_interface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B869B3D08C8D21C001CF041 /* driver_interface.h */; };
-		4BA3394E10B2E36800190E3B /* JackDriverLoader.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B869B4208C8D22F001CF041 /* JackDriverLoader.h */; };
-		4BA3394F10B2E36800190E3B /* JackEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2130834F02800C94B91 /* JackEngine.h */; };
-		4BA3395010B2E36800190E3B /* JackExternalClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D1F70834EFBD00C94B91 /* JackExternalClient.h */; };
-		4BA3395110B2E36800190E3B /* JackServer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF8D2220834F05C00C94B91 /* JackServer.h */; };
-		4BA3395510B2E36800190E3B /* JackConstants.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B66A8580934964500A89560 /* JackConstants.h */; };
-		4BA3395610B2E36800190E3B /* JackTransportEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */; };
-		4BA3395710B2E36800190E3B /* JackServerGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC2168D0A444BED00BDA09F /* JackServerGlobals.h */; };
-		4BA3395810B2E36800190E3B /* timestamps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF520580CB8D1010037470E /* timestamps.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395910B2E36800190E3B /* jack.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737A0CC60A6D001AFFD4 /* jack.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395A10B2E36800190E3B /* intclient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C73790CC60A6D001AFFD4 /* intclient.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395B10B2E36800190E3B /* ringbuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395C10B2E36800190E3B /* statistics.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737C0CC60A6D001AFFD4 /* statistics.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395D10B2E36800190E3B /* thread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737D0CC60A6D001AFFD4 /* thread.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395E10B2E36800190E3B /* transport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737E0CC60A6D001AFFD4 /* transport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3395F10B2E36800190E3B /* types.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737F0CC60A6D001AFFD4 /* types.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3396010B2E36800190E3B /* JackPortType.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAB95B70B9E20B800A0C723 /* JackPortType.h */; };
-		4BA3396110B2E36800190E3B /* JackMidiPort.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B80D7E50BA0D17400F035BB /* JackMidiPort.h */; };
-		4BA3396210B2E36800190E3B /* midiport.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6B9EF50CD0958B0051EE5A /* midiport.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3396310B2E36800190E3B /* JackDebugClient.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B98AE010931D30C0091932A /* JackDebugClient.h */; };
-		4BA3396410B2E36800190E3B /* JackTools.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE4CC000CDA153400CCF5BB /* JackTools.h */; };
-		4BA3396510B2E36800190E3B /* JackNetTool.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222AD70DC88268001A17F4 /* JackNetTool.h */; };
-		4BA3396610B2E36800190E3B /* jslist.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B9A26000DBF8584006E9FBC /* jslist.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BA3396710B2E36800190E3B /* JackMessageBuffer.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */; };
-		4BA3396810B2E36800190E3B /* JackRestartThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4CA9730E02CF9600F4BFDA /* JackRestartThreadedDriver.h */; };
-		4BA3396910B2E36800190E3B /* JackControlAPI.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B4E9AF90E5F1090000A3278 /* JackControlAPI.h */; };
-		4BA3396A10B2E36800190E3B /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */; };
-		4BA3396B10B2E36800190E3B /* JackEngineProfiling.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBAE40E0F42FA6100B8BD3F /* JackEngineProfiling.h */; };
-		4BA3396D10B2E36800190E3B /* JackMidiDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF339200F8B873E0080FB5B /* JackMidiDriver.h */; };
-		4BA3396E10B2E36800190E3B /* JackWaitThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBC93B90DF9736C002DF220 /* JackWaitThreadedDriver.h */; };
-		4BA3396F10B2E36800190E3B /* JackArgParser.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF284170F31B4BC00B05BE3 /* JackArgParser.h */; };
-		4BA3397310B2E36800190E3B /* JackShmMem.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */; };
-		4BA3397410B2E36800190E3B /* shm.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1900834EE8400C94B91 /* shm.c */; };
-		4BA3397510B2E36800190E3B /* JackActivationCount.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */; };
-		4BA3397610B2E36800190E3B /* JackGraphManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */; };
-		4BA3397710B2E36800190E3B /* JackPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */; };
-		4BA3397810B2E36800190E3B /* JackClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E50834EF6700C94B91 /* JackClient.cpp */; };
-		4BA3397910B2E36800190E3B /* JackAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */; };
-		4BA3397A10B2E36800190E3B /* JackConnectionManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */; };
-		4BA3397B10B2E36800190E3B /* JackFrameTimer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */; };
-		4BA3397C10B2E36800190E3B /* JackMachSemaphore.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */; };
-		4BA3397D10B2E36800190E3B /* JackMachThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */; };
-		4BA3397E10B2E36800190E3B /* JackGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B2C28F908DAD01E00249230 /* JackGlobals.cpp */; };
-		4BA3397F10B2E36800190E3B /* ringbuffer.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B003AB008E2B2BA0060EFDC /* ringbuffer.c */; };
-		4BA3398010B2E36800190E3B /* JackAudioDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D22A0834F07D00C94B91 /* JackAudioDriver.cpp */; };
-		4BA3398110B2E36800190E3B /* JackFreewheelDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1BA0834EEF100C94B91 /* JackFreewheelDriver.cpp */; };
-		4BA3398210B2E36800190E3B /* JackThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1BE0834EEFC00C94B91 /* JackThreadedDriver.cpp */; };
-		4BA3398310B2E36800190E3B /* JackDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1B60834EEE400C94B91 /* JackDriver.cpp */; };
-		4BA3398410B2E36800190E3B /* JackDriverLoader.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B869D7F08C9CB00001CF041 /* JackDriverLoader.cpp */; };
-		4BA3398510B2E36800190E3B /* JackEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2140834F02800C94B91 /* JackEngine.cpp */; };
-		4BA3398610B2E36800190E3B /* JackExternalClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1F80834EFBD00C94B91 /* JackExternalClient.cpp */; };
-		4BA3398710B2E36800190E3B /* JackInternalClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1ED0834EF9200C94B91 /* JackInternalClient.cpp */; };
-		4BA3398910B2E36800190E3B /* JackServer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D2210834F05C00C94B91 /* JackServer.cpp */; };
-		4BA3398E10B2E36800190E3B /* JackTransportEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */; };
-		4BA3398F10B2E36800190E3B /* JackServerAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1F50834EFB000C94B91 /* JackServerAPI.cpp */; };
-		4BA3399010B2E36800190E3B /* JackServerGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC216880A444BDE00BDA09F /* JackServerGlobals.cpp */; };
-		4BA3399110B2E36800190E3B /* timestamps.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF520520CB8D0E80037470E /* timestamps.c */; };
-		4BA3399210B2E36800190E3B /* JackPortType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */; };
-		4BA3399310B2E36800190E3B /* JackAudioPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */; };
-		4BA3399410B2E36800190E3B /* JackMidiPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */; };
-		4BA3399510B2E36800190E3B /* JackMidiAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */; };
-		4BA3399610B2E36800190E3B /* JackEngineControl.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */; };
-		4BA3399710B2E36800190E3B /* JackDebugClient.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B98AE000931D30C0091932A /* JackDebugClient.cpp */; };
-		4BA3399810B2E36800190E3B /* JackTools.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */; };
-		4BA3399910B2E36800190E3B /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222AD60DC88268001A17F4 /* JackNetTool.cpp */; };
-		4BA3399A10B2E36800190E3B /* JackError.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B9A25B30DBF8330006E9FBC /* JackError.cpp */; };
-		4BA3399B10B2E36800190E3B /* JackMessageBuffer.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */; };
-		4BA3399C10B2E36800190E3B /* JackRestartThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4CA9740E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp */; };
-		4BA3399D10B2E36800190E3B /* JackControlAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B4E9AF80E5F1090000A3278 /* JackControlAPI.cpp */; };
-		4BA3399E10B2E36800190E3B /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4BA3399F10B2E36800190E3B /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4BA339A010B2E36800190E3B /* JackEngineProfiling.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBAE40F0F42FA6100B8BD3F /* JackEngineProfiling.cpp */; };
-		4BA339A210B2E36800190E3B /* JackMidiDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF3391F0F8B873E0080FB5B /* JackMidiDriver.cpp */; };
-		4BA339A310B2E36800190E3B /* JackWaitThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBC93B80DF9736C002DF220 /* JackWaitThreadedDriver.cpp */; };
-		4BA339A410B2E36800190E3B /* JackArgParser.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF284160F31B4BC00B05BE3 /* JackArgParser.cpp */; };
-		4BA339A710B2E36800190E3B /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4BA4ADB40E87AB2500F26C85 /* JackCoreAudioDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE5FECB0E725C090020B576 /* JackCoreAudioDriver.cpp */; };
-		4BA4ADB50E87AB2600F26C85 /* JackCoreAudioDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE5FECC0E725C090020B576 /* JackCoreAudioDriver.h */; };
-		4BA692B30CBE4C2D00EAD520 /* ipload.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BA692B20CBE4C2D00EAD520 /* ipload.c */; };
-		4BA692D70CBE4CC600EAD520 /* ipunload.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BA692D60CBE4CC600EAD520 /* ipunload.c */; };
-		4BA7BE0F0DC232A400AA3457 /* Jackservermp.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */; };
-		4BA7BE1A0DC2347500AA3457 /* Jackservermp.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */; };
-		4BA7BE200DC234FB00AA3457 /* Jackservermp.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */; };
-		4BA7BE240DC2350D00AA3457 /* Jackservermp.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */; };
-		4BA7BE270DC2352A00AA3457 /* Jackservermp.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */; };
-		4BA7FECA0D8E76650017FF73 /* control.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BA7FEC80D8E76650017FF73 /* control.c */; };
-		4BAA150314F04FB600402512 /* JackAC3Encoder.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAA150114F04FB600402512 /* JackAC3Encoder.cpp */; };
-		4BAA150414F04FB600402512 /* JackAC3Encoder.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAA150214F04FB600402512 /* JackAC3Encoder.h */; };
-		4BAA150514F04FB600402512 /* JackAC3Encoder.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAA150114F04FB600402512 /* JackAC3Encoder.cpp */; };
-		4BAA150614F04FB600402512 /* JackAC3Encoder.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAA150214F04FB600402512 /* JackAC3Encoder.h */; };
-		4BAB95B80B9E20B800A0C723 /* JackPortType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */; };
-		4BAB95B90B9E20B800A0C723 /* JackPortType.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAB95B70B9E20B800A0C723 /* JackPortType.h */; };
-		4BAB95BA0B9E20B800A0C723 /* JackPortType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */; };
-		4BAB95BB0B9E20B800A0C723 /* JackPortType.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BAB95B70B9E20B800A0C723 /* JackPortType.h */; };
-		4BAB95ED0B9E21A500A0C723 /* JackAudioPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */; };
-		4BAB95EE0B9E21A500A0C723 /* JackAudioPort.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */; };
-		4BB4214B14D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BB4214C14D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */; };
-		4BB4214D14D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */; };
-		4BB4214E14D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BB4214F14D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */; };
-		4BB4215014D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */; };
-		4BB4215114D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BB4215214D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */; };
-		4BB4215314D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */; };
-		4BB4215414D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BB4215514D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */; };
-		4BB4215614D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */; };
-		4BB4215714D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BB4215814D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */; };
-		4BB4215914D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */; };
-		4BB4215A14D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BB4215B14D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */; };
-		4BB4215C14D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */; };
-		4BB9D4B30E2610B300351653 /* JackTransportEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */; };
-		4BB9D4B40E2610B400351653 /* JackTransportEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */; };
-		4BB9D4E40E26112900351653 /* JackEngineControl.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */; };
-		4BBAE4100F42FA6100B8BD3F /* JackEngineProfiling.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBAE40E0F42FA6100B8BD3F /* JackEngineProfiling.h */; };
-		4BBAE4110F42FA6100B8BD3F /* JackEngineProfiling.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBAE40F0F42FA6100B8BD3F /* JackEngineProfiling.cpp */; };
-		4BBAE4120F42FA6100B8BD3F /* JackEngineProfiling.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBAE40E0F42FA6100B8BD3F /* JackEngineProfiling.h */; };
-		4BBAE4130F42FA6100B8BD3F /* JackEngineProfiling.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBAE40F0F42FA6100B8BD3F /* JackEngineProfiling.cpp */; };
-		4BBB00D30E72614F0018AB1B /* JackPortAudioDevices.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBB00CF0E72614F0018AB1B /* JackPortAudioDevices.cpp */; };
-		4BBB00D40E72614F0018AB1B /* JackPortAudioDevices.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBB00D00E72614F0018AB1B /* JackPortAudioDevices.h */; };
-		4BBB00D50E72614F0018AB1B /* JackPortAudioDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBB00D10E72614F0018AB1B /* JackPortAudioDriver.cpp */; };
-		4BBB00D60E72614F0018AB1B /* JackPortAudioDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBB00D20E72614F0018AB1B /* JackPortAudioDriver.h */; };
-		4BBC93BA0DF9736C002DF220 /* JackWaitThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBC93B80DF9736C002DF220 /* JackWaitThreadedDriver.cpp */; };
-		4BBC93BB0DF9736C002DF220 /* JackWaitThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBC93B90DF9736C002DF220 /* JackWaitThreadedDriver.h */; };
-		4BC216850A444BAD00BDA09F /* JackServerAPI.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF8D1F50834EFB000C94B91 /* JackServerAPI.cpp */; };
-		4BC216890A444BDE00BDA09F /* JackServerGlobals.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC216880A444BDE00BDA09F /* JackServerGlobals.cpp */; };
-		4BC2168E0A444BED00BDA09F /* JackServerGlobals.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC2168D0A444BED00BDA09F /* JackServerGlobals.h */; };
-		4BC2CA55113C6C930076717C /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B76C7680E5AB2DB00E2AC21 /* JackNetInterface.cpp */; };
-		4BC2CA56113C6C940076717C /* JackNetInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B76C7690E5AB2DB00E2AC21 /* JackNetInterface.h */; };
-		4BC2CA57113C6C9B0076717C /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B90E703BCC0066E42F /* JackNetUnixSocket.cpp */; };
-		4BC2CA58113C6C9C0076717C /* JackNetUnixSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6BA0E703BCC0066E42F /* JackNetUnixSocket.h */; };
-		4BC2CA59113C6CB60076717C /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B76C7680E5AB2DB00E2AC21 /* JackNetInterface.cpp */; };
-		4BC2CA5A113C6CB80076717C /* JackNetInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B76C7690E5AB2DB00E2AC21 /* JackNetInterface.h */; };
-		4BC2CA5B113C6CBE0076717C /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B90E703BCC0066E42F /* JackNetUnixSocket.cpp */; };
-		4BC2CA5C113C6CC00076717C /* JackNetUnixSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6BA0E703BCC0066E42F /* JackNetUnixSocket.h */; };
-		4BC2CA5D113C6CC90076717C /* JackNetInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B76C7680E5AB2DB00E2AC21 /* JackNetInterface.cpp */; };
-		4BC2CA5E113C6CCA0076717C /* JackNetInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B76C7690E5AB2DB00E2AC21 /* JackNetInterface.h */; };
-		4BC2CA5F113C6CD10076717C /* JackNetUnixSocket.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6B90E703BCC0066E42F /* JackNetUnixSocket.cpp */; };
-		4BC2CA60113C6CD20076717C /* JackNetUnixSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6BA0E703BCC0066E42F /* JackNetUnixSocket.h */; };
-		4BC3B6A40E703B2E0066E42F /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4BC3B6A50E703B2E0066E42F /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */; };
-		4BC3B6A60E703B2E0066E42F /* JackPosixThread.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */; };
-		4BC3B6A70E703B2E0066E42F /* JackPosixThread.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */; };
-		4BCC87960D57168300A7FEB1 /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4BCC87970D57168300A7FEB1 /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4BCC87980D57168300A7FEB1 /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4BCC87990D57168300A7FEB1 /* Accelerate.framework in Frameworks */ = {isa = PBXBuildFile; fileRef = 4BCC87950D57168300A7FEB1 /* Accelerate.framework */; };
-		4BD4B4D809BACD9600750C0F /* JackTransportEngine.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */; };
-		4BD4B4D909BACD9600750C0F /* JackTransportEngine.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */; };
-		4BD6240D0CBCF16600DE782F /* inprocess.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BD6240C0CBCF16600DE782F /* inprocess.c */; };
-		4BDCDB951001FB9C00B15929 /* JackCoreMidiDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF339140F8B86DC0080FB5B /* JackCoreMidiDriver.h */; };
-		4BDCDB971001FB9C00B15929 /* JackCoreMidiDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF339150F8B86DC0080FB5B /* JackCoreMidiDriver.cpp */; };
-		4BDCDBB91001FCC000B15929 /* JackNetDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222ADD0DC882A5001A17F4 /* JackNetDriver.h */; };
-		4BDCDBBD1001FCC000B15929 /* JackNetDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222ADC0DC882A5001A17F4 /* JackNetDriver.cpp */; };
-		4BDCDBD11001FD0100B15929 /* JackWaitThreadedDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BBC93B80DF9736C002DF220 /* JackWaitThreadedDriver.cpp */; };
-		4BDCDBD21001FD0200B15929 /* JackWaitThreadedDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BBC93B90DF9736C002DF220 /* JackWaitThreadedDriver.h */; };
-		4BDCDBD91001FD2D00B15929 /* JackNetManager.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222AEC0DC883B3001A17F4 /* JackNetManager.h */; };
-		4BDCDBDE1001FD2D00B15929 /* JackNetManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222AEB0DC883B3001A17F4 /* JackNetManager.cpp */; };
-		4BDCDBEE1001FD7300B15929 /* JackAudioAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3070E2362E700DD4A82 /* JackAudioAdapter.h */; };
-		4BDCDBEF1001FD7300B15929 /* JackAudioAdapterInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */; };
-		4BDCDBF11001FD7300B15929 /* JackLibSampleRateResampler.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */; };
-		4BDCDBF21001FD7300B15929 /* JackCoreAudioAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE5FED00E725C320020B576 /* JackCoreAudioAdapter.h */; };
-		4BDCDBF41001FD7300B15929 /* JackAudioAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3060E2362E700DD4A82 /* JackAudioAdapter.cpp */; };
-		4BDCDBF51001FD7300B15929 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */; };
-		4BDCDBF61001FD7300B15929 /* JackLibSampleRateResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */; };
-		4BDCDBF71001FD7300B15929 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3120E2362E700DD4A82 /* JackResampler.cpp */; };
-		4BDCDBF81001FD7300B15929 /* JackAudioAdapterFactory.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF4BAB00E3480AB00403CDF /* JackAudioAdapterFactory.cpp */; };
-		4BDCDBF91001FD7300B15929 /* JackCoreAudioAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE5FECF0E725C320020B576 /* JackCoreAudioAdapter.cpp */; };
-		4BDCDC091001FDA800B15929 /* JackArgParser.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF284160F31B4BC00B05BE3 /* JackArgParser.cpp */; };
-		4BDCDC0A1001FDA800B15929 /* JackArgParser.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF284170F31B4BC00B05BE3 /* JackArgParser.h */; };
-		4BDCDC111001FDE300B15929 /* JackAudioAdapterInterface.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */; };
-		4BDCDC131001FDE300B15929 /* JackLibSampleRateResampler.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */; };
-		4BDCDC141001FDE300B15929 /* JackNetAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B5E08E00E5B676C00BEE4E0 /* JackNetAdapter.h */; };
-		4BDCDC161001FDE300B15929 /* JackAudioAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B19B3070E2362E700DD4A82 /* JackAudioAdapter.h */; };
-		4BDCDC191001FDE300B15929 /* JackAudioAdapterInterface.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */; };
-		4BDCDC1A1001FDE300B15929 /* JackLibSampleRateResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */; };
-		4BDCDC1B1001FDE300B15929 /* JackResampler.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3120E2362E700DD4A82 /* JackResampler.cpp */; };
-		4BDCDC1C1001FDE300B15929 /* JackNetAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B5E08DF0E5B676C00BEE4E0 /* JackNetAdapter.cpp */; };
-		4BDCDC1E1001FDE300B15929 /* JackAudioAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B19B3060E2362E700DD4A82 /* JackAudioAdapter.cpp */; };
-		4BE3225A0CC611EF00AFA640 /* types.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737F0CC60A6D001AFFD4 /* types.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BE3225B0CC611F500AFA640 /* types.h in Headers */ = {isa = PBXBuildFile; fileRef = 4B6C737F0CC60A6D001AFFD4 /* types.h */; settings = {ATTRIBUTES = (Public, ); }; };
-		4BE4CC010CDA153400CCF5BB /* JackTools.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */; };
-		4BE4CC020CDA153500CCF5BB /* JackTools.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE4CC000CDA153400CCF5BB /* JackTools.h */; };
-		4BE4CC030CDA153500CCF5BB /* JackTools.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */; };
-		4BE4CC040CDA153500CCF5BB /* JackTools.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE4CC000CDA153400CCF5BB /* JackTools.h */; };
-		4BE5FECD0E725C090020B576 /* JackCoreAudioDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE5FECB0E725C090020B576 /* JackCoreAudioDriver.cpp */; };
-		4BE5FECE0E725C090020B576 /* JackCoreAudioDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE5FECC0E725C090020B576 /* JackCoreAudioDriver.h */; };
-		4BE5FED10E725C320020B576 /* JackCoreAudioAdapter.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE5FECF0E725C320020B576 /* JackCoreAudioAdapter.cpp */; };
-		4BE5FED20E725C320020B576 /* JackCoreAudioAdapter.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BE5FED00E725C320020B576 /* JackCoreAudioAdapter.h */; };
-		4BE6C6AD0A3E0A65005A203A /* test.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BE6C6AC0A3E0A65005A203A /* test.cpp */; };
-		4BF1007C15135D8200B88F80 /* JackPosixMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4B327BA614B4B50400976483 /* JackPosixMutex.cpp */; };
-		4BF1007D15135D8800B88F80 /* JackPosixMutex.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */; };
-		4BF2841A0F31B4BC00B05BE3 /* JackArgParser.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF284160F31B4BC00B05BE3 /* JackArgParser.cpp */; };
-		4BF2841B0F31B4BC00B05BE3 /* JackArgParser.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF284170F31B4BC00B05BE3 /* JackArgParser.h */; };
-		4BF3391A0F8B86DC0080FB5B /* JackCoreMidiDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF339140F8B86DC0080FB5B /* JackCoreMidiDriver.h */; };
-		4BF3391B0F8B86DC0080FB5B /* JackCoreMidiDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF339150F8B86DC0080FB5B /* JackCoreMidiDriver.cpp */; };
-		4BF339210F8B873E0080FB5B /* JackMidiDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF3391F0F8B873E0080FB5B /* JackMidiDriver.cpp */; };
-		4BF339220F8B873E0080FB5B /* JackMidiDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF339200F8B873E0080FB5B /* JackMidiDriver.h */; };
-		4BF339230F8B873E0080FB5B /* JackMidiDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF3391F0F8B873E0080FB5B /* JackMidiDriver.cpp */; };
-		4BF339240F8B873E0080FB5B /* JackMidiDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF339200F8B873E0080FB5B /* JackMidiDriver.h */; };
-		4BF4BAB10E3480AB00403CDF /* JackAudioAdapterFactory.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF4BAB00E3480AB00403CDF /* JackAudioAdapterFactory.cpp */; };
-		4BF520530CB8D0E80037470E /* timestamps.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF520520CB8D0E80037470E /* timestamps.c */; };
-		4BF520540CB8D0E80037470E /* timestamps.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF520520CB8D0E80037470E /* timestamps.c */; };
-		4BF520590CB8D1010037470E /* timestamps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF520580CB8D1010037470E /* timestamps.h */; settings = {ATTRIBUTES = (); }; };
-		4BF5205A0CB8D1010037470E /* timestamps.h in Headers */ = {isa = PBXBuildFile; fileRef = 4BF520580CB8D1010037470E /* timestamps.h */; settings = {ATTRIBUTES = (); }; };
-		4BF5FBBC0E878B9C003D2374 /* JackPosixServerLaunch.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBBA0E878B9C003D2374 /* JackPosixServerLaunch.cpp */; };
-		4BF5FBCA0E878D24003D2374 /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4BF5FBCB0E878D24003D2374 /* JackMachTime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4BF5FBC80E878D24003D2374 /* JackMachTime.c */; };
-		4BFA5E9F0DEC4DD900FA4CDB /* testMutex.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 4BFA5E9E0DEC4DD900FA4CDB /* testMutex.cpp */; };
-		4BFA82850DF6A9E40087B4E1 /* evmon.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363E200DEB0401001F72D9 /* evmon.c */; };
-		4BFA82980DF6A9E40087B4E1 /* bufsize.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363E710DEB0808001F72D9 /* bufsize.c */; };
-		4BFA82A40DF6A9E40087B4E1 /* capture_client.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363EED0DEB094B001F72D9 /* capture_client.c */; };
-		4BFA82B00DF6A9E40087B4E1 /* monitor_client.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363F220DEB0AB0001F72D9 /* monitor_client.c */; };
-		4BFA82BC0DF6A9E40087B4E1 /* showtime.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363F3D0DEB0C31001F72D9 /* showtime.c */; };
-		4BFA82C80DF6A9E40087B4E1 /* impulse_grabber.c in Sources */ = {isa = PBXBuildFile; fileRef = 4B363F750DEB0D7D001F72D9 /* impulse_grabber.c */; };
-		BA047C760E14E79D0041F3B6 /* JackNetSocket.h in Headers */ = {isa = PBXBuildFile; fileRef = BA047C710E14E7540041F3B6 /* JackNetSocket.h */; };
-		BA222AD80DC88268001A17F4 /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222AD60DC88268001A17F4 /* JackNetTool.cpp */; };
-		BA222AD90DC88269001A17F4 /* JackNetTool.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222AD70DC88268001A17F4 /* JackNetTool.h */; };
-		BA222ADA0DC88269001A17F4 /* JackNetTool.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222AD60DC88268001A17F4 /* JackNetTool.cpp */; };
-		BA222ADB0DC88269001A17F4 /* JackNetTool.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222AD70DC88268001A17F4 /* JackNetTool.h */; };
-		BA222ADE0DC882A5001A17F4 /* JackNetDriver.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222ADC0DC882A5001A17F4 /* JackNetDriver.cpp */; };
-		BA222ADF0DC882A5001A17F4 /* JackNetDriver.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222ADD0DC882A5001A17F4 /* JackNetDriver.h */; };
-		BA222AED0DC883B3001A17F4 /* JackNetManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = BA222AEB0DC883B3001A17F4 /* JackNetManager.cpp */; };
-		BA222AEE0DC883B3001A17F4 /* JackNetManager.h in Headers */ = {isa = PBXBuildFile; fileRef = BA222AEC0DC883B3001A17F4 /* JackNetManager.h */; };
-/* End PBXBuildFile section */
-
-/* Begin PBXContainerItemProxy section */
-		4B0A28F30D520D11002EFF74 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B0A28DC0D52073D002EFF74;
-			remoteInfo = jack_thread_wait;
-		};
-		4B0A292F0D5210C4002EFF74 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B0A29230D52108E002EFF74;
-			remoteInfo = "jack_thread_wait 64 bits";
-		};
-		4B19B32B0E23636E00DD4A82 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B19B2F60E23620F00DD4A82;
-			remoteInfo = audioadapter;
-		};
-		4B20220B133A9C370019E213 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B2021DC133A9BA40019E213;
-			remoteInfo = "jack_midi_latency 64 bits";
-		};
-		4B224B330E65BA330066BE5B /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B5E08BF0E5B66EE00BEE4E0;
-			remoteInfo = netadapter;
-		};
-		4B3224E610A3157900838A8E /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B3224D710A3156800838A8E;
-			remoteInfo = "jack_netone Universal";
-		};
-		4B32258A10A31A9000838A8E /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B32255710A3187800838A8E;
-			remoteInfo = "jack_netsource Universal";
-		};
-		4B32258C10A31A9D00838A8E /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B3224D710A3156800838A8E;
-			remoteInfo = "jack_netone Universal";
-		};
-		4B32258E10A31AB400838A8E /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B32257110A3190C00838A8E;
-			remoteInfo = "jack_netsource 64 bits";
-		};
-		4B32259010A31ABA00838A8E /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B32251D10A316B200838A8E;
-			remoteInfo = "jack_netone 64 bits";
-		};
-		4B35C5540D4731D2000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699D03097D421600A18468;
-			remoteInfo = "jack_external_metro Universal";
-		};
-		4B35C67D0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C41B0D4731D1000DE7AE;
-			remoteInfo = "jackdmp framework 64bits";
-		};
-		4B35C67F0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C4270D4731D1000DE7AE;
-			remoteInfo = "Jackmp.framework 64 bits";
-		};
-		4B35C6810D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C4850D4731D1000DE7AE;
-			remoteInfo = "Jackdmp.framework 64 bits";
-		};
-		4B35C6850D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C50A0D4731D1000DE7AE;
-			remoteInfo = "jack_midiseq 64 bits";
-		};
-		4B35C6870D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5160D4731D1000DE7AE;
-			remoteInfo = "jack_midisine 64 bits";
-		};
-		4B35C6890D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5220D4731D1000DE7AE;
-			remoteInfo = "jack_metro 64 bits";
-		};
-		4B35C68B0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C52E0D4731D1000DE7AE;
-			remoteInfo = "jack_lsp 64 bits";
-		};
-		4B35C68D0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C53A0D4731D1000DE7AE;
-			remoteInfo = "jack_connect 64 bits";
-		};
-		4B35C68F0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5460D4731D1000DE7AE;
-			remoteInfo = "jack_disconnect 64 bits";
-		};
-		4B35C6910D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5520D4731D2000DE7AE;
-			remoteInfo = "jack_freewheel 64 bits";
-		};
-		4B35C6930D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5600D4731D2000DE7AE;
-			remoteInfo = "jdelay 64 bits";
-		};
-		4B35C6950D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C56C0D4731D2000DE7AE;
-			remoteInfo = "jack_external_metro 64 bits";
-		};
-		4B35C69B0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C59C0D4731D2000DE7AE;
-			remoteInfo = "zombie 64 bits";
-		};
-		4B35C69D0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5A80D4731D2000DE7AE;
-			remoteInfo = "jack_test 64 bits";
-		};
-		4B35C69F0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5B40D4731D2000DE7AE;
-			remoteInfo = "jack_cpu 64 bits";
-		};
-		4B35C6A10D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5C00D4731D2000DE7AE;
-			remoteInfo = "jack_load 64 bits";
-		};
-		4B35C6A30D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C5CC0D4731D2000DE7AE;
-			remoteInfo = "jack_unload 64 bits";
-		};
-		4B35C6AB0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C6140D4731D2000DE7AE;
-			remoteInfo = "jack_coreaudio 64 bits";
-		};
-		4B35C6AF0D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C62A0D4731D2000DE7AE;
-			remoteInfo = "jack_dummy 64 bits";
-		};
-		4B35C6B10D4733B9000DE7AE /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C6350D4731D3000DE7AE;
-			remoteInfo = "inprocess 64 bits";
-		};
-		4B363DE40DEB037F001F72D9 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B363DCE0DEB02F6001F72D9;
-			remoteInfo = "jack_alias Universal";
-		};
-		4B363E740DEB0838001F72D9 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B363E100DEB03C5001F72D9;
-			remoteInfo = "jack_evmon Universal";
-		};
-		4B363E760DEB0838001F72D9 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B363E440DEB0775001F72D9;
-			remoteInfo = "jack_bufsize Universal";
-		};
-		4B363F240DEB0ABE001F72D9 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B363F140DEB0A6A001F72D9;
-			remoteInfo = "jack_monitor_client Universal";
-		};
-		4B363F520DEB0CFE001F72D9 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B363F2B0DEB0BD1001F72D9;
-			remoteInfo = "jack_showtime Universal";
-		};
-		4B363F770DEB0D85001F72D9 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B363F680DEB0D4E001F72D9;
-			remoteInfo = "jack_impulse_grabber Universal";
-		};
-		4B38120013269CB600C61B14 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B3811551326878E00C61B14;
-			remoteInfo = "jack_latent_client Universal";
-		};
-		4B38120213269CCB00C61B14 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B38118D1326884E00C61B14;
-			remoteInfo = "jack_latent_client 64 bits";
-		};
-		4B43A8CC1014607100E52943 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B43A8B010145F6F00E52943;
-			remoteInfo = "jack_loopback Universal";
-		};
-		4B43A8E81014618D00E52943 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B43A8DD1014615800E52943;
-			remoteInfo = "jack_loopback 64 bits";
-		};
-		4B5A1BCE0CD1CCC80005BF74 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B5A1BB10CD1CB9E0005BF74;
-			remoteInfo = jack_midiseq;
-		};
-		4B5A1BE10CD1CD730005BF74 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B5A1BD00CD1CCE10005BF74;
-			remoteInfo = jack_midisine;
-		};
-		4B66550D127C356E00753A79 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B6654ED127C34AE00753A79;
-			remoteInfo = "jack_server_control 64 bits";
-		};
-		4B699DB3097D421700A18468 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699C4C097D421600A18468;
-			remoteInfo = "Jackdmp.framework Universal";
-		};
-		4B699DB5097D421700A18468 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699C00097D421600A18468;
-			remoteInfo = "Jackmp.framework Universal";
-		};
-		4B699DB7097D421700A18468 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699BA7097D421600A18468;
-			remoteInfo = "jackdmp framework Universal";
-		};
-		4B699DB9097D421700A18468 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699D97097D421700A18468;
-			remoteInfo = "jack_coreaudio Universal";
-		};
-		4B699DBB097D421700A18468 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699DA6097D421700A18468;
-			remoteInfo = "jack_dummy Universal";
-		};
-		4B699DBF097D421700A18468 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699D03097D421600A18468;
-			remoteInfo = "jack_external_metro Universal";
-		};
-		4B8F16F9132916910002AD73 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B8F16DB13290DC80002AD73;
-			remoteInfo = "jack_midi_dump Universal";
-		};
-		4B8F16FB1329169F0002AD73 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B8F16E813290E0E0002AD73;
-			remoteInfo = "jack_midi_dump 64 bits";
-		};
-		4BA693E80CBE5BBA00EAD520 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BA692A60CBE4BC700EAD520;
-			remoteInfo = "jack_load Universal";
-		};
-		4BA693EA0CBE5BBA00EAD520 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BA692CA0CBE4C9000EAD520;
-			remoteInfo = "jack_unload Universal";
-		};
-		4BA7FECC0D8E76810017FF73 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BA7FEB90D8E76270017FF73;
-			remoteInfo = "jack_control Universal";
-		};
-		4BAA1A7514CA08FE003269AD /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B35C61F0D4731D2000DE7AE;
-			remoteInfo = "jack_portaudio 64 bits";
-		};
-		4BB492A61372A393005F2601 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B8692821371DB4700D2D11B;
-			remoteInfo = "Jacknet.framework 64 bits";
-		};
-		4BD624D20CBCF55700DE782F /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BD623ED0CBCF0F000DE782F;
-			remoteInfo = inprocess;
-		};
-		4BDCDC2B1002036100B15929 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BDCDB931001FB9C00B15929;
-			remoteInfo = "jack_coremidi 64 bits";
-		};
-		4BDCDC2D1002036100B15929 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BDCDBB71001FCC000B15929;
-			remoteInfo = "jack_net 64 bits";
-		};
-		4BDCDC2F1002036100B15929 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BDCDBD71001FD2D00B15929;
-			remoteInfo = "netmanager 64 bits";
-		};
-		4BDCDC38100203D500B15929 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BDCDBEC1001FD7300B15929;
-			remoteInfo = "audioadapter 64 bits";
-		};
-		4BDCDC3A100203D500B15929 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BDCDC0F1001FDE300B15929;
-			remoteInfo = "netadapter 64 bits";
-		};
-		4BE99D620AD7A19100C59091 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BE99D260AD7A04800C59091;
-			remoteInfo = "jack_cpu Universal";
-		};
-		4BF339270F8B87800080FB5B /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BF339020F8B864B0080FB5B;
-			remoteInfo = jack_coremidi;
-		};
-		4BFA83310DF6AB540087B4E1 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BFA82820DF6A9E40087B4E1;
-			remoteInfo = "jack_evmon 64 bits";
-		};
-		4BFA83330DF6AB540087B4E1 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BFA82950DF6A9E40087B4E1;
-			remoteInfo = "jack_bufsize 64 bits";
-		};
-		4BFA83370DF6AB540087B4E1 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BFA82AD0DF6A9E40087B4E1;
-			remoteInfo = "jack_monitor_client 64 bits";
-		};
-		4BFA83390DF6AB540087B4E1 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BFA82B90DF6A9E40087B4E1;
-			remoteInfo = "jack_showtime 64 bits";
-		};
-		4BFA833B0DF6AB540087B4E1 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BFA82C50DF6A9E40087B4E1;
-			remoteInfo = "jack_impulse_grabber 64 bits";
-		};
-		4BFA99430AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699CB1097D421600A18468;
-			remoteInfo = "jack_metro Universal";
-		};
-		4BFA99450AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699CC1097D421600A18468;
-			remoteInfo = "jack_lsp Universal";
-		};
-		4BFA99470AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699CD1097D421600A18468;
-			remoteInfo = "jack_connect Universal";
-		};
-		4BFA99490AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699CE1097D421600A18468;
-			remoteInfo = "jack_disconnect Universal";
-		};
-		4BFA994B0AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699CF1097D421600A18468;
-			remoteInfo = "jack_freewheel Universal";
-		};
-		4BFA994D0AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699D03097D421600A18468;
-			remoteInfo = "jack_external_metro Universal";
-		};
-		4BFA99530AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4B699D3F097D421600A18468;
-			remoteInfo = "zombie Universal";
-		};
-		4BFA99550AAAED90009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BE6C6910A3E096F005A203A;
-			remoteInfo = "jack_test Universal";
-		};
-		4BFA99AB0AAAF41D009E916C /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = 4BFA99980AAAF3B0009E916C;
-			remoteInfo = "jdelay Universal";
-		};
-		BA222AEF0DC883EF001A17F4 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = BA222AE00DC882DB001A17F4;
-			remoteInfo = netmanager;
-		};
-		BA222AF10DC883F3001A17F4 /* PBXContainerItemProxy */ = {
-			isa = PBXContainerItemProxy;
-			containerPortal = 08FB7793FE84155DC02AAC07 /* Project object */;
-			proxyType = 1;
-			remoteGlobalIDString = BA222AC50DC88132001A17F4;
-			remoteInfo = "jack_net Universal";
-		};
-/* End PBXContainerItemProxy section */
-
-/* Begin PBXFileReference section */
-		4B003AB008E2B2BA0060EFDC /* ringbuffer.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = ringbuffer.c; path = ../common/ringbuffer.c; sourceTree = SOURCE_ROOT; };
-		4B05A04D0DF72BC000840F4C /* alsa_driver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = alsa_driver.h; path = ../linux/alsa/alsa_driver.h; sourceTree = SOURCE_ROOT; };
-		4B05A04E0DF72BC000840F4C /* alsa_midi.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = alsa_midi.h; path = ../linux/alsa/alsa_midi.h; sourceTree = SOURCE_ROOT; };
-		4B05A04F0DF72BC000840F4C /* alsa_midi_impl.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = alsa_midi_impl.h; path = ../linux/alsa/alsa_midi_impl.h; sourceTree = SOURCE_ROOT; };
-		4B05A0500DF72BC000840F4C /* alsa_midi_jackmp.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = alsa_midi_jackmp.cpp; path = ../linux/alsa/alsa_midi_jackmp.cpp; sourceTree = SOURCE_ROOT; };
-		4B05A0510DF72BC000840F4C /* alsa_rawmidi.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = alsa_rawmidi.c; path = ../linux/alsa/alsa_rawmidi.c; sourceTree = SOURCE_ROOT; };
-		4B05A0520DF72BC000840F4C /* alsa_seqmidi.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = alsa_seqmidi.c; path = ../linux/alsa/alsa_seqmidi.c; sourceTree = SOURCE_ROOT; };
-		4B05A0530DF72BC000840F4C /* bitset.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = bitset.h; path = ../linux/alsa/bitset.h; sourceTree = SOURCE_ROOT; };
-		4B05A0540DF72BC000840F4C /* generic.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = generic.h; path = ../linux/alsa/generic.h; sourceTree = SOURCE_ROOT; };
-		4B05A0550DF72BC000840F4C /* generic_hw.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = generic_hw.c; path = ../linux/alsa/generic_hw.c; sourceTree = SOURCE_ROOT; };
-		4B05A0560DF72BC000840F4C /* hammerfall.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = hammerfall.c; path = ../linux/alsa/hammerfall.c; sourceTree = SOURCE_ROOT; };
-		4B05A0570DF72BC000840F4C /* hammerfall.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = hammerfall.h; path = ../linux/alsa/hammerfall.h; sourceTree = SOURCE_ROOT; };
-		4B05A0580DF72BC000840F4C /* hardware.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = hardware.h; path = ../linux/alsa/hardware.h; sourceTree = SOURCE_ROOT; };
-		4B05A0590DF72BC000840F4C /* hdsp.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = hdsp.c; path = ../linux/alsa/hdsp.c; sourceTree = SOURCE_ROOT; };
-		4B05A05A0DF72BC000840F4C /* hdsp.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = hdsp.h; path = ../linux/alsa/hdsp.h; sourceTree = SOURCE_ROOT; };
-		4B05A05B0DF72BC000840F4C /* ice1712.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = ice1712.c; path = ../linux/alsa/ice1712.c; sourceTree = SOURCE_ROOT; };
-		4B05A05C0DF72BC000840F4C /* ice1712.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = ice1712.h; path = ../linux/alsa/ice1712.h; sourceTree = SOURCE_ROOT; };
-		4B05A05D0DF72BC000840F4C /* JackAlsaDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackAlsaDriver.cpp; path = ../linux/alsa/JackAlsaDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B05A05E0DF72BC000840F4C /* JackAlsaDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackAlsaDriver.h; path = ../linux/alsa/JackAlsaDriver.h; sourceTree = SOURCE_ROOT; };
-		4B05A05F0DF72BC000840F4C /* jslist.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = jslist.h; path = ../linux/alsa/jslist.h; sourceTree = SOURCE_ROOT; };
-		4B05A0620DF72BC000840F4C /* midi_pack.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = midi_pack.h; path = ../linux/alsa/midi_pack.h; sourceTree = SOURCE_ROOT; };
-		4B05A0630DF72BC000840F4C /* midi_unpack.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = midi_unpack.h; path = ../linux/alsa/midi_unpack.h; sourceTree = SOURCE_ROOT; };
-		4B05A0640DF72BC000840F4C /* usx2y.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = usx2y.c; path = ../linux/alsa/usx2y.c; sourceTree = SOURCE_ROOT; };
-		4B05A0650DF72BC000840F4C /* usx2y.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = usx2y.h; path = ../linux/alsa/usx2y.h; sourceTree = SOURCE_ROOT; };
-		4B05A07D0DF72BC000840F4C /* driver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = driver.h; path = ../linux/driver.h; sourceTree = SOURCE_ROOT; };
-		4B0A28E60D52073D002EFF74 /* jack_thread_wait */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_thread_wait; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B0A28EC0D520852002EFF74 /* tw.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = tw.c; path = "../example-clients/tw.c"; sourceTree = SOURCE_ROOT; };
-		4B0A292D0D52108E002EFF74 /* jack_thread_wait */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_thread_wait; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackGenericClientChannel.cpp; path = ../common/JackGenericClientChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackGenericClientChannel.h; path = ../common/JackGenericClientChannel.h; sourceTree = SOURCE_ROOT; };
-		4B193931133F311400547810 /* JackMidiAsyncQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiAsyncQueue.cpp; path = ../common/JackMidiAsyncQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B193932133F311400547810 /* JackMidiAsyncQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiAsyncQueue.h; path = ../common/JackMidiAsyncQueue.h; sourceTree = SOURCE_ROOT; };
-		4B19393B133F313000547810 /* JackMidiAsyncWaitQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiAsyncWaitQueue.cpp; path = ../common/JackMidiAsyncWaitQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B19393C133F313000547810 /* JackMidiAsyncWaitQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiAsyncWaitQueue.h; path = ../common/JackMidiAsyncWaitQueue.h; sourceTree = SOURCE_ROOT; };
-		4B193945133F315200547810 /* JackMidiReadQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiReadQueue.cpp; path = ../common/JackMidiReadQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B193946133F315200547810 /* JackMidiReadQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiReadQueue.h; path = ../common/JackMidiReadQueue.h; sourceTree = SOURCE_ROOT; };
-		4B19395D133F317300547810 /* JackMidiBufferReadQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiBufferReadQueue.cpp; path = ../common/JackMidiBufferReadQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B19395E133F317300547810 /* JackMidiBufferReadQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiBufferReadQueue.h; path = ../common/JackMidiBufferReadQueue.h; sourceTree = SOURCE_ROOT; };
-		4B193968133F319000547810 /* JackMidiBufferWriteQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiBufferWriteQueue.cpp; path = ../common/JackMidiBufferWriteQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B193969133F319000547810 /* JackMidiBufferWriteQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiBufferWriteQueue.h; path = ../common/JackMidiBufferWriteQueue.h; sourceTree = SOURCE_ROOT; };
-		4B193973133F31CB00547810 /* JackMidiReceiveQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiReceiveQueue.cpp; path = ../common/JackMidiReceiveQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B193974133F31CB00547810 /* JackMidiReceiveQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiReceiveQueue.h; path = ../common/JackMidiReceiveQueue.h; sourceTree = SOURCE_ROOT; };
-		4B193975133F31CB00547810 /* JackMidiSendQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiSendQueue.cpp; path = ../common/JackMidiSendQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B193976133F31CB00547810 /* JackMidiSendQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiSendQueue.h; path = ../common/JackMidiSendQueue.h; sourceTree = SOURCE_ROOT; };
-		4B193977133F31CB00547810 /* JackMidiUtil.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiUtil.cpp; path = ../common/JackMidiUtil.cpp; sourceTree = SOURCE_ROOT; };
-		4B193978133F31CB00547810 /* JackMidiUtil.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiUtil.h; path = ../common/JackMidiUtil.h; sourceTree = SOURCE_ROOT; };
-		4B193979133F31CB00547810 /* JackMidiWriteQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiWriteQueue.cpp; path = ../common/JackMidiWriteQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B19397A133F31CB00547810 /* JackMidiWriteQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiWriteQueue.h; path = ../common/JackMidiWriteQueue.h; sourceTree = SOURCE_ROOT; };
-		4B193990133F321500547810 /* JackFilters.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackFilters.h; path = ../common/JackFilters.h; sourceTree = SOURCE_ROOT; };
-		4B19B3000E23620F00DD4A82 /* audioadapter.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = audioadapter.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B19B3060E2362E700DD4A82 /* JackAudioAdapter.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackAudioAdapter.cpp; path = ../common/JackAudioAdapter.cpp; sourceTree = SOURCE_ROOT; };
-		4B19B3070E2362E700DD4A82 /* JackAudioAdapter.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackAudioAdapter.h; path = ../common/JackAudioAdapter.h; sourceTree = SOURCE_ROOT; };
-		4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackAudioAdapterInterface.cpp; path = ../common/JackAudioAdapterInterface.cpp; sourceTree = SOURCE_ROOT; };
-		4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackAudioAdapterInterface.h; path = ../common/JackAudioAdapterInterface.h; sourceTree = SOURCE_ROOT; };
-		4B19B30C0E2362E700DD4A82 /* JackException.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackException.h; path = ../common/JackException.h; sourceTree = SOURCE_ROOT; };
-		4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackLibSampleRateResampler.cpp; path = ../common/JackLibSampleRateResampler.cpp; sourceTree = SOURCE_ROOT; };
-		4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackLibSampleRateResampler.h; path = ../common/JackLibSampleRateResampler.h; sourceTree = SOURCE_ROOT; };
-		4B19B3120E2362E700DD4A82 /* JackResampler.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackResampler.cpp; path = ../common/JackResampler.cpp; sourceTree = SOURCE_ROOT; };
-		4B2021E6133A9BA40019E213 /* jack_midi_latency_test */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midi_latency_test; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B202209133A9C1C0019E213 /* midi_latency_test.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = midi_latency_test.c; path = "../example-clients/midi_latency_test.c"; sourceTree = SOURCE_ROOT; };
-		4B21794D13E2EEA60095B3E5 /* JackTimedDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackTimedDriver.cpp; path = ../common/JackTimedDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B21794E13E2EEA60095B3E5 /* JackTimedDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackTimedDriver.h; path = ../common/JackTimedDriver.h; sourceTree = SOURCE_ROOT; };
-		4B2C28F908DAD01E00249230 /* JackGlobals.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackGlobals.cpp; path = ../common/JackGlobals.cpp; sourceTree = SOURCE_ROOT; };
-		4B3224E510A3156800838A8E /* jack_netone.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_netone.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B3224E810A315B100838A8E /* JackNetOneDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetOneDriver.cpp; path = ../common/JackNetOneDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B3224E910A315B100838A8E /* JackNetOneDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackNetOneDriver.h; path = ../common/JackNetOneDriver.h; sourceTree = SOURCE_ROOT; };
-		4B3224EC10A315C400838A8E /* netjack_packet.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = netjack_packet.c; path = ../common/netjack_packet.c; sourceTree = SOURCE_ROOT; };
-		4B3224ED10A315C400838A8E /* netjack_packet.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = netjack_packet.h; path = ../common/netjack_packet.h; sourceTree = SOURCE_ROOT; };
-		4B3224EE10A315C400838A8E /* netjack.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = netjack.c; path = ../common/netjack.c; sourceTree = SOURCE_ROOT; };
-		4B3224EF10A315C400838A8E /* netjack.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = netjack.h; path = ../common/netjack.h; sourceTree = SOURCE_ROOT; };
-		4B32252B10A316B200838A8E /* jack_netone.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_netone.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B32256110A3187800838A8E /* jack_netsource */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_netsource; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B32256310A318E300838A8E /* netsource.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = netsource.c; path = "../example-clients/netsource.c"; sourceTree = SOURCE_ROOT; };
-		4B32257B10A3190C00838A8E /* jack_netsource */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_netsource; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B327BA614B4B50400976483 /* JackPosixMutex.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPosixMutex.cpp; path = ../posix/JackPosixMutex.cpp; sourceTree = SOURCE_ROOT; };
-		4B349826133A6AF500D130AB /* JackALSARawMidiDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackALSARawMidiDriver.cpp; path = ../linux/alsarawmidi/JackALSARawMidiDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B349827133A6AF500D130AB /* JackALSARawMidiDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackALSARawMidiDriver.h; path = ../linux/alsarawmidi/JackALSARawMidiDriver.h; sourceTree = SOURCE_ROOT; };
-		4B349828133A6AF500D130AB /* JackALSARawMidiInputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackALSARawMidiInputPort.cpp; path = ../linux/alsarawmidi/JackALSARawMidiInputPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B349829133A6AF500D130AB /* JackALSARawMidiInputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackALSARawMidiInputPort.h; path = ../linux/alsarawmidi/JackALSARawMidiInputPort.h; sourceTree = SOURCE_ROOT; };
-		4B34982A133A6AF500D130AB /* JackALSARawMidiOutputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackALSARawMidiOutputPort.cpp; path = ../linux/alsarawmidi/JackALSARawMidiOutputPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B34982B133A6AF500D130AB /* JackALSARawMidiOutputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackALSARawMidiOutputPort.h; path = ../linux/alsarawmidi/JackALSARawMidiOutputPort.h; sourceTree = SOURCE_ROOT; };
-		4B34982C133A6AF500D130AB /* JackALSARawMidiPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackALSARawMidiPort.cpp; path = ../linux/alsarawmidi/JackALSARawMidiPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B34982D133A6AF500D130AB /* JackALSARawMidiPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackALSARawMidiPort.h; path = ../linux/alsarawmidi/JackALSARawMidiPort.h; sourceTree = SOURCE_ROOT; };
-		4B34982E133A6AF500D130AB /* JackALSARawMidiReceiveQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackALSARawMidiReceiveQueue.cpp; path = ../linux/alsarawmidi/JackALSARawMidiReceiveQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B34982F133A6AF500D130AB /* JackALSARawMidiReceiveQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackALSARawMidiReceiveQueue.h; path = ../linux/alsarawmidi/JackALSARawMidiReceiveQueue.h; sourceTree = SOURCE_ROOT; };
-		4B349830133A6AF500D130AB /* JackALSARawMidiSendQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackALSARawMidiSendQueue.cpp; path = ../linux/alsarawmidi/JackALSARawMidiSendQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B349831133A6AF500D130AB /* JackALSARawMidiSendQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackALSARawMidiSendQueue.h; path = ../linux/alsarawmidi/JackALSARawMidiSendQueue.h; sourceTree = SOURCE_ROOT; };
-		4B349838133A6B6F00D130AB /* ffado_driver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = ffado_driver.h; path = ../linux/firewire/ffado_driver.h; sourceTree = SOURCE_ROOT; };
-		4B349839133A6B6F00D130AB /* JackFFADODriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackFFADODriver.cpp; path = ../linux/firewire/JackFFADODriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B34983A133A6B6F00D130AB /* JackFFADODriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackFFADODriver.h; path = ../linux/firewire/JackFFADODriver.h; sourceTree = SOURCE_ROOT; };
-		4B34983B133A6B6F00D130AB /* JackFFADOMidiInputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackFFADOMidiInputPort.cpp; path = ../linux/firewire/JackFFADOMidiInputPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B34983C133A6B6F00D130AB /* JackFFADOMidiInputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackFFADOMidiInputPort.h; path = ../linux/firewire/JackFFADOMidiInputPort.h; sourceTree = SOURCE_ROOT; };
-		4B34983D133A6B6F00D130AB /* JackFFADOMidiOutputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackFFADOMidiOutputPort.cpp; path = ../linux/firewire/JackFFADOMidiOutputPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B34983E133A6B6F00D130AB /* JackFFADOMidiOutputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackFFADOMidiOutputPort.h; path = ../linux/firewire/JackFFADOMidiOutputPort.h; sourceTree = SOURCE_ROOT; };
-		4B34983F133A6B6F00D130AB /* JackFFADOMidiReceiveQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackFFADOMidiReceiveQueue.cpp; path = ../linux/firewire/JackFFADOMidiReceiveQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B349840133A6B6F00D130AB /* JackFFADOMidiReceiveQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackFFADOMidiReceiveQueue.h; path = ../linux/firewire/JackFFADOMidiReceiveQueue.h; sourceTree = SOURCE_ROOT; };
-		4B349841133A6B6F00D130AB /* JackFFADOMidiSendQueue.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackFFADOMidiSendQueue.cpp; path = ../linux/firewire/JackFFADOMidiSendQueue.cpp; sourceTree = SOURCE_ROOT; };
-		4B349842133A6B6F00D130AB /* JackFFADOMidiSendQueue.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackFFADOMidiSendQueue.h; path = ../linux/firewire/JackFFADOMidiSendQueue.h; sourceTree = SOURCE_ROOT; };
-		4B35C4250D4731D1000DE7AE /* jackdmp */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jackdmp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C4830D4731D1000DE7AE /* Jackmp.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jackmp.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jackservermp.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5140D4731D1000DE7AE /* jack_midiseq */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midiseq; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5200D4731D1000DE7AE /* jack_midisine */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midisine; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C52C0D4731D1000DE7AE /* jack_metro */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_metro; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5380D4731D1000DE7AE /* jack_lsp */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_lsp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5440D4731D1000DE7AE /* jack_connect */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_connect; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5500D4731D1000DE7AE /* jack_disconnect */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_disconnect; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C55E0D4731D2000DE7AE /* jack_freewheel */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_freewheel; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C56A0D4731D2000DE7AE /* jack_iodelay */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_iodelay; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5760D4731D2000DE7AE /* jack_external_metro */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_external_metro; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5860D4731D2000DE7AE /* testAtomic */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = testAtomic; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C59A0D4731D2000DE7AE /* testSem */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = testSem; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5A60D4731D2000DE7AE /* zombie */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = zombie; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5B20D4731D2000DE7AE /* jack_test */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_test; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5BE0D4731D2000DE7AE /* jack_cpu */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_cpu; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5CA0D4731D2000DE7AE /* jack_load */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_load; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5D60D4731D2000DE7AE /* jack_unload */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_unload; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5EA0D4731D2000DE7AE /* synchroServer */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = synchroServer; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C5FE0D4731D2000DE7AE /* synchroClient */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = synchroClient; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C6120D4731D2000DE7AE /* synchroServerClient */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = synchroServerClient; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C61E0D4731D2000DE7AE /* jack_coreaudio.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_coreaudio.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C6290D4731D2000DE7AE /* jack_portaudio.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_portaudio.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C6340D4731D2000DE7AE /* jack_dummy.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_dummy.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B35C63E0D4731D3000DE7AE /* inprocess.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = inprocess.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363DD80DEB02F6001F72D9 /* jack_alias */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_alias; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363DDE0DEB034E001F72D9 /* alias.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = alias.c; path = "../example-clients/alias.c"; sourceTree = SOURCE_ROOT; };
-		4B363E1A0DEB03C5001F72D9 /* jack_evmon */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_evmon; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363E200DEB0401001F72D9 /* evmon.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = evmon.c; path = "../example-clients/evmon.c"; sourceTree = SOURCE_ROOT; };
-		4B363E4E0DEB0775001F72D9 /* jack_bufsize */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_bufsize; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363E710DEB0808001F72D9 /* bufsize.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = bufsize.c; path = "../example-clients/bufsize.c"; sourceTree = SOURCE_ROOT; };
-		4B363EE90DEB091C001F72D9 /* jack_rec */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_rec; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363EED0DEB094B001F72D9 /* capture_client.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = capture_client.c; path = "../example-clients/capture_client.c"; sourceTree = SOURCE_ROOT; };
-		4B363F1E0DEB0A6A001F72D9 /* jack_monitor_client */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_monitor_client; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363F220DEB0AB0001F72D9 /* monitor_client.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = monitor_client.c; path = "../example-clients/monitor_client.c"; sourceTree = SOURCE_ROOT; };
-		4B363F350DEB0BD1001F72D9 /* jack_showtime */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_showtime; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363F3D0DEB0C31001F72D9 /* showtime.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = showtime.c; path = "../example-clients/showtime.c"; sourceTree = SOURCE_ROOT; };
-		4B363F720DEB0D4E001F72D9 /* jack_impulse_grabber */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_impulse_grabber; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B363F750DEB0D7D001F72D9 /* impulse_grabber.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = impulse_grabber.c; path = "../example-clients/impulse_grabber.c"; sourceTree = SOURCE_ROOT; };
-		4B370A14133DD7E200237B68 /* JackCoreMidiInputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiInputPort.cpp; path = ../../coremidi/JackCoreMidiInputPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A15133DD7E200237B68 /* JackCoreMidiInputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiInputPort.h; path = ../../coremidi/JackCoreMidiInputPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A16133DD7E200237B68 /* JackCoreMidiOutputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiOutputPort.cpp; path = ../../coremidi/JackCoreMidiOutputPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A17133DD7E200237B68 /* JackCoreMidiOutputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiOutputPort.h; path = ../../coremidi/JackCoreMidiOutputPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A18133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiPhysicalInputPort.cpp; path = ../../coremidi/JackCoreMidiPhysicalInputPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A19133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiPhysicalInputPort.h; path = ../../coremidi/JackCoreMidiPhysicalInputPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A1A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiPhysicalOutputPort.cpp; path = ../../coremidi/JackCoreMidiPhysicalOutputPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A1B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiPhysicalOutputPort.h; path = ../../coremidi/JackCoreMidiPhysicalOutputPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A1C133DD7E300237B68 /* JackCoreMidiPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiPort.cpp; path = ../../coremidi/JackCoreMidiPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A1D133DD7E300237B68 /* JackCoreMidiPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiPort.h; path = ../../coremidi/JackCoreMidiPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A1E133DD7E300237B68 /* JackCoreMidiUtil.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiUtil.cpp; path = ../../coremidi/JackCoreMidiUtil.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A1F133DD7E300237B68 /* JackCoreMidiUtil.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiUtil.h; path = ../../coremidi/JackCoreMidiUtil.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A20133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiVirtualInputPort.cpp; path = ../../coremidi/JackCoreMidiVirtualInputPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A21133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiVirtualInputPort.h; path = ../../coremidi/JackCoreMidiVirtualInputPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A22133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiVirtualOutputPort.cpp; path = ../../coremidi/JackCoreMidiVirtualOutputPort.cpp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B370A23133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiVirtualOutputPort.h; path = ../../coremidi/JackCoreMidiVirtualOutputPort.h; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B38115F1326878E00C61B14 /* jack_latent_client */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_latent_client; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B3811971326884E00C61B14 /* jack_latent_client */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_latent_client; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B3811FA13269C8300C61B14 /* latent_client.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = latent_client.c; path = "../example-clients/latent_client.c"; sourceTree = SOURCE_ROOT; };
-		4B38141F1327AA6800C61B14 /* iodelay.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = iodelay.cpp; path = ../tests/iodelay.cpp; sourceTree = SOURCE_ROOT; };
-		4B3F49070AD8503300491C6E /* cpu.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = cpu.c; path = ../tests/cpu.c; sourceTree = SOURCE_ROOT; };
-		4B43A8BA10145F6F00E52943 /* jack_loopback.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_loopback.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B43A8C81014605000E52943 /* JackLoopbackDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackLoopbackDriver.cpp; path = ../common/JackLoopbackDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B43A8C91014605000E52943 /* JackLoopbackDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackLoopbackDriver.h; path = ../common/JackLoopbackDriver.h; sourceTree = SOURCE_ROOT; };
-		4B43A8E71014615800E52943 /* jack_loopback.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_loopback.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B464301076CAC7700E5077C /* Jack-Info.plist */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = text.plist.xml; path = "Jack-Info.plist"; sourceTree = SOURCE_ROOT; };
-		4B47ACD710B5890100469C67 /* Jackmp.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jackmp.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B49D3B314864D41003390F8 /* JackWinMMEDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinMMEDriver.cpp; path = ../windows/winmme/JackWinMMEDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3B414864D41003390F8 /* JackWinMMEDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinMMEDriver.h; path = ../windows/winmme/JackWinMMEDriver.h; sourceTree = SOURCE_ROOT; };
-		4B49D3B514864D41003390F8 /* JackWinMMEInputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinMMEInputPort.cpp; path = ../windows/winmme/JackWinMMEInputPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3B614864D41003390F8 /* JackWinMMEInputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinMMEInputPort.h; path = ../windows/winmme/JackWinMMEInputPort.h; sourceTree = SOURCE_ROOT; };
-		4B49D3B714864D41003390F8 /* JackWinMMEOutputPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinMMEOutputPort.cpp; path = ../windows/winmme/JackWinMMEOutputPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3B814864D41003390F8 /* JackWinMMEOutputPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinMMEOutputPort.h; path = ../windows/winmme/JackWinMMEOutputPort.h; sourceTree = SOURCE_ROOT; };
-		4B49D3B914864D41003390F8 /* JackWinMMEPort.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinMMEPort.cpp; path = ../windows/winmme/JackWinMMEPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3BA14864D41003390F8 /* JackWinMMEPort.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinMMEPort.h; path = ../windows/winmme/JackWinMMEPort.h; sourceTree = SOURCE_ROOT; };
-		4B49D3BC14864D49003390F8 /* JackPortAudioAdapter.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPortAudioAdapter.cpp; path = ../windows/portaudio/JackPortAudioAdapter.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3BD14864D49003390F8 /* JackPortAudioAdapter.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPortAudioAdapter.h; path = ../windows/portaudio/JackPortAudioAdapter.h; sourceTree = SOURCE_ROOT; };
-		4B49D3BE14864D49003390F8 /* JackPortAudioDevices.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPortAudioDevices.cpp; path = ../windows/portaudio/JackPortAudioDevices.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3BF14864D49003390F8 /* JackPortAudioDevices.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPortAudioDevices.h; path = ../windows/portaudio/JackPortAudioDevices.h; sourceTree = SOURCE_ROOT; };
-		4B49D3C014864D49003390F8 /* JackPortAudioDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPortAudioDriver.cpp; path = ../windows/portaudio/JackPortAudioDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3C114864D49003390F8 /* JackPortAudioDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPortAudioDriver.h; path = ../windows/portaudio/JackPortAudioDriver.h; sourceTree = SOURCE_ROOT; };
-		4B49D3C214864D49003390F8 /* pa_asio.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = pa_asio.h; path = ../windows/portaudio/pa_asio.h; sourceTree = SOURCE_ROOT; };
-		4B49D3C314864D49003390F8 /* portaudio.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = portaudio.h; path = ../windows/portaudio/portaudio.h; sourceTree = SOURCE_ROOT; };
-		4B49D3C914864DA7003390F8 /* JackLinuxTime.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = JackLinuxTime.c; path = ../linux/JackLinuxTime.c; sourceTree = SOURCE_ROOT; };
-		4B49D3D814864DEC003390F8 /* JackWinThread.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinThread.cpp; path = ../windows/JackWinThread.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3D914864DEC003390F8 /* JackWinServerLaunch.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinServerLaunch.cpp; path = ../windows/JackWinServerLaunch.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3DA14864DEC003390F8 /* JackWinSemaphore.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinSemaphore.cpp; path = ../windows/JackWinSemaphore.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3DB14864DEC003390F8 /* JackWinProcessSync.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinProcessSync.cpp; path = ../windows/JackWinProcessSync.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3DC14864DEC003390F8 /* JackWinNamedPipeServerNotifyChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinNamedPipeServerNotifyChannel.cpp; path = ../windows/JackWinNamedPipeServerNotifyChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3DD14864DEC003390F8 /* JackWinNamedPipeServerChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinNamedPipeServerChannel.cpp; path = ../windows/JackWinNamedPipeServerChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3DE14864DEC003390F8 /* JackWinNamedPipeNotifyChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinNamedPipeNotifyChannel.cpp; path = ../windows/JackWinNamedPipeNotifyChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3DF14864DEC003390F8 /* JackWinNamedPipeClientChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinNamedPipeClientChannel.cpp; path = ../windows/JackWinNamedPipeClientChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3E014864DED003390F8 /* JackWinNamedPipe.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinNamedPipe.cpp; path = ../windows/JackWinNamedPipe.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3E114864DED003390F8 /* JackWinEvent.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWinEvent.cpp; path = ../windows/JackWinEvent.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3E214864DED003390F8 /* JackNetWinSocket.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetWinSocket.cpp; path = ../windows/JackNetWinSocket.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3E314864DED003390F8 /* JackMMCSS.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMMCSS.cpp; path = ../windows/JackMMCSS.cpp; sourceTree = SOURCE_ROOT; };
-		4B49D3E414864DED003390F8 /* JackWinTime.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = JackWinTime.c; path = ../windows/JackWinTime.c; sourceTree = SOURCE_ROOT; };
-		4B49D3EA14864DED003390F8 /* JackWinThread.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinThread.h; path = ../windows/JackWinThread.h; sourceTree = SOURCE_ROOT; };
-		4B49D3EB14864DED003390F8 /* JackWinSemaphore.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinSemaphore.h; path = ../windows/JackWinSemaphore.h; sourceTree = SOURCE_ROOT; };
-		4B49D3EC14864DED003390F8 /* JackWinProcessSync.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinProcessSync.h; path = ../windows/JackWinProcessSync.h; sourceTree = SOURCE_ROOT; };
-		4B49D3ED14864DED003390F8 /* JackWinNamedPipeServerNotifyChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinNamedPipeServerNotifyChannel.h; path = ../windows/JackWinNamedPipeServerNotifyChannel.h; sourceTree = SOURCE_ROOT; };
-		4B49D3EE14864DED003390F8 /* JackWinNamedPipeServerChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinNamedPipeServerChannel.h; path = ../windows/JackWinNamedPipeServerChannel.h; sourceTree = SOURCE_ROOT; };
-		4B49D3EF14864DED003390F8 /* JackWinNamedPipeNotifyChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinNamedPipeNotifyChannel.h; path = ../windows/JackWinNamedPipeNotifyChannel.h; sourceTree = SOURCE_ROOT; };
-		4B49D3F014864DED003390F8 /* JackWinNamedPipeClientChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinNamedPipeClientChannel.h; path = ../windows/JackWinNamedPipeClientChannel.h; sourceTree = SOURCE_ROOT; };
-		4B49D3F114864DED003390F8 /* JackWinNamedPipe.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinNamedPipe.h; path = ../windows/JackWinNamedPipe.h; sourceTree = SOURCE_ROOT; };
-		4B49D3F214864DED003390F8 /* JackWinMutex.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinMutex.h; path = ../windows/JackWinMutex.h; sourceTree = SOURCE_ROOT; };
-		4B49D3F314864DED003390F8 /* JackWinEvent.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWinEvent.h; path = ../windows/JackWinEvent.h; sourceTree = SOURCE_ROOT; };
-		4B49D3F814864DED003390F8 /* JackNetWinSocket.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackNetWinSocket.h; path = ../windows/JackNetWinSocket.h; sourceTree = SOURCE_ROOT; };
-		4B49D3F914864DED003390F8 /* JackMMCSS.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMMCSS.h; path = ../windows/JackMMCSS.h; sourceTree = SOURCE_ROOT; };
-		4B49D44014865F22003390F8 /* net.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = net.h; path = ../common/jack/net.h; sourceTree = SOURCE_ROOT; };
-		4B49D44114865F22003390F8 /* session.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = session.h; path = ../common/jack/session.h; sourceTree = SOURCE_ROOT; };
-		4B4CA9730E02CF9600F4BFDA /* JackRestartThreadedDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackRestartThreadedDriver.h; path = ../common/JackRestartThreadedDriver.h; sourceTree = SOURCE_ROOT; };
-		4B4CA9740E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackRestartThreadedDriver.cpp; path = ../common/JackRestartThreadedDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B4E9AF80E5F1090000A3278 /* JackControlAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackControlAPI.cpp; path = ../common/JackControlAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4B4E9AF90E5F1090000A3278 /* JackControlAPI.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackControlAPI.h; path = ../common/JackControlAPI.h; sourceTree = SOURCE_ROOT; };
-		4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMessageBuffer.cpp; path = ../common/JackMessageBuffer.cpp; sourceTree = SOURCE_ROOT; };
-		4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMessageBuffer.h; path = ../common/JackMessageBuffer.h; sourceTree = SOURCE_ROOT; };
-		4B57F5950D72C27900B4E719 /* jack_thread_wait */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_thread_wait; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B5A1BBB0CD1CB9E0005BF74 /* jack_midiseq */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midiseq; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B5A1BBD0CD1CC110005BF74 /* midiseq.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = midiseq.c; path = "../example-clients/midiseq.c"; sourceTree = SOURCE_ROOT; };
-		4B5A1BDA0CD1CCE10005BF74 /* jack_midisine */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midisine; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B5A1BDC0CD1CD420005BF74 /* midisine.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = midisine.c; path = "../example-clients/midisine.c"; sourceTree = SOURCE_ROOT; };
-		4B5E08D50E5B66EE00BEE4E0 /* netadapter.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = netadapter.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B5E08DF0E5B676C00BEE4E0 /* JackNetAdapter.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetAdapter.cpp; path = ../common/JackNetAdapter.cpp; sourceTree = SOURCE_ROOT; };
-		4B5E08E00E5B676C00BEE4E0 /* JackNetAdapter.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackNetAdapter.h; path = ../common/JackNetAdapter.h; sourceTree = SOURCE_ROOT; };
-		4B5F253D0DEE9B8F0041E486 /* JackLockedEngine.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackLockedEngine.h; path = ../common/JackLockedEngine.h; sourceTree = SOURCE_ROOT; };
-		4B60CE480AAABA31004956AA /* connect.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = connect.c; path = "../example-clients/connect.c"; sourceTree = SOURCE_ROOT; };
-		4B6654F7127C34AE00753A79 /* jack_server_control */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_server_control; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B6654FB127C350100753A79 /* server_control.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = server_control.cpp; path = "../example-clients/server_control.cpp"; sourceTree = SOURCE_ROOT; };
-		4B66A8580934964500A89560 /* JackConstants.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackConstants.h; path = ../common/JackConstants.h; sourceTree = SOURCE_ROOT; };
-		4B67AB8C14B4B03800B4AA9A /* JackException.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackException.cpp; path = ../common/JackException.cpp; sourceTree = SOURCE_ROOT; };
-		4B699BB1097D421600A18468 /* jackdmp */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jackdmp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699C47097D421600A18468 /* Jackmp.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jackmp.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699CAC097D421600A18468 /* Jackservermp.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jackservermp.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699CBB097D421600A18468 /* jack_metro */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_metro; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699CCB097D421600A18468 /* jack_lsp */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_lsp; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699CDB097D421600A18468 /* jack_connect */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_connect; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699CEB097D421600A18468 /* jack_disconnect */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_disconnect; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699CFD097D421600A18468 /* jack_freewheel */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_freewheel; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D0D097D421600A18468 /* jack_external_metro */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_external_metro; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D21097D421600A18468 /* testAtomic */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = testAtomic; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D39097D421600A18468 /* testSem */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = testSem; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D49097D421600A18468 /* zombie */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = zombie; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D61097D421600A18468 /* synchroServer */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = synchroServer; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D79097D421600A18468 /* synchroClient */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = synchroClient; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699D91097D421700A18468 /* synchroServerClient */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = synchroServerClient; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699DA1097D421700A18468 /* jack_coreaudio.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_coreaudio.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B699DB0097D421700A18468 /* jack_dummy.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_dummy.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B6B9EF50CD0958B0051EE5A /* midiport.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = midiport.h; path = ../common/jack/midiport.h; sourceTree = SOURCE_ROOT; };
-		4B6C73790CC60A6D001AFFD4 /* intclient.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = intclient.h; path = ../common/jack/intclient.h; sourceTree = SOURCE_ROOT; };
-		4B6C737A0CC60A6D001AFFD4 /* jack.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = jack.h; path = ../common/jack/jack.h; sourceTree = SOURCE_ROOT; };
-		4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = ringbuffer.h; path = ../common/jack/ringbuffer.h; sourceTree = SOURCE_ROOT; };
-		4B6C737C0CC60A6D001AFFD4 /* statistics.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = statistics.h; path = ../common/jack/statistics.h; sourceTree = SOURCE_ROOT; };
-		4B6C737D0CC60A6D001AFFD4 /* thread.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = thread.h; path = ../common/jack/thread.h; sourceTree = SOURCE_ROOT; };
-		4B6C737E0CC60A6D001AFFD4 /* transport.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = transport.h; path = ../common/jack/transport.h; sourceTree = SOURCE_ROOT; };
-		4B6C737F0CC60A6D001AFFD4 /* types.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = types.h; path = ../common/jack/types.h; sourceTree = SOURCE_ROOT; };
-		4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackEngineControl.cpp; path = ../common/JackEngineControl.cpp; sourceTree = SOURCE_ROOT; };
-		4B76C7680E5AB2DB00E2AC21 /* JackNetInterface.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetInterface.cpp; path = ../common/JackNetInterface.cpp; sourceTree = SOURCE_ROOT; };
-		4B76C7690E5AB2DB00E2AC21 /* JackNetInterface.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackNetInterface.h; path = ../common/JackNetInterface.h; sourceTree = SOURCE_ROOT; };
-		4B80D7E50BA0D17400F035BB /* JackMidiPort.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackMidiPort.h; path = ../common/JackMidiPort.h; sourceTree = SOURCE_ROOT; };
-		4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiPort.cpp; path = ../common/JackMidiPort.cpp; sourceTree = SOURCE_ROOT; };
-		4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiAPI.cpp; path = ../common/JackMidiAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4B8692DB1371DB4700D2D11B /* Jacknet.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jacknet.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B8693151371DD0A00D2D11B /* JackNetAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetAPI.cpp; path = ../common/JackNetAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4B869B3D08C8D21C001CF041 /* driver_interface.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = driver_interface.h; path = ../common/driver_interface.h; sourceTree = SOURCE_ROOT; };
-		4B869B4208C8D22F001CF041 /* JackDriverLoader.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackDriverLoader.h; path = ../common/JackDriverLoader.h; sourceTree = SOURCE_ROOT; };
-		4B869D7F08C9CB00001CF041 /* JackDriverLoader.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackDriverLoader.cpp; path = ../common/JackDriverLoader.cpp; sourceTree = SOURCE_ROOT; };
-		4B88D03911298BEE007A87C1 /* weakjack.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = weakjack.h; path = ../common/jack/weakjack.h; sourceTree = SOURCE_ROOT; };
-		4B88D03A11298BEE007A87C1 /* weakmacros.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = weakmacros.h; path = ../common/jack/weakmacros.h; sourceTree = SOURCE_ROOT; };
-		4B8F16E513290DC80002AD73 /* jack_midi_dump */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midi_dump; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B8F16F213290E0E0002AD73 /* jack_midi_dump */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_midi_dump; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B8F16F41329161E0002AD73 /* midi_dump.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = midi_dump.c; path = "../example-clients/midi_dump.c"; sourceTree = SOURCE_ROOT; };
-		4B90669814BEE6D20074CD40 /* JackRequestDecoder.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackRequestDecoder.cpp; path = ../common/JackRequestDecoder.cpp; sourceTree = SOURCE_ROOT; };
-		4B90669914BEE6D20074CD40 /* JackRequestDecoder.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackRequestDecoder.h; path = ../common/JackRequestDecoder.h; sourceTree = SOURCE_ROOT; };
-		4B90679914BEFB500074CD40 /* JackSolarisTime.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = JackSolarisTime.c; path = ../solaris/JackSolarisTime.c; sourceTree = SOURCE_ROOT; };
-		4B90679A14BEFB5A0074CD40 /* JackBoomerDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackBoomerDriver.cpp; path = ../solaris/oss/JackBoomerDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B90679B14BEFB5A0074CD40 /* JackBoomerDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackBoomerDriver.h; path = ../solaris/oss/JackBoomerDriver.h; sourceTree = SOURCE_ROOT; };
-		4B90679C14BEFB5A0074CD40 /* JackOSSAdapter.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackOSSAdapter.cpp; path = ../solaris/oss/JackOSSAdapter.cpp; sourceTree = SOURCE_ROOT; };
-		4B90679D14BEFB5A0074CD40 /* JackOSSAdapter.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackOSSAdapter.h; path = ../solaris/oss/JackOSSAdapter.h; sourceTree = SOURCE_ROOT; };
-		4B90679E14BEFB5A0074CD40 /* JackOSSDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackOSSDriver.cpp; path = ../solaris/oss/JackOSSDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4B90679F14BEFB5A0074CD40 /* JackOSSDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackOSSDriver.h; path = ../solaris/oss/JackOSSDriver.h; sourceTree = SOURCE_ROOT; };
-		4B940B9B06DDDE5B00D77F60 /* AudioHardware.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = AudioHardware.h; path = /System/Library/Frameworks/CoreAudio.framework/Versions/A/Headers/AudioHardware.h; sourceTree = "<absolute>"; };
-		4B94334910A5E666002A187F /* systemdeps.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = systemdeps.h; path = ../common/jack/systemdeps.h; sourceTree = SOURCE_ROOT; };
-		4B95BCAD0D913073000F7695 /* control.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = control.h; path = ../common/jack/control.h; sourceTree = SOURCE_ROOT; };
-		4B978DBB0A31CF4A009E2DD1 /* jack_portaudio.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_portaudio.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4B98AE000931D30C0091932A /* JackDebugClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackDebugClient.cpp; path = ../common/JackDebugClient.cpp; sourceTree = SOURCE_ROOT; };
-		4B98AE010931D30C0091932A /* JackDebugClient.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackDebugClient.h; path = ../common/JackDebugClient.h; sourceTree = SOURCE_ROOT; };
-		4B9A25B30DBF8330006E9FBC /* JackError.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackError.cpp; path = ../common/JackError.cpp; sourceTree = SOURCE_ROOT; };
-		4B9A26000DBF8584006E9FBC /* jslist.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = jslist.h; path = ../common/jack/jslist.h; sourceTree = SOURCE_ROOT; };
-		4BA2574C132FB49B009F2D3F /* alsa_driver.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; path = alsa_driver.c; sourceTree = "<group>"; };
-		4BA339AC10B2E36800190E3B /* Jackservermp.framework */ = {isa = PBXFileReference; explicitFileType = wrapper.framework; includeInIndex = 0; path = Jackservermp.framework; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BA577BC08BF8BE200F82DE1 /* testSynchroClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = testSynchroClient.cpp; path = ../tests/testSynchroClient.cpp; sourceTree = SOURCE_ROOT; };
-		4BA577FB08BF8E4600F82DE1 /* testSynchroServer.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = testSynchroServer.cpp; path = ../tests/testSynchroServer.cpp; sourceTree = SOURCE_ROOT; };
-		4BA692B00CBE4BC700EAD520 /* jack_load */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_load; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BA692B20CBE4C2D00EAD520 /* ipload.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = ipload.c; path = "../example-clients/ipload.c"; sourceTree = SOURCE_ROOT; };
-		4BA692D40CBE4C9000EAD520 /* jack_unload */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_unload; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BA692D60CBE4CC600EAD520 /* ipunload.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = ipunload.c; path = "../example-clients/ipunload.c"; sourceTree = SOURCE_ROOT; };
-		4BA7FEC30D8E76270017FF73 /* jack_server_control */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_server_control; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BA7FEC80D8E76650017FF73 /* control.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; name = control.c; path = "../example-clients/control.c"; sourceTree = SOURCE_ROOT; };
-		4BAA150114F04FB600402512 /* JackAC3Encoder.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackAC3Encoder.cpp; path = ../common/JackAC3Encoder.cpp; sourceTree = SOURCE_ROOT; };
-		4BAA150214F04FB600402512 /* JackAC3Encoder.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackAC3Encoder.h; path = ../common/JackAC3Encoder.h; sourceTree = SOURCE_ROOT; };
-		4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackPortType.cpp; path = ../common/JackPortType.cpp; sourceTree = SOURCE_ROOT; };
-		4BAB95B70B9E20B800A0C723 /* JackPortType.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackPortType.h; path = ../common/JackPortType.h; sourceTree = SOURCE_ROOT; };
-		4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackAudioPort.cpp; path = ../common/JackAudioPort.cpp; sourceTree = SOURCE_ROOT; };
-		4BB371D40C1AD85A0050C1E4 /* JackNotification.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackNotification.h; path = ../common/JackNotification.h; sourceTree = SOURCE_ROOT; };
-		4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPosixMutex.h; path = ../posix/JackPosixMutex.h; sourceTree = SOURCE_ROOT; };
-		4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPosixProcessSync.cpp; path = ../posix/JackPosixProcessSync.cpp; sourceTree = SOURCE_ROOT; };
-		4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPosixProcessSync.h; path = ../posix/JackPosixProcessSync.h; sourceTree = SOURCE_ROOT; };
-		4BBAE40E0F42FA6100B8BD3F /* JackEngineProfiling.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackEngineProfiling.h; path = ../common/JackEngineProfiling.h; sourceTree = SOURCE_ROOT; };
-		4BBAE40F0F42FA6100B8BD3F /* JackEngineProfiling.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackEngineProfiling.cpp; path = ../common/JackEngineProfiling.cpp; sourceTree = SOURCE_ROOT; };
-		4BBB00CF0E72614F0018AB1B /* JackPortAudioDevices.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackPortAudioDevices.cpp; path = ../windows/portaudio/JackPortAudioDevices.cpp; sourceTree = SOURCE_ROOT; };
-		4BBB00D00E72614F0018AB1B /* JackPortAudioDevices.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackPortAudioDevices.h; path = ../windows/portaudio/JackPortAudioDevices.h; sourceTree = SOURCE_ROOT; };
-		4BBB00D10E72614F0018AB1B /* JackPortAudioDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackPortAudioDriver.cpp; path = ../windows/portaudio/JackPortAudioDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BBB00D20E72614F0018AB1B /* JackPortAudioDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackPortAudioDriver.h; path = ../windows/portaudio/JackPortAudioDriver.h; sourceTree = SOURCE_ROOT; };
-		4BBC93B80DF9736C002DF220 /* JackWaitThreadedDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackWaitThreadedDriver.cpp; path = ../common/JackWaitThreadedDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BBC93B90DF9736C002DF220 /* JackWaitThreadedDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackWaitThreadedDriver.h; path = ../common/JackWaitThreadedDriver.h; sourceTree = SOURCE_ROOT; };
-		4BBD13CC08C71EB40079F7FF /* testSynchroServerClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = testSynchroServerClient.cpp; path = ../tests/testSynchroServerClient.cpp; sourceTree = SOURCE_ROOT; };
-		4BC216880A444BDE00BDA09F /* JackServerGlobals.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackServerGlobals.cpp; path = ../common/JackServerGlobals.cpp; sourceTree = SOURCE_ROOT; };
-		4BC2168D0A444BED00BDA09F /* JackServerGlobals.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackServerGlobals.h; path = ../common/JackServerGlobals.h; sourceTree = SOURCE_ROOT; };
-		4BC3988908B3CF6C00B6F371 /* JackDummyDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackDummyDriver.cpp; path = ../common/JackDummyDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3988A08B3CF6C00B6F371 /* JackDummyDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackDummyDriver.h; path = ../common/JackDummyDriver.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPosixThread.cpp; path = ../posix/JackPosixThread.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPosixThread.h; path = ../posix/JackPosixThread.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackSocket.cpp; path = ../posix/JackSocket.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6AE0E703B8D0066E42F /* JackSocket.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackSocket.h; path = ../posix/JackSocket.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6AF0E703B8D0066E42F /* JackSocketClientChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackSocketClientChannel.cpp; path = ../posix/JackSocketClientChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6B00E703B8D0066E42F /* JackSocketClientChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackSocketClientChannel.h; path = ../posix/JackSocketClientChannel.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6B10E703B8D0066E42F /* JackSocketNotifyChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackSocketNotifyChannel.cpp; path = ../posix/JackSocketNotifyChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6B20E703B8D0066E42F /* JackSocketNotifyChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackSocketNotifyChannel.h; path = ../posix/JackSocketNotifyChannel.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6B30E703B8D0066E42F /* JackSocketServerChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackSocketServerChannel.cpp; path = ../posix/JackSocketServerChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6B40E703B8D0066E42F /* JackSocketServerChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackSocketServerChannel.h; path = ../posix/JackSocketServerChannel.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6B50E703B8D0066E42F /* JackSocketServerNotifyChannel.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackSocketServerNotifyChannel.cpp; path = ../posix/JackSocketServerNotifyChannel.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6B60E703B8D0066E42F /* JackSocketServerNotifyChannel.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackSocketServerNotifyChannel.h; path = ../posix/JackSocketServerNotifyChannel.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6B70E703BAA0066E42F /* JackPosixSemaphore.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPosixSemaphore.cpp; path = ../posix/JackPosixSemaphore.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6B80E703BAA0066E42F /* JackPosixSemaphore.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackPosixSemaphore.h; path = ../posix/JackPosixSemaphore.h; sourceTree = SOURCE_ROOT; };
-		4BC3B6B90E703BCC0066E42F /* JackNetUnixSocket.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetUnixSocket.cpp; path = ../posix/JackNetUnixSocket.cpp; sourceTree = SOURCE_ROOT; };
-		4BC3B6BA0E703BCC0066E42F /* JackNetUnixSocket.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackNetUnixSocket.h; path = ../posix/JackNetUnixSocket.h; sourceTree = SOURCE_ROOT; };
-		4BC8326D0DF42C7D00DD1C93 /* JackMutex.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMutex.h; path = ../common/JackMutex.h; sourceTree = SOURCE_ROOT; };
-		4BCC87950D57168300A7FEB1 /* Accelerate.framework */ = {isa = PBXFileReference; lastKnownFileType = wrapper.framework; name = Accelerate.framework; path = /System/Library/Frameworks/Accelerate.framework; sourceTree = "<absolute>"; };
-		4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackTransportEngine.h; path = ../common/JackTransportEngine.h; sourceTree = SOURCE_ROOT; };
-		4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackTransportEngine.cpp; path = ../common/JackTransportEngine.cpp; sourceTree = SOURCE_ROOT; };
-		4BD561C708EEB910006BBC2A /* JackSynchro.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackSynchro.h; path = ../common/JackSynchro.h; sourceTree = SOURCE_ROOT; };
-		4BD623F70CBCF0F000DE782F /* inprocess.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = inprocess.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BD6240C0CBCF16600DE782F /* inprocess.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = inprocess.c; path = "../example-clients/inprocess.c"; sourceTree = SOURCE_ROOT; };
-		4BDCDB9D1001FB9C00B15929 /* jack_coremidi.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_coremidi.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BDCDBC51001FCC000B15929 /* jack_net.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_net.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BDCDBE81001FD2D00B15929 /* netmanager.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = netmanager.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BDCDBFF1001FD7300B15929 /* audioadapter.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = audioadapter.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BDCDC251001FDE300B15929 /* netadapter.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = netadapter.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackTools.cpp; path = ../common/JackTools.cpp; sourceTree = SOURCE_ROOT; };
-		4BE4CC000CDA153400CCF5BB /* JackTools.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackTools.h; path = ../common/JackTools.h; sourceTree = SOURCE_ROOT; };
-		4BE5FECB0E725C090020B576 /* JackCoreAudioDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreAudioDriver.cpp; path = coreaudio/JackCoreAudioDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BE5FECC0E725C090020B576 /* JackCoreAudioDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackCoreAudioDriver.h; path = coreaudio/JackCoreAudioDriver.h; sourceTree = SOURCE_ROOT; };
-		4BE5FECF0E725C320020B576 /* JackCoreAudioAdapter.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreAudioAdapter.cpp; path = coreaudio/JackCoreAudioAdapter.cpp; sourceTree = SOURCE_ROOT; };
-		4BE5FED00E725C320020B576 /* JackCoreAudioAdapter.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackCoreAudioAdapter.h; path = coreaudio/JackCoreAudioAdapter.h; sourceTree = SOURCE_ROOT; };
-		4BE6C6A30A3E096F005A203A /* jack_test */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_test; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BE6C6AC0A3E0A65005A203A /* test.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = test.cpp; path = ../tests/test.cpp; sourceTree = SOURCE_ROOT; };
-		4BE99D300AD7A04800C59091 /* jack_cpu */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_cpu; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BF284160F31B4BC00B05BE3 /* JackArgParser.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackArgParser.cpp; path = ../common/JackArgParser.cpp; sourceTree = SOURCE_ROOT; };
-		4BF284170F31B4BC00B05BE3 /* JackArgParser.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackArgParser.h; path = ../common/JackArgParser.h; sourceTree = SOURCE_ROOT; };
-		4BF3390C0F8B864B0080FB5B /* jack_coremidi.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_coremidi.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BF339140F8B86DC0080FB5B /* JackCoreMidiDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackCoreMidiDriver.h; path = coremidi/JackCoreMidiDriver.h; sourceTree = SOURCE_ROOT; };
-		4BF339150F8B86DC0080FB5B /* JackCoreMidiDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackCoreMidiDriver.cpp; path = coremidi/JackCoreMidiDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BF3391F0F8B873E0080FB5B /* JackMidiDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackMidiDriver.cpp; path = ../common/JackMidiDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BF339200F8B873E0080FB5B /* JackMidiDriver.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = JackMidiDriver.h; path = ../common/JackMidiDriver.h; sourceTree = SOURCE_ROOT; };
-		4BF4BAB00E3480AB00403CDF /* JackAudioAdapterFactory.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackAudioAdapterFactory.cpp; path = ../common/JackAudioAdapterFactory.cpp; sourceTree = SOURCE_ROOT; };
-		4BF520520CB8D0E80037470E /* timestamps.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = timestamps.c; path = ../common/timestamps.c; sourceTree = SOURCE_ROOT; };
-		4BF520580CB8D1010037470E /* timestamps.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = timestamps.h; path = ../common/timestamps.h; sourceTree = SOURCE_ROOT; };
-		4BF5FBBA0E878B9C003D2374 /* JackPosixServerLaunch.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JackPosixServerLaunch.cpp; path = ../posix/JackPosixServerLaunch.cpp; sourceTree = SOURCE_ROOT; };
-		4BF5FBC80E878D24003D2374 /* JackMachTime.c */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.c; path = JackMachTime.c; sourceTree = SOURCE_ROOT; };
-		4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = JackMachSemaphore.cpp; sourceTree = SOURCE_ROOT; };
-		4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; path = JackMachSemaphore.h; sourceTree = SOURCE_ROOT; };
-		4BF772FD08B3330F00149912 /* JackAtomic.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackAtomic.h; path = ../common/JackAtomic.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1670834EDD900C94B91 /* zombie.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = zombie.c; path = "../example-clients/zombie.c"; sourceTree = SOURCE_ROOT; };
-		4BF8D1690834EDE600C94B91 /* lsp.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = lsp.c; path = "..//example-clients/lsp.c"; sourceTree = SOURCE_ROOT; };
-		4BF8D16B0834EDF000C94B91 /* metro.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = metro.c; path = "../example-clients/metro.c"; sourceTree = SOURCE_ROOT; };
-		4BF8D1710834EE0F00C94B91 /* freewheel.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = freewheel.c; path = "../example-clients/freewheel.c"; sourceTree = SOURCE_ROOT; };
-		4BF8D1770834EE4800C94B91 /* JackError.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackError.h; path = ../common/JackError.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1830834EE5800C94B91 /* JackTime.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackTime.h; path = ../common/JackTime.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1870834EE7900C94B91 /* JackShmMem.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackShmMem.h; path = ../common/JackShmMem.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackShmMem.cpp; path = ../common/JackShmMem.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D18F0834EE8400C94B91 /* shm.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = shm.h; path = ../common/shm.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1900834EE8400C94B91 /* shm.c */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.c; name = shm.c; path = ../common/shm.c; sourceTree = SOURCE_ROOT; };
-		4BF8D19F0834EE9E00C94B91 /* JackThread.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackThread.h; path = ../common/JackThread.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackActivationCount.h; path = ../common/JackActivationCount.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackActivationCount.cpp; path = ../common/JackActivationCount.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1AF0834EEC400C94B91 /* JackChannel.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackChannel.h; path = ../common/JackChannel.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1B30834EED500C94B91 /* JackInternalClientChannel.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackInternalClientChannel.h; path = ../common/JackInternalClientChannel.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1B50834EEE400C94B91 /* JackDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackDriver.h; path = ../common/JackDriver.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1B60834EEE400C94B91 /* JackDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackDriver.cpp; path = ../common/JackDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1B90834EEF100C94B91 /* JackFreewheelDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackFreewheelDriver.h; path = ../common/JackFreewheelDriver.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1BA0834EEF100C94B91 /* JackFreewheelDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackFreewheelDriver.cpp; path = ../common/JackFreewheelDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1BD0834EEFC00C94B91 /* JackThreadedDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackThreadedDriver.h; path = ../common/JackThreadedDriver.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1BE0834EEFC00C94B91 /* JackThreadedDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackThreadedDriver.cpp; path = ../common/JackThreadedDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1C10834EF0800C94B91 /* JackAtomicState.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackAtomicState.h; path = ../common/JackAtomicState.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackConnectionManager.h; path = ../common/JackConnectionManager.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackConnectionManager.cpp; path = ../common/JackConnectionManager.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackGraphManager.h; path = ../common/JackGraphManager.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackGraphManager.cpp; path = ../common/JackGraphManager.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1CF0834EF2F00C94B91 /* JackPort.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackPort.h; path = ../common/JackPort.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackPort.cpp; path = ../common/JackPort.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackClientInterface.h; path = ../common/JackClientInterface.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackClientControl.h; path = ../common/JackClientControl.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1E10834EF5500C94B91 /* JackClient.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackClient.h; path = ../common/JackClient.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1E50834EF6700C94B91 /* JackClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackClient.cpp; path = ../common/JackClient.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackAPI.cpp; path = ../common/JackAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1ED0834EF9200C94B91 /* JackInternalClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackInternalClient.cpp; path = ../common/JackInternalClient.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackInternalClient.h; path = ../common/JackInternalClient.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1F50834EFB000C94B91 /* JackServerAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackServerAPI.cpp; path = ../common/JackServerAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1F70834EFBD00C94B91 /* JackExternalClient.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackExternalClient.h; path = ../common/JackExternalClient.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1F80834EFBD00C94B91 /* JackExternalClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackExternalClient.cpp; path = ../common/JackExternalClient.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1FB0834EFD100C94B91 /* JackLibGlobals.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackLibGlobals.h; path = ../common/JackLibGlobals.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1FC0834EFD100C94B91 /* JackLibClient.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackLibClient.h; path = ../common/JackLibClient.h; sourceTree = SOURCE_ROOT; };
-		4BF8D1FD0834EFD100C94B91 /* JackLibClient.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackLibClient.cpp; path = ../common/JackLibClient.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D1FE0834EFD100C94B91 /* JackLibAPI.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackLibAPI.cpp; path = ../common/JackLibAPI.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D2130834F02800C94B91 /* JackEngine.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackEngine.h; path = ../common/JackEngine.h; sourceTree = SOURCE_ROOT; };
-		4BF8D2140834F02800C94B91 /* JackEngine.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackEngine.cpp; path = ../common/JackEngine.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D2190834F03D00C94B91 /* JackEngineControl.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackEngineControl.h; path = ../common/JackEngineControl.h; sourceTree = SOURCE_ROOT; };
-		4BF8D2210834F05C00C94B91 /* JackServer.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackServer.cpp; path = ../common/JackServer.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D2220834F05C00C94B91 /* JackServer.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackServer.h; path = ../common/JackServer.h; sourceTree = SOURCE_ROOT; };
-		4BF8D2250834F06A00C94B91 /* Jackdmp.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = Jackdmp.cpp; path = ../common/Jackdmp.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D2290834F07D00C94B91 /* JackAudioDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackAudioDriver.h; path = ../common/JackAudioDriver.h; sourceTree = SOURCE_ROOT; };
-		4BF8D22A0834F07D00C94B91 /* JackAudioDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackAudioDriver.cpp; path = ../common/JackAudioDriver.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D23E0834F1C300C94B91 /* testAtomic.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = testAtomic.cpp; path = ../tests/testAtomic.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8D2470834F20600C94B91 /* testSem.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = testSem.cpp; path = ../tests/testSem.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackFrameTimer.cpp; path = ../common/JackFrameTimer.cpp; sourceTree = SOURCE_ROOT; };
-		4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackFrameTimer.h; path = ../common/JackFrameTimer.h; sourceTree = SOURCE_ROOT; };
-		4BFA5E980DEC4D9C00FA4CDB /* testMutex */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = testMutex; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA5E9E0DEC4DD900FA4CDB /* testMutex.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = testMutex.cpp; path = ../tests/testMutex.cpp; sourceTree = SOURCE_ROOT; };
-		4BFA828C0DF6A9E40087B4E1 /* jack_evmon */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_evmon; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA829F0DF6A9E40087B4E1 /* jack_bufsize */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_bufsize; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA82AB0DF6A9E40087B4E1 /* jack_rec */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_rec; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA82B70DF6A9E40087B4E1 /* jack_monitor_client */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_monitor_client; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA82C30DF6A9E40087B4E1 /* jack_showtime */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_showtime; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA82CF0DF6A9E40087B4E1 /* jack_impulse_grabber */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_impulse_grabber; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFA99A20AAAF3B0009E916C /* jack_iodelay */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = jack_iodelay; sourceTree = BUILT_PRODUCTS_DIR; };
-		4BFB73F608AD291A00DB99B8 /* JackGlobals.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackGlobals.h; path = ../common/JackGlobals.h; sourceTree = SOURCE_ROOT; };
-		4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; path = JackMachThread.cpp; sourceTree = SOURCE_ROOT; };
-		4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; path = JackMachThread.h; sourceTree = SOURCE_ROOT; };
-		BA047C710E14E7540041F3B6 /* JackNetSocket.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackNetSocket.h; path = ../common/JackNetSocket.h; sourceTree = SOURCE_ROOT; };
-		BA222ACF0DC88132001A17F4 /* jack_net.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = jack_net.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		BA222AD60DC88268001A17F4 /* JackNetTool.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetTool.cpp; path = ../common/JackNetTool.cpp; sourceTree = SOURCE_ROOT; };
-		BA222AD70DC88268001A17F4 /* JackNetTool.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackNetTool.h; path = ../common/JackNetTool.h; sourceTree = SOURCE_ROOT; };
-		BA222ADC0DC882A5001A17F4 /* JackNetDriver.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetDriver.cpp; path = ../common/JackNetDriver.cpp; sourceTree = SOURCE_ROOT; };
-		BA222ADD0DC882A5001A17F4 /* JackNetDriver.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackNetDriver.h; path = ../common/JackNetDriver.h; sourceTree = SOURCE_ROOT; };
-		BA222AE90DC882DB001A17F4 /* netmanager.so */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.dylib"; includeInIndex = 0; path = netmanager.so; sourceTree = BUILT_PRODUCTS_DIR; };
-		BA222AEB0DC883B3001A17F4 /* JackNetManager.cpp */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.cpp.cpp; name = JackNetManager.cpp; path = ../common/JackNetManager.cpp; sourceTree = SOURCE_ROOT; };
-		BA222AEC0DC883B3001A17F4 /* JackNetManager.h */ = {isa = PBXFileReference; fileEncoding = 30; lastKnownFileType = sourcecode.c.h; name = JackNetManager.h; path = ../common/JackNetManager.h; sourceTree = SOURCE_ROOT; };
-		C6859E8B029090EE04C91782 /* JackServer.1 */ = {isa = PBXFileReference; lastKnownFileType = text.man; path = JackServer.1; sourceTree = "<group>"; };
-/* End PBXFileReference section */
-
-/* Begin PBXFrameworksBuildPhase section */
-		4B0A28E00D52073D002EFF74 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0A29270D52108E002EFF74 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B19B2FB0E23620F00DD4A82 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B2021E0133A9BA40019E213 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3224E010A3156800838A8E /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32252610A316B200838A8E /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32255B10A3187800838A8E /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32257510A3190C00838A8E /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C41F0D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C47E0D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCC87980D57168300A7FEB1 /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4F70D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCC87990D57168300A7FEB1 /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C50E0D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C51A0D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5260D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5320D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C53E0D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C54A0D4731D1000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5580D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5640D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5700D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5800D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA7BE0F0DC232A400AA3457 /* Jackservermp.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5940D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA7BE1A0DC2347500AA3457 /* Jackservermp.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5A00D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5AC0D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5B80D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5C40D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5D00D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5E40D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA7BE200DC234FB00AA3457 /* Jackservermp.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5F80D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA7BE240DC2350D00AA3457 /* Jackservermp.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C60C0D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA7BE270DC2352A00AA3457 /* Jackservermp.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6190D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6240D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C62F0D4731D2000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6390D4731D3000DE7AE /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363DD20DEB02F6001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E140DEB03C5001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E480DEB0775001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363EE30DEB091C001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F180DEB0A6A001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F2F0DEB0BD1001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F6C0DEB0D4E001F72D9 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3811591326878E00C61B14 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3811911326884E00C61B14 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B43A8B510145F6F00E52943 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B43A8E21014615800E52943 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B47ACD110B5890100469C67 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B47ACD210B5890100469C67 /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BB50CD1CB9E0005BF74 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BD40CD1CCE10005BF74 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5E08D00E5B66EE00BEE4E0 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B6654F1127C34AE00753A79 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699BAB097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C42097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCC87970D57168300A7FEB1 /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CA7097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BCC87960D57168300A7FEB1 /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CB5097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CC5097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CD5097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CE5097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CF7097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D07097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D1B097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D33097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D43097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D5B097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D73097D421600A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D8B097D421700A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D9C097D421700A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699DAB097D421700A18468 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8692D51371DB4700D2D11B /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B8692D61371DB4700D2D11B /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16DF13290DC80002AD73 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16EC13290E0E0002AD73 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B978DB60A31CF4A009E2DD1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA339A610B2E36800190E3B /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA339A710B2E36800190E3B /* Accelerate.framework in Frameworks */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692AA0CBE4BC700EAD520 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692CE0CBE4C9000EAD520 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA7FEBD0D8E76270017FF73 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BD623F20CBCF0F000DE782F /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDB981001FB9C00B15929 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBC01001FCC000B15929 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBE31001FD2D00B15929 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBFA1001FD7300B15929 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDC201001FDE300B15929 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE6C69D0A3E096F005A203A /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE99D2A0AD7A04800C59091 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BF339070F8B864B0080FB5B /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA5E910DEC4D9C00FA4CDB /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82860DF6A9E40087B4E1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82990DF6A9E40087B4E1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82A50DF6A9E40087B4E1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82B10DF6A9E40087B4E1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82BD0DF6A9E40087B4E1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82C90DF6A9E40087B4E1 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA999C0AAAF3B0009E916C /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		BA222ACA0DC88132001A17F4 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		BA222AE40DC882DB001A17F4 /* Frameworks */ = {
-			isa = PBXFrameworksBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXFrameworksBuildPhase section */
-
-/* Begin PBXGroup section */
-		0249A662FF388D9811CA2CEA /* External Frameworks and Libraries */ = {
-			isa = PBXGroup;
-			children = (
-				4BCC87950D57168300A7FEB1 /* Accelerate.framework */,
-			);
-			name = "External Frameworks and Libraries";
-			sourceTree = "<group>";
-		};
-		08FB7794FE84155DC02AAC07 /* JackServer */ = {
-			isa = PBXGroup;
-			children = (
-				08FB7795FE84155DC02AAC07 /* Source */,
-				C6859E8C029090F304C91782 /* Documentation */,
-				0249A662FF388D9811CA2CEA /* External Frameworks and Libraries */,
-				1AB674ADFE9D54B511CA2CBB /* Products */,
-				4B464301076CAC7700E5077C /* Jack-Info.plist */,
-			);
-			name = JackServer;
-			sourceTree = "<group>";
-		};
-		08FB7795FE84155DC02AAC07 /* Source */ = {
-			isa = PBXGroup;
-			children = (
-				4B05A09D0DF72C6000840F4C /* Additional */,
-				4B6BEB4A07A6CCDC00A5DBDA /* Tests */,
-				4B37C20006DF1F900016E567 /* Latency */,
-				4B03383E0797E19900686131 /* Simple clients */,
-				4B765CC805ECE17900571F78 /* Tools */,
-				4BA550FC05E2421400569492 /* Shm */,
-				4BA33DF905EDFD8C000CCD5F /* Thread */,
-				4BA3874007947A46008D8992 /* Synchro */,
-				4BA550FF05E2423600569492 /* Channels */,
-				4BA550F605E241B800569492 /* Driver */,
-				4BA3873B079479C2008D8992 /* Graph */,
-				4BA550FA05E241F200569492 /* Ports */,
-				4BD56D74079687D7006D44F9 /* Client */,
-				4B9B627005E60A9E001E19AA /* Server */,
-			);
-			name = Source;
-			sourceTree = "<group>";
-		};
-		1AB674ADFE9D54B511CA2CBB /* Products */ = {
-			isa = PBXGroup;
-			children = (
-				4B699BB1097D421600A18468 /* jackdmp */,
-				4B699C47097D421600A18468 /* Jackmp.framework */,
-				4B699CAC097D421600A18468 /* Jackservermp.framework */,
-				4B699CBB097D421600A18468 /* jack_metro */,
-				4B699CCB097D421600A18468 /* jack_lsp */,
-				4B699CDB097D421600A18468 /* jack_connect */,
-				4B699CEB097D421600A18468 /* jack_disconnect */,
-				4B699CFD097D421600A18468 /* jack_freewheel */,
-				4B699D0D097D421600A18468 /* jack_external_metro */,
-				4B699D21097D421600A18468 /* testAtomic */,
-				4B699D39097D421600A18468 /* testSem */,
-				4B699D49097D421600A18468 /* zombie */,
-				4B699D61097D421600A18468 /* synchroServer */,
-				4B699D79097D421600A18468 /* synchroClient */,
-				4B699D91097D421700A18468 /* synchroServerClient */,
-				4B699DA1097D421700A18468 /* jack_coreaudio.so */,
-				4B699DB0097D421700A18468 /* jack_dummy.so */,
-				4B978DBB0A31CF4A009E2DD1 /* jack_portaudio.so */,
-				4BE6C6A30A3E096F005A203A /* jack_test */,
-				4BFA99A20AAAF3B0009E916C /* jack_iodelay */,
-				4BE99D300AD7A04800C59091 /* jack_cpu */,
-				4BD623F70CBCF0F000DE782F /* inprocess.so */,
-				4BA692B00CBE4BC700EAD520 /* jack_load */,
-				4BA692D40CBE4C9000EAD520 /* jack_unload */,
-				4B5A1BBB0CD1CB9E0005BF74 /* jack_midiseq */,
-				4B5A1BDA0CD1CCE10005BF74 /* jack_midisine */,
-				4B35C4250D4731D1000DE7AE /* jackdmp */,
-				4B35C4830D4731D1000DE7AE /* Jackmp.framework */,
-				4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */,
-				4B35C5140D4731D1000DE7AE /* jack_midiseq */,
-				4B35C5200D4731D1000DE7AE /* jack_midisine */,
-				4B35C52C0D4731D1000DE7AE /* jack_metro */,
-				4B35C5380D4731D1000DE7AE /* jack_lsp */,
-				4B35C5440D4731D1000DE7AE /* jack_connect */,
-				4B35C5500D4731D1000DE7AE /* jack_disconnect */,
-				4B35C55E0D4731D2000DE7AE /* jack_freewheel */,
-				4B35C56A0D4731D2000DE7AE /* jack_iodelay */,
-				4B35C5760D4731D2000DE7AE /* jack_external_metro */,
-				4B35C5860D4731D2000DE7AE /* testAtomic */,
-				4B35C59A0D4731D2000DE7AE /* testSem */,
-				4B35C5A60D4731D2000DE7AE /* zombie */,
-				4B35C5B20D4731D2000DE7AE /* jack_test */,
-				4B35C5BE0D4731D2000DE7AE /* jack_cpu */,
-				4B35C5CA0D4731D2000DE7AE /* jack_load */,
-				4B35C5D60D4731D2000DE7AE /* jack_unload */,
-				4B35C5EA0D4731D2000DE7AE /* synchroServer */,
-				4B35C5FE0D4731D2000DE7AE /* synchroClient */,
-				4B35C6120D4731D2000DE7AE /* synchroServerClient */,
-				4B35C61E0D4731D2000DE7AE /* jack_coreaudio.so */,
-				4B35C6290D4731D2000DE7AE /* jack_portaudio.so */,
-				4B35C6340D4731D2000DE7AE /* jack_dummy.so */,
-				4B35C63E0D4731D3000DE7AE /* inprocess.so */,
-				4B0A28E60D52073D002EFF74 /* jack_thread_wait */,
-				4B0A292D0D52108E002EFF74 /* jack_thread_wait */,
-				4B57F5950D72C27900B4E719 /* jack_thread_wait */,
-				4BA7FEC30D8E76270017FF73 /* jack_server_control */,
-				BA222ACF0DC88132001A17F4 /* jack_net.so */,
-				BA222AE90DC882DB001A17F4 /* netmanager.so */,
-				4BA7FEC30D8E76270017FF73 /* jack_server_control */,
-				4B363DD80DEB02F6001F72D9 /* jack_alias */,
-				4B363E1A0DEB03C5001F72D9 /* jack_evmon */,
-				4B363E4E0DEB0775001F72D9 /* jack_bufsize */,
-				4B363EE90DEB091C001F72D9 /* jack_rec */,
-				4B363F1E0DEB0A6A001F72D9 /* jack_monitor_client */,
-				4B363F350DEB0BD1001F72D9 /* jack_showtime */,
-				4B363F720DEB0D4E001F72D9 /* jack_impulse_grabber */,
-				4BFA5E980DEC4D9C00FA4CDB /* testMutex */,
-				4BFA828C0DF6A9E40087B4E1 /* jack_evmon */,
-				4BFA829F0DF6A9E40087B4E1 /* jack_bufsize */,
-				4BFA82AB0DF6A9E40087B4E1 /* jack_rec */,
-				4BFA82B70DF6A9E40087B4E1 /* jack_monitor_client */,
-				4BFA82C30DF6A9E40087B4E1 /* jack_showtime */,
-				4BFA82CF0DF6A9E40087B4E1 /* jack_impulse_grabber */,
-				4B19B3000E23620F00DD4A82 /* audioadapter.so */,
-				4B5E08D50E5B66EE00BEE4E0 /* netadapter.so */,
-				4BF3390C0F8B864B0080FB5B /* jack_coremidi.so */,
-				4BDCDB9D1001FB9C00B15929 /* jack_coremidi.so */,
-				4BDCDBC51001FCC000B15929 /* jack_net.so */,
-				4BDCDBE81001FD2D00B15929 /* netmanager.so */,
-				4BDCDBFF1001FD7300B15929 /* audioadapter.so */,
-				4BDCDC251001FDE300B15929 /* netadapter.so */,
-				4B43A8BA10145F6F00E52943 /* jack_loopback.so */,
-				4B43A8E71014615800E52943 /* jack_loopback.so */,
-				4B3224E510A3156800838A8E /* jack_netone.so */,
-				4B32252B10A316B200838A8E /* jack_netone.so */,
-				4B32256110A3187800838A8E /* jack_netsource */,
-				4B32257B10A3190C00838A8E /* jack_netsource */,
-				4BA339AC10B2E36800190E3B /* Jackservermp.framework */,
-				4B47ACD710B5890100469C67 /* Jackmp.framework */,
-				4B6654F7127C34AE00753A79 /* jack_server_control */,
-				4B38115F1326878E00C61B14 /* jack_latent_client */,
-				4B3811971326884E00C61B14 /* jack_latent_client */,
-				4B8F16E513290DC80002AD73 /* jack_midi_dump */,
-				4B8F16F213290E0E0002AD73 /* jack_midi_dump */,
-				4B2021E6133A9BA40019E213 /* jack_midi_latency_test */,
-				4B8692DB1371DB4700D2D11B /* Jacknet.framework */,
-			);
-			name = Products;
-			sourceTree = "<group>";
-		};
-		4B03383E0797E19900686131 /* Simple clients */ = {
-			isa = PBXGroup;
-			children = (
-				4B202209133A9C1C0019E213 /* midi_latency_test.c */,
-				4B8F16F41329161E0002AD73 /* midi_dump.c */,
-				4B3811FA13269C8300C61B14 /* latent_client.c */,
-				4B6654FB127C350100753A79 /* server_control.cpp */,
-				4B363F750DEB0D7D001F72D9 /* impulse_grabber.c */,
-				4B363F220DEB0AB0001F72D9 /* monitor_client.c */,
-				4B363EED0DEB094B001F72D9 /* capture_client.c */,
-				4B363E710DEB0808001F72D9 /* bufsize.c */,
-				4B363E200DEB0401001F72D9 /* evmon.c */,
-				4B363DDE0DEB034E001F72D9 /* alias.c */,
-				4BA7FEC80D8E76650017FF73 /* control.c */,
-				4B0A28EC0D520852002EFF74 /* tw.c */,
-				4B5A1BDC0CD1CD420005BF74 /* midisine.c */,
-				4B5A1BBD0CD1CC110005BF74 /* midiseq.c */,
-				4BA692D60CBE4CC600EAD520 /* ipunload.c */,
-				4BA692B20CBE4C2D00EAD520 /* ipload.c */,
-				4BD6240C0CBCF16600DE782F /* inprocess.c */,
-				4B60CE480AAABA31004956AA /* connect.c */,
-				4BF8D1670834EDD900C94B91 /* zombie.c */,
-				4BF8D1690834EDE600C94B91 /* lsp.c */,
-				4BF8D16B0834EDF000C94B91 /* metro.c */,
-				4BF8D1710834EE0F00C94B91 /* freewheel.c */,
-				4B363F3D0DEB0C31001F72D9 /* showtime.c */,
-			);
-			name = "Simple clients";
-			sourceTree = "<group>";
-		};
-		4B05A0420DF72B8500840F4C /* Linux */ = {
-			isa = PBXGroup;
-			children = (
-				4B05A07D0DF72BC000840F4C /* driver.h */,
-				4B49D3C914864DA7003390F8 /* JackLinuxTime.c */,
-				4B349837133A6B6F00D130AB /* firewire */,
-				4B349825133A6AF500D130AB /* alsarawmidi */,
-				4B05A04C0DF72BC000840F4C /* alsa */,
-			);
-			name = Linux;
-			sourceTree = "<group>";
-		};
-		4B05A04C0DF72BC000840F4C /* alsa */ = {
-			isa = PBXGroup;
-			children = (
-				4BA2574C132FB49B009F2D3F /* alsa_driver.c */,
-				4B05A04D0DF72BC000840F4C /* alsa_driver.h */,
-				4B05A04E0DF72BC000840F4C /* alsa_midi.h */,
-				4B05A04F0DF72BC000840F4C /* alsa_midi_impl.h */,
-				4B05A0500DF72BC000840F4C /* alsa_midi_jackmp.cpp */,
-				4B05A0510DF72BC000840F4C /* alsa_rawmidi.c */,
-				4B05A0520DF72BC000840F4C /* alsa_seqmidi.c */,
-				4B05A0530DF72BC000840F4C /* bitset.h */,
-				4B05A0540DF72BC000840F4C /* generic.h */,
-				4B05A0550DF72BC000840F4C /* generic_hw.c */,
-				4B05A0560DF72BC000840F4C /* hammerfall.c */,
-				4B05A0570DF72BC000840F4C /* hammerfall.h */,
-				4B05A0580DF72BC000840F4C /* hardware.h */,
-				4B05A0590DF72BC000840F4C /* hdsp.c */,
-				4B05A05A0DF72BC000840F4C /* hdsp.h */,
-				4B05A05B0DF72BC000840F4C /* ice1712.c */,
-				4B05A05C0DF72BC000840F4C /* ice1712.h */,
-				4B05A05D0DF72BC000840F4C /* JackAlsaDriver.cpp */,
-				4B05A05E0DF72BC000840F4C /* JackAlsaDriver.h */,
-				4B05A05F0DF72BC000840F4C /* jslist.h */,
-				4B05A0620DF72BC000840F4C /* midi_pack.h */,
-				4B05A0630DF72BC000840F4C /* midi_unpack.h */,
-				4B05A0640DF72BC000840F4C /* usx2y.c */,
-				4B05A0650DF72BC000840F4C /* usx2y.h */,
-			);
-			name = alsa;
-			path = ../linux/alsa;
-			sourceTree = SOURCE_ROOT;
-		};
-		4B05A08A0DF72BF600840F4C /* Windows */ = {
-			isa = PBXGroup;
-			children = (
-				4B49D3D814864DEC003390F8 /* JackWinThread.cpp */,
-				4B49D3D914864DEC003390F8 /* JackWinServerLaunch.cpp */,
-				4B49D3DA14864DEC003390F8 /* JackWinSemaphore.cpp */,
-				4B49D3DB14864DEC003390F8 /* JackWinProcessSync.cpp */,
-				4B49D3DC14864DEC003390F8 /* JackWinNamedPipeServerNotifyChannel.cpp */,
-				4B49D3DD14864DEC003390F8 /* JackWinNamedPipeServerChannel.cpp */,
-				4B49D3DE14864DEC003390F8 /* JackWinNamedPipeNotifyChannel.cpp */,
-				4B49D3DF14864DEC003390F8 /* JackWinNamedPipeClientChannel.cpp */,
-				4B49D3E014864DED003390F8 /* JackWinNamedPipe.cpp */,
-				4B49D3E114864DED003390F8 /* JackWinEvent.cpp */,
-				4B49D3E214864DED003390F8 /* JackNetWinSocket.cpp */,
-				4B49D3E314864DED003390F8 /* JackMMCSS.cpp */,
-				4B49D3E414864DED003390F8 /* JackWinTime.c */,
-				4B49D3EA14864DED003390F8 /* JackWinThread.h */,
-				4B49D3EB14864DED003390F8 /* JackWinSemaphore.h */,
-				4B49D3EC14864DED003390F8 /* JackWinProcessSync.h */,
-				4B49D3ED14864DED003390F8 /* JackWinNamedPipeServerNotifyChannel.h */,
-				4B49D3EE14864DED003390F8 /* JackWinNamedPipeServerChannel.h */,
-				4B49D3EF14864DED003390F8 /* JackWinNamedPipeNotifyChannel.h */,
-				4B49D3F014864DED003390F8 /* JackWinNamedPipeClientChannel.h */,
-				4B49D3F114864DED003390F8 /* JackWinNamedPipe.h */,
-				4B49D3F214864DED003390F8 /* JackWinMutex.h */,
-				4B49D3F314864DED003390F8 /* JackWinEvent.h */,
-				4B49D3F814864DED003390F8 /* JackNetWinSocket.h */,
-				4B49D3F914864DED003390F8 /* JackMMCSS.h */,
-				4B49D3BB14864D49003390F8 /* portaudio */,
-				4B49D3B214864D41003390F8 /* winmme */,
-			);
-			name = Windows;
-			sourceTree = "<group>";
-		};
-		4B05A09D0DF72C6000840F4C /* Additional */ = {
-			isa = PBXGroup;
-			children = (
-				4B90676814BEFB270074CD40 /* Solaris */,
-				4B05A08A0DF72BF600840F4C /* Windows */,
-				4B05A0420DF72B8500840F4C /* Linux */,
-			);
-			name = Additional;
-			sourceTree = "<group>";
-		};
-		4B19B3010E23629800DD4A82 /* Adapter */ = {
-			isa = PBXGroup;
-			children = (
-				4BE5FECF0E725C320020B576 /* JackCoreAudioAdapter.cpp */,
-				4BE5FED00E725C320020B576 /* JackCoreAudioAdapter.h */,
-				4BF4BAB00E3480AB00403CDF /* JackAudioAdapterFactory.cpp */,
-				4B19B3060E2362E700DD4A82 /* JackAudioAdapter.cpp */,
-				4B19B3070E2362E700DD4A82 /* JackAudioAdapter.h */,
-				4B19B3080E2362E700DD4A82 /* JackAudioAdapterInterface.cpp */,
-				4B19B3090E2362E700DD4A82 /* JackAudioAdapterInterface.h */,
-				4B19B30C0E2362E700DD4A82 /* JackException.h */,
-				4B19B30E0E2362E700DD4A82 /* JackLibSampleRateResampler.cpp */,
-				4B19B30F0E2362E700DD4A82 /* JackLibSampleRateResampler.h */,
-				4B19B3120E2362E700DD4A82 /* JackResampler.cpp */,
-			);
-			name = Adapter;
-			sourceTree = "<group>";
-		};
-		4B349825133A6AF500D130AB /* alsarawmidi */ = {
-			isa = PBXGroup;
-			children = (
-				4B349826133A6AF500D130AB /* JackALSARawMidiDriver.cpp */,
-				4B349827133A6AF500D130AB /* JackALSARawMidiDriver.h */,
-				4B349828133A6AF500D130AB /* JackALSARawMidiInputPort.cpp */,
-				4B349829133A6AF500D130AB /* JackALSARawMidiInputPort.h */,
-				4B34982A133A6AF500D130AB /* JackALSARawMidiOutputPort.cpp */,
-				4B34982B133A6AF500D130AB /* JackALSARawMidiOutputPort.h */,
-				4B34982C133A6AF500D130AB /* JackALSARawMidiPort.cpp */,
-				4B34982D133A6AF500D130AB /* JackALSARawMidiPort.h */,
-				4B34982E133A6AF500D130AB /* JackALSARawMidiReceiveQueue.cpp */,
-				4B34982F133A6AF500D130AB /* JackALSARawMidiReceiveQueue.h */,
-				4B349830133A6AF500D130AB /* JackALSARawMidiSendQueue.cpp */,
-				4B349831133A6AF500D130AB /* JackALSARawMidiSendQueue.h */,
-			);
-			name = alsarawmidi;
-			path = ../linux/alsarawmidi;
-			sourceTree = SOURCE_ROOT;
-		};
-		4B349837133A6B6F00D130AB /* firewire */ = {
-			isa = PBXGroup;
-			children = (
-				4B349838133A6B6F00D130AB /* ffado_driver.h */,
-				4B349839133A6B6F00D130AB /* JackFFADODriver.cpp */,
-				4B34983A133A6B6F00D130AB /* JackFFADODriver.h */,
-				4B34983B133A6B6F00D130AB /* JackFFADOMidiInputPort.cpp */,
-				4B34983C133A6B6F00D130AB /* JackFFADOMidiInputPort.h */,
-				4B34983D133A6B6F00D130AB /* JackFFADOMidiOutputPort.cpp */,
-				4B34983E133A6B6F00D130AB /* JackFFADOMidiOutputPort.h */,
-				4B34983F133A6B6F00D130AB /* JackFFADOMidiReceiveQueue.cpp */,
-				4B349840133A6B6F00D130AB /* JackFFADOMidiReceiveQueue.h */,
-				4B349841133A6B6F00D130AB /* JackFFADOMidiSendQueue.cpp */,
-				4B349842133A6B6F00D130AB /* JackFFADOMidiSendQueue.h */,
-			);
-			name = firewire;
-			path = ../linux/firewire;
-			sourceTree = SOURCE_ROOT;
-		};
-		4B37C20006DF1F900016E567 /* Latency */ = {
-			isa = PBXGroup;
-			children = (
-			);
-			name = Latency;
-			sourceTree = "<group>";
-		};
-		4B49D3B214864D41003390F8 /* winmme */ = {
-			isa = PBXGroup;
-			children = (
-				4B49D3B314864D41003390F8 /* JackWinMMEDriver.cpp */,
-				4B49D3B414864D41003390F8 /* JackWinMMEDriver.h */,
-				4B49D3B514864D41003390F8 /* JackWinMMEInputPort.cpp */,
-				4B49D3B614864D41003390F8 /* JackWinMMEInputPort.h */,
-				4B49D3B714864D41003390F8 /* JackWinMMEOutputPort.cpp */,
-				4B49D3B814864D41003390F8 /* JackWinMMEOutputPort.h */,
-				4B49D3B914864D41003390F8 /* JackWinMMEPort.cpp */,
-				4B49D3BA14864D41003390F8 /* JackWinMMEPort.h */,
-			);
-			name = winmme;
-			path = ../windows/winmme;
-			sourceTree = SOURCE_ROOT;
-		};
-		4B49D3BB14864D49003390F8 /* portaudio */ = {
-			isa = PBXGroup;
-			children = (
-				4B49D3BC14864D49003390F8 /* JackPortAudioAdapter.cpp */,
-				4B49D3BD14864D49003390F8 /* JackPortAudioAdapter.h */,
-				4B49D3BE14864D49003390F8 /* JackPortAudioDevices.cpp */,
-				4B49D3BF14864D49003390F8 /* JackPortAudioDevices.h */,
-				4B49D3C014864D49003390F8 /* JackPortAudioDriver.cpp */,
-				4B49D3C114864D49003390F8 /* JackPortAudioDriver.h */,
-				4B49D3C214864D49003390F8 /* pa_asio.h */,
-				4B49D3C314864D49003390F8 /* portaudio.h */,
-			);
-			name = portaudio;
-			path = ../windows/portaudio;
-			sourceTree = SOURCE_ROOT;
-		};
-		4B6BEB4A07A6CCDC00A5DBDA /* Tests */ = {
-			isa = PBXGroup;
-			children = (
-				4B38141F1327AA6800C61B14 /* iodelay.cpp */,
-				4B3F49070AD8503300491C6E /* cpu.c */,
-				4BF8D23E0834F1C300C94B91 /* testAtomic.cpp */,
-				4BF8D2470834F20600C94B91 /* testSem.cpp */,
-				4BA577BC08BF8BE200F82DE1 /* testSynchroClient.cpp */,
-				4BA577FB08BF8E4600F82DE1 /* testSynchroServer.cpp */,
-				4BBD13CC08C71EB40079F7FF /* testSynchroServerClient.cpp */,
-				4BFA5E9E0DEC4DD900FA4CDB /* testMutex.cpp */,
-				4BE6C6AC0A3E0A65005A203A /* test.cpp */,
-			);
-			name = Tests;
-			sourceTree = "<group>";
-		};
-		4B6C73780CC60A6D001AFFD4 /* jack */ = {
-			isa = PBXGroup;
-			children = (
-				4B49D44014865F22003390F8 /* net.h */,
-				4B49D44114865F22003390F8 /* session.h */,
-				4B94334910A5E666002A187F /* systemdeps.h */,
-				4B9A26000DBF8584006E9FBC /* jslist.h */,
-				4B95BCAD0D913073000F7695 /* control.h */,
-				4B6B9EF50CD0958B0051EE5A /* midiport.h */,
-				4B6C73790CC60A6D001AFFD4 /* intclient.h */,
-				4B6C737A0CC60A6D001AFFD4 /* jack.h */,
-				4B6C737B0CC60A6D001AFFD4 /* ringbuffer.h */,
-				4B6C737C0CC60A6D001AFFD4 /* statistics.h */,
-				4B6C737D0CC60A6D001AFFD4 /* thread.h */,
-				4B6C737E0CC60A6D001AFFD4 /* transport.h */,
-				4B6C737F0CC60A6D001AFFD4 /* types.h */,
-				4B88D03911298BEE007A87C1 /* weakjack.h */,
-				4B88D03A11298BEE007A87C1 /* weakmacros.h */,
-			);
-			name = jack;
-			path = ../common/jack;
-			sourceTree = SOURCE_ROOT;
-		};
-		4B765CC805ECE17900571F78 /* Tools */ = {
-			isa = PBXGroup;
-			children = (
-				4BF284160F31B4BC00B05BE3 /* JackArgParser.cpp */,
-				4BF284170F31B4BC00B05BE3 /* JackArgParser.h */,
-				4BF5FBC80E878D24003D2374 /* JackMachTime.c */,
-				4B4F9C8A0DC20C0400706CB0 /* JackMessageBuffer.cpp */,
-				4B4F9C8B0DC20C0400706CB0 /* JackMessageBuffer.h */,
-				4B9A25B30DBF8330006E9FBC /* JackError.cpp */,
-				4B003AB008E2B2BA0060EFDC /* ringbuffer.c */,
-				4BF8D1770834EE4800C94B91 /* JackError.h */,
-				4BF8D1830834EE5800C94B91 /* JackTime.h */,
-			);
-			name = Tools;
-			sourceTree = "<group>";
-		};
-		4B90676814BEFB270074CD40 /* Solaris */ = {
-			isa = PBXGroup;
-			children = (
-				4B90679914BEFB500074CD40 /* JackSolarisTime.c */,
-				4B90679A14BEFB5A0074CD40 /* JackBoomerDriver.cpp */,
-				4B90679B14BEFB5A0074CD40 /* JackBoomerDriver.h */,
-				4B90679C14BEFB5A0074CD40 /* JackOSSAdapter.cpp */,
-				4B90679D14BEFB5A0074CD40 /* JackOSSAdapter.h */,
-				4B90679E14BEFB5A0074CD40 /* JackOSSDriver.cpp */,
-				4B90679F14BEFB5A0074CD40 /* JackOSSDriver.h */,
-			);
-			name = Solaris;
-			sourceTree = "<group>";
-		};
-		4B9B627005E60A9E001E19AA /* Server */ = {
-			isa = PBXGroup;
-			children = (
-				4B6C73780CC60A6D001AFFD4 /* jack */,
-				4B67AB8C14B4B03800B4AA9A /* JackException.cpp */,
-				4BE4CC000CDA153400CCF5BB /* JackTools.h */,
-				4BE4CBFF0CDA153400CCF5BB /* JackTools.cpp */,
-				4B4E9AF80E5F1090000A3278 /* JackControlAPI.cpp */,
-				4B4E9AF90E5F1090000A3278 /* JackControlAPI.h */,
-				4B66A8580934964500A89560 /* JackConstants.h */,
-				4BFB73F608AD291A00DB99B8 /* JackGlobals.h */,
-				4B2C28F908DAD01E00249230 /* JackGlobals.cpp */,
-				4BF8D2190834F03D00C94B91 /* JackEngineControl.h */,
-				4B6F7AEC0CD0CDBD00F48A9D /* JackEngineControl.cpp */,
-				4BBAE40E0F42FA6100B8BD3F /* JackEngineProfiling.h */,
-				4BBAE40F0F42FA6100B8BD3F /* JackEngineProfiling.cpp */,
-				4BD4B4D409BACD9600750C0F /* JackTransportEngine.h */,
-				4BD4B4D509BACD9600750C0F /* JackTransportEngine.cpp */,
-				4BF8D2220834F05C00C94B91 /* JackServer.h */,
-				4BF8D2210834F05C00C94B91 /* JackServer.cpp */,
-				4BF8D2250834F06A00C94B91 /* Jackdmp.cpp */,
-				4BC2168D0A444BED00BDA09F /* JackServerGlobals.h */,
-				4BC216880A444BDE00BDA09F /* JackServerGlobals.cpp */,
-			);
-			name = Server;
-			sourceTree = "<group>";
-		};
-		4BA33DF905EDFD8C000CCD5F /* Thread */ = {
-			isa = PBXGroup;
-			children = (
-				4BC3B6A20E703B2E0066E42F /* JackPosixThread.cpp */,
-				4BC3B6A30E703B2E0066E42F /* JackPosixThread.h */,
-				4BF8D19F0834EE9E00C94B91 /* JackThread.h */,
-				4BFB741F08AD2B9900DB99B8 /* JackMachThread.h */,
-				4BFB741E08AD2B9900DB99B8 /* JackMachThread.cpp */,
-			);
-			name = Thread;
-			sourceTree = "<group>";
-		};
-		4BA3873B079479C2008D8992 /* Graph */ = {
-			isa = PBXGroup;
-			children = (
-				4BF772FD08B3330F00149912 /* JackAtomic.h */,
-				4BF8D1C10834EF0800C94B91 /* JackAtomicState.h */,
-				4BF8D1C30834EF1400C94B91 /* JackConnectionManager.h */,
-				4BF8D1C40834EF1400C94B91 /* JackConnectionManager.cpp */,
-				4BF8D1C70834EF2200C94B91 /* JackGraphManager.h */,
-				4BF8D1C80834EF2200C94B91 /* JackGraphManager.cpp */,
-			);
-			name = Graph;
-			sourceTree = "<group>";
-		};
-		4BA3874007947A46008D8992 /* Synchro */ = {
-			isa = PBXGroup;
-			children = (
-				4BB4214914D2C0A700A1CAE1 /* JackPosixProcessSync.cpp */,
-				4BB4214A14D2C0A700A1CAE1 /* JackPosixProcessSync.h */,
-				4B327BA614B4B50400976483 /* JackPosixMutex.cpp */,
-				4BB4214814D2C0A700A1CAE1 /* JackPosixMutex.h */,
-				4BC3B6B70E703BAA0066E42F /* JackPosixSemaphore.cpp */,
-				4BC3B6B80E703BAA0066E42F /* JackPosixSemaphore.h */,
-				4BD561C708EEB910006BBC2A /* JackSynchro.h */,
-				4BF8D1A70834EEB400C94B91 /* JackActivationCount.h */,
-				4BF8D1A80834EEB400C94B91 /* JackActivationCount.cpp */,
-				4BF6C1D608ACE64C001E2013 /* JackMachSemaphore.h */,
-				4BF6C1D508ACE64C001E2013 /* JackMachSemaphore.cpp */,
-				4BC8326D0DF42C7D00DD1C93 /* JackMutex.h */,
-			);
-			name = Synchro;
-			sourceTree = "<group>";
-		};
-		4BA550F605E241B800569492 /* Driver */ = {
-			isa = PBXGroup;
-			children = (
-				4B869B3D08C8D21C001CF041 /* driver_interface.h */,
-				4B43A8C91014605000E52943 /* JackLoopbackDriver.h */,
-				4B43A8C81014605000E52943 /* JackLoopbackDriver.cpp */,
-				4B869B4208C8D22F001CF041 /* JackDriverLoader.h */,
-				4B869D7F08C9CB00001CF041 /* JackDriverLoader.cpp */,
-				4BF8D1B50834EEE400C94B91 /* JackDriver.h */,
-				4BF8D1B60834EEE400C94B91 /* JackDriver.cpp */,
-				4BC3988A08B3CF6C00B6F371 /* JackDummyDriver.h */,
-				4BC3988908B3CF6C00B6F371 /* JackDummyDriver.cpp */,
-				4B21794E13E2EEA60095B3E5 /* JackTimedDriver.h */,
-				4B21794D13E2EEA60095B3E5 /* JackTimedDriver.cpp */,
-				4BF3390D0F8B86AF0080FB5B /* MIDI */,
-				4B19B3010E23629800DD4A82 /* Adapter */,
-				4BD56D8707968982006D44F9 /* Threaded */,
-				BA222AEA0DC88379001A17F4 /* Net */,
-				4BD56D8607968979006D44F9 /* Audio */,
-			);
-			name = Driver;
-			sourceTree = "<group>";
-		};
-		4BA550F905E241D900569492 /* Library */ = {
-			isa = PBXGroup;
-			children = (
-				4BF8D1FB0834EFD100C94B91 /* JackLibGlobals.h */,
-				4BF8D1FC0834EFD100C94B91 /* JackLibClient.h */,
-				4BF8D1FD0834EFD100C94B91 /* JackLibClient.cpp */,
-				4BF8D1FE0834EFD100C94B91 /* JackLibAPI.cpp */,
-			);
-			name = Library;
-			sourceTree = "<group>";
-		};
-		4BA550FA05E241F200569492 /* Ports */ = {
-			isa = PBXGroup;
-			children = (
-				4BA550FB05E2420000569492 /* Engine */,
-				4B80D7E60BA0D17400F035BB /* JackMidiPort.cpp */,
-				4B80D7E50BA0D17400F035BB /* JackMidiPort.h */,
-				4BAB95EC0B9E21A500A0C723 /* JackAudioPort.cpp */,
-				4BAB95B70B9E20B800A0C723 /* JackPortType.h */,
-				4BAB95B60B9E20B800A0C723 /* JackPortType.cpp */,
-				4BF8D1CF0834EF2F00C94B91 /* JackPort.h */,
-				4BF8D1D00834EF2F00C94B91 /* JackPort.cpp */,
-			);
-			name = Ports;
-			sourceTree = "<group>";
-		};
-		4BA550FB05E2420000569492 /* Engine */ = {
-			isa = PBXGroup;
-			children = (
-				4B193990133F321500547810 /* JackFilters.h */,
-				4B5F253D0DEE9B8F0041E486 /* JackLockedEngine.h */,
-				4BF8D2130834F02800C94B91 /* JackEngine.h */,
-				4BF8D2140834F02800C94B91 /* JackEngine.cpp */,
-				4BF8FB0E08AC88EF00D1A344 /* JackFrameTimer.h */,
-				4BF8FB0D08AC88EF00D1A344 /* JackFrameTimer.cpp */,
-			);
-			name = Engine;
-			sourceTree = "<group>";
-		};
-		4BA550FC05E2421400569492 /* Shm */ = {
-			isa = PBXGroup;
-			children = (
-				4BF8D18F0834EE8400C94B91 /* shm.h */,
-				4BF8D1900834EE8400C94B91 /* shm.c */,
-				4BF8D1870834EE7900C94B91 /* JackShmMem.h */,
-				4BF8D1880834EE7900C94B91 /* JackShmMem.cpp */,
-			);
-			name = Shm;
-			sourceTree = "<group>";
-		};
-		4BA550FF05E2423600569492 /* Channels */ = {
-			isa = PBXGroup;
-			children = (
-				4B90669814BEE6D20074CD40 /* JackRequestDecoder.cpp */,
-				4B90669914BEE6D20074CD40 /* JackRequestDecoder.h */,
-				4B1499EE14BDA5B300A51A3C /* JackGenericClientChannel.cpp */,
-				4B1499EF14BDA5B300A51A3C /* JackGenericClientChannel.h */,
-				4BF8D1AF0834EEC400C94B91 /* JackChannel.h */,
-				4BF8D1B30834EED500C94B91 /* JackInternalClientChannel.h */,
-				4BB371D40C1AD85A0050C1E4 /* JackNotification.h */,
-				4BFB299908AF452300D450D4 /* Socket */,
-			);
-			name = Channels;
-			sourceTree = "<group>";
-		};
-		4BD56D73079687AD006D44F9 /* External */ = {
-			isa = PBXGroup;
-			children = (
-				4BF8D1F70834EFBD00C94B91 /* JackExternalClient.h */,
-				4BF8D1F80834EFBD00C94B91 /* JackExternalClient.cpp */,
-			);
-			name = External;
-			sourceTree = "<group>";
-		};
-		4BD56D74079687D7006D44F9 /* Client */ = {
-			isa = PBXGroup;
-			children = (
-				4BF5FBBA0E878B9C003D2374 /* JackPosixServerLaunch.cpp */,
-				4BF8D1D90834EF4500C94B91 /* JackClientInterface.h */,
-				4BF8D1DD0834EF4D00C94B91 /* JackClientControl.h */,
-				4BF8D1E10834EF5500C94B91 /* JackClient.h */,
-				4BF8D1E50834EF6700C94B91 /* JackClient.cpp */,
-				4B98AE010931D30C0091932A /* JackDebugClient.h */,
-				4B98AE000931D30C0091932A /* JackDebugClient.cpp */,
-				4BF8D1E90834EF7500C94B91 /* JackAPI.cpp */,
-				4B80D7E70BA0D17400F035BB /* JackMidiAPI.cpp */,
-				4BF520580CB8D1010037470E /* timestamps.h */,
-				4BF520520CB8D0E80037470E /* timestamps.c */,
-				4BD56D75079687EB006D44F9 /* Internal  */,
-				4BD56D73079687AD006D44F9 /* External */,
-				4BA550F905E241D900569492 /* Library */,
-			);
-			name = Client;
-			sourceTree = "<group>";
-		};
-		4BD56D75079687EB006D44F9 /* Internal  */ = {
-			isa = PBXGroup;
-			children = (
-				4BF8D1EE0834EF9200C94B91 /* JackInternalClient.h */,
-				4BF8D1ED0834EF9200C94B91 /* JackInternalClient.cpp */,
-				4BF8D1F50834EFB000C94B91 /* JackServerAPI.cpp */,
-			);
-			name = "Internal ";
-			sourceTree = "<group>";
-		};
-		4BD56D8607968979006D44F9 /* Audio */ = {
-			isa = PBXGroup;
-			children = (
-				4BAA150114F04FB600402512 /* JackAC3Encoder.cpp */,
-				4BAA150214F04FB600402512 /* JackAC3Encoder.h */,
-				4BBB00CF0E72614F0018AB1B /* JackPortAudioDevices.cpp */,
-				4BBB00D00E72614F0018AB1B /* JackPortAudioDevices.h */,
-				4BBB00D10E72614F0018AB1B /* JackPortAudioDriver.cpp */,
-				4BBB00D20E72614F0018AB1B /* JackPortAudioDriver.h */,
-				4BE5FECB0E725C090020B576 /* JackCoreAudioDriver.cpp */,
-				4BE5FECC0E725C090020B576 /* JackCoreAudioDriver.h */,
-				4B940B9B06DDDE5B00D77F60 /* AudioHardware.h */,
-				4BF8D2290834F07D00C94B91 /* JackAudioDriver.h */,
-				4BF8D22A0834F07D00C94B91 /* JackAudioDriver.cpp */,
-			);
-			name = Audio;
-			sourceTree = "<group>";
-		};
-		4BD56D8707968982006D44F9 /* Threaded */ = {
-			isa = PBXGroup;
-			children = (
-				4BF8D1BD0834EEFC00C94B91 /* JackThreadedDriver.h */,
-				4BF8D1BE0834EEFC00C94B91 /* JackThreadedDriver.cpp */,
-				4BF8D1B90834EEF100C94B91 /* JackFreewheelDriver.h */,
-				4BF8D1BA0834EEF100C94B91 /* JackFreewheelDriver.cpp */,
-				4B4CA9730E02CF9600F4BFDA /* JackRestartThreadedDriver.h */,
-				4B4CA9740E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp */,
-				4BBC93B90DF9736C002DF220 /* JackWaitThreadedDriver.h */,
-				4BBC93B80DF9736C002DF220 /* JackWaitThreadedDriver.cpp */,
-			);
-			name = Threaded;
-			sourceTree = "<group>";
-		};
-		4BF3390D0F8B86AF0080FB5B /* MIDI */ = {
-			isa = PBXGroup;
-			children = (
-				4B193973133F31CB00547810 /* JackMidiReceiveQueue.cpp */,
-				4B193974133F31CB00547810 /* JackMidiReceiveQueue.h */,
-				4B193975133F31CB00547810 /* JackMidiSendQueue.cpp */,
-				4B193976133F31CB00547810 /* JackMidiSendQueue.h */,
-				4B193977133F31CB00547810 /* JackMidiUtil.cpp */,
-				4B193978133F31CB00547810 /* JackMidiUtil.h */,
-				4B193979133F31CB00547810 /* JackMidiWriteQueue.cpp */,
-				4B19397A133F31CB00547810 /* JackMidiWriteQueue.h */,
-				4B193968133F319000547810 /* JackMidiBufferWriteQueue.cpp */,
-				4B193969133F319000547810 /* JackMidiBufferWriteQueue.h */,
-				4B19395D133F317300547810 /* JackMidiBufferReadQueue.cpp */,
-				4B19395E133F317300547810 /* JackMidiBufferReadQueue.h */,
-				4B193945133F315200547810 /* JackMidiReadQueue.cpp */,
-				4B193946133F315200547810 /* JackMidiReadQueue.h */,
-				4B19393B133F313000547810 /* JackMidiAsyncWaitQueue.cpp */,
-				4B19393C133F313000547810 /* JackMidiAsyncWaitQueue.h */,
-				4B193931133F311400547810 /* JackMidiAsyncQueue.cpp */,
-				4B193932133F311400547810 /* JackMidiAsyncQueue.h */,
-				4B370A14133DD7E200237B68 /* JackCoreMidiInputPort.cpp */,
-				4B370A15133DD7E200237B68 /* JackCoreMidiInputPort.h */,
-				4B370A16133DD7E200237B68 /* JackCoreMidiOutputPort.cpp */,
-				4B370A17133DD7E200237B68 /* JackCoreMidiOutputPort.h */,
-				4B370A18133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.cpp */,
-				4B370A19133DD7E200237B68 /* JackCoreMidiPhysicalInputPort.h */,
-				4B370A1A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp */,
-				4B370A1B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h */,
-				4B370A1C133DD7E300237B68 /* JackCoreMidiPort.cpp */,
-				4B370A1D133DD7E300237B68 /* JackCoreMidiPort.h */,
-				4B370A1E133DD7E300237B68 /* JackCoreMidiUtil.cpp */,
-				4B370A1F133DD7E300237B68 /* JackCoreMidiUtil.h */,
-				4B370A20133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp */,
-				4B370A21133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h */,
-				4B370A22133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp */,
-				4B370A23133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h */,
-				4BF3391F0F8B873E0080FB5B /* JackMidiDriver.cpp */,
-				4BF339200F8B873E0080FB5B /* JackMidiDriver.h */,
-				4BF339140F8B86DC0080FB5B /* JackCoreMidiDriver.h */,
-				4BF339150F8B86DC0080FB5B /* JackCoreMidiDriver.cpp */,
-			);
-			name = MIDI;
-			sourceTree = "<group>";
-		};
-		4BFB299908AF452300D450D4 /* Socket */ = {
-			isa = PBXGroup;
-			children = (
-				4BC3B6AD0E703B8D0066E42F /* JackSocket.cpp */,
-				4BC3B6AE0E703B8D0066E42F /* JackSocket.h */,
-				4BC3B6AF0E703B8D0066E42F /* JackSocketClientChannel.cpp */,
-				4BC3B6B00E703B8D0066E42F /* JackSocketClientChannel.h */,
-				4BC3B6B10E703B8D0066E42F /* JackSocketNotifyChannel.cpp */,
-				4BC3B6B20E703B8D0066E42F /* JackSocketNotifyChannel.h */,
-				4BC3B6B30E703B8D0066E42F /* JackSocketServerChannel.cpp */,
-				4BC3B6B40E703B8D0066E42F /* JackSocketServerChannel.h */,
-				4BC3B6B50E703B8D0066E42F /* JackSocketServerNotifyChannel.cpp */,
-				4BC3B6B60E703B8D0066E42F /* JackSocketServerNotifyChannel.h */,
-			);
-			name = Socket;
-			sourceTree = "<group>";
-		};
-		BA222AEA0DC88379001A17F4 /* Net */ = {
-			isa = PBXGroup;
-			children = (
-				4B8693151371DD0A00D2D11B /* JackNetAPI.cpp */,
-				4B32256310A318E300838A8E /* netsource.c */,
-				4B3224EC10A315C400838A8E /* netjack_packet.c */,
-				4B3224ED10A315C400838A8E /* netjack_packet.h */,
-				4B3224EE10A315C400838A8E /* netjack.c */,
-				4B3224EF10A315C400838A8E /* netjack.h */,
-				4B3224E810A315B100838A8E /* JackNetOneDriver.cpp */,
-				4B3224E910A315B100838A8E /* JackNetOneDriver.h */,
-				4BC3B6B90E703BCC0066E42F /* JackNetUnixSocket.cpp */,
-				4BC3B6BA0E703BCC0066E42F /* JackNetUnixSocket.h */,
-				4B5E08DF0E5B676C00BEE4E0 /* JackNetAdapter.cpp */,
-				4B5E08E00E5B676C00BEE4E0 /* JackNetAdapter.h */,
-				4B76C7680E5AB2DB00E2AC21 /* JackNetInterface.cpp */,
-				4B76C7690E5AB2DB00E2AC21 /* JackNetInterface.h */,
-				BA222ADD0DC882A5001A17F4 /* JackNetDriver.h */,
-				BA222ADC0DC882A5001A17F4 /* JackNetDriver.cpp */,
-				BA047C710E14E7540041F3B6 /* JackNetSocket.h */,
-				BA222AEB0DC883B3001A17F4 /* JackNetManager.cpp */,
-				BA222AEC0DC883B3001A17F4 /* JackNetManager.h */,
-				BA222AD60DC88268001A17F4 /* JackNetTool.cpp */,
-				BA222AD70DC88268001A17F4 /* JackNetTool.h */,
-			);
-			name = Net;
-			sourceTree = "<group>";
-		};
-		C6859E8C029090F304C91782 /* Documentation */ = {
-			isa = PBXGroup;
-			children = (
-				C6859E8B029090EE04C91782 /* JackServer.1 */,
-			);
-			name = Documentation;
-			sourceTree = "<group>";
-		};
-/* End PBXGroup section */
-
-/* Begin PBXHeadersBuildPhase section */
-		4B0A28DD0D52073D002EFF74 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0A29240D52108E002EFF74 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B19B2F70E23620F00DD4A82 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B19B3140E2362E800DD4A82 /* JackAudioAdapter.h in Headers */,
-				4B19B3160E2362E800DD4A82 /* JackAudioAdapterInterface.h in Headers */,
-				4B19B31C0E2362E800DD4A82 /* JackLibSampleRateResampler.h in Headers */,
-				4BE5FED20E725C320020B576 /* JackCoreAudioAdapter.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B2021DD133A9BA40019E213 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3224D810A3156800838A8E /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3224EB10A315B100838A8E /* JackNetOneDriver.h in Headers */,
-				4B3224F110A315C400838A8E /* netjack_packet.h in Headers */,
-				4B3224F310A315C400838A8E /* netjack.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32251E10A316B200838A8E /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B32253210A3173A00838A8E /* JackNetOneDriver.h in Headers */,
-				4B32253410A3173C00838A8E /* netjack.h in Headers */,
-				4B32253610A3173E00838A8E /* netjack_packet.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32255810A3187800838A8E /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B32256E10A318FD00838A8E /* netjack_packet.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32257210A3190C00838A8E /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B32258010A3195A00838A8E /* netjack_packet.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C41C0D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B9A26040DBF8584006E9FBC /* jslist.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4280D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C42A0D4731D1000DE7AE /* JackError.h in Headers */,
-				4B35C42B0D4731D1000DE7AE /* JackTime.h in Headers */,
-				4B35C42C0D4731D1000DE7AE /* JackShmMem.h in Headers */,
-				4B35C42D0D4731D1000DE7AE /* shm.h in Headers */,
-				4B35C42F0D4731D1000DE7AE /* JackThread.h in Headers */,
-				4B35C4300D4731D1000DE7AE /* JackActivationCount.h in Headers */,
-				4B35C4310D4731D1000DE7AE /* JackChannel.h in Headers */,
-				4B35C4320D4731D1000DE7AE /* JackGraphManager.h in Headers */,
-				4B35C4330D4731D1000DE7AE /* JackPort.h in Headers */,
-				4B35C4340D4731D1000DE7AE /* JackClientInterface.h in Headers */,
-				4B35C4350D4731D1000DE7AE /* JackClientControl.h in Headers */,
-				4B35C4360D4731D1000DE7AE /* JackClient.h in Headers */,
-				4B35C4370D4731D1000DE7AE /* JackInternalClient.h in Headers */,
-				4B35C4380D4731D1000DE7AE /* JackLibGlobals.h in Headers */,
-				4B35C4390D4731D1000DE7AE /* JackLibClient.h in Headers */,
-				4B35C43A0D4731D1000DE7AE /* JackConnectionManager.h in Headers */,
-				4B35C43B0D4731D1000DE7AE /* JackFrameTimer.h in Headers */,
-				4B35C43D0D4731D1000DE7AE /* JackMachSemaphore.h in Headers */,
-				4B35C43E0D4731D1000DE7AE /* JackGlobals.h in Headers */,
-				4B35C43F0D4731D1000DE7AE /* JackMachThread.h in Headers */,
-				4B35C4460D4731D1000DE7AE /* JackSynchro.h in Headers */,
-				4B35C4470D4731D1000DE7AE /* JackDebugClient.h in Headers */,
-				4B35C4480D4731D1000DE7AE /* JackConstants.h in Headers */,
-				4B35C4490D4731D1000DE7AE /* JackTransportEngine.h in Headers */,
-				4B35C44A0D4731D1000DE7AE /* timestamps.h in Headers */,
-				4B35C44B0D4731D1000DE7AE /* intclient.h in Headers */,
-				4B35C44C0D4731D1000DE7AE /* jack.h in Headers */,
-				4B35C44D0D4731D1000DE7AE /* ringbuffer.h in Headers */,
-				4B35C44E0D4731D1000DE7AE /* statistics.h in Headers */,
-				4B35C44F0D4731D1000DE7AE /* thread.h in Headers */,
-				4B35C4500D4731D1000DE7AE /* transport.h in Headers */,
-				4B35C4510D4731D1000DE7AE /* types.h in Headers */,
-				4B35C4520D4731D1000DE7AE /* JackPortType.h in Headers */,
-				4B35C4530D4731D1000DE7AE /* JackMidiPort.h in Headers */,
-				4B35C4540D4731D1000DE7AE /* midiport.h in Headers */,
-				4B35C4550D4731D1000DE7AE /* JackTools.h in Headers */,
-				4B9A26050DBF8584006E9FBC /* jslist.h in Headers */,
-				4B4F9C910DC20C0400706CB0 /* JackMessageBuffer.h in Headers */,
-				4B93F19E0E87998400E4ECCD /* JackPosixThread.h in Headers */,
-				4B88D03F11298BEE007A87C1 /* weakjack.h in Headers */,
-				4B88D04011298BEE007A87C1 /* weakmacros.h in Headers */,
-				4B8A38F0117B827900664E07 /* JackSocket.h in Headers */,
-				4B8A38F7117B82B200664E07 /* JackSocketClientChannel.h in Headers */,
-				4B5160A813215E8B00BB7DCB /* systemdeps.h in Headers */,
-				4B193993133F321500547810 /* JackFilters.h in Headers */,
-				4B49D44614865F22003390F8 /* net.h in Headers */,
-				4B49D44714865F22003390F8 /* session.h in Headers */,
-				4B1499F714BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */,
-				4BB4215114D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */,
-				4BB4215314D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */,
-				4B4C3B651BC2FF6A0004CC35 /* JackPosixSemaphore.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4860D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C4880D4731D1000DE7AE /* JackError.h in Headers */,
-				4B35C4890D4731D1000DE7AE /* JackTime.h in Headers */,
-				4B35C48A0D4731D1000DE7AE /* JackShmMem.h in Headers */,
-				4B35C48B0D4731D1000DE7AE /* shm.h in Headers */,
-				4B35C48D0D4731D1000DE7AE /* JackThread.h in Headers */,
-				4B35C48E0D4731D1000DE7AE /* JackActivationCount.h in Headers */,
-				4B35C48F0D4731D1000DE7AE /* JackChannel.h in Headers */,
-				4B35C4900D4731D1000DE7AE /* JackGraphManager.h in Headers */,
-				4B35C4910D4731D1000DE7AE /* JackPort.h in Headers */,
-				4B35C4920D4731D1000DE7AE /* JackClientInterface.h in Headers */,
-				4B35C4930D4731D1000DE7AE /* JackClientControl.h in Headers */,
-				4B35C4940D4731D1000DE7AE /* JackClient.h in Headers */,
-				4B35C4950D4731D1000DE7AE /* JackInternalClient.h in Headers */,
-				4B35C4960D4731D1000DE7AE /* JackConnectionManager.h in Headers */,
-				4B35C4970D4731D1000DE7AE /* JackFrameTimer.h in Headers */,
-				4B35C4990D4731D1000DE7AE /* JackMachSemaphore.h in Headers */,
-				4B35C49A0D4731D1000DE7AE /* JackGlobals.h in Headers */,
-				4B35C49B0D4731D1000DE7AE /* JackMachThread.h in Headers */,
-				4B35C4A00D4731D1000DE7AE /* JackSynchro.h in Headers */,
-				4B35C4A10D4731D1000DE7AE /* JackAudioDriver.h in Headers */,
-				4B35C4A20D4731D1000DE7AE /* JackFreewheelDriver.h in Headers */,
-				4B35C4A30D4731D1000DE7AE /* JackThreadedDriver.h in Headers */,
-				4B35C4A40D4731D1000DE7AE /* JackDriver.h in Headers */,
-				4B35C4A50D4731D1000DE7AE /* driver_interface.h in Headers */,
-				4B35C4A70D4731D1000DE7AE /* JackDriverLoader.h in Headers */,
-				4B35C4A90D4731D1000DE7AE /* JackEngine.h in Headers */,
-				4B35C4AA0D4731D1000DE7AE /* JackExternalClient.h in Headers */,
-				4B35C4AB0D4731D1000DE7AE /* JackServer.h in Headers */,
-				4B35C4B20D4731D1000DE7AE /* JackConstants.h in Headers */,
-				4B35C4B30D4731D1000DE7AE /* JackTransportEngine.h in Headers */,
-				4B35C4B40D4731D1000DE7AE /* JackServerGlobals.h in Headers */,
-				4B35C4B50D4731D1000DE7AE /* timestamps.h in Headers */,
-				4B35C4B60D4731D1000DE7AE /* jack.h in Headers */,
-				4B35C4B70D4731D1000DE7AE /* intclient.h in Headers */,
-				4B35C4B80D4731D1000DE7AE /* ringbuffer.h in Headers */,
-				4B35C4B90D4731D1000DE7AE /* statistics.h in Headers */,
-				4B35C4BA0D4731D1000DE7AE /* thread.h in Headers */,
-				4B35C4BB0D4731D1000DE7AE /* transport.h in Headers */,
-				4B35C4BC0D4731D1000DE7AE /* types.h in Headers */,
-				4B35C4BD0D4731D1000DE7AE /* JackPortType.h in Headers */,
-				4B35C4BE0D4731D1000DE7AE /* JackMidiPort.h in Headers */,
-				4B35C4BF0D4731D1000DE7AE /* midiport.h in Headers */,
-				4B35C4C00D4731D1000DE7AE /* JackDebugClient.h in Headers */,
-				4B35C4C10D4731D1000DE7AE /* JackTools.h in Headers */,
-				BA222ADB0DC88269001A17F4 /* JackNetTool.h in Headers */,
-				4B9A26060DBF8584006E9FBC /* jslist.h in Headers */,
-				4B4F9C930DC20C0400706CB0 /* JackMessageBuffer.h in Headers */,
-				4B4CA9770E02CF9600F4BFDA /* JackRestartThreadedDriver.h in Headers */,
-				4B4E9AFD0E5F1090000A3278 /* JackControlAPI.h in Headers */,
-				4B93F19A0E87992200E4ECCD /* JackPosixThread.h in Headers */,
-				4BBAE4120F42FA6100B8BD3F /* JackEngineProfiling.h in Headers */,
-				4BF339220F8B873E0080FB5B /* JackMidiDriver.h in Headers */,
-				4BDCDBD21001FD0200B15929 /* JackWaitThreadedDriver.h in Headers */,
-				4BDCDC0A1001FDA800B15929 /* JackArgParser.h in Headers */,
-				4B88D04311298BEE007A87C1 /* weakjack.h in Headers */,
-				4B88D04411298BEE007A87C1 /* weakmacros.h in Headers */,
-				4BC2CA5A113C6CB80076717C /* JackNetInterface.h in Headers */,
-				4BC2CA5C113C6CC00076717C /* JackNetUnixSocket.h in Headers */,
-				4B8A38A8117B80DA00664E07 /* JackSocket.h in Headers */,
-				4B8A38AD117B810A00664E07 /* JackSocketNotifyChannel.h in Headers */,
-				4B8A38B0117B812500664E07 /* JackSocketServerChannel.h in Headers */,
-				4B8A38C4117B814000664E07 /* JackSocketServerNotifyChannel.h in Headers */,
-				4B5160AA13215ED900BB7DCB /* systemdeps.h in Headers */,
-				4B193995133F321500547810 /* JackFilters.h in Headers */,
-				4B97B6611344B49500794F57 /* JackMidiAsyncQueue.h in Headers */,
-				4B97B6631344B4A800794F57 /* JackMidiAsyncWaitQueue.h in Headers */,
-				4B97B6651344B4B500794F57 /* JackMidiBufferReadQueue.h in Headers */,
-				4B97B6671344B4C700794F57 /* JackMidiBufferWriteQueue.h in Headers */,
-				4B97B66F1344B4DC00794F57 /* JackMidiReadQueue.h in Headers */,
-				4B97B6711344B4EA00794F57 /* JackMidiReceiveQueue.h in Headers */,
-				4B97B6781344B50800794F57 /* JackMidiSendQueue.h in Headers */,
-				4B97B67A1344B51600794F57 /* JackMidiUtil.h in Headers */,
-				4B97B67C1344B52800794F57 /* JackMidiWriteQueue.h in Headers */,
-				4B21795213E2EEA60095B3E5 /* JackTimedDriver.h in Headers */,
-				4B49D44A14865F22003390F8 /* net.h in Headers */,
-				4B49D44B14865F22003390F8 /* session.h in Headers */,
-				4B1499F114BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */,
-				4B90669B14BEE6D20074CD40 /* JackRequestDecoder.h in Headers */,
-				4BB4215714D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */,
-				4BB4215914D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */,
-				4B4C3B6D1BC2FFC70004CC35 /* JackPosixSemaphore.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C50B0D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5170D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5230D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C52F0D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C53B0D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5470D4731D1000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5550D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5610D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C56D0D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5790D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5890D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C59D0D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5A90D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5B50D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5C10D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5CD0D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5D90D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5DA0D4731D2000DE7AE /* JackError.h in Headers */,
-				4B35C5DB0D4731D2000DE7AE /* JackConstants.h in Headers */,
-				4B4F9D830DC2178F00706CB0 /* JackMessageBuffer.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5ED0D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6010D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6150D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA4ADB50E87AB2600F26C85 /* JackCoreAudioDriver.h in Headers */,
-				4BAA150614F04FB600402512 /* JackAC3Encoder.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6200D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C62B0D4731D2000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C62C0D4731D2000DE7AE /* JackDummyDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6360D4731D3000DE7AE /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363DCF0DEB02F6001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E110DEB03C5001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E450DEB0775001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363EE00DEB091C001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F150DEB0A6A001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F2C0DEB0BD1001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F690DEB0D4E001F72D9 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3811561326878E00C61B14 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B38118E1326884E00C61B14 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B43A8B110145F6F00E52943 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B43A8CB1014605000E52943 /* JackLoopbackDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B43A8DE1014615800E52943 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B43A8DF1014615800E52943 /* JackLoopbackDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B47AC8110B5890100469C67 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B47AC8310B5890100469C67 /* JackError.h in Headers */,
-				4B47AC8410B5890100469C67 /* JackTime.h in Headers */,
-				4B47AC8510B5890100469C67 /* JackShmMem.h in Headers */,
-				4B47AC8610B5890100469C67 /* shm.h in Headers */,
-				4B47AC8710B5890100469C67 /* JackThread.h in Headers */,
-				4B47AC8810B5890100469C67 /* JackActivationCount.h in Headers */,
-				4B47AC8910B5890100469C67 /* JackChannel.h in Headers */,
-				4B47AC8A10B5890100469C67 /* JackGraphManager.h in Headers */,
-				4B47AC8B10B5890100469C67 /* JackPort.h in Headers */,
-				4B47AC8C10B5890100469C67 /* JackClientInterface.h in Headers */,
-				4B47AC8D10B5890100469C67 /* JackClientControl.h in Headers */,
-				4B47AC8E10B5890100469C67 /* JackClient.h in Headers */,
-				4B47AC8F10B5890100469C67 /* JackInternalClient.h in Headers */,
-				4B47AC9010B5890100469C67 /* JackLibGlobals.h in Headers */,
-				4B47AC9110B5890100469C67 /* JackLibClient.h in Headers */,
-				4B47AC9210B5890100469C67 /* JackConnectionManager.h in Headers */,
-				4B47AC9310B5890100469C67 /* JackFrameTimer.h in Headers */,
-				4B47AC9410B5890100469C67 /* JackMachSemaphore.h in Headers */,
-				4B47AC9510B5890100469C67 /* JackGlobals.h in Headers */,
-				4B47AC9610B5890100469C67 /* JackMachThread.h in Headers */,
-				4B47AC9810B5890100469C67 /* JackSynchro.h in Headers */,
-				4B47AC9910B5890100469C67 /* JackDebugClient.h in Headers */,
-				4B47AC9A10B5890100469C67 /* JackConstants.h in Headers */,
-				4B47AC9B10B5890100469C67 /* JackTransportEngine.h in Headers */,
-				4B47AC9C10B5890100469C67 /* timestamps.h in Headers */,
-				4B47AC9D10B5890100469C67 /* intclient.h in Headers */,
-				4B47AC9E10B5890100469C67 /* jack.h in Headers */,
-				4B47AC9F10B5890100469C67 /* ringbuffer.h in Headers */,
-				4B47ACA010B5890100469C67 /* statistics.h in Headers */,
-				4B47ACA110B5890100469C67 /* thread.h in Headers */,
-				4B47ACA210B5890100469C67 /* transport.h in Headers */,
-				4B47ACA310B5890100469C67 /* types.h in Headers */,
-				4B47ACA410B5890100469C67 /* JackPortType.h in Headers */,
-				4B47ACA510B5890100469C67 /* JackMidiPort.h in Headers */,
-				4B47ACA610B5890100469C67 /* midiport.h in Headers */,
-				4B47ACA710B5890100469C67 /* JackTools.h in Headers */,
-				4B47ACA810B5890100469C67 /* jslist.h in Headers */,
-				4B47ACA910B5890100469C67 /* JackMessageBuffer.h in Headers */,
-				4B47ACAA10B5890100469C67 /* JackPosixThread.h in Headers */,
-				4B88D04111298BEE007A87C1 /* weakjack.h in Headers */,
-				4B88D04211298BEE007A87C1 /* weakmacros.h in Headers */,
-				4B5160A913215EBF00BB7DCB /* systemdeps.h in Headers */,
-				4B193994133F321500547810 /* JackFilters.h in Headers */,
-				4B49D44814865F22003390F8 /* net.h in Headers */,
-				4B49D44914865F22003390F8 /* session.h in Headers */,
-				4B1499F914BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */,
-				4BB4215414D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */,
-				4BB4215614D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */,
-				4B4C3B6B1BC2FFB50004CC35 /* JackPosixSemaphore.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BB20CD1CB9E0005BF74 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BD10CD1CCE10005BF74 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5E08C00E5B66EE00BEE4E0 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B5E08C30E5B66EE00BEE4E0 /* JackAudioAdapterInterface.h in Headers */,
-				4B5E08C60E5B66EE00BEE4E0 /* JackLibSampleRateResampler.h in Headers */,
-				4B5E08E20E5B676D00BEE4E0 /* JackNetAdapter.h in Headers */,
-				4B5E08EF0E5B680200BEE4E0 /* JackAudioAdapter.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B6654EE127C34AE00753A79 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699BA8097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C01097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699C03097D421600A18468 /* JackError.h in Headers */,
-				4B699C04097D421600A18468 /* JackTime.h in Headers */,
-				4B699C05097D421600A18468 /* JackShmMem.h in Headers */,
-				4B699C06097D421600A18468 /* shm.h in Headers */,
-				4B699C08097D421600A18468 /* JackThread.h in Headers */,
-				4B699C09097D421600A18468 /* JackActivationCount.h in Headers */,
-				4B699C0A097D421600A18468 /* JackChannel.h in Headers */,
-				4B699C0B097D421600A18468 /* JackGraphManager.h in Headers */,
-				4B699C0C097D421600A18468 /* JackPort.h in Headers */,
-				4B699C0D097D421600A18468 /* JackClientInterface.h in Headers */,
-				4B699C0E097D421600A18468 /* JackClientControl.h in Headers */,
-				4B699C0F097D421600A18468 /* JackClient.h in Headers */,
-				4B699C10097D421600A18468 /* JackInternalClient.h in Headers */,
-				4B699C11097D421600A18468 /* JackLibGlobals.h in Headers */,
-				4B699C12097D421600A18468 /* JackLibClient.h in Headers */,
-				4B699C13097D421600A18468 /* JackConnectionManager.h in Headers */,
-				4B699C14097D421600A18468 /* JackFrameTimer.h in Headers */,
-				4B699C16097D421600A18468 /* JackMachSemaphore.h in Headers */,
-				4B699C17097D421600A18468 /* JackGlobals.h in Headers */,
-				4B699C18097D421600A18468 /* JackMachThread.h in Headers */,
-				4B699C20097D421600A18468 /* JackSynchro.h in Headers */,
-				4B699C21097D421600A18468 /* JackDebugClient.h in Headers */,
-				4B699C22097D421600A18468 /* JackConstants.h in Headers */,
-				4BF520590CB8D1010037470E /* timestamps.h in Headers */,
-				4B6C73800CC60A7F001AFFD4 /* intclient.h in Headers */,
-				4B6C73810CC60A7F001AFFD4 /* jack.h in Headers */,
-				4B6C73820CC60A7F001AFFD4 /* ringbuffer.h in Headers */,
-				4B6C73830CC60A80001AFFD4 /* statistics.h in Headers */,
-				4B6C73840CC60A80001AFFD4 /* thread.h in Headers */,
-				4B6C73850CC60A81001AFFD4 /* transport.h in Headers */,
-				4BE3225A0CC611EF00AFA640 /* types.h in Headers */,
-				4BAB95B90B9E20B800A0C723 /* JackPortType.h in Headers */,
-				4B80D7E80BA0D17400F035BB /* JackMidiPort.h in Headers */,
-				4B6B9EF60CD095930051EE5A /* midiport.h in Headers */,
-				4BE4CC020CDA153500CCF5BB /* JackTools.h in Headers */,
-				4B9A26010DBF8584006E9FBC /* jslist.h in Headers */,
-				4B4F9C8F0DC20C0400706CB0 /* JackMessageBuffer.h in Headers */,
-				4BB9D4B30E2610B300351653 /* JackTransportEngine.h in Headers */,
-				4BC3B6A50E703B2E0066E42F /* JackPosixThread.h in Headers */,
-				4B94334A10A5E666002A187F /* systemdeps.h in Headers */,
-				4B88D03B11298BEE007A87C1 /* weakjack.h in Headers */,
-				4B88D03C11298BEE007A87C1 /* weakmacros.h in Headers */,
-				4B2209ED12F6BC2200E5DC26 /* JackSocket.h in Headers */,
-				4B2209EF12F6BC2500E5DC26 /* JackSocketClientChannel.h in Headers */,
-				4B193991133F321500547810 /* JackFilters.h in Headers */,
-				4B49D44414865F22003390F8 /* net.h in Headers */,
-				4B49D44514865F22003390F8 /* session.h in Headers */,
-				4B1499F514BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */,
-				4BB4214B14D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */,
-				4BB4214D14D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C4D097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699C4F097D421600A18468 /* JackError.h in Headers */,
-				4B699C50097D421600A18468 /* JackTime.h in Headers */,
-				4B699C51097D421600A18468 /* JackShmMem.h in Headers */,
-				4B699C52097D421600A18468 /* shm.h in Headers */,
-				4B699C54097D421600A18468 /* JackThread.h in Headers */,
-				4B699C55097D421600A18468 /* JackActivationCount.h in Headers */,
-				4B699C56097D421600A18468 /* JackChannel.h in Headers */,
-				4B699C57097D421600A18468 /* JackGraphManager.h in Headers */,
-				4B699C58097D421600A18468 /* JackPort.h in Headers */,
-				4B699C59097D421600A18468 /* JackClientInterface.h in Headers */,
-				4B699C5A097D421600A18468 /* JackClientControl.h in Headers */,
-				4B699C5B097D421600A18468 /* JackClient.h in Headers */,
-				4B699C5C097D421600A18468 /* JackInternalClient.h in Headers */,
-				4B699C5D097D421600A18468 /* JackConnectionManager.h in Headers */,
-				4B699C5E097D421600A18468 /* JackFrameTimer.h in Headers */,
-				4B699C60097D421600A18468 /* JackMachSemaphore.h in Headers */,
-				4B699C61097D421600A18468 /* JackGlobals.h in Headers */,
-				4B699C62097D421600A18468 /* JackMachThread.h in Headers */,
-				4B699C68097D421600A18468 /* JackSynchro.h in Headers */,
-				4B699C69097D421600A18468 /* JackAudioDriver.h in Headers */,
-				4B699C6A097D421600A18468 /* JackFreewheelDriver.h in Headers */,
-				4B699C6B097D421600A18468 /* JackThreadedDriver.h in Headers */,
-				4B699C6C097D421600A18468 /* JackDriver.h in Headers */,
-				4B699C6D097D421600A18468 /* driver_interface.h in Headers */,
-				4B699C6F097D421600A18468 /* JackDriverLoader.h in Headers */,
-				4B699C71097D421600A18468 /* JackEngine.h in Headers */,
-				4B699C73097D421600A18468 /* JackExternalClient.h in Headers */,
-				4B699C74097D421600A18468 /* JackServer.h in Headers */,
-				4B699C7B097D421600A18468 /* JackConstants.h in Headers */,
-				4BD4B4D809BACD9600750C0F /* JackTransportEngine.h in Headers */,
-				4BC2168E0A444BED00BDA09F /* JackServerGlobals.h in Headers */,
-				4BF5205A0CB8D1010037470E /* timestamps.h in Headers */,
-				4B6C73860CC60A83001AFFD4 /* jack.h in Headers */,
-				4B6C73870CC60A84001AFFD4 /* intclient.h in Headers */,
-				4B6C73880CC60A84001AFFD4 /* ringbuffer.h in Headers */,
-				4B6C73890CC60A85001AFFD4 /* statistics.h in Headers */,
-				4B6C738A0CC60A85001AFFD4 /* thread.h in Headers */,
-				4B6C738B0CC60A86001AFFD4 /* transport.h in Headers */,
-				4BE3225B0CC611F500AFA640 /* types.h in Headers */,
-				4BAB95BB0B9E20B800A0C723 /* JackPortType.h in Headers */,
-				4B80D7EB0BA0D17400F035BB /* JackMidiPort.h in Headers */,
-				4B6B9EF70CD095970051EE5A /* midiport.h in Headers */,
-				4B5DB9840CD2429B00EBA5EE /* JackDebugClient.h in Headers */,
-				4BE4CC040CDA153500CCF5BB /* JackTools.h in Headers */,
-				BA222AD90DC88269001A17F4 /* JackNetTool.h in Headers */,
-				BA047C760E14E79D0041F3B6 /* JackNetSocket.h in Headers */,
-				4B95BCAE0D913073000F7695 /* control.h in Headers */,
-				4B9A26020DBF8584006E9FBC /* jslist.h in Headers */,
-				4B4F9C8D0DC20C0400706CB0 /* JackMessageBuffer.h in Headers */,
-				4B5F253E0DEE9B8F0041E486 /* JackLockedEngine.h in Headers */,
-				4BBC93BB0DF9736C002DF220 /* JackWaitThreadedDriver.h in Headers */,
-				4B4CA9750E02CF9600F4BFDA /* JackRestartThreadedDriver.h in Headers */,
-				4B4E9AFB0E5F1090000A3278 /* JackControlAPI.h in Headers */,
-				4BC3B6A70E703B2E0066E42F /* JackPosixThread.h in Headers */,
-				4BF2841B0F31B4BC00B05BE3 /* JackArgParser.h in Headers */,
-				4BBAE4100F42FA6100B8BD3F /* JackEngineProfiling.h in Headers */,
-				4BF339240F8B873E0080FB5B /* JackMidiDriver.h in Headers */,
-				4B94334B10A5E666002A187F /* systemdeps.h in Headers */,
-				4B88D03D11298BEE007A87C1 /* weakjack.h in Headers */,
-				4B88D03E11298BEE007A87C1 /* weakmacros.h in Headers */,
-				4BC2CA56113C6C940076717C /* JackNetInterface.h in Headers */,
-				4BC2CA58113C6C9C0076717C /* JackNetUnixSocket.h in Headers */,
-				4B2209E212F6BBF400E5DC26 /* JackSocketServerChannel.h in Headers */,
-				4B2209E412F6BBF600E5DC26 /* JackSocketServerNotifyChannel.h in Headers */,
-				4B2209E712F6BC0300E5DC26 /* JackSocket.h in Headers */,
-				4B2209EA12F6BC1600E5DC26 /* JackSocketNotifyChannel.h in Headers */,
-				4B193992133F321500547810 /* JackFilters.h in Headers */,
-				4B97B6391344B3C300794F57 /* JackMidiAsyncQueue.h in Headers */,
-				4B97B63D1344B3EC00794F57 /* JackMidiAsyncWaitQueue.h in Headers */,
-				4B97B6411344B40C00794F57 /* JackMidiBufferReadQueue.h in Headers */,
-				4B97B6541344B42400794F57 /* JackMidiBufferWriteQueue.h in Headers */,
-				4B97B6561344B43600794F57 /* JackMidiReadQueue.h in Headers */,
-				4B97B6591344B44800794F57 /* JackMidiReceiveQueue.h in Headers */,
-				4B97B65B1344B45600794F57 /* JackMidiSendQueue.h in Headers */,
-				4B97B65D1344B46400794F57 /* JackMidiUtil.h in Headers */,
-				4B97B65F1344B47100794F57 /* JackMidiWriteQueue.h in Headers */,
-				4B21795013E2EEA60095B3E5 /* JackTimedDriver.h in Headers */,
-				4B49D44214865F22003390F8 /* net.h in Headers */,
-				4B49D44314865F22003390F8 /* session.h in Headers */,
-				4B1499FB14BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */,
-				4B90669F14BEE6D20074CD40 /* JackRequestDecoder.h in Headers */,
-				4BB4214E14D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */,
-				4BB4215014D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CB2097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CC2097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CD2097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CE2097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CF4097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D04097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D14097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D28097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D40097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D50097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D68097D421600A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D80097D421700A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D98097D421700A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BE5FECE0E725C090020B576 /* JackCoreAudioDriver.h in Headers */,
-				4BAA150414F04FB600402512 /* JackAC3Encoder.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699DA7097D421700A18468 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699DA8097D421700A18468 /* JackDummyDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8692831371DB4700D2D11B /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B8692FA1371DC6300D2D11B /* JackAudioAdapterInterface.h in Headers */,
-				4B8692FD1371DC8A00D2D11B /* JackGlobals.h in Headers */,
-				4B86930D1371DCB000D2D11B /* JackMachThread.h in Headers */,
-				4B8693181371DD2A00D2D11B /* JackNetInterface.h in Headers */,
-				4B86931A1371DD4400D2D11B /* JackNetTool.h in Headers */,
-				4B86934E1371DEBD00D2D11B /* JackLibSampleRateResampler.h in Headers */,
-				4B49D44E14865F22003390F8 /* net.h in Headers */,
-				4B49D44F14865F22003390F8 /* session.h in Headers */,
-				4BF1007D15135D8800B88F80 /* JackPosixMutex.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16DC13290DC80002AD73 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16E913290E0E0002AD73 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B978DB20A31CF4A009E2DD1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BBB00D40E72614F0018AB1B /* JackPortAudioDevices.h in Headers */,
-				4BBB00D60E72614F0018AB1B /* JackPortAudioDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA3393410B2E36800190E3B /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA3393610B2E36800190E3B /* JackError.h in Headers */,
-				4BA3393710B2E36800190E3B /* JackTime.h in Headers */,
-				4BA3393810B2E36800190E3B /* JackShmMem.h in Headers */,
-				4BA3393910B2E36800190E3B /* shm.h in Headers */,
-				4BA3393A10B2E36800190E3B /* JackThread.h in Headers */,
-				4BA3393B10B2E36800190E3B /* JackActivationCount.h in Headers */,
-				4BA3393C10B2E36800190E3B /* JackChannel.h in Headers */,
-				4BA3393D10B2E36800190E3B /* JackGraphManager.h in Headers */,
-				4BA3393E10B2E36800190E3B /* JackPort.h in Headers */,
-				4BA3393F10B2E36800190E3B /* JackClientInterface.h in Headers */,
-				4BA3394010B2E36800190E3B /* JackClientControl.h in Headers */,
-				4BA3394110B2E36800190E3B /* JackClient.h in Headers */,
-				4BA3394210B2E36800190E3B /* JackInternalClient.h in Headers */,
-				4BA3394310B2E36800190E3B /* JackConnectionManager.h in Headers */,
-				4BA3394410B2E36800190E3B /* JackFrameTimer.h in Headers */,
-				4BA3394510B2E36800190E3B /* JackMachSemaphore.h in Headers */,
-				4BA3394610B2E36800190E3B /* JackGlobals.h in Headers */,
-				4BA3394710B2E36800190E3B /* JackMachThread.h in Headers */,
-				4BA3394810B2E36800190E3B /* JackSynchro.h in Headers */,
-				4BA3394910B2E36800190E3B /* JackAudioDriver.h in Headers */,
-				4BA3394A10B2E36800190E3B /* JackFreewheelDriver.h in Headers */,
-				4BA3394B10B2E36800190E3B /* JackThreadedDriver.h in Headers */,
-				4BA3394C10B2E36800190E3B /* JackDriver.h in Headers */,
-				4BA3394D10B2E36800190E3B /* driver_interface.h in Headers */,
-				4BA3394E10B2E36800190E3B /* JackDriverLoader.h in Headers */,
-				4BA3394F10B2E36800190E3B /* JackEngine.h in Headers */,
-				4BA3395010B2E36800190E3B /* JackExternalClient.h in Headers */,
-				4BA3395110B2E36800190E3B /* JackServer.h in Headers */,
-				4BA3395510B2E36800190E3B /* JackConstants.h in Headers */,
-				4BA3395610B2E36800190E3B /* JackTransportEngine.h in Headers */,
-				4BA3395710B2E36800190E3B /* JackServerGlobals.h in Headers */,
-				4BA3395810B2E36800190E3B /* timestamps.h in Headers */,
-				4BA3395910B2E36800190E3B /* jack.h in Headers */,
-				4BA3395A10B2E36800190E3B /* intclient.h in Headers */,
-				4BA3395B10B2E36800190E3B /* ringbuffer.h in Headers */,
-				4BA3395C10B2E36800190E3B /* statistics.h in Headers */,
-				4BA3395D10B2E36800190E3B /* thread.h in Headers */,
-				4BA3395E10B2E36800190E3B /* transport.h in Headers */,
-				4BA3395F10B2E36800190E3B /* types.h in Headers */,
-				4BA3396010B2E36800190E3B /* JackPortType.h in Headers */,
-				4BA3396110B2E36800190E3B /* JackMidiPort.h in Headers */,
-				4BA3396210B2E36800190E3B /* midiport.h in Headers */,
-				4BA3396310B2E36800190E3B /* JackDebugClient.h in Headers */,
-				4BA3396410B2E36800190E3B /* JackTools.h in Headers */,
-				4BA3396510B2E36800190E3B /* JackNetTool.h in Headers */,
-				4BA3396610B2E36800190E3B /* jslist.h in Headers */,
-				4BA3396710B2E36800190E3B /* JackMessageBuffer.h in Headers */,
-				4BA3396810B2E36800190E3B /* JackRestartThreadedDriver.h in Headers */,
-				4BA3396910B2E36800190E3B /* JackControlAPI.h in Headers */,
-				4BA3396A10B2E36800190E3B /* JackPosixThread.h in Headers */,
-				4BA3396B10B2E36800190E3B /* JackEngineProfiling.h in Headers */,
-				4BA3396D10B2E36800190E3B /* JackMidiDriver.h in Headers */,
-				4BA3396E10B2E36800190E3B /* JackWaitThreadedDriver.h in Headers */,
-				4BA3396F10B2E36800190E3B /* JackArgParser.h in Headers */,
-				4B88D04511298BEE007A87C1 /* weakjack.h in Headers */,
-				4B88D04611298BEE007A87C1 /* weakmacros.h in Headers */,
-				4BC2CA5E113C6CCA0076717C /* JackNetInterface.h in Headers */,
-				4BC2CA60113C6CD20076717C /* JackNetUnixSocket.h in Headers */,
-				4B5160AE13215EF900BB7DCB /* systemdeps.h in Headers */,
-				4B193996133F321500547810 /* JackFilters.h in Headers */,
-				4B6FE13A13DDABE000B4B943 /* JackSocketServerNotifyChannel.h in Headers */,
-				4B6FE13C13DDABF100B4B943 /* JackSocketServerChannel.h in Headers */,
-				4B6FE13E13DDAC0500B4B943 /* JackSocketNotifyChannel.h in Headers */,
-				4B6FE14513DDAC4C00B4B943 /* JackSocket.h in Headers */,
-				4B6FE14E13DDACD200B4B943 /* JackMidiAsyncQueue.h in Headers */,
-				4B6FE15413DDACF300B4B943 /* JackMidiBufferWriteQueue.h in Headers */,
-				4B6FE15B13DDAD3D00B4B943 /* JackMidiWriteQueue.h in Headers */,
-				4B6FE15D13DDAD4E00B4B943 /* JackMidiUtil.h in Headers */,
-				4B6FE15F13DDAD5900B4B943 /* JackMidiSendQueue.h in Headers */,
-				4B6FE16113DDAD6600B4B943 /* JackMidiReceiveQueue.h in Headers */,
-				4B6FE16313DDAD7700B4B943 /* JackMidiReadQueue.h in Headers */,
-				4B6FE16513DDAD8800B4B943 /* JackMidiBufferReadQueue.h in Headers */,
-				4B6FE16713DDAD9700B4B943 /* JackMidiAsyncWaitQueue.h in Headers */,
-				4B21795413E2EEA60095B3E5 /* JackTimedDriver.h in Headers */,
-				4B49D44C14865F22003390F8 /* net.h in Headers */,
-				4B49D44D14865F22003390F8 /* session.h in Headers */,
-				4B1499F314BDA5B300A51A3C /* JackGenericClientChannel.h in Headers */,
-				4B90669D14BEE6D20074CD40 /* JackRequestDecoder.h in Headers */,
-				4BB4215A14D2C0A700A1CAE1 /* JackPosixMutex.h in Headers */,
-				4BB4215C14D2C0A700A1CAE1 /* JackPosixProcessSync.h in Headers */,
-				4B4C3B6F1BC2FFE00004CC35 /* JackPosixSemaphore.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692A70CBE4BC700EAD520 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692CB0CBE4C9000EAD520 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA7FEBA0D8E76270017FF73 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BD623EE0CBCF0F000DE782F /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDB941001FB9C00B15929 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDB951001FB9C00B15929 /* JackCoreMidiDriver.h in Headers */,
-				4B370A35133DD7E300237B68 /* JackCoreMidiInputPort.h in Headers */,
-				4B370A37133DD7E300237B68 /* JackCoreMidiOutputPort.h in Headers */,
-				4B370A39133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.h in Headers */,
-				4B370A3B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h in Headers */,
-				4B370A3D133DD7E300237B68 /* JackCoreMidiPort.h in Headers */,
-				4B370A3F133DD7E300237B68 /* JackCoreMidiUtil.h in Headers */,
-				4B370A41133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h in Headers */,
-				4B370A43133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBB81001FCC000B15929 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDBB91001FCC000B15929 /* JackNetDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBD81001FD2D00B15929 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDBD91001FD2D00B15929 /* JackNetManager.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBED1001FD7300B15929 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDBEE1001FD7300B15929 /* JackAudioAdapter.h in Headers */,
-				4BDCDBEF1001FD7300B15929 /* JackAudioAdapterInterface.h in Headers */,
-				4BDCDBF11001FD7300B15929 /* JackLibSampleRateResampler.h in Headers */,
-				4BDCDBF21001FD7300B15929 /* JackCoreAudioAdapter.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDC101001FDE300B15929 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDC111001FDE300B15929 /* JackAudioAdapterInterface.h in Headers */,
-				4BDCDC131001FDE300B15929 /* JackLibSampleRateResampler.h in Headers */,
-				4BDCDC141001FDE300B15929 /* JackNetAdapter.h in Headers */,
-				4BDCDC161001FDE300B15929 /* JackAudioAdapter.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE6C6920A3E096F005A203A /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE99D270AD7A04800C59091 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BF339030F8B864B0080FB5B /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BF3391A0F8B86DC0080FB5B /* JackCoreMidiDriver.h in Headers */,
-				4B370A25133DD7E300237B68 /* JackCoreMidiInputPort.h in Headers */,
-				4B370A27133DD7E300237B68 /* JackCoreMidiOutputPort.h in Headers */,
-				4B370A29133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.h in Headers */,
-				4B370A2B133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.h in Headers */,
-				4B370A2D133DD7E300237B68 /* JackCoreMidiPort.h in Headers */,
-				4B370A2F133DD7E300237B68 /* JackCoreMidiUtil.h in Headers */,
-				4B370A31133DD7E300237B68 /* JackCoreMidiVirtualInputPort.h in Headers */,
-				4B370A33133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA5E8C0DEC4D9C00FA4CDB /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82830DF6A9E40087B4E1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82960DF6A9E40087B4E1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82A20DF6A9E40087B4E1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82AE0DF6A9E40087B4E1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82BA0DF6A9E40087B4E1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82C60DF6A9E40087B4E1 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA99990AAAF3B0009E916C /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		BA222AC60DC88132001A17F4 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				BA222ADF0DC882A5001A17F4 /* JackNetDriver.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		BA222AE10DC882DB001A17F4 /* Headers */ = {
-			isa = PBXHeadersBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				BA222AEE0DC883B3001A17F4 /* JackNetManager.h in Headers */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXHeadersBuildPhase section */
-
-/* Begin PBXNativeTarget section */
-		4B0A28DC0D52073D002EFF74 /* jack_thread_wait */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B0A28E20D52073D002EFF74 /* Build configuration list for PBXNativeTarget "jack_thread_wait" */;
-			buildPhases = (
-				4B0A28DD0D52073D002EFF74 /* Headers */,
-				4B0A28DE0D52073D002EFF74 /* Sources */,
-				4B0A28E00D52073D002EFF74 /* Frameworks */,
-				4B0A28E10D52073D002EFF74 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = jack_thread_wait;
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B0A28E60D52073D002EFF74 /* jack_thread_wait */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B0A29230D52108E002EFF74 /* jack_thread_wait 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B0A29290D52108E002EFF74 /* Build configuration list for PBXNativeTarget "jack_thread_wait 64 bits" */;
-			buildPhases = (
-				4B0A29240D52108E002EFF74 /* Headers */,
-				4B0A29250D52108E002EFF74 /* Sources */,
-				4B0A29270D52108E002EFF74 /* Frameworks */,
-				4B0A29280D52108E002EFF74 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_thread_wait 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B0A292D0D52108E002EFF74 /* jack_thread_wait */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B19B2F60E23620F00DD4A82 /* audioadapter Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B19B2FC0E23620F00DD4A82 /* Build configuration list for PBXNativeTarget "audioadapter Universal" */;
-			buildPhases = (
-				4B19B2F70E23620F00DD4A82 /* Headers */,
-				4B19B2F90E23620F00DD4A82 /* Sources */,
-				4B19B2FB0E23620F00DD4A82 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "audioadapter Universal";
-			productName = jack_coreaudio;
-			productReference = 4B19B3000E23620F00DD4A82 /* audioadapter.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B2021DC133A9BA40019E213 /* jack_midi_latency 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B2021E2133A9BA40019E213 /* Build configuration list for PBXNativeTarget "jack_midi_latency 64 bits" */;
-			buildPhases = (
-				4B2021DD133A9BA40019E213 /* Headers */,
-				4B2021DE133A9BA40019E213 /* Sources */,
-				4B2021E0133A9BA40019E213 /* Frameworks */,
-				4B2021E1133A9BA40019E213 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midi_latency 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B2021E6133A9BA40019E213 /* jack_midi_latency_test */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B3224D710A3156800838A8E /* jack_netone Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B3224E110A3156800838A8E /* Build configuration list for PBXNativeTarget "jack_netone Universal" */;
-			buildPhases = (
-				4B3224D810A3156800838A8E /* Headers */,
-				4B3224DC10A3156800838A8E /* Sources */,
-				4B3224E010A3156800838A8E /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_netone Universal";
-			productName = jack_coreaudio;
-			productReference = 4B3224E510A3156800838A8E /* jack_netone.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B32251D10A316B200838A8E /* jack_netone 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B32252710A316B200838A8E /* Build configuration list for PBXNativeTarget "jack_netone 64 bits" */;
-			buildPhases = (
-				4B32251E10A316B200838A8E /* Headers */,
-				4B32252210A316B200838A8E /* Sources */,
-				4B32252610A316B200838A8E /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_netone 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4B32252B10A316B200838A8E /* jack_netone.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B32255710A3187800838A8E /* jack_netsource Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B32255D10A3187800838A8E /* Build configuration list for PBXNativeTarget "jack_netsource Universal" */;
-			buildPhases = (
-				4B32255810A3187800838A8E /* Headers */,
-				4B32255910A3187800838A8E /* Sources */,
-				4B32255B10A3187800838A8E /* Frameworks */,
-				4B32255C10A3187800838A8E /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_netsource Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B32256110A3187800838A8E /* jack_netsource */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B32257110A3190C00838A8E /* jack_netsource 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B32257710A3190C00838A8E /* Build configuration list for PBXNativeTarget "jack_netsource 64 bits" */;
-			buildPhases = (
-				4B32257210A3190C00838A8E /* Headers */,
-				4B32257310A3190C00838A8E /* Sources */,
-				4B32257510A3190C00838A8E /* Frameworks */,
-				4B32257610A3190C00838A8E /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_netsource 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B32257B10A3190C00838A8E /* jack_netsource */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C41B0D4731D1000DE7AE /* jackdmp framework 64bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C4210D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jackdmp framework 64bits" */;
-			buildPhases = (
-				4B35C41C0D4731D1000DE7AE /* Headers */,
-				4B35C41D0D4731D1000DE7AE /* Sources */,
-				4B35C41F0D4731D1000DE7AE /* Frameworks */,
-				4B35C4200D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jackdmp framework 64bits";
-			productInstallPath = /usr/local/bin;
-			productName = TestMacEngine;
-			productReference = 4B35C4250D4731D1000DE7AE /* jackdmp */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C4270D4731D1000DE7AE /* Jackmp.framework 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C47F0D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "Jackmp.framework 64 bits" */;
-			buildPhases = (
-				4B35C4280D4731D1000DE7AE /* Headers */,
-				4B35C4560D4731D1000DE7AE /* Resources */,
-				4B35C4570D4731D1000DE7AE /* Sources */,
-				4B35C47D0D4731D1000DE7AE /* Rez */,
-				4B35C47E0D4731D1000DE7AE /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jackmp.framework 64 bits";
-			productName = Jack;
-			productReference = 4B35C4830D4731D1000DE7AE /* Jackmp.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4B35C4850D4731D1000DE7AE /* Jackservermp.framework 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C4F80D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "Jackservermp.framework 64 bits" */;
-			buildPhases = (
-				4B35C4860D4731D1000DE7AE /* Headers */,
-				4B35C4C20D4731D1000DE7AE /* Resources */,
-				4B35C4C30D4731D1000DE7AE /* Sources */,
-				4B35C4F60D4731D1000DE7AE /* Rez */,
-				4B35C4F70D4731D1000DE7AE /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jackservermp.framework 64 bits";
-			productName = Jack;
-			productReference = 4B35C4FC0D4731D1000DE7AE /* Jackservermp.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4B35C50A0D4731D1000DE7AE /* jack_midiseq 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5100D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_midiseq 64 bits" */;
-			buildPhases = (
-				4B35C50B0D4731D1000DE7AE /* Headers */,
-				4B35C50C0D4731D1000DE7AE /* Sources */,
-				4B35C50E0D4731D1000DE7AE /* Frameworks */,
-				4B35C50F0D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midiseq 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B35C5140D4731D1000DE7AE /* jack_midiseq */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5160D4731D1000DE7AE /* jack_midisine 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C51C0D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_midisine 64 bits" */;
-			buildPhases = (
-				4B35C5170D4731D1000DE7AE /* Headers */,
-				4B35C5180D4731D1000DE7AE /* Sources */,
-				4B35C51A0D4731D1000DE7AE /* Frameworks */,
-				4B35C51B0D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midisine 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B35C5200D4731D1000DE7AE /* jack_midisine */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5220D4731D1000DE7AE /* jack_metro 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5280D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_metro 64 bits" */;
-			buildPhases = (
-				4B35C5230D4731D1000DE7AE /* Headers */,
-				4B35C5240D4731D1000DE7AE /* Sources */,
-				4B35C5260D4731D1000DE7AE /* Frameworks */,
-				4B35C5270D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_metro 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B35C52C0D4731D1000DE7AE /* jack_metro */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C52E0D4731D1000DE7AE /* jack_lsp 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5340D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_lsp 64 bits" */;
-			buildPhases = (
-				4B35C52F0D4731D1000DE7AE /* Headers */,
-				4B35C5300D4731D1000DE7AE /* Sources */,
-				4B35C5320D4731D1000DE7AE /* Frameworks */,
-				4B35C5330D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_lsp 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_lsp;
-			productReference = 4B35C5380D4731D1000DE7AE /* jack_lsp */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C53A0D4731D1000DE7AE /* jack_connect 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5400D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_connect 64 bits" */;
-			buildPhases = (
-				4B35C53B0D4731D1000DE7AE /* Headers */,
-				4B35C53C0D4731D1000DE7AE /* Sources */,
-				4B35C53E0D4731D1000DE7AE /* Frameworks */,
-				4B35C53F0D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_connect 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_connect;
-			productReference = 4B35C5440D4731D1000DE7AE /* jack_connect */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5460D4731D1000DE7AE /* jack_disconnect 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C54C0D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_disconnect 64 bits" */;
-			buildPhases = (
-				4B35C5470D4731D1000DE7AE /* Headers */,
-				4B35C5480D4731D1000DE7AE /* Sources */,
-				4B35C54A0D4731D1000DE7AE /* Frameworks */,
-				4B35C54B0D4731D1000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_disconnect 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_disconnect;
-			productReference = 4B35C5500D4731D1000DE7AE /* jack_disconnect */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5520D4731D2000DE7AE /* jack_freewheel 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C55A0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_freewheel 64 bits" */;
-			buildPhases = (
-				4B35C5550D4731D2000DE7AE /* Headers */,
-				4B35C5560D4731D2000DE7AE /* Sources */,
-				4B35C5580D4731D2000DE7AE /* Frameworks */,
-				4B35C5590D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-				4B35C5530D4731D2000DE7AE /* PBXTargetDependency */,
-			);
-			name = "jack_freewheel 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_freewheel;
-			productReference = 4B35C55E0D4731D2000DE7AE /* jack_freewheel */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5600D4731D2000DE7AE /* jack_iodelay 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5660D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_iodelay 64 bits" */;
-			buildPhases = (
-				4B35C5610D4731D2000DE7AE /* Headers */,
-				4B35C5620D4731D2000DE7AE /* Sources */,
-				4B35C5640D4731D2000DE7AE /* Frameworks */,
-				4B35C5650D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_iodelay 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_lsp;
-			productReference = 4B35C56A0D4731D2000DE7AE /* jack_iodelay */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C56C0D4731D2000DE7AE /* jack_external_metro 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5720D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_external_metro 64 bits" */;
-			buildPhases = (
-				4B35C56D0D4731D2000DE7AE /* Headers */,
-				4B35C56E0D4731D2000DE7AE /* Sources */,
-				4B35C5700D4731D2000DE7AE /* Frameworks */,
-				4B35C5710D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_external_metro 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B35C5760D4731D2000DE7AE /* jack_external_metro */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5780D4731D2000DE7AE /* testAtomic 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5820D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "testAtomic 64 bits" */;
-			buildPhases = (
-				4B35C5790D4731D2000DE7AE /* Headers */,
-				4B35C57C0D4731D2000DE7AE /* Sources */,
-				4B35C5800D4731D2000DE7AE /* Frameworks */,
-				4B35C5810D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "testAtomic 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testAtomic;
-			productReference = 4B35C5860D4731D2000DE7AE /* testAtomic */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5880D4731D2000DE7AE /* testSem 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5960D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "testSem 64 bits" */;
-			buildPhases = (
-				4B35C5890D4731D2000DE7AE /* Headers */,
-				4B35C58C0D4731D2000DE7AE /* Sources */,
-				4B35C5940D4731D2000DE7AE /* Frameworks */,
-				4B35C5950D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "testSem 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B35C59A0D4731D2000DE7AE /* testSem */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C59C0D4731D2000DE7AE /* zombie 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5A20D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "zombie 64 bits" */;
-			buildPhases = (
-				4B35C59D0D4731D2000DE7AE /* Headers */,
-				4B35C59E0D4731D2000DE7AE /* Sources */,
-				4B35C5A00D4731D2000DE7AE /* Frameworks */,
-				4B35C5A10D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "zombie 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = zombie;
-			productReference = 4B35C5A60D4731D2000DE7AE /* zombie */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5A80D4731D2000DE7AE /* jack_test 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5AE0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_test 64 bits" */;
-			buildPhases = (
-				4B35C5A90D4731D2000DE7AE /* Headers */,
-				4B35C5AA0D4731D2000DE7AE /* Sources */,
-				4B35C5AC0D4731D2000DE7AE /* Frameworks */,
-				4B35C5AD0D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_test 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B35C5B20D4731D2000DE7AE /* jack_test */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5B40D4731D2000DE7AE /* jack_cpu 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5BA0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_cpu 64 bits" */;
-			buildPhases = (
-				4B35C5B50D4731D2000DE7AE /* Headers */,
-				4B35C5B60D4731D2000DE7AE /* Sources */,
-				4B35C5B80D4731D2000DE7AE /* Frameworks */,
-				4B35C5B90D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_cpu 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B35C5BE0D4731D2000DE7AE /* jack_cpu */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5C00D4731D2000DE7AE /* jack_load 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5C60D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_load 64 bits" */;
-			buildPhases = (
-				4B35C5C10D4731D2000DE7AE /* Headers */,
-				4B35C5C20D4731D2000DE7AE /* Sources */,
-				4B35C5C40D4731D2000DE7AE /* Frameworks */,
-				4B35C5C50D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_load 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B35C5CA0D4731D2000DE7AE /* jack_load */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5CC0D4731D2000DE7AE /* jack_unload 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5D20D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_unload 64 bits" */;
-			buildPhases = (
-				4B35C5CD0D4731D2000DE7AE /* Headers */,
-				4B35C5CE0D4731D2000DE7AE /* Sources */,
-				4B35C5D00D4731D2000DE7AE /* Frameworks */,
-				4B35C5D10D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_unload 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B35C5D60D4731D2000DE7AE /* jack_unload */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5D80D4731D2000DE7AE /* synchroServer 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5E60D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "synchroServer 64 bits" */;
-			buildPhases = (
-				4B35C5D90D4731D2000DE7AE /* Headers */,
-				4B35C5DC0D4731D2000DE7AE /* Sources */,
-				4B35C5E40D4731D2000DE7AE /* Frameworks */,
-				4B35C5E50D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "synchroServer 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = synchroServer;
-			productReference = 4B35C5EA0D4731D2000DE7AE /* synchroServer */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C5EC0D4731D2000DE7AE /* synchroClient 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C5FA0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "synchroClient 64 bits" */;
-			buildPhases = (
-				4B35C5ED0D4731D2000DE7AE /* Headers */,
-				4B35C5F00D4731D2000DE7AE /* Sources */,
-				4B35C5F80D4731D2000DE7AE /* Frameworks */,
-				4B35C5F90D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "synchroClient 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = synchroServer;
-			productReference = 4B35C5FE0D4731D2000DE7AE /* synchroClient */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C6000D4731D2000DE7AE /* synchroServerClient 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C60E0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "synchroServerClient 64 bits" */;
-			buildPhases = (
-				4B35C6010D4731D2000DE7AE /* Headers */,
-				4B35C6040D4731D2000DE7AE /* Sources */,
-				4B35C60C0D4731D2000DE7AE /* Frameworks */,
-				4B35C60D0D4731D2000DE7AE /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "synchroServerClient 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = synchroServer;
-			productReference = 4B35C6120D4731D2000DE7AE /* synchroServerClient */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B35C6140D4731D2000DE7AE /* jack_coreaudio 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C61A0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_coreaudio 64 bits" */;
-			buildPhases = (
-				4B35C6150D4731D2000DE7AE /* Headers */,
-				4B35C6170D4731D2000DE7AE /* Sources */,
-				4B35C6190D4731D2000DE7AE /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-				4BAA1A7614CA08FE003269AD /* PBXTargetDependency */,
-			);
-			name = "jack_coreaudio 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4B35C61E0D4731D2000DE7AE /* jack_coreaudio.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B35C61F0D4731D2000DE7AE /* jack_portaudio 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C6250D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_portaudio 64 bits" */;
-			buildPhases = (
-				4B35C6200D4731D2000DE7AE /* Headers */,
-				4B35C6220D4731D2000DE7AE /* Sources */,
-				4B35C6240D4731D2000DE7AE /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_portaudio 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4B35C6290D4731D2000DE7AE /* jack_portaudio.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B35C62A0D4731D2000DE7AE /* jack_dummy 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C6300D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_dummy 64 bits" */;
-			buildPhases = (
-				4B35C62B0D4731D2000DE7AE /* Headers */,
-				4B35C62D0D4731D2000DE7AE /* Sources */,
-				4B35C62F0D4731D2000DE7AE /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_dummy 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4B35C6340D4731D2000DE7AE /* jack_dummy.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B35C6350D4731D3000DE7AE /* inprocess 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B35C63A0D4731D3000DE7AE /* Build configuration list for PBXNativeTarget "inprocess 64 bits" */;
-			buildPhases = (
-				4B35C6360D4731D3000DE7AE /* Headers */,
-				4B35C6370D4731D3000DE7AE /* Sources */,
-				4B35C6390D4731D3000DE7AE /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "inprocess 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4B35C63E0D4731D3000DE7AE /* inprocess.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B363DCE0DEB02F6001F72D9 /* jack_alias Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363DD40DEB02F6001F72D9 /* Build configuration list for PBXNativeTarget "jack_alias Universal" */;
-			buildPhases = (
-				4B363DCF0DEB02F6001F72D9 /* Headers */,
-				4B363DD00DEB02F6001F72D9 /* Sources */,
-				4B363DD20DEB02F6001F72D9 /* Frameworks */,
-				4B363DD30DEB02F6001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_alias Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363DD80DEB02F6001F72D9 /* jack_alias */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B363E100DEB03C5001F72D9 /* jack_evmon Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363E160DEB03C5001F72D9 /* Build configuration list for PBXNativeTarget "jack_evmon Universal" */;
-			buildPhases = (
-				4B363E110DEB03C5001F72D9 /* Headers */,
-				4B363E120DEB03C5001F72D9 /* Sources */,
-				4B363E140DEB03C5001F72D9 /* Frameworks */,
-				4B363E150DEB03C5001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_evmon Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363E1A0DEB03C5001F72D9 /* jack_evmon */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B363E440DEB0775001F72D9 /* jack_bufsize Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363E4A0DEB0775001F72D9 /* Build configuration list for PBXNativeTarget "jack_bufsize Universal" */;
-			buildPhases = (
-				4B363E450DEB0775001F72D9 /* Headers */,
-				4B363E460DEB0775001F72D9 /* Sources */,
-				4B363E480DEB0775001F72D9 /* Frameworks */,
-				4B363E490DEB0775001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_bufsize Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363E4E0DEB0775001F72D9 /* jack_bufsize */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B363EDF0DEB091C001F72D9 /* jack_rec Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363EE50DEB091C001F72D9 /* Build configuration list for PBXNativeTarget "jack_rec Universal" */;
-			buildPhases = (
-				4B363EE00DEB091C001F72D9 /* Headers */,
-				4B363EE10DEB091C001F72D9 /* Sources */,
-				4B363EE30DEB091C001F72D9 /* Frameworks */,
-				4B363EE40DEB091C001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_rec Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363EE90DEB091C001F72D9 /* jack_rec */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B363F140DEB0A6A001F72D9 /* jack_monitor_client Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363F1A0DEB0A6A001F72D9 /* Build configuration list for PBXNativeTarget "jack_monitor_client Universal" */;
-			buildPhases = (
-				4B363F150DEB0A6A001F72D9 /* Headers */,
-				4B363F160DEB0A6A001F72D9 /* Sources */,
-				4B363F180DEB0A6A001F72D9 /* Frameworks */,
-				4B363F190DEB0A6A001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_monitor_client Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363F1E0DEB0A6A001F72D9 /* jack_monitor_client */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B363F2B0DEB0BD1001F72D9 /* jack_showtime Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363F310DEB0BD1001F72D9 /* Build configuration list for PBXNativeTarget "jack_showtime Universal" */;
-			buildPhases = (
-				4B363F2C0DEB0BD1001F72D9 /* Headers */,
-				4B363F2D0DEB0BD1001F72D9 /* Sources */,
-				4B363F2F0DEB0BD1001F72D9 /* Frameworks */,
-				4B363F300DEB0BD1001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_showtime Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363F350DEB0BD1001F72D9 /* jack_showtime */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B363F680DEB0D4E001F72D9 /* jack_impulse_grabber Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B363F6E0DEB0D4E001F72D9 /* Build configuration list for PBXNativeTarget "jack_impulse_grabber Universal" */;
-			buildPhases = (
-				4B363F690DEB0D4E001F72D9 /* Headers */,
-				4B363F6A0DEB0D4E001F72D9 /* Sources */,
-				4B363F6C0DEB0D4E001F72D9 /* Frameworks */,
-				4B363F6D0DEB0D4E001F72D9 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_impulse_grabber Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B363F720DEB0D4E001F72D9 /* jack_impulse_grabber */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B3811551326878E00C61B14 /* jack_latent_client Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B38115B1326878E00C61B14 /* Build configuration list for PBXNativeTarget "jack_latent_client Universal" */;
-			buildPhases = (
-				4B3811561326878E00C61B14 /* Headers */,
-				4B3811571326878E00C61B14 /* Sources */,
-				4B3811591326878E00C61B14 /* Frameworks */,
-				4B38115A1326878E00C61B14 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_latent_client Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B38115F1326878E00C61B14 /* jack_latent_client */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B38118D1326884E00C61B14 /* jack_latent_client 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B3811931326884E00C61B14 /* Build configuration list for PBXNativeTarget "jack_latent_client 64 bits" */;
-			buildPhases = (
-				4B38118E1326884E00C61B14 /* Headers */,
-				4B38118F1326884E00C61B14 /* Sources */,
-				4B3811911326884E00C61B14 /* Frameworks */,
-				4B3811921326884E00C61B14 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_latent_client 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B3811971326884E00C61B14 /* jack_latent_client */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B43A8B010145F6F00E52943 /* jack_loopback Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B43A8B610145F6F00E52943 /* Build configuration list for PBXNativeTarget "jack_loopback Universal" */;
-			buildPhases = (
-				4B43A8B110145F6F00E52943 /* Headers */,
-				4B43A8B310145F6F00E52943 /* Sources */,
-				4B43A8B510145F6F00E52943 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_loopback Universal";
-			productName = jack_coreaudio;
-			productReference = 4B43A8BA10145F6F00E52943 /* jack_loopback.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B43A8DD1014615800E52943 /* jack_loopback 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B43A8E31014615800E52943 /* Build configuration list for PBXNativeTarget "jack_loopback 64 bits" */;
-			buildPhases = (
-				4B43A8DE1014615800E52943 /* Headers */,
-				4B43A8E01014615800E52943 /* Sources */,
-				4B43A8E21014615800E52943 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_loopback 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4B43A8E71014615800E52943 /* jack_loopback.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B47AC8010B5890100469C67 /* Jackmp.framework 64 bits debugging */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B47ACD310B5890100469C67 /* Build configuration list for PBXNativeTarget "Jackmp.framework 64 bits debugging" */;
-			buildPhases = (
-				4B47AC8110B5890100469C67 /* Headers */,
-				4B47ACAC10B5890100469C67 /* Resources */,
-				4B47ACAD10B5890100469C67 /* Sources */,
-				4B47ACD010B5890100469C67 /* Rez */,
-				4B47ACD110B5890100469C67 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jackmp.framework 64 bits debugging";
-			productName = Jack;
-			productReference = 4B47ACD710B5890100469C67 /* Jackmp.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4B5A1BB10CD1CB9E0005BF74 /* jack_midiseq Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B5A1BB70CD1CB9E0005BF74 /* Build configuration list for PBXNativeTarget "jack_midiseq Universal" */;
-			buildPhases = (
-				4B5A1BB20CD1CB9E0005BF74 /* Headers */,
-				4B5A1BB30CD1CB9E0005BF74 /* Sources */,
-				4B5A1BB50CD1CB9E0005BF74 /* Frameworks */,
-				4B5A1BB60CD1CB9E0005BF74 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midiseq Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B5A1BBB0CD1CB9E0005BF74 /* jack_midiseq */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B5A1BD00CD1CCE10005BF74 /* jack_midisine Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B5A1BD60CD1CCE10005BF74 /* Build configuration list for PBXNativeTarget "jack_midisine Universal" */;
-			buildPhases = (
-				4B5A1BD10CD1CCE10005BF74 /* Headers */,
-				4B5A1BD20CD1CCE10005BF74 /* Sources */,
-				4B5A1BD40CD1CCE10005BF74 /* Frameworks */,
-				4B5A1BD50CD1CCE10005BF74 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midisine Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B5A1BDA0CD1CCE10005BF74 /* jack_midisine */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B5E08BF0E5B66EE00BEE4E0 /* netadapter Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B5E08D10E5B66EE00BEE4E0 /* Build configuration list for PBXNativeTarget "netadapter Universal" */;
-			buildPhases = (
-				4B5E08C00E5B66EE00BEE4E0 /* Headers */,
-				4B5E08C90E5B66EE00BEE4E0 /* Sources */,
-				4B5E08D00E5B66EE00BEE4E0 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "netadapter Universal";
-			productName = jack_coreaudio;
-			productReference = 4B5E08D50E5B66EE00BEE4E0 /* netadapter.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B6654ED127C34AE00753A79 /* jack_server_control 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B6654F3127C34AE00753A79 /* Build configuration list for PBXNativeTarget "jack_server_control 64 bits" */;
-			buildPhases = (
-				4B6654EE127C34AE00753A79 /* Headers */,
-				4B6654EF127C34AE00753A79 /* Sources */,
-				4B6654F1127C34AE00753A79 /* Frameworks */,
-				4B6654F2127C34AE00753A79 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_server_control 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B6654F7127C34AE00753A79 /* jack_server_control */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699BA7097D421600A18468 /* jackdmp framework Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699BAD097D421600A18468 /* Build configuration list for PBXNativeTarget "jackdmp framework Universal" */;
-			buildPhases = (
-				4B699BA8097D421600A18468 /* Headers */,
-				4B699BA9097D421600A18468 /* Sources */,
-				4B699BAB097D421600A18468 /* Frameworks */,
-				4B699BAC097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jackdmp framework Universal";
-			productInstallPath = /usr/local/bin;
-			productName = TestMacEngine;
-			productReference = 4B699BB1097D421600A18468 /* jackdmp */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699C00097D421600A18468 /* Jackmp.framework Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699C43097D421600A18468 /* Build configuration list for PBXNativeTarget "Jackmp.framework Universal" */;
-			buildPhases = (
-				4B699C01097D421600A18468 /* Headers */,
-				4B699C23097D421600A18468 /* Resources */,
-				4B699C24097D421600A18468 /* Sources */,
-				4B699C41097D421600A18468 /* Rez */,
-				4B699C42097D421600A18468 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jackmp.framework Universal";
-			productName = Jack;
-			productReference = 4B699C47097D421600A18468 /* Jackmp.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4B699C4C097D421600A18468 /* Jackservermp.framework Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699CA8097D421600A18468 /* Build configuration list for PBXNativeTarget "Jackservermp.framework Universal" */;
-			buildPhases = (
-				4B699C4D097D421600A18468 /* Headers */,
-				4B699C7C097D421600A18468 /* Resources */,
-				4B699C7D097D421600A18468 /* Sources */,
-				4B699CA6097D421600A18468 /* Rez */,
-				4B699CA7097D421600A18468 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jackservermp.framework Universal";
-			productName = Jack;
-			productReference = 4B699CAC097D421600A18468 /* Jackservermp.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4B699CB1097D421600A18468 /* jack_metro Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699CB7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_metro Universal" */;
-			buildPhases = (
-				4B699CB2097D421600A18468 /* Headers */,
-				4B699CB3097D421600A18468 /* Sources */,
-				4B699CB5097D421600A18468 /* Frameworks */,
-				4B699CB6097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_metro Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B699CBB097D421600A18468 /* jack_metro */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699CC1097D421600A18468 /* jack_lsp Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699CC7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_lsp Universal" */;
-			buildPhases = (
-				4B699CC2097D421600A18468 /* Headers */,
-				4B699CC3097D421600A18468 /* Sources */,
-				4B699CC5097D421600A18468 /* Frameworks */,
-				4B699CC6097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_lsp Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_lsp;
-			productReference = 4B699CCB097D421600A18468 /* jack_lsp */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699CD1097D421600A18468 /* jack_connect Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699CD7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_connect Universal" */;
-			buildPhases = (
-				4B699CD2097D421600A18468 /* Headers */,
-				4B699CD3097D421600A18468 /* Sources */,
-				4B699CD5097D421600A18468 /* Frameworks */,
-				4B699CD6097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_connect Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_connect;
-			productReference = 4B699CDB097D421600A18468 /* jack_connect */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699CE1097D421600A18468 /* jack_disconnect Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699CE7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_disconnect Universal" */;
-			buildPhases = (
-				4B699CE2097D421600A18468 /* Headers */,
-				4B699CE3097D421600A18468 /* Sources */,
-				4B699CE5097D421600A18468 /* Frameworks */,
-				4B699CE6097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_disconnect Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_disconnect;
-			productReference = 4B699CEB097D421600A18468 /* jack_disconnect */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699CF1097D421600A18468 /* jack_freewheel Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699CF9097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_freewheel Universal" */;
-			buildPhases = (
-				4B699CF4097D421600A18468 /* Headers */,
-				4B699CF5097D421600A18468 /* Sources */,
-				4B699CF7097D421600A18468 /* Frameworks */,
-				4B699CF8097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-				4B699DC0097D421700A18468 /* PBXTargetDependency */,
-			);
-			name = "jack_freewheel Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_freewheel;
-			productReference = 4B699CFD097D421600A18468 /* jack_freewheel */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D03097D421600A18468 /* jack_external_metro Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D09097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_external_metro Universal" */;
-			buildPhases = (
-				4B699D04097D421600A18468 /* Headers */,
-				4B699D05097D421600A18468 /* Sources */,
-				4B699D07097D421600A18468 /* Frameworks */,
-				4B699D08097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_external_metro Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B699D0D097D421600A18468 /* jack_external_metro */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D13097D421600A18468 /* testAtomic Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D1D097D421600A18468 /* Build configuration list for PBXNativeTarget "testAtomic Universal" */;
-			buildPhases = (
-				4B699D14097D421600A18468 /* Headers */,
-				4B699D17097D421600A18468 /* Sources */,
-				4B699D1B097D421600A18468 /* Frameworks */,
-				4B699D1C097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "testAtomic Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testAtomic;
-			productReference = 4B699D21097D421600A18468 /* testAtomic */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D27097D421600A18468 /* testSem Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D35097D421600A18468 /* Build configuration list for PBXNativeTarget "testSem Universal" */;
-			buildPhases = (
-				4B699D28097D421600A18468 /* Headers */,
-				4B699D2B097D421600A18468 /* Sources */,
-				4B699D33097D421600A18468 /* Frameworks */,
-				4B699D34097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "testSem Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4B699D39097D421600A18468 /* testSem */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D3F097D421600A18468 /* zombie Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D45097D421600A18468 /* Build configuration list for PBXNativeTarget "zombie Universal" */;
-			buildPhases = (
-				4B699D40097D421600A18468 /* Headers */,
-				4B699D41097D421600A18468 /* Sources */,
-				4B699D43097D421600A18468 /* Frameworks */,
-				4B699D44097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "zombie Universal";
-			productInstallPath = /usr/local/bin;
-			productName = zombie;
-			productReference = 4B699D49097D421600A18468 /* zombie */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D4F097D421600A18468 /* synchroServer Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D5D097D421600A18468 /* Build configuration list for PBXNativeTarget "synchroServer Universal" */;
-			buildPhases = (
-				4B699D50097D421600A18468 /* Headers */,
-				4B699D53097D421600A18468 /* Sources */,
-				4B699D5B097D421600A18468 /* Frameworks */,
-				4B699D5C097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "synchroServer Universal";
-			productInstallPath = /usr/local/bin;
-			productName = synchroServer;
-			productReference = 4B699D61097D421600A18468 /* synchroServer */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D67097D421600A18468 /* synchroClient Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D75097D421600A18468 /* Build configuration list for PBXNativeTarget "synchroClient Universal" */;
-			buildPhases = (
-				4B699D68097D421600A18468 /* Headers */,
-				4B699D6B097D421600A18468 /* Sources */,
-				4B699D73097D421600A18468 /* Frameworks */,
-				4B699D74097D421600A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "synchroClient Universal";
-			productInstallPath = /usr/local/bin;
-			productName = synchroServer;
-			productReference = 4B699D79097D421600A18468 /* synchroClient */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D7F097D421700A18468 /* synchroServerClient Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D8D097D421700A18468 /* Build configuration list for PBXNativeTarget "synchroServerClient Universal" */;
-			buildPhases = (
-				4B699D80097D421700A18468 /* Headers */,
-				4B699D83097D421700A18468 /* Sources */,
-				4B699D8B097D421700A18468 /* Frameworks */,
-				4B699D8C097D421700A18468 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "synchroServerClient Universal";
-			productInstallPath = /usr/local/bin;
-			productName = synchroServer;
-			productReference = 4B699D91097D421700A18468 /* synchroServerClient */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B699D97097D421700A18468 /* jack_coreaudio Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699D9D097D421700A18468 /* Build configuration list for PBXNativeTarget "jack_coreaudio Universal" */;
-			buildPhases = (
-				4B699D98097D421700A18468 /* Headers */,
-				4B699D9A097D421700A18468 /* Sources */,
-				4B699D9C097D421700A18468 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_coreaudio Universal";
-			productName = jack_coreaudio;
-			productReference = 4B699DA1097D421700A18468 /* jack_coreaudio.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B699DA6097D421700A18468 /* jack_dummy Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B699DAC097D421700A18468 /* Build configuration list for PBXNativeTarget "jack_dummy Universal" */;
-			buildPhases = (
-				4B699DA7097D421700A18468 /* Headers */,
-				4B699DA9097D421700A18468 /* Sources */,
-				4B699DAB097D421700A18468 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_dummy Universal";
-			productName = jack_coreaudio;
-			productReference = 4B699DB0097D421700A18468 /* jack_dummy.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4B8692821371DB4700D2D11B /* Jacknet.framework 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B8692D71371DB4700D2D11B /* Build configuration list for PBXNativeTarget "Jacknet.framework 64 bits" */;
-			buildPhases = (
-				4B8692831371DB4700D2D11B /* Headers */,
-				4B8692B21371DB4700D2D11B /* Resources */,
-				4B8692B31371DB4700D2D11B /* Sources */,
-				4B8692D41371DB4700D2D11B /* Rez */,
-				4B8692D51371DB4700D2D11B /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jacknet.framework 64 bits";
-			productName = Jack;
-			productReference = 4B8692DB1371DB4700D2D11B /* Jacknet.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4B8F16DB13290DC80002AD73 /* jack_midi_dump Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B8F16E113290DC80002AD73 /* Build configuration list for PBXNativeTarget "jack_midi_dump Universal" */;
-			buildPhases = (
-				4B8F16DC13290DC80002AD73 /* Headers */,
-				4B8F16DD13290DC80002AD73 /* Sources */,
-				4B8F16DF13290DC80002AD73 /* Frameworks */,
-				4B8F16E013290DC80002AD73 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midi_dump Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B8F16E513290DC80002AD73 /* jack_midi_dump */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B8F16E813290E0E0002AD73 /* jack_midi_dump 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B8F16EE13290E0E0002AD73 /* Build configuration list for PBXNativeTarget "jack_midi_dump 64 bits" */;
-			buildPhases = (
-				4B8F16E913290E0E0002AD73 /* Headers */,
-				4B8F16EA13290E0E0002AD73 /* Sources */,
-				4B8F16EC13290E0E0002AD73 /* Frameworks */,
-				4B8F16ED13290E0E0002AD73 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_midi_dump 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4B8F16F213290E0E0002AD73 /* jack_midi_dump */;
-			productType = "com.apple.product-type.tool";
-		};
-		4B978DB10A31CF4A009E2DD1 /* jack_portaudio Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4B978DB70A31CF4A009E2DD1 /* Build configuration list for PBXNativeTarget "jack_portaudio Universal" */;
-			buildPhases = (
-				4B978DB20A31CF4A009E2DD1 /* Headers */,
-				4B978DB40A31CF4A009E2DD1 /* Sources */,
-				4B978DB60A31CF4A009E2DD1 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_portaudio Universal";
-			productName = jack_coreaudio;
-			productReference = 4B978DBB0A31CF4A009E2DD1 /* jack_portaudio.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BA3393310B2E36800190E3B /* Jackservermp.framework 64 bits profiling */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BA339A810B2E36800190E3B /* Build configuration list for PBXNativeTarget "Jackservermp.framework 64 bits profiling" */;
-			buildPhases = (
-				4BA3393410B2E36800190E3B /* Headers */,
-				4BA3397010B2E36800190E3B /* Resources */,
-				4BA3397110B2E36800190E3B /* Sources */,
-				4BA339A510B2E36800190E3B /* Rez */,
-				4BA339A610B2E36800190E3B /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "Jackservermp.framework 64 bits profiling";
-			productName = Jack;
-			productReference = 4BA339AC10B2E36800190E3B /* Jackservermp.framework */;
-			productType = "com.apple.product-type.framework";
-		};
-		4BA692A60CBE4BC700EAD520 /* jack_load Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BA692AC0CBE4BC700EAD520 /* Build configuration list for PBXNativeTarget "jack_load Universal" */;
-			buildPhases = (
-				4BA692A70CBE4BC700EAD520 /* Headers */,
-				4BA692A80CBE4BC700EAD520 /* Sources */,
-				4BA692AA0CBE4BC700EAD520 /* Frameworks */,
-				4BA692AB0CBE4BC700EAD520 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_load Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4BA692B00CBE4BC700EAD520 /* jack_load */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BA692CA0CBE4C9000EAD520 /* jack_unload Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BA692D00CBE4C9000EAD520 /* Build configuration list for PBXNativeTarget "jack_unload Universal" */;
-			buildPhases = (
-				4BA692CB0CBE4C9000EAD520 /* Headers */,
-				4BA692CC0CBE4C9000EAD520 /* Sources */,
-				4BA692CE0CBE4C9000EAD520 /* Frameworks */,
-				4BA692CF0CBE4C9000EAD520 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_unload Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4BA692D40CBE4C9000EAD520 /* jack_unload */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BA7FEB90D8E76270017FF73 /* jack_server_control Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BA7FEBF0D8E76270017FF73 /* Build configuration list for PBXNativeTarget "jack_server_control Universal" */;
-			buildPhases = (
-				4BA7FEBA0D8E76270017FF73 /* Headers */,
-				4BA7FEBB0D8E76270017FF73 /* Sources */,
-				4BA7FEBD0D8E76270017FF73 /* Frameworks */,
-				4BA7FEBE0D8E76270017FF73 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_server_control Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_lsp;
-			productReference = 4BA7FEC30D8E76270017FF73 /* jack_server_control */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BD623ED0CBCF0F000DE782F /* inprocess Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BD623F30CBCF0F000DE782F /* Build configuration list for PBXNativeTarget "inprocess Universal" */;
-			buildPhases = (
-				4BD623EE0CBCF0F000DE782F /* Headers */,
-				4BD623F00CBCF0F000DE782F /* Sources */,
-				4BD623F20CBCF0F000DE782F /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "inprocess Universal";
-			productName = jack_coreaudio;
-			productReference = 4BD623F70CBCF0F000DE782F /* inprocess.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BDCDB931001FB9C00B15929 /* jack_coremidi 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BDCDB991001FB9C00B15929 /* Build configuration list for PBXNativeTarget "jack_coremidi 64 bits" */;
-			buildPhases = (
-				4BDCDB941001FB9C00B15929 /* Headers */,
-				4BDCDB961001FB9C00B15929 /* Sources */,
-				4BDCDB981001FB9C00B15929 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_coremidi 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4BDCDB9D1001FB9C00B15929 /* jack_coremidi.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BDCDBB71001FCC000B15929 /* jack_net 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BDCDBC11001FCC000B15929 /* Build configuration list for PBXNativeTarget "jack_net 64 bits" */;
-			buildPhases = (
-				4BDCDBB81001FCC000B15929 /* Headers */,
-				4BDCDBBC1001FCC000B15929 /* Sources */,
-				4BDCDBC01001FCC000B15929 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_net 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4BDCDBC51001FCC000B15929 /* jack_net.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BDCDBD71001FD2D00B15929 /* netmanager 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BDCDBE41001FD2D00B15929 /* Build configuration list for PBXNativeTarget "netmanager 64 bits" */;
-			buildPhases = (
-				4BDCDBD81001FD2D00B15929 /* Headers */,
-				4BDCDBDD1001FD2D00B15929 /* Sources */,
-				4BDCDBE31001FD2D00B15929 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "netmanager 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4BDCDBE81001FD2D00B15929 /* netmanager.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BDCDBEC1001FD7300B15929 /* audioadapter 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BDCDBFB1001FD7300B15929 /* Build configuration list for PBXNativeTarget "audioadapter 64 bits" */;
-			buildPhases = (
-				4BDCDBED1001FD7300B15929 /* Headers */,
-				4BDCDBF31001FD7300B15929 /* Sources */,
-				4BDCDBFA1001FD7300B15929 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "audioadapter 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4BDCDBFF1001FD7300B15929 /* audioadapter.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BDCDC0F1001FDE300B15929 /* netadapter 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BDCDC211001FDE300B15929 /* Build configuration list for PBXNativeTarget "netadapter 64 bits" */;
-			buildPhases = (
-				4BDCDC101001FDE300B15929 /* Headers */,
-				4BDCDC181001FDE300B15929 /* Sources */,
-				4BDCDC201001FDE300B15929 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "netadapter 64 bits";
-			productName = jack_coreaudio;
-			productReference = 4BDCDC251001FDE300B15929 /* netadapter.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BE6C6910A3E096F005A203A /* jack_test Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BE6C69F0A3E096F005A203A /* Build configuration list for PBXNativeTarget "jack_test Universal" */;
-			buildPhases = (
-				4BE6C6920A3E096F005A203A /* Headers */,
-				4BE6C6950A3E096F005A203A /* Sources */,
-				4BE6C69D0A3E096F005A203A /* Frameworks */,
-				4BE6C69E0A3E096F005A203A /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_test Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4BE6C6A30A3E096F005A203A /* jack_test */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BE99D260AD7A04800C59091 /* jack_cpu Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BE99D2C0AD7A04800C59091 /* Build configuration list for PBXNativeTarget "jack_cpu Universal" */;
-			buildPhases = (
-				4BE99D270AD7A04800C59091 /* Headers */,
-				4BE99D280AD7A04800C59091 /* Sources */,
-				4BE99D2A0AD7A04800C59091 /* Frameworks */,
-				4BE99D2B0AD7A04800C59091 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_cpu Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4BE99D300AD7A04800C59091 /* jack_cpu */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BF339020F8B864B0080FB5B /* jack_coremidi Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BF339080F8B864B0080FB5B /* Build configuration list for PBXNativeTarget "jack_coremidi Universal" */;
-			buildPhases = (
-				4BF339030F8B864B0080FB5B /* Headers */,
-				4BF339050F8B864B0080FB5B /* Sources */,
-				4BF339070F8B864B0080FB5B /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_coremidi Universal";
-			productName = jack_coreaudio;
-			productReference = 4BF3390C0F8B864B0080FB5B /* jack_coremidi.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		4BFA5E8B0DEC4D9C00FA4CDB /* testMutex Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA5E940DEC4D9C00FA4CDB /* Build configuration list for PBXNativeTarget "testMutex Universal" */;
-			buildPhases = (
-				4BFA5E8C0DEC4D9C00FA4CDB /* Headers */,
-				4BFA5E8D0DEC4D9C00FA4CDB /* Sources */,
-				4BFA5E910DEC4D9C00FA4CDB /* Frameworks */,
-				4BFA5E930DEC4D9C00FA4CDB /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "testMutex Universal";
-			productInstallPath = /usr/local/bin;
-			productName = testSem;
-			productReference = 4BFA5E980DEC4D9C00FA4CDB /* testMutex */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA82820DF6A9E40087B4E1 /* jack_evmon 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA82880DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_evmon 64 bits" */;
-			buildPhases = (
-				4BFA82830DF6A9E40087B4E1 /* Headers */,
-				4BFA82840DF6A9E40087B4E1 /* Sources */,
-				4BFA82860DF6A9E40087B4E1 /* Frameworks */,
-				4BFA82870DF6A9E40087B4E1 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_evmon 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4BFA828C0DF6A9E40087B4E1 /* jack_evmon */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA82950DF6A9E40087B4E1 /* jack_bufsize 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA829B0DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_bufsize 64 bits" */;
-			buildPhases = (
-				4BFA82960DF6A9E40087B4E1 /* Headers */,
-				4BFA82970DF6A9E40087B4E1 /* Sources */,
-				4BFA82990DF6A9E40087B4E1 /* Frameworks */,
-				4BFA829A0DF6A9E40087B4E1 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_bufsize 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4BFA829F0DF6A9E40087B4E1 /* jack_bufsize */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA82A10DF6A9E40087B4E1 /* jack_rec 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA82A70DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_rec 64 bits" */;
-			buildPhases = (
-				4BFA82A20DF6A9E40087B4E1 /* Headers */,
-				4BFA82A30DF6A9E40087B4E1 /* Sources */,
-				4BFA82A50DF6A9E40087B4E1 /* Frameworks */,
-				4BFA82A60DF6A9E40087B4E1 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_rec 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4BFA82AB0DF6A9E40087B4E1 /* jack_rec */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA82AD0DF6A9E40087B4E1 /* jack_monitor_client 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA82B30DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_monitor_client 64 bits" */;
-			buildPhases = (
-				4BFA82AE0DF6A9E40087B4E1 /* Headers */,
-				4BFA82AF0DF6A9E40087B4E1 /* Sources */,
-				4BFA82B10DF6A9E40087B4E1 /* Frameworks */,
-				4BFA82B20DF6A9E40087B4E1 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_monitor_client 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4BFA82B70DF6A9E40087B4E1 /* jack_monitor_client */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA82B90DF6A9E40087B4E1 /* jack_showtime 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA82BF0DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_showtime 64 bits" */;
-			buildPhases = (
-				4BFA82BA0DF6A9E40087B4E1 /* Headers */,
-				4BFA82BB0DF6A9E40087B4E1 /* Sources */,
-				4BFA82BD0DF6A9E40087B4E1 /* Frameworks */,
-				4BFA82BE0DF6A9E40087B4E1 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_showtime 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4BFA82C30DF6A9E40087B4E1 /* jack_showtime */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA82C50DF6A9E40087B4E1 /* jack_impulse_grabber 64 bits */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA82CB0DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_impulse_grabber 64 bits" */;
-			buildPhases = (
-				4BFA82C60DF6A9E40087B4E1 /* Headers */,
-				4BFA82C70DF6A9E40087B4E1 /* Sources */,
-				4BFA82C90DF6A9E40087B4E1 /* Frameworks */,
-				4BFA82CA0DF6A9E40087B4E1 /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_impulse_grabber 64 bits";
-			productInstallPath = /usr/local/bin;
-			productName = jack_metro;
-			productReference = 4BFA82CF0DF6A9E40087B4E1 /* jack_impulse_grabber */;
-			productType = "com.apple.product-type.tool";
-		};
-		4BFA99980AAAF3B0009E916C /* jack_iodelay Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = 4BFA999E0AAAF3B0009E916C /* Build configuration list for PBXNativeTarget "jack_iodelay Universal" */;
-			buildPhases = (
-				4BFA99990AAAF3B0009E916C /* Headers */,
-				4BFA999A0AAAF3B0009E916C /* Sources */,
-				4BFA999C0AAAF3B0009E916C /* Frameworks */,
-				4BFA999D0AAAF3B0009E916C /* Rez */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "jack_iodelay Universal";
-			productInstallPath = /usr/local/bin;
-			productName = jack_lsp;
-			productReference = 4BFA99A20AAAF3B0009E916C /* jack_iodelay */;
-			productType = "com.apple.product-type.tool";
-		};
-		BA222AC50DC88132001A17F4 /* jack_net Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = BA222ACB0DC88132001A17F4 /* Build configuration list for PBXNativeTarget "jack_net Universal" */;
-			buildPhases = (
-				BA222AC60DC88132001A17F4 /* Headers */,
-				BA222AC80DC88132001A17F4 /* Sources */,
-				BA222ACA0DC88132001A17F4 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-				4B3224E710A3157900838A8E /* PBXTargetDependency */,
-			);
-			name = "jack_net Universal";
-			productName = jack_coreaudio;
-			productReference = BA222ACF0DC88132001A17F4 /* jack_net.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-		BA222AE00DC882DB001A17F4 /* netmanager Universal */ = {
-			isa = PBXNativeTarget;
-			buildConfigurationList = BA222AE50DC882DB001A17F4 /* Build configuration list for PBXNativeTarget "netmanager Universal" */;
-			buildPhases = (
-				BA222AE10DC882DB001A17F4 /* Headers */,
-				BA222AE20DC882DB001A17F4 /* Sources */,
-				BA222AE40DC882DB001A17F4 /* Frameworks */,
-			);
-			buildRules = (
-			);
-			dependencies = (
-			);
-			name = "netmanager Universal";
-			productName = jack_coreaudio;
-			productReference = BA222AE90DC882DB001A17F4 /* netmanager.so */;
-			productType = "com.apple.product-type.library.dynamic";
-		};
-/* End PBXNativeTarget section */
-
-/* Begin PBXProject section */
-		08FB7793FE84155DC02AAC07 /* Project object */ = {
-			isa = PBXProject;
-			buildConfigurationList = 4B699DD5097D427F00A18468 /* Build configuration list for PBXProject "Jackdmp" */;
-			compatibilityVersion = "Xcode 2.4";
-			developmentRegion = English;
-			hasScannedForEncodings = 1;
-			knownRegions = (
-				English,
-				Japanese,
-				French,
-				German,
-			);
-			mainGroup = 08FB7794FE84155DC02AAC07 /* JackServer */;
-			projectDirPath = "";
-			projectRoot = "";
-			targets = (
-				4B699B26097D421600A18468 /* All Universal 32 bits */,
-				4B35C6420D47339B000DE7AE /* All Universal 32/64 bits */,
-				4B699BA7097D421600A18468 /* jackdmp framework Universal */,
-				4B699C00097D421600A18468 /* Jackmp.framework Universal */,
-				4B699C4C097D421600A18468 /* Jackservermp.framework Universal */,
-				4B5A1BB10CD1CB9E0005BF74 /* jack_midiseq Universal */,
-				4B5A1BD00CD1CCE10005BF74 /* jack_midisine Universal */,
-				4B8F16DB13290DC80002AD73 /* jack_midi_dump Universal */,
-				4B363DCE0DEB02F6001F72D9 /* jack_alias Universal */,
-				4B699CB1097D421600A18468 /* jack_metro Universal */,
-				4B699CC1097D421600A18468 /* jack_lsp Universal */,
-				4B699CD1097D421600A18468 /* jack_connect Universal */,
-				4B699CE1097D421600A18468 /* jack_disconnect Universal */,
-				4B699CF1097D421600A18468 /* jack_freewheel Universal */,
-				4BFA99980AAAF3B0009E916C /* jack_iodelay Universal */,
-				4B699D03097D421600A18468 /* jack_external_metro Universal */,
-				4B699D13097D421600A18468 /* testAtomic Universal */,
-				4B699D27097D421600A18468 /* testSem Universal */,
-				4BFA5E8B0DEC4D9C00FA4CDB /* testMutex Universal */,
-				4B699D3F097D421600A18468 /* zombie Universal */,
-				4BE6C6910A3E096F005A203A /* jack_test Universal */,
-				4BA7FEB90D8E76270017FF73 /* jack_server_control Universal */,
-				4BE99D260AD7A04800C59091 /* jack_cpu Universal */,
-				4BA692A60CBE4BC700EAD520 /* jack_load Universal */,
-				4BA692CA0CBE4C9000EAD520 /* jack_unload Universal */,
-				4B0A28DC0D52073D002EFF74 /* jack_thread_wait */,
-				4B363E100DEB03C5001F72D9 /* jack_evmon Universal */,
-				4B363E440DEB0775001F72D9 /* jack_bufsize Universal */,
-				4B363EDF0DEB091C001F72D9 /* jack_rec Universal */,
-				4B3811551326878E00C61B14 /* jack_latent_client Universal */,
-				4B363F140DEB0A6A001F72D9 /* jack_monitor_client Universal */,
-				4B363F2B0DEB0BD1001F72D9 /* jack_showtime Universal */,
-				4B363F680DEB0D4E001F72D9 /* jack_impulse_grabber Universal */,
-				4B32255710A3187800838A8E /* jack_netsource Universal */,
-				4B699D4F097D421600A18468 /* synchroServer Universal */,
-				4B699D67097D421600A18468 /* synchroClient Universal */,
-				4B699D7F097D421700A18468 /* synchroServerClient Universal */,
-				4B699D97097D421700A18468 /* jack_coreaudio Universal */,
-				4B978DB10A31CF4A009E2DD1 /* jack_portaudio Universal */,
-				4BF339020F8B864B0080FB5B /* jack_coremidi Universal */,
-				4B43A8B010145F6F00E52943 /* jack_loopback Universal */,
-				4B699DA6097D421700A18468 /* jack_dummy Universal */,
-				BA222AC50DC88132001A17F4 /* jack_net Universal */,
-				4B3224D710A3156800838A8E /* jack_netone Universal */,
-				4BD623ED0CBCF0F000DE782F /* inprocess Universal */,
-				BA222AE00DC882DB001A17F4 /* netmanager Universal */,
-				4B19B2F60E23620F00DD4A82 /* audioadapter Universal */,
-				4B5E08BF0E5B66EE00BEE4E0 /* netadapter Universal */,
-				4B35C41B0D4731D1000DE7AE /* jackdmp framework 64bits */,
-				4B35C4270D4731D1000DE7AE /* Jackmp.framework 64 bits */,
-				4B47AC8010B5890100469C67 /* Jackmp.framework 64 bits debugging */,
-				4B35C4850D4731D1000DE7AE /* Jackservermp.framework 64 bits */,
-				4BA3393310B2E36800190E3B /* Jackservermp.framework 64 bits profiling */,
-				4B8692821371DB4700D2D11B /* Jacknet.framework 64 bits */,
-				4B35C50A0D4731D1000DE7AE /* jack_midiseq 64 bits */,
-				4B35C5160D4731D1000DE7AE /* jack_midisine 64 bits */,
-				4B8F16E813290E0E0002AD73 /* jack_midi_dump 64 bits */,
-				4B2021DC133A9BA40019E213 /* jack_midi_latency 64 bits */,
-				4B35C5220D4731D1000DE7AE /* jack_metro 64 bits */,
-				4B35C52E0D4731D1000DE7AE /* jack_lsp 64 bits */,
-				4B35C53A0D4731D1000DE7AE /* jack_connect 64 bits */,
-				4B35C5460D4731D1000DE7AE /* jack_disconnect 64 bits */,
-				4B35C5520D4731D2000DE7AE /* jack_freewheel 64 bits */,
-				4B35C5600D4731D2000DE7AE /* jack_iodelay 64 bits */,
-				4B35C56C0D4731D2000DE7AE /* jack_external_metro 64 bits */,
-				4B35C5780D4731D2000DE7AE /* testAtomic 64 bits */,
-				4B35C5880D4731D2000DE7AE /* testSem 64 bits */,
-				4B35C59C0D4731D2000DE7AE /* zombie 64 bits */,
-				4B35C5A80D4731D2000DE7AE /* jack_test 64 bits */,
-				4B35C5B40D4731D2000DE7AE /* jack_cpu 64 bits */,
-				4B35C5C00D4731D2000DE7AE /* jack_load 64 bits */,
-				4B35C5CC0D4731D2000DE7AE /* jack_unload 64 bits */,
-				4B0A29230D52108E002EFF74 /* jack_thread_wait 64 bits */,
-				4BFA82820DF6A9E40087B4E1 /* jack_evmon 64 bits */,
-				4BFA82950DF6A9E40087B4E1 /* jack_bufsize 64 bits */,
-				4BFA82A10DF6A9E40087B4E1 /* jack_rec 64 bits */,
-				4B38118D1326884E00C61B14 /* jack_latent_client 64 bits */,
-				4BFA82AD0DF6A9E40087B4E1 /* jack_monitor_client 64 bits */,
-				4BFA82B90DF6A9E40087B4E1 /* jack_showtime 64 bits */,
-				4BFA82C50DF6A9E40087B4E1 /* jack_impulse_grabber 64 bits */,
-				4B32257110A3190C00838A8E /* jack_netsource 64 bits */,
-				4B6654ED127C34AE00753A79 /* jack_server_control 64 bits */,
-				4B35C5D80D4731D2000DE7AE /* synchroServer 64 bits */,
-				4B35C5EC0D4731D2000DE7AE /* synchroClient 64 bits */,
-				4B35C6000D4731D2000DE7AE /* synchroServerClient 64 bits */,
-				4B35C6140D4731D2000DE7AE /* jack_coreaudio 64 bits */,
-				4B35C61F0D4731D2000DE7AE /* jack_portaudio 64 bits */,
-				4B35C62A0D4731D2000DE7AE /* jack_dummy 64 bits */,
-				4B43A8DD1014615800E52943 /* jack_loopback 64 bits */,
-				4BDCDB931001FB9C00B15929 /* jack_coremidi 64 bits */,
-				4BDCDBB71001FCC000B15929 /* jack_net 64 bits */,
-				4B32251D10A316B200838A8E /* jack_netone 64 bits */,
-				4BDCDBD71001FD2D00B15929 /* netmanager 64 bits */,
-				4BDCDBEC1001FD7300B15929 /* audioadapter 64 bits */,
-				4BDCDC0F1001FDE300B15929 /* netadapter 64 bits */,
-				4B35C6350D4731D3000DE7AE /* inprocess 64 bits */,
-			);
-		};
-/* End PBXProject section */
-
-/* Begin PBXResourcesBuildPhase section */
-		4B35C4560D4731D1000DE7AE /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4C20D4731D1000DE7AE /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B47ACAC10B5890100469C67 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C23097D421600A18468 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C7C097D421600A18468 /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8692B21371DB4700D2D11B /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA3397010B2E36800190E3B /* Resources */ = {
-			isa = PBXResourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXResourcesBuildPhase section */
-
-/* Begin PBXRezBuildPhase section */
-		4B0A28E10D52073D002EFF74 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0A29280D52108E002EFF74 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B2021E1133A9BA40019E213 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32255C10A3187800838A8E /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32257610A3190C00838A8E /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4200D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C47D0D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4F60D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C50F0D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C51B0D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5270D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5330D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C53F0D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C54B0D4731D1000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5590D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5650D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5710D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5810D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5950D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5A10D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5AD0D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5B90D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5C50D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5D10D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5E50D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5F90D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C60D0D4731D2000DE7AE /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363DD30DEB02F6001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E150DEB03C5001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E490DEB0775001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363EE40DEB091C001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F190DEB0A6A001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F300DEB0BD1001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F6D0DEB0D4E001F72D9 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B38115A1326878E00C61B14 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3811921326884E00C61B14 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B47ACD010B5890100469C67 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BB60CD1CB9E0005BF74 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BD50CD1CCE10005BF74 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B6654F2127C34AE00753A79 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699BAC097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C41097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CA6097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CB6097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CC6097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CD6097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CE6097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CF8097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D08097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D1C097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D34097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D44097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D5C097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D74097D421600A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D8C097D421700A18468 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8692D41371DB4700D2D11B /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16E013290DC80002AD73 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16ED13290E0E0002AD73 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA339A510B2E36800190E3B /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692AB0CBE4BC700EAD520 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692CF0CBE4C9000EAD520 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA7FEBE0D8E76270017FF73 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE6C69E0A3E096F005A203A /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE99D2B0AD7A04800C59091 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA5E930DEC4D9C00FA4CDB /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82870DF6A9E40087B4E1 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA829A0DF6A9E40087B4E1 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82A60DF6A9E40087B4E1 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82B20DF6A9E40087B4E1 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82BE0DF6A9E40087B4E1 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82CA0DF6A9E40087B4E1 /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA999D0AAAF3B0009E916C /* Rez */ = {
-			isa = PBXRezBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXRezBuildPhase section */
-
-/* Begin PBXSourcesBuildPhase section */
-		4B0A28DE0D52073D002EFF74 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B0A28ED0D520852002EFF74 /* tw.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B0A29250D52108E002EFF74 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B0A29260D52108E002EFF74 /* tw.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B19B2F90E23620F00DD4A82 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B19B3130E2362E800DD4A82 /* JackAudioAdapter.cpp in Sources */,
-				4B19B3150E2362E800DD4A82 /* JackAudioAdapterInterface.cpp in Sources */,
-				4B19B31B0E2362E800DD4A82 /* JackLibSampleRateResampler.cpp in Sources */,
-				4B19B31F0E2362E800DD4A82 /* JackResampler.cpp in Sources */,
-				4BF4BAB10E3480AB00403CDF /* JackAudioAdapterFactory.cpp in Sources */,
-				4BE5FED10E725C320020B576 /* JackCoreAudioAdapter.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B2021DE133A9BA40019E213 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B20220A133A9C1C0019E213 /* midi_latency_test.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3224DC10A3156800838A8E /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3224EA10A315B100838A8E /* JackNetOneDriver.cpp in Sources */,
-				4B3224F010A315C400838A8E /* netjack_packet.c in Sources */,
-				4B3224F210A315C400838A8E /* netjack.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32252210A316B200838A8E /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B32253110A3173900838A8E /* JackNetOneDriver.cpp in Sources */,
-				4B32253310A3173B00838A8E /* netjack.c in Sources */,
-				4B32253510A3173D00838A8E /* netjack_packet.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32255910A3187800838A8E /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B32256410A318E300838A8E /* netsource.c in Sources */,
-				4B32256D10A318FC00838A8E /* netjack_packet.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B32257310A3190C00838A8E /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B32257F10A3195900838A8E /* netjack_packet.c in Sources */,
-				4B32258110A3195B00838A8E /* netsource.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C41D0D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C41E0D4731D1000DE7AE /* Jackdmp.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4570D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C45B0D4731D1000DE7AE /* JackShmMem.cpp in Sources */,
-				4B35C45C0D4731D1000DE7AE /* shm.c in Sources */,
-				4B35C45E0D4731D1000DE7AE /* JackActivationCount.cpp in Sources */,
-				4B35C45F0D4731D1000DE7AE /* JackGraphManager.cpp in Sources */,
-				4B35C4600D4731D1000DE7AE /* JackPort.cpp in Sources */,
-				4B35C4610D4731D1000DE7AE /* JackClient.cpp in Sources */,
-				4B35C4620D4731D1000DE7AE /* JackAPI.cpp in Sources */,
-				4B35C4630D4731D1000DE7AE /* JackLibClient.cpp in Sources */,
-				4B35C4640D4731D1000DE7AE /* JackLibAPI.cpp in Sources */,
-				4B35C4650D4731D1000DE7AE /* JackConnectionManager.cpp in Sources */,
-				4B35C4660D4731D1000DE7AE /* JackFrameTimer.cpp in Sources */,
-				4B35C4680D4731D1000DE7AE /* JackMachSemaphore.cpp in Sources */,
-				4B35C4690D4731D1000DE7AE /* JackMachThread.cpp in Sources */,
-				4B35C4700D4731D1000DE7AE /* JackGlobals.cpp in Sources */,
-				4B35C4720D4731D1000DE7AE /* ringbuffer.c in Sources */,
-				4B35C4730D4731D1000DE7AE /* JackDebugClient.cpp in Sources */,
-				4B35C4740D4731D1000DE7AE /* JackTransportEngine.cpp in Sources */,
-				4B35C4760D4731D1000DE7AE /* timestamps.c in Sources */,
-				4B35C4770D4731D1000DE7AE /* JackPortType.cpp in Sources */,
-				4B35C4780D4731D1000DE7AE /* JackAudioPort.cpp in Sources */,
-				4B35C4790D4731D1000DE7AE /* JackMidiPort.cpp in Sources */,
-				4B35C47A0D4731D1000DE7AE /* JackMidiAPI.cpp in Sources */,
-				4B35C47B0D4731D1000DE7AE /* JackEngineControl.cpp in Sources */,
-				4B35C47C0D4731D1000DE7AE /* JackTools.cpp in Sources */,
-				4B9A26610DBF8ADD006E9FBC /* JackError.cpp in Sources */,
-				4B4F9C900DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */,
-				4B93F19C0E87998200E4ECCD /* JackPosixServerLaunch.cpp in Sources */,
-				4B93F19D0E87998400E4ECCD /* JackPosixThread.cpp in Sources */,
-				4B93F1C00E87A35400E4ECCD /* JackMachTime.c in Sources */,
-				4B8A38F1117B827E00664E07 /* JackSocketClientChannel.cpp in Sources */,
-				4B8A38F6117B82AB00664E07 /* JackSocket.cpp in Sources */,
-				4B327BAB14B4B50400976483 /* JackPosixMutex.cpp in Sources */,
-				4B1499F614BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */,
-				4BB4215214D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */,
-				4B4C3B641BC2FF670004CC35 /* JackPosixSemaphore.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C4C30D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C4C50D4731D1000DE7AE /* JackShmMem.cpp in Sources */,
-				4B35C4C60D4731D1000DE7AE /* shm.c in Sources */,
-				4B35C4C80D4731D1000DE7AE /* JackActivationCount.cpp in Sources */,
-				4B35C4C90D4731D1000DE7AE /* JackGraphManager.cpp in Sources */,
-				4B35C4CA0D4731D1000DE7AE /* JackPort.cpp in Sources */,
-				4B35C4CB0D4731D1000DE7AE /* JackClient.cpp in Sources */,
-				4B35C4CC0D4731D1000DE7AE /* JackAPI.cpp in Sources */,
-				4B35C4CD0D4731D1000DE7AE /* JackConnectionManager.cpp in Sources */,
-				4B35C4CE0D4731D1000DE7AE /* JackFrameTimer.cpp in Sources */,
-				4B35C4D00D4731D1000DE7AE /* JackMachSemaphore.cpp in Sources */,
-				4B35C4D10D4731D1000DE7AE /* JackMachThread.cpp in Sources */,
-				4B35C4D50D4731D1000DE7AE /* JackGlobals.cpp in Sources */,
-				4B35C4D70D4731D1000DE7AE /* ringbuffer.c in Sources */,
-				4B35C4D80D4731D1000DE7AE /* JackAudioDriver.cpp in Sources */,
-				4B35C4D90D4731D1000DE7AE /* JackFreewheelDriver.cpp in Sources */,
-				4B35C4DA0D4731D1000DE7AE /* JackThreadedDriver.cpp in Sources */,
-				4B35C4DB0D4731D1000DE7AE /* JackDriver.cpp in Sources */,
-				4B35C4DC0D4731D1000DE7AE /* JackDriverLoader.cpp in Sources */,
-				4B35C4DD0D4731D1000DE7AE /* JackEngine.cpp in Sources */,
-				4B35C4DE0D4731D1000DE7AE /* JackExternalClient.cpp in Sources */,
-				4B35C4DF0D4731D1000DE7AE /* JackInternalClient.cpp in Sources */,
-				4B35C4E20D4731D1000DE7AE /* JackServer.cpp in Sources */,
-				4B35C4EB0D4731D1000DE7AE /* JackTransportEngine.cpp in Sources */,
-				4B35C4EC0D4731D1000DE7AE /* JackServerAPI.cpp in Sources */,
-				4B35C4ED0D4731D1000DE7AE /* JackServerGlobals.cpp in Sources */,
-				4B35C4EE0D4731D1000DE7AE /* timestamps.c in Sources */,
-				4B35C4EF0D4731D1000DE7AE /* JackPortType.cpp in Sources */,
-				4B35C4F00D4731D1000DE7AE /* JackAudioPort.cpp in Sources */,
-				4B35C4F10D4731D1000DE7AE /* JackMidiPort.cpp in Sources */,
-				4B35C4F20D4731D1000DE7AE /* JackMidiAPI.cpp in Sources */,
-				4B35C4F30D4731D1000DE7AE /* JackEngineControl.cpp in Sources */,
-				4B35C4F40D4731D1000DE7AE /* JackDebugClient.cpp in Sources */,
-				4B35C4F50D4731D1000DE7AE /* JackTools.cpp in Sources */,
-				BA222ADA0DC88269001A17F4 /* JackNetTool.cpp in Sources */,
-				4B9A26640DBF8B14006E9FBC /* JackError.cpp in Sources */,
-				4B4F9C920DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */,
-				4B4CA9780E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp in Sources */,
-				4B4E9AFC0E5F1090000A3278 /* JackControlAPI.cpp in Sources */,
-				4B93F1990E87992100E4ECCD /* JackPosixThread.cpp in Sources */,
-				4B93F22B0E87A72500E4ECCD /* JackMachTime.c in Sources */,
-				4BBAE4130F42FA6100B8BD3F /* JackEngineProfiling.cpp in Sources */,
-				4BF339210F8B873E0080FB5B /* JackMidiDriver.cpp in Sources */,
-				4BDCDBD11001FD0100B15929 /* JackWaitThreadedDriver.cpp in Sources */,
-				4BDCDC091001FDA800B15929 /* JackArgParser.cpp in Sources */,
-				4BC2CA59113C6CB60076717C /* JackNetInterface.cpp in Sources */,
-				4BC2CA5B113C6CBE0076717C /* JackNetUnixSocket.cpp in Sources */,
-				4B8A38A7117B80D300664E07 /* JackSocket.cpp in Sources */,
-				4B8A38AE117B811100664E07 /* JackSocketNotifyChannel.cpp in Sources */,
-				4B8A38B1117B812D00664E07 /* JackSocketServerChannel.cpp in Sources */,
-				4B8A38B2117B813400664E07 /* JackSocketServerNotifyChannel.cpp in Sources */,
-				4B97B6601344B48F00794F57 /* JackMidiAsyncQueue.cpp in Sources */,
-				4B97B6621344B49C00794F57 /* JackMidiAsyncWaitQueue.cpp in Sources */,
-				4B97B6641344B4AE00794F57 /* JackMidiBufferReadQueue.cpp in Sources */,
-				4B97B6691344B4CE00794F57 /* JackMidiBufferWriteQueue.cpp in Sources */,
-				4B97B66E1344B4D500794F57 /* JackMidiReadQueue.cpp in Sources */,
-				4B97B6701344B4E300794F57 /* JackMidiReceiveQueue.cpp in Sources */,
-				4B97B6721344B4F000794F57 /* JackMidiSendQueue.cpp in Sources */,
-				4B97B6791344B50F00794F57 /* JackMidiUtil.cpp in Sources */,
-				4B97B67B1344B51D00794F57 /* JackMidiWriteQueue.cpp in Sources */,
-				4B21795113E2EEA60095B3E5 /* JackTimedDriver.cpp in Sources */,
-				4B67AB8E14B4B03800B4AA9A /* JackException.cpp in Sources */,
-				4B327BA814B4B50400976483 /* JackPosixMutex.cpp in Sources */,
-				4B1499F014BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */,
-				4B90669A14BEE6D20074CD40 /* JackRequestDecoder.cpp in Sources */,
-				4BB4215814D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */,
-				4B4C3B6C1BC2FFC40004CC35 /* JackPosixSemaphore.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C50C0D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C50D0D4731D1000DE7AE /* midiseq.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5180D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5190D4731D1000DE7AE /* midisine.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5240D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5250D4731D1000DE7AE /* metro.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5300D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5310D4731D1000DE7AE /* lsp.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C53C0D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C53D0D4731D1000DE7AE /* connect.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5480D4731D1000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5490D4731D1000DE7AE /* connect.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5560D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5570D4731D2000DE7AE /* freewheel.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5620D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3814211327AA6800C61B14 /* iodelay.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C56E0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C57C0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C57D0D4731D2000DE7AE /* testAtomic.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C58C0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C58D0D4731D2000DE7AE /* testSem.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C59E0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C59F0D4731D2000DE7AE /* zombie.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5AA0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5AB0D4731D2000DE7AE /* test.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5B60D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5B70D4731D2000DE7AE /* cpu.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5C20D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5C30D4731D2000DE7AE /* ipload.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5CE0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5CF0D4731D2000DE7AE /* ipunload.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5DC0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5DD0D4731D2000DE7AE /* JackMachSemaphore.cpp in Sources */,
-				4B35C5E00D4731D2000DE7AE /* JackMachThread.cpp in Sources */,
-				4B35C5E20D4731D2000DE7AE /* testSynchroServer.cpp in Sources */,
-				4B9A26790DBF8B88006E9FBC /* JackError.cpp in Sources */,
-				4B4F9D820DC2178E00706CB0 /* JackMessageBuffer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C5F00D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C5F60D4731D2000DE7AE /* testSynchroClient.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6040D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C60A0D4731D2000DE7AE /* testSynchroServerClient.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6170D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA4ADB40E87AB2500F26C85 /* JackCoreAudioDriver.cpp in Sources */,
-				4BAA150514F04FB600402512 /* JackAC3Encoder.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6220D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C62D0D4731D2000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C62E0D4731D2000DE7AE /* JackDummyDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B35C6370D4731D3000DE7AE /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B35C6380D4731D3000DE7AE /* inprocess.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363DD00DEB02F6001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363DDF0DEB034E001F72D9 /* alias.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E120DEB03C5001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363E210DEB0401001F72D9 /* evmon.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363E460DEB0775001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363E720DEB0808001F72D9 /* bufsize.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363EE10DEB091C001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363EEE0DEB094B001F72D9 /* capture_client.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F160DEB0A6A001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363F230DEB0AB0001F72D9 /* monitor_client.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F2D0DEB0BD1001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363F3E0DEB0C31001F72D9 /* showtime.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B363F6A0DEB0D4E001F72D9 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B363F760DEB0D7D001F72D9 /* impulse_grabber.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B3811571326878E00C61B14 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3811FC13269C8300C61B14 /* latent_client.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B38118F1326884E00C61B14 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3811FB13269C8300C61B14 /* latent_client.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B43A8B310145F6F00E52943 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B43A8CA1014605000E52943 /* JackLoopbackDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B43A8E01014615800E52943 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B43A8E11014615800E52943 /* JackLoopbackDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B47ACAD10B5890100469C67 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B47ACB110B5890100469C67 /* JackShmMem.cpp in Sources */,
-				4B47ACB210B5890100469C67 /* shm.c in Sources */,
-				4B47ACB310B5890100469C67 /* JackActivationCount.cpp in Sources */,
-				4B47ACB410B5890100469C67 /* JackGraphManager.cpp in Sources */,
-				4B47ACB510B5890100469C67 /* JackPort.cpp in Sources */,
-				4B47ACB610B5890100469C67 /* JackClient.cpp in Sources */,
-				4B47ACB710B5890100469C67 /* JackAPI.cpp in Sources */,
-				4B47ACB810B5890100469C67 /* JackLibClient.cpp in Sources */,
-				4B47ACB910B5890100469C67 /* JackLibAPI.cpp in Sources */,
-				4B47ACBA10B5890100469C67 /* JackConnectionManager.cpp in Sources */,
-				4B47ACBB10B5890100469C67 /* JackFrameTimer.cpp in Sources */,
-				4B47ACBC10B5890100469C67 /* JackMachSemaphore.cpp in Sources */,
-				4B47ACBD10B5890100469C67 /* JackMachThread.cpp in Sources */,
-				4B47ACBF10B5890100469C67 /* JackGlobals.cpp in Sources */,
-				4B47ACC010B5890100469C67 /* ringbuffer.c in Sources */,
-				4B47ACC110B5890100469C67 /* JackDebugClient.cpp in Sources */,
-				4B47ACC210B5890100469C67 /* JackTransportEngine.cpp in Sources */,
-				4B47ACC310B5890100469C67 /* timestamps.c in Sources */,
-				4B47ACC410B5890100469C67 /* JackPortType.cpp in Sources */,
-				4B47ACC510B5890100469C67 /* JackAudioPort.cpp in Sources */,
-				4B47ACC610B5890100469C67 /* JackMidiPort.cpp in Sources */,
-				4B47ACC710B5890100469C67 /* JackMidiAPI.cpp in Sources */,
-				4B47ACC810B5890100469C67 /* JackEngineControl.cpp in Sources */,
-				4B47ACC910B5890100469C67 /* JackTools.cpp in Sources */,
-				4B47ACCA10B5890100469C67 /* JackError.cpp in Sources */,
-				4B47ACCB10B5890100469C67 /* JackMessageBuffer.cpp in Sources */,
-				4B47ACCC10B5890100469C67 /* JackPosixServerLaunch.cpp in Sources */,
-				4B47ACCD10B5890100469C67 /* JackPosixThread.cpp in Sources */,
-				4B47ACCE10B5890100469C67 /* JackMachTime.c in Sources */,
-				4B327BAC14B4B50400976483 /* JackPosixMutex.cpp in Sources */,
-				4B1499F814BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */,
-				4BB4215514D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */,
-				4B4C3B6A1BC2FFB30004CC35 /* JackPosixSemaphore.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BB30CD1CB9E0005BF74 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B5A1BBE0CD1CC110005BF74 /* midiseq.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5A1BD20CD1CCE10005BF74 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B5A1BDD0CD1CD420005BF74 /* midisine.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B5E08C90E5B66EE00BEE4E0 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B5E08CC0E5B66EE00BEE4E0 /* JackAudioAdapterInterface.cpp in Sources */,
-				4B5E08CD0E5B66EE00BEE4E0 /* JackLibSampleRateResampler.cpp in Sources */,
-				4B5E08CE0E5B66EE00BEE4E0 /* JackResampler.cpp in Sources */,
-				4B5E08E10E5B676C00BEE4E0 /* JackNetAdapter.cpp in Sources */,
-				4B5E08EE0E5B680200BEE4E0 /* JackAudioAdapter.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B6654EF127C34AE00753A79 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B6654FC127C350100753A79 /* server_control.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699BA9097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699BAA097D421600A18468 /* Jackdmp.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C24097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699C28097D421600A18468 /* JackShmMem.cpp in Sources */,
-				4B699C29097D421600A18468 /* shm.c in Sources */,
-				4B699C2B097D421600A18468 /* JackActivationCount.cpp in Sources */,
-				4B699C2C097D421600A18468 /* JackGraphManager.cpp in Sources */,
-				4B699C2D097D421600A18468 /* JackPort.cpp in Sources */,
-				4B699C2E097D421600A18468 /* JackClient.cpp in Sources */,
-				4B699C2F097D421600A18468 /* JackAPI.cpp in Sources */,
-				4B699C30097D421600A18468 /* JackLibClient.cpp in Sources */,
-				4B699C31097D421600A18468 /* JackLibAPI.cpp in Sources */,
-				4B699C32097D421600A18468 /* JackConnectionManager.cpp in Sources */,
-				4B699C33097D421600A18468 /* JackFrameTimer.cpp in Sources */,
-				4B699C35097D421600A18468 /* JackMachSemaphore.cpp in Sources */,
-				4B699C36097D421600A18468 /* JackMachThread.cpp in Sources */,
-				4B699C3D097D421600A18468 /* JackGlobals.cpp in Sources */,
-				4B699C3F097D421600A18468 /* ringbuffer.c in Sources */,
-				4B699C40097D421600A18468 /* JackDebugClient.cpp in Sources */,
-				4BF520530CB8D0E80037470E /* timestamps.c in Sources */,
-				4BAB95B80B9E20B800A0C723 /* JackPortType.cpp in Sources */,
-				4BAB95ED0B9E21A500A0C723 /* JackAudioPort.cpp in Sources */,
-				4B80D7E90BA0D17400F035BB /* JackMidiPort.cpp in Sources */,
-				4B80D7EA0BA0D17400F035BB /* JackMidiAPI.cpp in Sources */,
-				4BE4CC010CDA153400CCF5BB /* JackTools.cpp in Sources */,
-				4B9A25B50DBF8330006E9FBC /* JackError.cpp in Sources */,
-				4B4F9C8E0DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */,
-				4BB9D4B40E2610B400351653 /* JackTransportEngine.cpp in Sources */,
-				4BB9D4E40E26112900351653 /* JackEngineControl.cpp in Sources */,
-				4BC3B6A40E703B2E0066E42F /* JackPosixThread.cpp in Sources */,
-				4BF5FBBC0E878B9C003D2374 /* JackPosixServerLaunch.cpp in Sources */,
-				4BF5FBCB0E878D24003D2374 /* JackMachTime.c in Sources */,
-				4B2209EC12F6BC2100E5DC26 /* JackSocket.cpp in Sources */,
-				4B2209EE12F6BC2300E5DC26 /* JackSocketClientChannel.cpp in Sources */,
-				4B327BAA14B4B50400976483 /* JackPosixMutex.cpp in Sources */,
-				4B1499F414BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */,
-				4BB4214C14D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699C7D097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699C7F097D421600A18468 /* JackShmMem.cpp in Sources */,
-				4B699C80097D421600A18468 /* shm.c in Sources */,
-				4B699C82097D421600A18468 /* JackActivationCount.cpp in Sources */,
-				4B699C83097D421600A18468 /* JackGraphManager.cpp in Sources */,
-				4B699C84097D421600A18468 /* JackPort.cpp in Sources */,
-				4B699C85097D421600A18468 /* JackClient.cpp in Sources */,
-				4B699C86097D421600A18468 /* JackAPI.cpp in Sources */,
-				4B699C87097D421600A18468 /* JackConnectionManager.cpp in Sources */,
-				4B699C88097D421600A18468 /* JackFrameTimer.cpp in Sources */,
-				4B699C8A097D421600A18468 /* JackMachSemaphore.cpp in Sources */,
-				4B699C8B097D421600A18468 /* JackMachThread.cpp in Sources */,
-				4B699C8F097D421600A18468 /* JackGlobals.cpp in Sources */,
-				4B699C91097D421600A18468 /* ringbuffer.c in Sources */,
-				4B699C92097D421600A18468 /* JackAudioDriver.cpp in Sources */,
-				4B699C93097D421600A18468 /* JackFreewheelDriver.cpp in Sources */,
-				4B699C94097D421600A18468 /* JackThreadedDriver.cpp in Sources */,
-				4B699C95097D421600A18468 /* JackDriver.cpp in Sources */,
-				4B699C96097D421600A18468 /* JackDriverLoader.cpp in Sources */,
-				4B699C97097D421600A18468 /* JackEngine.cpp in Sources */,
-				4B699C99097D421600A18468 /* JackExternalClient.cpp in Sources */,
-				4B699C9A097D421600A18468 /* JackInternalClient.cpp in Sources */,
-				4B699C9D097D421600A18468 /* JackServer.cpp in Sources */,
-				4BD4B4D909BACD9600750C0F /* JackTransportEngine.cpp in Sources */,
-				4BC216850A444BAD00BDA09F /* JackServerAPI.cpp in Sources */,
-				4BC216890A444BDE00BDA09F /* JackServerGlobals.cpp in Sources */,
-				4BF520540CB8D0E80037470E /* timestamps.c in Sources */,
-				4BAB95BA0B9E20B800A0C723 /* JackPortType.cpp in Sources */,
-				4BAB95EE0B9E21A500A0C723 /* JackAudioPort.cpp in Sources */,
-				4B80D7EC0BA0D17400F035BB /* JackMidiPort.cpp in Sources */,
-				4B80D7ED0BA0D17400F035BB /* JackMidiAPI.cpp in Sources */,
-				4B6F7AEE0CD0CDBD00F48A9D /* JackEngineControl.cpp in Sources */,
-				4B5DB9830CD2429A00EBA5EE /* JackDebugClient.cpp in Sources */,
-				4BE4CC030CDA153500CCF5BB /* JackTools.cpp in Sources */,
-				BA222AD80DC88268001A17F4 /* JackNetTool.cpp in Sources */,
-				4B9A25B60DBF8330006E9FBC /* JackError.cpp in Sources */,
-				4B4F9C8C0DC20C0400706CB0 /* JackMessageBuffer.cpp in Sources */,
-				4BBC93BA0DF9736C002DF220 /* JackWaitThreadedDriver.cpp in Sources */,
-				4B4CA9760E02CF9600F4BFDA /* JackRestartThreadedDriver.cpp in Sources */,
-				4B4E9AFA0E5F1090000A3278 /* JackControlAPI.cpp in Sources */,
-				4BC3B6A60E703B2E0066E42F /* JackPosixThread.cpp in Sources */,
-				4BF5FBCA0E878D24003D2374 /* JackMachTime.c in Sources */,
-				4BF2841A0F31B4BC00B05BE3 /* JackArgParser.cpp in Sources */,
-				4BBAE4110F42FA6100B8BD3F /* JackEngineProfiling.cpp in Sources */,
-				4BF339230F8B873E0080FB5B /* JackMidiDriver.cpp in Sources */,
-				4BC2CA55113C6C930076717C /* JackNetInterface.cpp in Sources */,
-				4BC2CA57113C6C9B0076717C /* JackNetUnixSocket.cpp in Sources */,
-				4B2209E112F6BBF300E5DC26 /* JackSocketServerChannel.cpp in Sources */,
-				4B2209E312F6BBF500E5DC26 /* JackSocketServerNotifyChannel.cpp in Sources */,
-				4B2209E612F6BC0200E5DC26 /* JackSocket.cpp in Sources */,
-				4B2209E912F6BC1500E5DC26 /* JackSocketNotifyChannel.cpp in Sources */,
-				4B97B6381344B3C100794F57 /* JackMidiAsyncQueue.cpp in Sources */,
-				4B97B63A1344B3C700794F57 /* JackMidiAsyncWaitQueue.cpp in Sources */,
-				4B97B63E1344B3F100794F57 /* JackMidiBufferReadQueue.cpp in Sources */,
-				4B97B6531344B41E00794F57 /* JackMidiBufferWriteQueue.cpp in Sources */,
-				4B97B6571344B43A00794F57 /* JackMidiReadQueue.cpp in Sources */,
-				4B97B6581344B43F00794F57 /* JackMidiReceiveQueue.cpp in Sources */,
-				4B97B65A1344B44F00794F57 /* JackMidiSendQueue.cpp in Sources */,
-				4B97B65C1344B45D00794F57 /* JackMidiUtil.cpp in Sources */,
-				4B97B65E1344B46B00794F57 /* JackMidiWriteQueue.cpp in Sources */,
-				4B21794F13E2EEA60095B3E5 /* JackTimedDriver.cpp in Sources */,
-				4B67AB8D14B4B03800B4AA9A /* JackException.cpp in Sources */,
-				4B327BA714B4B50400976483 /* JackPosixMutex.cpp in Sources */,
-				4B1499FA14BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */,
-				4B90669E14BEE6D20074CD40 /* JackRequestDecoder.cpp in Sources */,
-				4BB4214F14D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CB3097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699CB4097D421600A18468 /* metro.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CC3097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699CC4097D421600A18468 /* lsp.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CD3097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B60CE490AAABA31004956AA /* connect.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CE3097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B60CE4A0AAABA31004956AA /* connect.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699CF5097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699CF6097D421600A18468 /* freewheel.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D05097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D17097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699D18097D421600A18468 /* testAtomic.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D2B097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699D2C097D421600A18468 /* testSem.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D41097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699D42097D421600A18468 /* zombie.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D53097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699D59097D421600A18468 /* testSynchroServer.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D6B097D421600A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699D71097D421600A18468 /* testSynchroClient.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D83097D421700A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699D89097D421700A18468 /* testSynchroServerClient.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699D9A097D421700A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BE5FECD0E725C090020B576 /* JackCoreAudioDriver.cpp in Sources */,
-				4BAA150314F04FB600402512 /* JackAC3Encoder.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B699DA9097D421700A18468 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B699DAA097D421700A18468 /* JackDummyDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8692B31371DB4700D2D11B /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B8692F81371DC5200D2D11B /* JackAudioAdapterInterface.cpp in Sources */,
-				4B8692FB1371DC7100D2D11B /* JackGlobals.cpp in Sources */,
-				4B8692FE1371DC9700D2D11B /* JackMachThread.cpp in Sources */,
-				4B8693141371DCCA00D2D11B /* JackMachTime.c in Sources */,
-				4B8693161371DD0A00D2D11B /* JackNetAPI.cpp in Sources */,
-				4B8693171371DD2400D2D11B /* JackNetInterface.cpp in Sources */,
-				4B8693191371DD3B00D2D11B /* JackNetTool.cpp in Sources */,
-				4B86931B1371DD4C00D2D11B /* JackNetUnixSocket.cpp in Sources */,
-				4B8693231371DD6000D2D11B /* JackPosixThread.cpp in Sources */,
-				4B8693251371DD7E00D2D11B /* JackResampler.cpp in Sources */,
-				4B86932C1371DD9B00D2D11B /* ringbuffer.c in Sources */,
-				4B86934D1371DEBA00D2D11B /* JackLibSampleRateResampler.cpp in Sources */,
-				4B327BD614B4B6E700976483 /* JackException.cpp in Sources */,
-				4BF1007C15135D8200B88F80 /* JackPosixMutex.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16DD13290DC80002AD73 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B8F16F51329161E0002AD73 /* midi_dump.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B8F16EA13290E0E0002AD73 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B8F16F61329161E0002AD73 /* midi_dump.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4B978DB40A31CF4A009E2DD1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BBB00D30E72614F0018AB1B /* JackPortAudioDevices.cpp in Sources */,
-				4BBB00D50E72614F0018AB1B /* JackPortAudioDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA3397110B2E36800190E3B /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA3397310B2E36800190E3B /* JackShmMem.cpp in Sources */,
-				4BA3397410B2E36800190E3B /* shm.c in Sources */,
-				4BA3397510B2E36800190E3B /* JackActivationCount.cpp in Sources */,
-				4BA3397610B2E36800190E3B /* JackGraphManager.cpp in Sources */,
-				4BA3397710B2E36800190E3B /* JackPort.cpp in Sources */,
-				4BA3397810B2E36800190E3B /* JackClient.cpp in Sources */,
-				4BA3397910B2E36800190E3B /* JackAPI.cpp in Sources */,
-				4BA3397A10B2E36800190E3B /* JackConnectionManager.cpp in Sources */,
-				4BA3397B10B2E36800190E3B /* JackFrameTimer.cpp in Sources */,
-				4BA3397C10B2E36800190E3B /* JackMachSemaphore.cpp in Sources */,
-				4BA3397D10B2E36800190E3B /* JackMachThread.cpp in Sources */,
-				4BA3397E10B2E36800190E3B /* JackGlobals.cpp in Sources */,
-				4BA3397F10B2E36800190E3B /* ringbuffer.c in Sources */,
-				4BA3398010B2E36800190E3B /* JackAudioDriver.cpp in Sources */,
-				4BA3398110B2E36800190E3B /* JackFreewheelDriver.cpp in Sources */,
-				4BA3398210B2E36800190E3B /* JackThreadedDriver.cpp in Sources */,
-				4BA3398310B2E36800190E3B /* JackDriver.cpp in Sources */,
-				4BA3398410B2E36800190E3B /* JackDriverLoader.cpp in Sources */,
-				4BA3398510B2E36800190E3B /* JackEngine.cpp in Sources */,
-				4BA3398610B2E36800190E3B /* JackExternalClient.cpp in Sources */,
-				4BA3398710B2E36800190E3B /* JackInternalClient.cpp in Sources */,
-				4BA3398910B2E36800190E3B /* JackServer.cpp in Sources */,
-				4BA3398E10B2E36800190E3B /* JackTransportEngine.cpp in Sources */,
-				4BA3398F10B2E36800190E3B /* JackServerAPI.cpp in Sources */,
-				4BA3399010B2E36800190E3B /* JackServerGlobals.cpp in Sources */,
-				4BA3399110B2E36800190E3B /* timestamps.c in Sources */,
-				4BA3399210B2E36800190E3B /* JackPortType.cpp in Sources */,
-				4BA3399310B2E36800190E3B /* JackAudioPort.cpp in Sources */,
-				4BA3399410B2E36800190E3B /* JackMidiPort.cpp in Sources */,
-				4BA3399510B2E36800190E3B /* JackMidiAPI.cpp in Sources */,
-				4BA3399610B2E36800190E3B /* JackEngineControl.cpp in Sources */,
-				4BA3399710B2E36800190E3B /* JackDebugClient.cpp in Sources */,
-				4BA3399810B2E36800190E3B /* JackTools.cpp in Sources */,
-				4BA3399910B2E36800190E3B /* JackNetTool.cpp in Sources */,
-				4BA3399A10B2E36800190E3B /* JackError.cpp in Sources */,
-				4BA3399B10B2E36800190E3B /* JackMessageBuffer.cpp in Sources */,
-				4BA3399C10B2E36800190E3B /* JackRestartThreadedDriver.cpp in Sources */,
-				4BA3399D10B2E36800190E3B /* JackControlAPI.cpp in Sources */,
-				4BA3399E10B2E36800190E3B /* JackPosixThread.cpp in Sources */,
-				4BA3399F10B2E36800190E3B /* JackMachTime.c in Sources */,
-				4BA339A010B2E36800190E3B /* JackEngineProfiling.cpp in Sources */,
-				4BA339A210B2E36800190E3B /* JackMidiDriver.cpp in Sources */,
-				4BA339A310B2E36800190E3B /* JackWaitThreadedDriver.cpp in Sources */,
-				4BA339A410B2E36800190E3B /* JackArgParser.cpp in Sources */,
-				4BC2CA5D113C6CC90076717C /* JackNetInterface.cpp in Sources */,
-				4BC2CA5F113C6CD10076717C /* JackNetUnixSocket.cpp in Sources */,
-				4B6FE13B13DDABE700B4B943 /* JackSocketServerNotifyChannel.cpp in Sources */,
-				4B6FE13D13DDABFA00B4B943 /* JackSocketServerChannel.cpp in Sources */,
-				4B6FE13F13DDAC0C00B4B943 /* JackSocketNotifyChannel.cpp in Sources */,
-				4B6FE14413DDAC4700B4B943 /* JackSocket.cpp in Sources */,
-				4B6FE14D13DDACCC00B4B943 /* JackMidiAsyncQueue.cpp in Sources */,
-				4B6FE15313DDACEF00B4B943 /* JackMidiBufferWriteQueue.cpp in Sources */,
-				4B6FE15C13DDAD4600B4B943 /* JackMidiWriteQueue.cpp in Sources */,
-				4B6FE15E13DDAD5300B4B943 /* JackMidiUtil.cpp in Sources */,
-				4B6FE16013DDAD5F00B4B943 /* JackMidiSendQueue.cpp in Sources */,
-				4B6FE16213DDAD6F00B4B943 /* JackMidiReceiveQueue.cpp in Sources */,
-				4B6FE16413DDAD7F00B4B943 /* JackMidiReadQueue.cpp in Sources */,
-				4B6FE16613DDAD8F00B4B943 /* JackMidiBufferReadQueue.cpp in Sources */,
-				4B6FE16813DDAD9F00B4B943 /* JackMidiAsyncWaitQueue.cpp in Sources */,
-				4B21795313E2EEA60095B3E5 /* JackTimedDriver.cpp in Sources */,
-				4B67AB8F14B4B03800B4AA9A /* JackException.cpp in Sources */,
-				4B327BA914B4B50400976483 /* JackPosixMutex.cpp in Sources */,
-				4B1499F214BDA5B300A51A3C /* JackGenericClientChannel.cpp in Sources */,
-				4B90669C14BEE6D20074CD40 /* JackRequestDecoder.cpp in Sources */,
-				4BB4215B14D2C0A700A1CAE1 /* JackPosixProcessSync.cpp in Sources */,
-				4B4C3B6E1BC2FFDD0004CC35 /* JackPosixSemaphore.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692A80CBE4BC700EAD520 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA692B30CBE4C2D00EAD520 /* ipload.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA692CC0CBE4C9000EAD520 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA692D70CBE4CC600EAD520 /* ipunload.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BA7FEBB0D8E76270017FF73 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BA7FECA0D8E76650017FF73 /* control.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BD623F00CBCF0F000DE782F /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BD6240D0CBCF16600DE782F /* inprocess.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDB961001FB9C00B15929 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDB971001FB9C00B15929 /* JackCoreMidiDriver.cpp in Sources */,
-				4B370A34133DD7E300237B68 /* JackCoreMidiInputPort.cpp in Sources */,
-				4B370A36133DD7E300237B68 /* JackCoreMidiOutputPort.cpp in Sources */,
-				4B370A38133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.cpp in Sources */,
-				4B370A3A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp in Sources */,
-				4B370A3C133DD7E300237B68 /* JackCoreMidiPort.cpp in Sources */,
-				4B370A3E133DD7E300237B68 /* JackCoreMidiUtil.cpp in Sources */,
-				4B370A40133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp in Sources */,
-				4B370A42133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBBC1001FCC000B15929 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDBBD1001FCC000B15929 /* JackNetDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBDD1001FD2D00B15929 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDBDE1001FD2D00B15929 /* JackNetManager.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDBF31001FD7300B15929 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDBF41001FD7300B15929 /* JackAudioAdapter.cpp in Sources */,
-				4BDCDBF51001FD7300B15929 /* JackAudioAdapterInterface.cpp in Sources */,
-				4BDCDBF61001FD7300B15929 /* JackLibSampleRateResampler.cpp in Sources */,
-				4BDCDBF71001FD7300B15929 /* JackResampler.cpp in Sources */,
-				4BDCDBF81001FD7300B15929 /* JackAudioAdapterFactory.cpp in Sources */,
-				4BDCDBF91001FD7300B15929 /* JackCoreAudioAdapter.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BDCDC181001FDE300B15929 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BDCDC191001FDE300B15929 /* JackAudioAdapterInterface.cpp in Sources */,
-				4BDCDC1A1001FDE300B15929 /* JackLibSampleRateResampler.cpp in Sources */,
-				4BDCDC1B1001FDE300B15929 /* JackResampler.cpp in Sources */,
-				4BDCDC1C1001FDE300B15929 /* JackNetAdapter.cpp in Sources */,
-				4BDCDC1E1001FDE300B15929 /* JackAudioAdapter.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE6C6950A3E096F005A203A /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BE6C6AD0A3E0A65005A203A /* test.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BE99D280AD7A04800C59091 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3F49080AD8503300491C6E /* cpu.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BF339050F8B864B0080FB5B /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BF3391B0F8B86DC0080FB5B /* JackCoreMidiDriver.cpp in Sources */,
-				4B370A24133DD7E300237B68 /* JackCoreMidiInputPort.cpp in Sources */,
-				4B370A26133DD7E300237B68 /* JackCoreMidiOutputPort.cpp in Sources */,
-				4B370A28133DD7E300237B68 /* JackCoreMidiPhysicalInputPort.cpp in Sources */,
-				4B370A2A133DD7E300237B68 /* JackCoreMidiPhysicalOutputPort.cpp in Sources */,
-				4B370A2C133DD7E300237B68 /* JackCoreMidiPort.cpp in Sources */,
-				4B370A2E133DD7E300237B68 /* JackCoreMidiUtil.cpp in Sources */,
-				4B370A30133DD7E300237B68 /* JackCoreMidiVirtualInputPort.cpp in Sources */,
-				4B370A32133DD7E300237B68 /* JackCoreMidiVirtualOutputPort.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA5E8D0DEC4D9C00FA4CDB /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA5E9F0DEC4DD900FA4CDB /* testMutex.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82840DF6A9E40087B4E1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA82850DF6A9E40087B4E1 /* evmon.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82970DF6A9E40087B4E1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA82980DF6A9E40087B4E1 /* bufsize.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82A30DF6A9E40087B4E1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA82A40DF6A9E40087B4E1 /* capture_client.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82AF0DF6A9E40087B4E1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA82B00DF6A9E40087B4E1 /* monitor_client.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82BB0DF6A9E40087B4E1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA82BC0DF6A9E40087B4E1 /* showtime.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA82C70DF6A9E40087B4E1 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4BFA82C80DF6A9E40087B4E1 /* impulse_grabber.c in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		4BFA999A0AAAF3B0009E916C /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				4B3814201327AA6800C61B14 /* iodelay.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		BA222AC80DC88132001A17F4 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				BA222ADE0DC882A5001A17F4 /* JackNetDriver.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-		BA222AE20DC882DB001A17F4 /* Sources */ = {
-			isa = PBXSourcesBuildPhase;
-			buildActionMask = 2147483647;
-			files = (
-				BA222AED0DC883B3001A17F4 /* JackNetManager.cpp in Sources */,
-			);
-			runOnlyForDeploymentPostprocessing = 0;
-		};
-/* End PBXSourcesBuildPhase section */
-
-/* Begin PBXTargetDependency section */
-		4B0A28F40D520D11002EFF74 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B0A28DC0D52073D002EFF74 /* jack_thread_wait */;
-			targetProxy = 4B0A28F30D520D11002EFF74 /* PBXContainerItemProxy */;
-		};
-		4B0A29300D5210C4002EFF74 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B0A29230D52108E002EFF74 /* jack_thread_wait 64 bits */;
-			targetProxy = 4B0A292F0D5210C4002EFF74 /* PBXContainerItemProxy */;
-		};
-		4B19B32C0E23636E00DD4A82 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B19B2F60E23620F00DD4A82 /* audioadapter Universal */;
-			targetProxy = 4B19B32B0E23636E00DD4A82 /* PBXContainerItemProxy */;
-		};
-		4B20220C133A9C370019E213 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B2021DC133A9BA40019E213 /* jack_midi_latency 64 bits */;
-			targetProxy = 4B20220B133A9C370019E213 /* PBXContainerItemProxy */;
-		};
-		4B224B340E65BA330066BE5B /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B5E08BF0E5B66EE00BEE4E0 /* netadapter Universal */;
-			targetProxy = 4B224B330E65BA330066BE5B /* PBXContainerItemProxy */;
-		};
-		4B3224E710A3157900838A8E /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B3224D710A3156800838A8E /* jack_netone Universal */;
-			targetProxy = 4B3224E610A3157900838A8E /* PBXContainerItemProxy */;
-		};
-		4B32258B10A31A9000838A8E /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B32255710A3187800838A8E /* jack_netsource Universal */;
-			targetProxy = 4B32258A10A31A9000838A8E /* PBXContainerItemProxy */;
-		};
-		4B32258D10A31A9D00838A8E /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B3224D710A3156800838A8E /* jack_netone Universal */;
-			targetProxy = 4B32258C10A31A9D00838A8E /* PBXContainerItemProxy */;
-		};
-		4B32258F10A31AB400838A8E /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B32257110A3190C00838A8E /* jack_netsource 64 bits */;
-			targetProxy = 4B32258E10A31AB400838A8E /* PBXContainerItemProxy */;
-		};
-		4B32259110A31ABA00838A8E /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B32251D10A316B200838A8E /* jack_netone 64 bits */;
-			targetProxy = 4B32259010A31ABA00838A8E /* PBXContainerItemProxy */;
-		};
-		4B35C5530D4731D2000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699D03097D421600A18468 /* jack_external_metro Universal */;
-			targetProxy = 4B35C5540D4731D2000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C67E0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C41B0D4731D1000DE7AE /* jackdmp framework 64bits */;
-			targetProxy = 4B35C67D0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6800D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C4270D4731D1000DE7AE /* Jackmp.framework 64 bits */;
-			targetProxy = 4B35C67F0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6820D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C4850D4731D1000DE7AE /* Jackservermp.framework 64 bits */;
-			targetProxy = 4B35C6810D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6860D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C50A0D4731D1000DE7AE /* jack_midiseq 64 bits */;
-			targetProxy = 4B35C6850D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6880D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5160D4731D1000DE7AE /* jack_midisine 64 bits */;
-			targetProxy = 4B35C6870D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C68A0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5220D4731D1000DE7AE /* jack_metro 64 bits */;
-			targetProxy = 4B35C6890D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C68C0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C52E0D4731D1000DE7AE /* jack_lsp 64 bits */;
-			targetProxy = 4B35C68B0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C68E0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C53A0D4731D1000DE7AE /* jack_connect 64 bits */;
-			targetProxy = 4B35C68D0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6900D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5460D4731D1000DE7AE /* jack_disconnect 64 bits */;
-			targetProxy = 4B35C68F0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6920D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5520D4731D2000DE7AE /* jack_freewheel 64 bits */;
-			targetProxy = 4B35C6910D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6940D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5600D4731D2000DE7AE /* jack_iodelay 64 bits */;
-			targetProxy = 4B35C6930D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6960D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C56C0D4731D2000DE7AE /* jack_external_metro 64 bits */;
-			targetProxy = 4B35C6950D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C69C0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C59C0D4731D2000DE7AE /* zombie 64 bits */;
-			targetProxy = 4B35C69B0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C69E0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5A80D4731D2000DE7AE /* jack_test 64 bits */;
-			targetProxy = 4B35C69D0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6A00D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5B40D4731D2000DE7AE /* jack_cpu 64 bits */;
-			targetProxy = 4B35C69F0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6A20D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5C00D4731D2000DE7AE /* jack_load 64 bits */;
-			targetProxy = 4B35C6A10D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6A40D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C5CC0D4731D2000DE7AE /* jack_unload 64 bits */;
-			targetProxy = 4B35C6A30D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6AC0D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C6140D4731D2000DE7AE /* jack_coreaudio 64 bits */;
-			targetProxy = 4B35C6AB0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6B00D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C62A0D4731D2000DE7AE /* jack_dummy 64 bits */;
-			targetProxy = 4B35C6AF0D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B35C6B20D4733B9000DE7AE /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C6350D4731D3000DE7AE /* inprocess 64 bits */;
-			targetProxy = 4B35C6B10D4733B9000DE7AE /* PBXContainerItemProxy */;
-		};
-		4B363DE50DEB037F001F72D9 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B363DCE0DEB02F6001F72D9 /* jack_alias Universal */;
-			targetProxy = 4B363DE40DEB037F001F72D9 /* PBXContainerItemProxy */;
-		};
-		4B363E750DEB0838001F72D9 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B363E100DEB03C5001F72D9 /* jack_evmon Universal */;
-			targetProxy = 4B363E740DEB0838001F72D9 /* PBXContainerItemProxy */;
-		};
-		4B363E770DEB0838001F72D9 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B363E440DEB0775001F72D9 /* jack_bufsize Universal */;
-			targetProxy = 4B363E760DEB0838001F72D9 /* PBXContainerItemProxy */;
-		};
-		4B363F250DEB0ABE001F72D9 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B363F140DEB0A6A001F72D9 /* jack_monitor_client Universal */;
-			targetProxy = 4B363F240DEB0ABE001F72D9 /* PBXContainerItemProxy */;
-		};
-		4B363F530DEB0CFE001F72D9 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B363F2B0DEB0BD1001F72D9 /* jack_showtime Universal */;
-			targetProxy = 4B363F520DEB0CFE001F72D9 /* PBXContainerItemProxy */;
-		};
-		4B363F780DEB0D85001F72D9 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B363F680DEB0D4E001F72D9 /* jack_impulse_grabber Universal */;
-			targetProxy = 4B363F770DEB0D85001F72D9 /* PBXContainerItemProxy */;
-		};
-		4B38120113269CB600C61B14 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B3811551326878E00C61B14 /* jack_latent_client Universal */;
-			targetProxy = 4B38120013269CB600C61B14 /* PBXContainerItemProxy */;
-		};
-		4B38120313269CCB00C61B14 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B38118D1326884E00C61B14 /* jack_latent_client 64 bits */;
-			targetProxy = 4B38120213269CCB00C61B14 /* PBXContainerItemProxy */;
-		};
-		4B43A8CD1014607100E52943 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B43A8B010145F6F00E52943 /* jack_loopback Universal */;
-			targetProxy = 4B43A8CC1014607100E52943 /* PBXContainerItemProxy */;
-		};
-		4B43A8E91014618D00E52943 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B43A8DD1014615800E52943 /* jack_loopback 64 bits */;
-			targetProxy = 4B43A8E81014618D00E52943 /* PBXContainerItemProxy */;
-		};
-		4B5A1BCF0CD1CCC80005BF74 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B5A1BB10CD1CB9E0005BF74 /* jack_midiseq Universal */;
-			targetProxy = 4B5A1BCE0CD1CCC80005BF74 /* PBXContainerItemProxy */;
-		};
-		4B5A1BE20CD1CD730005BF74 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B5A1BD00CD1CCE10005BF74 /* jack_midisine Universal */;
-			targetProxy = 4B5A1BE10CD1CD730005BF74 /* PBXContainerItemProxy */;
-		};
-		4B66550E127C356E00753A79 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B6654ED127C34AE00753A79 /* jack_server_control 64 bits */;
-			targetProxy = 4B66550D127C356E00753A79 /* PBXContainerItemProxy */;
-		};
-		4B699DB4097D421700A18468 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699C4C097D421600A18468 /* Jackservermp.framework Universal */;
-			targetProxy = 4B699DB3097D421700A18468 /* PBXContainerItemProxy */;
-		};
-		4B699DB6097D421700A18468 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699C00097D421600A18468 /* Jackmp.framework Universal */;
-			targetProxy = 4B699DB5097D421700A18468 /* PBXContainerItemProxy */;
-		};
-		4B699DB8097D421700A18468 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699BA7097D421600A18468 /* jackdmp framework Universal */;
-			targetProxy = 4B699DB7097D421700A18468 /* PBXContainerItemProxy */;
-		};
-		4B699DBA097D421700A18468 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699D97097D421700A18468 /* jack_coreaudio Universal */;
-			targetProxy = 4B699DB9097D421700A18468 /* PBXContainerItemProxy */;
-		};
-		4B699DBC097D421700A18468 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699DA6097D421700A18468 /* jack_dummy Universal */;
-			targetProxy = 4B699DBB097D421700A18468 /* PBXContainerItemProxy */;
-		};
-		4B699DC0097D421700A18468 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699D03097D421600A18468 /* jack_external_metro Universal */;
-			targetProxy = 4B699DBF097D421700A18468 /* PBXContainerItemProxy */;
-		};
-		4B8F16FA132916910002AD73 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B8F16DB13290DC80002AD73 /* jack_midi_dump Universal */;
-			targetProxy = 4B8F16F9132916910002AD73 /* PBXContainerItemProxy */;
-		};
-		4B8F16FC1329169F0002AD73 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B8F16E813290E0E0002AD73 /* jack_midi_dump 64 bits */;
-			targetProxy = 4B8F16FB1329169F0002AD73 /* PBXContainerItemProxy */;
-		};
-		4BA693E90CBE5BBA00EAD520 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BA692A60CBE4BC700EAD520 /* jack_load Universal */;
-			targetProxy = 4BA693E80CBE5BBA00EAD520 /* PBXContainerItemProxy */;
-		};
-		4BA693EB0CBE5BBA00EAD520 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BA692CA0CBE4C9000EAD520 /* jack_unload Universal */;
-			targetProxy = 4BA693EA0CBE5BBA00EAD520 /* PBXContainerItemProxy */;
-		};
-		4BA7FECD0D8E76810017FF73 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BA7FEB90D8E76270017FF73 /* jack_server_control Universal */;
-			targetProxy = 4BA7FECC0D8E76810017FF73 /* PBXContainerItemProxy */;
-		};
-		4BAA1A7614CA08FE003269AD /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B35C61F0D4731D2000DE7AE /* jack_portaudio 64 bits */;
-			targetProxy = 4BAA1A7514CA08FE003269AD /* PBXContainerItemProxy */;
-		};
-		4BB492A71372A393005F2601 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B8692821371DB4700D2D11B /* Jacknet.framework 64 bits */;
-			targetProxy = 4BB492A61372A393005F2601 /* PBXContainerItemProxy */;
-		};
-		4BD624D30CBCF55700DE782F /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BD623ED0CBCF0F000DE782F /* inprocess Universal */;
-			targetProxy = 4BD624D20CBCF55700DE782F /* PBXContainerItemProxy */;
-		};
-		4BDCDC2C1002036100B15929 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BDCDB931001FB9C00B15929 /* jack_coremidi 64 bits */;
-			targetProxy = 4BDCDC2B1002036100B15929 /* PBXContainerItemProxy */;
-		};
-		4BDCDC2E1002036100B15929 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BDCDBB71001FCC000B15929 /* jack_net 64 bits */;
-			targetProxy = 4BDCDC2D1002036100B15929 /* PBXContainerItemProxy */;
-		};
-		4BDCDC301002036100B15929 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BDCDBD71001FD2D00B15929 /* netmanager 64 bits */;
-			targetProxy = 4BDCDC2F1002036100B15929 /* PBXContainerItemProxy */;
-		};
-		4BDCDC39100203D500B15929 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BDCDBEC1001FD7300B15929 /* audioadapter 64 bits */;
-			targetProxy = 4BDCDC38100203D500B15929 /* PBXContainerItemProxy */;
-		};
-		4BDCDC3B100203D500B15929 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BDCDC0F1001FDE300B15929 /* netadapter 64 bits */;
-			targetProxy = 4BDCDC3A100203D500B15929 /* PBXContainerItemProxy */;
-		};
-		4BE99D630AD7A19100C59091 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BE99D260AD7A04800C59091 /* jack_cpu Universal */;
-			targetProxy = 4BE99D620AD7A19100C59091 /* PBXContainerItemProxy */;
-		};
-		4BF339280F8B87800080FB5B /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BF339020F8B864B0080FB5B /* jack_coremidi Universal */;
-			targetProxy = 4BF339270F8B87800080FB5B /* PBXContainerItemProxy */;
-		};
-		4BFA83320DF6AB540087B4E1 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BFA82820DF6A9E40087B4E1 /* jack_evmon 64 bits */;
-			targetProxy = 4BFA83310DF6AB540087B4E1 /* PBXContainerItemProxy */;
-		};
-		4BFA83340DF6AB540087B4E1 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BFA82950DF6A9E40087B4E1 /* jack_bufsize 64 bits */;
-			targetProxy = 4BFA83330DF6AB540087B4E1 /* PBXContainerItemProxy */;
-		};
-		4BFA83380DF6AB540087B4E1 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BFA82AD0DF6A9E40087B4E1 /* jack_monitor_client 64 bits */;
-			targetProxy = 4BFA83370DF6AB540087B4E1 /* PBXContainerItemProxy */;
-		};
-		4BFA833A0DF6AB540087B4E1 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BFA82B90DF6A9E40087B4E1 /* jack_showtime 64 bits */;
-			targetProxy = 4BFA83390DF6AB540087B4E1 /* PBXContainerItemProxy */;
-		};
-		4BFA833C0DF6AB540087B4E1 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BFA82C50DF6A9E40087B4E1 /* jack_impulse_grabber 64 bits */;
-			targetProxy = 4BFA833B0DF6AB540087B4E1 /* PBXContainerItemProxy */;
-		};
-		4BFA99440AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699CB1097D421600A18468 /* jack_metro Universal */;
-			targetProxy = 4BFA99430AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA99460AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699CC1097D421600A18468 /* jack_lsp Universal */;
-			targetProxy = 4BFA99450AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA99480AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699CD1097D421600A18468 /* jack_connect Universal */;
-			targetProxy = 4BFA99470AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA994A0AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699CE1097D421600A18468 /* jack_disconnect Universal */;
-			targetProxy = 4BFA99490AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA994C0AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699CF1097D421600A18468 /* jack_freewheel Universal */;
-			targetProxy = 4BFA994B0AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA994E0AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699D03097D421600A18468 /* jack_external_metro Universal */;
-			targetProxy = 4BFA994D0AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA99540AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4B699D3F097D421600A18468 /* zombie Universal */;
-			targetProxy = 4BFA99530AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA99560AAAED90009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BE6C6910A3E096F005A203A /* jack_test Universal */;
-			targetProxy = 4BFA99550AAAED90009E916C /* PBXContainerItemProxy */;
-		};
-		4BFA99AC0AAAF41D009E916C /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = 4BFA99980AAAF3B0009E916C /* jack_iodelay Universal */;
-			targetProxy = 4BFA99AB0AAAF41D009E916C /* PBXContainerItemProxy */;
-		};
-		BA222AF00DC883EF001A17F4 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = BA222AE00DC882DB001A17F4 /* netmanager Universal */;
-			targetProxy = BA222AEF0DC883EF001A17F4 /* PBXContainerItemProxy */;
-		};
-		BA222AF20DC883F3001A17F4 /* PBXTargetDependency */ = {
-			isa = PBXTargetDependency;
-			target = BA222AC50DC88132001A17F4 /* jack_net Universal */;
-			targetProxy = BA222AF10DC883F3001A17F4 /* PBXContainerItemProxy */;
-		};
-/* End PBXTargetDependency section */
-
-/* Begin XCBuildConfiguration section */
-		4B0A28E30D52073D002EFF74 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_thread_wait;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B0A28E40D52073D002EFF74 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_thread_wait;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B0A28E50D52073D002EFF74 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_thread_wait;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B0A292A0D52108E002EFF74 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_thread_wait;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B0A292B0D52108E002EFF74 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_thread_wait;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B0A292C0D52108E002EFF74 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_thread_wait;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B19B2FD0E23620F00DD4A82 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = i386;
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					/opt/local/include,
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = audioadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B19B2FE0E23620F00DD4A82 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_BIT_PRE_XCODE_3_1 = "ppc i386";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					/opt/local/include,
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = audioadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B19B2FF0E23620F00DD4A82 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B2021E3133A9BA40019E213 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midi_latency_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B2021E4133A9BA40019E213 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midi_latency_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B2021E5133A9BA40019E213 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B3224E210A3156800838A8E /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_netone;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B3224E310A3156800838A8E /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_netone;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B3224E410A3156800838A8E /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT_API_0_7",
-					"-DHAVE_CELT",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B32252810A316B200838A8E /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_netone;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B32252910A316B200838A8E /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_netone;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B32252A10A316B200838A8E /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B32255E10A3187800838A8E /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					../common,
-				);
-				OTHER_CFLAGS = (
-					"-DNO_JACK_ERROR",
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DNO_JACK_ERROR",
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_LDFLAGS = (
-					libcelt.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_netsource;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B32255F10A3187800838A8E /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DNO_JACK_ERROR",
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DNO_JACK_ERROR",
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_LDFLAGS = (
-					libcelt.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_netsource;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B32256010A3187800838A8E /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-					"$(OTHER_CFLAGS)",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B32257810A3190C00838A8E /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					../common,
-				);
-				OTHER_CFLAGS = (
-					"-DNO_JACK_ERROR",
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					libcelt.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_netsource;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B32257910A3190C00838A8E /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DNO_JACK_ERROR",
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					libcelt.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_netsource;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B32257A10A3190C00838A8E /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = (
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT",
-					"-DHAVE_CELT_API_0_7",
-					"$(OTHER_CFLAGS)",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C4220D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jackdmp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C4230D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jackdmp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C4240D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../common,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jackdmp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C4800D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DUSE_CLASSIC_AUTOLAUNCH",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C4810D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DUSE_CLASSIC_AUTOLAUNCH",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C4820D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4B35C4F90D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackservermp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C4FA0D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DLIB_DIR=\\\"lib\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackservermp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C4FB0D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DLIB_DIR=\\\"lib\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackdmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4B35C5110D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5120D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5130D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C51D0D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C51E0D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C51F0D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5290D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C52A0D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C52B0D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5350D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5360D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5370D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5410D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_connect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				SYMROOT = build;
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5420D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_connect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				SYMROOT = build;
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5430D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_connect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				SYMROOT = build;
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C54D0D4731D1000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_disconnect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C54E0D4731D1000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_disconnect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C54F0D4731D1000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_disconnect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C55B0D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_freewheel;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C55C0D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_freewheel;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C55D0D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_freewheel;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5670D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_iodelay;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5680D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_iodelay;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5690D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jdelay;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5730D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_external_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5740D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_external_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5750D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_external_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5830D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					.,
-					RPC,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testAtomic;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5840D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					.,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testAtomic;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5850D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				HEADER_SEARCH_PATHS = RPC;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testAtomic;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5970D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					.,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5980D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					.,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5990D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5A30D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = zombie;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5A40D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = zombie;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5A50D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = zombie;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5AF0D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5B00D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5B10D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5BB0D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_cpu;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5BC0D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_cpu;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5BD0D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_cpu;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5C70D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_load;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5C80D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_load;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5C90D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_load;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5D30D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_unload;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5D40D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_unload;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5D50D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_unload;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5E70D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../posix,
-					.,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServer;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5E80D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServer;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5E90D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServer;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C5FB0D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../posix,
-					.,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C5FC0D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					../posix,
-					.,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C5FD0D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C60F0D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../posix,
-					.,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServerClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C6100D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					../posix,
-					.,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServerClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C6110D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServerClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C61B0D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../common/jack,
-					../posix,
-					.,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					libaften_static.a,
-					libaften_pcm.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C61C0D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../common/jack,
-					../posix,
-					.,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					libaften_pcm.a,
-					libaften_static.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C61D0D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C6260D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common/;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libportaudio.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					AudioToolbox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					AudioUnit,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_portaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C6270D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common/;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libportaudio.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					AudioUnit,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioToolbox,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_portaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C6280D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common/;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libportaudio.a,
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					AudioUnit,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_portaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C6310D4731D2000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					../posix,
-					.,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C6320D4731D2000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					../posix,
-					.,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C6330D4731D2000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C63B0D4731D3000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C63C0D4731D3000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C63D0D4731D3000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc64,
-					ppc,
-					i386,
-					x86_64,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B35C67A0D47339B000DE7AE /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = "";
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = All;
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B35C67B0D47339B000DE7AE /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				OTHER_LDFLAGS = "";
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = All;
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B35C67C0D47339B000DE7AE /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = "";
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = All;
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363DD50DEB02F6001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_alias;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363DD60DEB02F6001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_alias;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363DD70DEB02F6001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363E170DEB03C5001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_evmon;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363E180DEB03C5001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_evmon;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363E190DEB03C5001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363E4B0DEB0775001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_bufsize;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363E4C0DEB0775001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_bufsize;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363E4D0DEB0775001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363EE60DEB091C001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					../common,
-				);
-				LIBRARY_SEARCH_PATHS = /opt/local/lib;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsndfile.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_rec;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363EE70DEB091C001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					../common,
-				);
-				LIBRARY_SEARCH_PATHS = /opt/local/lib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsndfile.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_rec;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363EE80DEB091C001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363F1B0DEB0A6A001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_monitor_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363F1C0DEB0A6A001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_monitor_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363F1D0DEB0A6A001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363F320DEB0BD1001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_showtime;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363F330DEB0BD1001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_showtime;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363F340DEB0BD1001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B363F6F0DEB0D4E001F72D9 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_impulse_grabber;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B363F700DEB0D4E001F72D9 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_impulse_grabber;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B363F710DEB0D4E001F72D9 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B38115C1326878E00C61B14 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				LIBRARY_SEARCH_PATHS = "";
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_latent_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B38115D1326878E00C61B14 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				LIBRARY_SEARCH_PATHS = "";
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_latent_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B38115E1326878E00C61B14 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B3811941326884E00C61B14 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_latent_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B3811951326884E00C61B14 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_latent_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B3811961326884E00C61B14 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B43A8B710145F6F00E52943 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					.,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_loopback;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B43A8B810145F6F00E52943 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					.,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_loopback;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B43A8B910145F6F00E52943 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B43A8E41014615800E52943 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					.,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_loopback;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B43A8E51014615800E52943 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					.,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_loopback;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B43A8E61014615800E52943 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B47ACD410B5890100469C67 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DUSE_CLASSIC_AUTOLAUNCH",
-					"-D__CLIENTDEBUG__",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B47ACD510B5890100469C67 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DUSE_CLASSIC_AUTOLAUNCH",
-					"-D__CLIENTDEBUG__",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B47ACD610B5890100469C67 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4B5A1BB80CD1CB9E0005BF74 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B5A1BB90CD1CB9E0005BF74 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B5A1BBA0CD1CB9E0005BF74 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B5A1BD70CD1CCE10005BF74 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B5A1BD80CD1CCE10005BF74 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B5A1BD90CD1CCE10005BF74 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B5E08D20E5B66EE00BEE4E0 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = i386;
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B5E08D30E5B66EE00BEE4E0 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_BIT_PRE_XCODE_3_1 = "ppc i386";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					.,
-					../posix,
-					../common,
-					../common/jack,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B5E08D40E5B66EE00BEE4E0 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B6654F4127C34AE00753A79 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_server_control;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B6654F5127C34AE00753A79 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_server_control;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B6654F6127C34AE00753A79 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699B34097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = "";
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = All;
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699B35097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = "";
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = All;
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699B36097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = "";
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = All;
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699BAE097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jackdmp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699BAF097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jackdmp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699BB0097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../common,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jackdmp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699C44097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DUSE_CLASSIC_AUTOLAUNCH",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699C45097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_SYMBOLS_PRIVATE_EXTERN = YES;
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DUSE_CLASSIC_AUTOLAUNCH",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699C46097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4B699CA9097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackservermp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699CAA097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_SYMBOLS_PRIVATE_EXTERN = YES;
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DLIB_DIR=\\\"lib\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackservermp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699CAB097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DLIB_DIR=\\\"lib\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackdmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4B699CB8097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699CB9097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699CBA097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699CC8097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699CC9097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699CCA097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699CD8097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_connect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				SYMROOT = build;
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699CD9097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_connect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				SYMROOT = build;
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699CDA097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_connect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				SYMROOT = build;
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699CE8097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_disconnect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699CE9097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_disconnect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699CEA097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_disconnect;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699CFA097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_freewheel;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699CFB097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_freewheel;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699CFC097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_freewheel;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D0A097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_external_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D0B097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_external_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D0C097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_external_metro;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D1E097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-					RPC,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testAtomic;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D1F097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-					RPC,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testAtomic;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D20097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				HEADER_SEARCH_PATHS = RPC;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testAtomic;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D36097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common,
-					../common/jack,
-					../posix,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D37097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common,
-					../common/jack,
-					../posix,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D38097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D46097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = zombie;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D47097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = zombie;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D48097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = zombie;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D5E097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServer;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D5F097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServer;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D60097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServer;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D76097D421600A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D77097D421600A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D78097D421600A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D8E097D421700A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServerClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D8F097D421700A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServerClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699D90097D421700A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = synchroServerClient;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699D9E097D421700A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libaften_static.a,
-					libaften_pcm.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699D9F097D421700A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libaften_static.a,
-					libaften_pcm.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699DA0097D421700A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699DAD097D421700A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					.,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B699DAE097D421700A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../common/jack,
-					.,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B699DAF097D421700A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B699DD6097D427F00A18468 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-			};
-			name = Development;
-		};
-		4B699DD7097D427F00A18468 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-			};
-			name = Deployment;
-		};
-		4B699DD8097D427F00A18468 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-			};
-			name = Default;
-		};
-		4B8692D81371DB4700D2D11B /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = (
-					/opt/local/lib,
-					/usr/lib/gcc/darwin/3.3,
-				);
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jacknet;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B8692D91371DB4700D2D11B /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = (
-					/opt/local/lib,
-					/usr/lib/gcc/darwin/3.3,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jacknet;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B8692DA1371DB4700D2D11B /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-DUSE_POSIX_SHM",
-					"-D__SMP__",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DMACH_RPC_MACH_SEMA",
-					"-D__SMP__",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DJACK_LOCATION=\\\"/usr/local/bin\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4B8F16E213290DC80002AD73 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midi_dump;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B8F16E313290DC80002AD73 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midi_dump;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B8F16E413290DC80002AD73 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B8F16EF13290E0E0002AD73 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midi_dump;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B8F16F013290E0E0002AD73 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midi_dump;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B8F16F113290E0E0002AD73 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midisine;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4B978DB80A31CF4A009E2DD1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common/;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libportaudio.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					AudioToolbox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					AudioUnit,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_portaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4B978DB90A31CF4A009E2DD1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common/;
-				INSTALL_PATH = /usr/local/lib;
-				LD_OPENMP_FLAGS = "-fopenmp";
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libportaudio.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					AudioUnit,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioToolbox,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_portaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4B978DBA0A31CF4A009E2DD1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common/;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					libportaudio.a,
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					AudioUnit,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_portaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BA339A910B2E36800190E3B /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-DJACK_MONITOR",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DJACK_MONITOR",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackservermp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BA339AA10B2E36800190E3B /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DEAD_CODE_STRIPPING = YES;
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_AUTO_VECTORIZATION = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_ENABLE_SSE3_EXTENSIONS = YES;
-				GCC_ENABLE_SUPPLEMENTAL_SSE3_INSTRUCTIONS = YES;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					../posix,
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = (
-					"-DJACK_MONITOR",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DJACK_MONITOR",
-					"-DSERVER_SIDE",
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DLIB_DIR=\\\"lib\\\"";
-				OTHER_LDFLAGS = (
-					libopus.a,
-					"-framework",
-					Carbon,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackservermp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BA339AB10B2E36800190E3B /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DEBUG_INFORMATION_FORMAT = dwarf;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				FRAMEWORK_VERSION = A;
-				GCC_PRECOMPILE_PREFIX_HEADER = YES;
-				GCC_PREFIX_HEADER = "$(SYSTEM_LIBRARY_DIR)/Frameworks/Carbon.framework/Headers/Carbon.h";
-				GCC_WARN_FOUR_CHARACTER_CONSTANTS = NO;
-				GCC_WARN_UNKNOWN_PRAGMAS = NO;
-				GENERATE_PKGINFO_FILE = NO;
-				HEADER_SEARCH_PATHS = (
-					RPC,
-					../common/jack,
-				);
-				INFOPLIST_FILE = "Jack-Info.plist";
-				INSTALL_PATH = "$(LOCAL_LIBRARY_DIR)/Frameworks";
-				LIBRARY_SEARCH_PATHS = /usr/lib/gcc/darwin/3.3;
-				OTHER_CFLAGS = (
-					"-D__SMP__",
-					"-DUSE_POSIX_SHM",
-				);
-				OTHER_CPLUSPLUSFLAGS = (
-					"-D__SMP__",
-					"-DMACH_RPC_MACH_SEMA",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1)",
-					"$(OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2)",
-				);
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_1 = "-DADDON_DIR=\\\"/usr/local/lib/jackmp\\\"";
-				OTHER_CPLUSPLUSFLAGS_QUOTED_FOR_TARGET_2 = "-DLIB_DIR=\\\"lib\\\"";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Carbon,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = Jackdmp;
-				REZ_EXECUTABLE = NO;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = "-Wmost";
-			};
-			name = Default;
-		};
-		4BA692AD0CBE4BC700EAD520 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_load;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BA692AE0CBE4BC700EAD520 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_load;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BA692AF0CBE4BC700EAD520 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_load;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BA692D10CBE4C9000EAD520 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_unload;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BA692D20CBE4C9000EAD520 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_unload;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BA692D30CBE4C9000EAD520 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_unload;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BA7FEC00D8E76270017FF73 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_server_control;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BA7FEC10D8E76270017FF73 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_server_control;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BA7FEC20D8E76270017FF73 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_lsp;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BD623F40CBCF0F000DE782F /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BD623F50CBCF0F000DE782F /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BD623F60CBCF0F000DE782F /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BDCDB9A1001FB9C00B15929 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreMIDI,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coremidi;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BDCDB9B1001FB9C00B15929 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreMIDI,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coremidi;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BDCDB9C1001FB9C00B15929 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BDCDBC21001FCC000B15929 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_net;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BDCDBC31001FCC000B15929 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_net;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BDCDBC41001FCC000B15929 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BDCDBE51001FD2D00B15929 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netmanager;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BDCDBE61001FD2D00B15929 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"$(OTHER_CFLAGS)",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netmanager;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BDCDBE71001FD2D00B15929 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BDCDBFC1001FD7300B15929 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					x86_64,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					/opt/local/include,
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = audioadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BDCDBFD1001FD7300B15929 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					x86_64,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					../macosx,
-					/opt/local/include,
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DSERVER_SIDE",
-					"$(OTHER_CFLAGS)",
-				);
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = audioadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BDCDBFE1001FD7300B15929 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					x86_64,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BDCDC221001FDE300B15929 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					x86_64,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BDCDC231001FDE300B15929 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					x86_64,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					.,
-					../posix,
-					../common,
-					../common/jack,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_CELT",
-					"-DSERVER_SIDE",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsamplerate.a,
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netadapter;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BDCDC241001FDE300B15929 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					x86_64,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BE6C6A00A3E096F005A203A /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BE6C6A10A3E096F005A203A /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BE6C6A20A3E096F005A203A /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					ppc,
-					i386,
-				);
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_test;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BE99D2D0AD7A04800C59091 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_cpu;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BE99D2E0AD7A04800C59091 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_cpu;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BE99D2F0AD7A04800C59091 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_cpu;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BF339090F8B864B0080FB5B /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreMIDI,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coremidi;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BF3390A0F8B864B0080FB5B /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../common/jack,
-					../posix,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreMIDI,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coremidi;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BF3390B0F8B864B0080FB5B /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_coreaudio;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA5E950DEC4D9C00FA4CDB /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA5E960DEC4D9C00FA4CDB /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_OPTIMIZATION_LEVEL = 3;
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testMutex;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA5E970DEC4D9C00FA4CDB /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = (
-					"$(inherited)",
-					"$(FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1)",
-				);
-				FRAMEWORK_SEARCH_PATHS_QUOTED_FOR_TARGET_1 = "\"$(SRCROOT)/build/Development\"";
-				GCC_OPTIMIZATION_LEVEL = 3;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = testSem;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA82890DF6A9E40087B4E1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_evmon;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA828A0DF6A9E40087B4E1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_evmon;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA828B0DF6A9E40087B4E1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA829C0DF6A9E40087B4E1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_bufsize;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA829D0DF6A9E40087B4E1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_bufsize;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA829E0DF6A9E40087B4E1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA82A80DF6A9E40087B4E1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					../common,
-				);
-				LIBRARY_SEARCH_PATHS = /opt/local/lib;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsndfile.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_rec;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA82A90DF6A9E40087B4E1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = (
-					/opt/local/include,
-					../common,
-				);
-				LIBRARY_SEARCH_PATHS = /opt/local/lib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					/opt/local/lib/libsndfile.a,
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_rec;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA82AA0DF6A9E40087B4E1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA82B40DF6A9E40087B4E1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_monitor_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA82B50DF6A9E40087B4E1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_monitor_client;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA82B60DF6A9E40087B4E1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA82C00DF6A9E40087B4E1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_showtime;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA82C10DF6A9E40087B4E1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_showtime;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA82C20DF6A9E40087B4E1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA82CC0DF6A9E40087B4E1 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_impulse_grabber;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA82CD0DF6A9E40087B4E1 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_impulse_grabber;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA82CE0DF6A9E40087B4E1 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = "$(ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1)";
-				ARCHS_STANDARD_32_64_BIT_PRE_XCODE_3_1 = "x86_64 i386 ppc";
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-					"-framework",
-					CoreFoundation,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_midiseq;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		4BFA999F0AAAF3B0009E916C /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_iodelay;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		4BFA99A00AAAF3B0009E916C /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				FRAMEWORK_SEARCH_PATHS = "";
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				HEADER_SEARCH_PATHS = ../common;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jack_iodelay;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		4BFA99A10AAAF3B0009E916C /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				FRAMEWORK_SEARCH_PATHS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				OTHER_CFLAGS = "";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackmp,
-				);
-				OTHER_REZFLAGS = "";
-				PRODUCT_NAME = jdelay;
-				REZ_EXECUTABLE = YES;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		BA222ACC0DC88132001A17F4 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_net;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		BA222ACD0DC88132001A17F4 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				HEADER_SEARCH_PATHS = (
-					../common,
-					.,
-					../common/jack,
-					../posix,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = (
-					"-DHAVE_OPUS",
-					"-DMACH_RPC_MACH_SEMA",
-				);
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreServices,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_net;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		BA222ACE0DC88132001A17F4 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "-DMACH_RPC_MACH_SEMA";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = jack_dummy;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-		BA222AE60DC882DB001A17F4 /* Development */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = NO;
-				DEBUGGING_SYMBOLS = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_DYNAMIC_NO_PIC = NO;
-				GCC_ENABLE_FIX_AND_CONTINUE = YES;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = YES;
-				GCC_MODEL_TUNING = G4;
-				GCC_OPTIMIZATION_LEVEL = 0;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netmanager;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = YES;
-			};
-			name = Development;
-		};
-		BA222AE70DC882DB001A17F4 /* Deployment */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				COPY_PHASE_STRIP = YES;
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_ENABLE_FIX_AND_CONTINUE = NO;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = (
-					.,
-					../posix,
-					../common/jack,
-					../common,
-				);
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				MACOSX_DEPLOYMENT_TARGET = 10.4;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackservermp,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = netmanager;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-				ZERO_LINK = NO;
-			};
-			name = Deployment;
-		};
-		BA222AE80DC882DB001A17F4 /* Default */ = {
-			isa = XCBuildConfiguration;
-			buildSettings = {
-				ARCHS = (
-					i386,
-					ppc,
-				);
-				DYLIB_COMPATIBILITY_VERSION = 1;
-				DYLIB_CURRENT_VERSION = 1;
-				EXECUTABLE_EXTENSION = so;
-				GCC_GENERATE_DEBUGGING_SYMBOLS = NO;
-				GCC_MODEL_TUNING = G4;
-				GCC_PREPROCESSOR_DEFINITIONS = "";
-				HEADER_SEARCH_PATHS = ../common;
-				INSTALL_PATH = /usr/local/lib;
-				LIBRARY_STYLE = DYNAMIC;
-				MACH_O_TYPE = mh_dylib;
-				OTHER_CFLAGS = "";
-				OTHER_CPLUSPLUSFLAGS = "$(OTHER_CFLAGS)";
-				OTHER_LDFLAGS = (
-					"-framework",
-					Jackdmp,
-					"-framework",
-					AudioToolBox,
-					"-framework",
-					CoreAudio,
-					"-framework",
-					CoreServices,
-					"-framework",
-					AudioUnit,
-				);
-				OTHER_REZFLAGS = "";
-				PREBINDING = NO;
-				PRODUCT_NAME = inprocess;
-				SDKROOT = "";
-				SECTORDER_FLAGS = "";
-				WARNING_CFLAGS = (
-					"-Wmost",
-					"-Wno-four-char-constants",
-					"-Wno-unknown-pragmas",
-				);
-			};
-			name = Default;
-		};
-/* End XCBuildConfiguration section */
-
-/* Begin XCConfigurationList section */
-		4B0A28E20D52073D002EFF74 /* Build configuration list for PBXNativeTarget "jack_thread_wait" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B0A28E30D52073D002EFF74 /* Development */,
-				4B0A28E40D52073D002EFF74 /* Deployment */,
-				4B0A28E50D52073D002EFF74 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B0A29290D52108E002EFF74 /* Build configuration list for PBXNativeTarget "jack_thread_wait 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B0A292A0D52108E002EFF74 /* Development */,
-				4B0A292B0D52108E002EFF74 /* Deployment */,
-				4B0A292C0D52108E002EFF74 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B19B2FC0E23620F00DD4A82 /* Build configuration list for PBXNativeTarget "audioadapter Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B19B2FD0E23620F00DD4A82 /* Development */,
-				4B19B2FE0E23620F00DD4A82 /* Deployment */,
-				4B19B2FF0E23620F00DD4A82 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B2021E2133A9BA40019E213 /* Build configuration list for PBXNativeTarget "jack_midi_latency 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B2021E3133A9BA40019E213 /* Development */,
-				4B2021E4133A9BA40019E213 /* Deployment */,
-				4B2021E5133A9BA40019E213 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B3224E110A3156800838A8E /* Build configuration list for PBXNativeTarget "jack_netone Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B3224E210A3156800838A8E /* Development */,
-				4B3224E310A3156800838A8E /* Deployment */,
-				4B3224E410A3156800838A8E /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B32252710A316B200838A8E /* Build configuration list for PBXNativeTarget "jack_netone 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B32252810A316B200838A8E /* Development */,
-				4B32252910A316B200838A8E /* Deployment */,
-				4B32252A10A316B200838A8E /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B32255D10A3187800838A8E /* Build configuration list for PBXNativeTarget "jack_netsource Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B32255E10A3187800838A8E /* Development */,
-				4B32255F10A3187800838A8E /* Deployment */,
-				4B32256010A3187800838A8E /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B32257710A3190C00838A8E /* Build configuration list for PBXNativeTarget "jack_netsource 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B32257810A3190C00838A8E /* Development */,
-				4B32257910A3190C00838A8E /* Deployment */,
-				4B32257A10A3190C00838A8E /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C4210D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jackdmp framework 64bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C4220D4731D1000DE7AE /* Development */,
-				4B35C4230D4731D1000DE7AE /* Deployment */,
-				4B35C4240D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C47F0D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "Jackmp.framework 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C4800D4731D1000DE7AE /* Development */,
-				4B35C4810D4731D1000DE7AE /* Deployment */,
-				4B35C4820D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C4F80D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "Jackservermp.framework 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C4F90D4731D1000DE7AE /* Development */,
-				4B35C4FA0D4731D1000DE7AE /* Deployment */,
-				4B35C4FB0D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5100D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_midiseq 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5110D4731D1000DE7AE /* Development */,
-				4B35C5120D4731D1000DE7AE /* Deployment */,
-				4B35C5130D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C51C0D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_midisine 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C51D0D4731D1000DE7AE /* Development */,
-				4B35C51E0D4731D1000DE7AE /* Deployment */,
-				4B35C51F0D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5280D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_metro 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5290D4731D1000DE7AE /* Development */,
-				4B35C52A0D4731D1000DE7AE /* Deployment */,
-				4B35C52B0D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5340D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_lsp 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5350D4731D1000DE7AE /* Development */,
-				4B35C5360D4731D1000DE7AE /* Deployment */,
-				4B35C5370D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5400D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_connect 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5410D4731D1000DE7AE /* Development */,
-				4B35C5420D4731D1000DE7AE /* Deployment */,
-				4B35C5430D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C54C0D4731D1000DE7AE /* Build configuration list for PBXNativeTarget "jack_disconnect 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C54D0D4731D1000DE7AE /* Development */,
-				4B35C54E0D4731D1000DE7AE /* Deployment */,
-				4B35C54F0D4731D1000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C55A0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_freewheel 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C55B0D4731D2000DE7AE /* Development */,
-				4B35C55C0D4731D2000DE7AE /* Deployment */,
-				4B35C55D0D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5660D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_iodelay 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5670D4731D2000DE7AE /* Development */,
-				4B35C5680D4731D2000DE7AE /* Deployment */,
-				4B35C5690D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5720D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_external_metro 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5730D4731D2000DE7AE /* Development */,
-				4B35C5740D4731D2000DE7AE /* Deployment */,
-				4B35C5750D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5820D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "testAtomic 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5830D4731D2000DE7AE /* Development */,
-				4B35C5840D4731D2000DE7AE /* Deployment */,
-				4B35C5850D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5960D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "testSem 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5970D4731D2000DE7AE /* Development */,
-				4B35C5980D4731D2000DE7AE /* Deployment */,
-				4B35C5990D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5A20D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "zombie 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5A30D4731D2000DE7AE /* Development */,
-				4B35C5A40D4731D2000DE7AE /* Deployment */,
-				4B35C5A50D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5AE0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_test 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5AF0D4731D2000DE7AE /* Development */,
-				4B35C5B00D4731D2000DE7AE /* Deployment */,
-				4B35C5B10D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5BA0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_cpu 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5BB0D4731D2000DE7AE /* Development */,
-				4B35C5BC0D4731D2000DE7AE /* Deployment */,
-				4B35C5BD0D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5C60D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_load 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5C70D4731D2000DE7AE /* Development */,
-				4B35C5C80D4731D2000DE7AE /* Deployment */,
-				4B35C5C90D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5D20D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_unload 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5D30D4731D2000DE7AE /* Development */,
-				4B35C5D40D4731D2000DE7AE /* Deployment */,
-				4B35C5D50D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5E60D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "synchroServer 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5E70D4731D2000DE7AE /* Development */,
-				4B35C5E80D4731D2000DE7AE /* Deployment */,
-				4B35C5E90D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C5FA0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "synchroClient 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C5FB0D4731D2000DE7AE /* Development */,
-				4B35C5FC0D4731D2000DE7AE /* Deployment */,
-				4B35C5FD0D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C60E0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "synchroServerClient 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C60F0D4731D2000DE7AE /* Development */,
-				4B35C6100D4731D2000DE7AE /* Deployment */,
-				4B35C6110D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C61A0D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_coreaudio 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C61B0D4731D2000DE7AE /* Development */,
-				4B35C61C0D4731D2000DE7AE /* Deployment */,
-				4B35C61D0D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C6250D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_portaudio 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C6260D4731D2000DE7AE /* Development */,
-				4B35C6270D4731D2000DE7AE /* Deployment */,
-				4B35C6280D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C6300D4731D2000DE7AE /* Build configuration list for PBXNativeTarget "jack_dummy 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C6310D4731D2000DE7AE /* Development */,
-				4B35C6320D4731D2000DE7AE /* Deployment */,
-				4B35C6330D4731D2000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C63A0D4731D3000DE7AE /* Build configuration list for PBXNativeTarget "inprocess 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C63B0D4731D3000DE7AE /* Development */,
-				4B35C63C0D4731D3000DE7AE /* Deployment */,
-				4B35C63D0D4731D3000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B35C6790D47339B000DE7AE /* Build configuration list for PBXAggregateTarget "All Universal 32/64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B35C67A0D47339B000DE7AE /* Development */,
-				4B35C67B0D47339B000DE7AE /* Deployment */,
-				4B35C67C0D47339B000DE7AE /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363DD40DEB02F6001F72D9 /* Build configuration list for PBXNativeTarget "jack_alias Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363DD50DEB02F6001F72D9 /* Development */,
-				4B363DD60DEB02F6001F72D9 /* Deployment */,
-				4B363DD70DEB02F6001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363E160DEB03C5001F72D9 /* Build configuration list for PBXNativeTarget "jack_evmon Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363E170DEB03C5001F72D9 /* Development */,
-				4B363E180DEB03C5001F72D9 /* Deployment */,
-				4B363E190DEB03C5001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363E4A0DEB0775001F72D9 /* Build configuration list for PBXNativeTarget "jack_bufsize Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363E4B0DEB0775001F72D9 /* Development */,
-				4B363E4C0DEB0775001F72D9 /* Deployment */,
-				4B363E4D0DEB0775001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363EE50DEB091C001F72D9 /* Build configuration list for PBXNativeTarget "jack_rec Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363EE60DEB091C001F72D9 /* Development */,
-				4B363EE70DEB091C001F72D9 /* Deployment */,
-				4B363EE80DEB091C001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363F1A0DEB0A6A001F72D9 /* Build configuration list for PBXNativeTarget "jack_monitor_client Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363F1B0DEB0A6A001F72D9 /* Development */,
-				4B363F1C0DEB0A6A001F72D9 /* Deployment */,
-				4B363F1D0DEB0A6A001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363F310DEB0BD1001F72D9 /* Build configuration list for PBXNativeTarget "jack_showtime Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363F320DEB0BD1001F72D9 /* Development */,
-				4B363F330DEB0BD1001F72D9 /* Deployment */,
-				4B363F340DEB0BD1001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B363F6E0DEB0D4E001F72D9 /* Build configuration list for PBXNativeTarget "jack_impulse_grabber Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B363F6F0DEB0D4E001F72D9 /* Development */,
-				4B363F700DEB0D4E001F72D9 /* Deployment */,
-				4B363F710DEB0D4E001F72D9 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B38115B1326878E00C61B14 /* Build configuration list for PBXNativeTarget "jack_latent_client Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B38115C1326878E00C61B14 /* Development */,
-				4B38115D1326878E00C61B14 /* Deployment */,
-				4B38115E1326878E00C61B14 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B3811931326884E00C61B14 /* Build configuration list for PBXNativeTarget "jack_latent_client 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B3811941326884E00C61B14 /* Development */,
-				4B3811951326884E00C61B14 /* Deployment */,
-				4B3811961326884E00C61B14 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B43A8B610145F6F00E52943 /* Build configuration list for PBXNativeTarget "jack_loopback Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B43A8B710145F6F00E52943 /* Development */,
-				4B43A8B810145F6F00E52943 /* Deployment */,
-				4B43A8B910145F6F00E52943 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B43A8E31014615800E52943 /* Build configuration list for PBXNativeTarget "jack_loopback 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B43A8E41014615800E52943 /* Development */,
-				4B43A8E51014615800E52943 /* Deployment */,
-				4B43A8E61014615800E52943 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B47ACD310B5890100469C67 /* Build configuration list for PBXNativeTarget "Jackmp.framework 64 bits debugging" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B47ACD410B5890100469C67 /* Development */,
-				4B47ACD510B5890100469C67 /* Deployment */,
-				4B47ACD610B5890100469C67 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B5A1BB70CD1CB9E0005BF74 /* Build configuration list for PBXNativeTarget "jack_midiseq Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B5A1BB80CD1CB9E0005BF74 /* Development */,
-				4B5A1BB90CD1CB9E0005BF74 /* Deployment */,
-				4B5A1BBA0CD1CB9E0005BF74 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B5A1BD60CD1CCE10005BF74 /* Build configuration list for PBXNativeTarget "jack_midisine Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B5A1BD70CD1CCE10005BF74 /* Development */,
-				4B5A1BD80CD1CCE10005BF74 /* Deployment */,
-				4B5A1BD90CD1CCE10005BF74 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B5E08D10E5B66EE00BEE4E0 /* Build configuration list for PBXNativeTarget "netadapter Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B5E08D20E5B66EE00BEE4E0 /* Development */,
-				4B5E08D30E5B66EE00BEE4E0 /* Deployment */,
-				4B5E08D40E5B66EE00BEE4E0 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B6654F3127C34AE00753A79 /* Build configuration list for PBXNativeTarget "jack_server_control 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B6654F4127C34AE00753A79 /* Development */,
-				4B6654F5127C34AE00753A79 /* Deployment */,
-				4B6654F6127C34AE00753A79 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699B33097D421600A18468 /* Build configuration list for PBXAggregateTarget "All Universal 32 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699B34097D421600A18468 /* Development */,
-				4B699B35097D421600A18468 /* Deployment */,
-				4B699B36097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699BAD097D421600A18468 /* Build configuration list for PBXNativeTarget "jackdmp framework Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699BAE097D421600A18468 /* Development */,
-				4B699BAF097D421600A18468 /* Deployment */,
-				4B699BB0097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699C43097D421600A18468 /* Build configuration list for PBXNativeTarget "Jackmp.framework Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699C44097D421600A18468 /* Development */,
-				4B699C45097D421600A18468 /* Deployment */,
-				4B699C46097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699CA8097D421600A18468 /* Build configuration list for PBXNativeTarget "Jackservermp.framework Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699CA9097D421600A18468 /* Development */,
-				4B699CAA097D421600A18468 /* Deployment */,
-				4B699CAB097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699CB7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_metro Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699CB8097D421600A18468 /* Development */,
-				4B699CB9097D421600A18468 /* Deployment */,
-				4B699CBA097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699CC7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_lsp Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699CC8097D421600A18468 /* Development */,
-				4B699CC9097D421600A18468 /* Deployment */,
-				4B699CCA097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699CD7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_connect Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699CD8097D421600A18468 /* Development */,
-				4B699CD9097D421600A18468 /* Deployment */,
-				4B699CDA097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699CE7097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_disconnect Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699CE8097D421600A18468 /* Development */,
-				4B699CE9097D421600A18468 /* Deployment */,
-				4B699CEA097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699CF9097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_freewheel Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699CFA097D421600A18468 /* Development */,
-				4B699CFB097D421600A18468 /* Deployment */,
-				4B699CFC097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D09097D421600A18468 /* Build configuration list for PBXNativeTarget "jack_external_metro Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D0A097D421600A18468 /* Development */,
-				4B699D0B097D421600A18468 /* Deployment */,
-				4B699D0C097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D1D097D421600A18468 /* Build configuration list for PBXNativeTarget "testAtomic Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D1E097D421600A18468 /* Development */,
-				4B699D1F097D421600A18468 /* Deployment */,
-				4B699D20097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D35097D421600A18468 /* Build configuration list for PBXNativeTarget "testSem Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D36097D421600A18468 /* Development */,
-				4B699D37097D421600A18468 /* Deployment */,
-				4B699D38097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D45097D421600A18468 /* Build configuration list for PBXNativeTarget "zombie Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D46097D421600A18468 /* Development */,
-				4B699D47097D421600A18468 /* Deployment */,
-				4B699D48097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D5D097D421600A18468 /* Build configuration list for PBXNativeTarget "synchroServer Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D5E097D421600A18468 /* Development */,
-				4B699D5F097D421600A18468 /* Deployment */,
-				4B699D60097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D75097D421600A18468 /* Build configuration list for PBXNativeTarget "synchroClient Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D76097D421600A18468 /* Development */,
-				4B699D77097D421600A18468 /* Deployment */,
-				4B699D78097D421600A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D8D097D421700A18468 /* Build configuration list for PBXNativeTarget "synchroServerClient Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D8E097D421700A18468 /* Development */,
-				4B699D8F097D421700A18468 /* Deployment */,
-				4B699D90097D421700A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699D9D097D421700A18468 /* Build configuration list for PBXNativeTarget "jack_coreaudio Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699D9E097D421700A18468 /* Development */,
-				4B699D9F097D421700A18468 /* Deployment */,
-				4B699DA0097D421700A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699DAC097D421700A18468 /* Build configuration list for PBXNativeTarget "jack_dummy Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699DAD097D421700A18468 /* Development */,
-				4B699DAE097D421700A18468 /* Deployment */,
-				4B699DAF097D421700A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B699DD5097D427F00A18468 /* Build configuration list for PBXProject "Jackdmp" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B699DD6097D427F00A18468 /* Development */,
-				4B699DD7097D427F00A18468 /* Deployment */,
-				4B699DD8097D427F00A18468 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B8692D71371DB4700D2D11B /* Build configuration list for PBXNativeTarget "Jacknet.framework 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B8692D81371DB4700D2D11B /* Development */,
-				4B8692D91371DB4700D2D11B /* Deployment */,
-				4B8692DA1371DB4700D2D11B /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B8F16E113290DC80002AD73 /* Build configuration list for PBXNativeTarget "jack_midi_dump Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B8F16E213290DC80002AD73 /* Development */,
-				4B8F16E313290DC80002AD73 /* Deployment */,
-				4B8F16E413290DC80002AD73 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B8F16EE13290E0E0002AD73 /* Build configuration list for PBXNativeTarget "jack_midi_dump 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B8F16EF13290E0E0002AD73 /* Development */,
-				4B8F16F013290E0E0002AD73 /* Deployment */,
-				4B8F16F113290E0E0002AD73 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4B978DB70A31CF4A009E2DD1 /* Build configuration list for PBXNativeTarget "jack_portaudio Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4B978DB80A31CF4A009E2DD1 /* Development */,
-				4B978DB90A31CF4A009E2DD1 /* Deployment */,
-				4B978DBA0A31CF4A009E2DD1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BA339A810B2E36800190E3B /* Build configuration list for PBXNativeTarget "Jackservermp.framework 64 bits profiling" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BA339A910B2E36800190E3B /* Development */,
-				4BA339AA10B2E36800190E3B /* Deployment */,
-				4BA339AB10B2E36800190E3B /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BA692AC0CBE4BC700EAD520 /* Build configuration list for PBXNativeTarget "jack_load Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BA692AD0CBE4BC700EAD520 /* Development */,
-				4BA692AE0CBE4BC700EAD520 /* Deployment */,
-				4BA692AF0CBE4BC700EAD520 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BA692D00CBE4C9000EAD520 /* Build configuration list for PBXNativeTarget "jack_unload Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BA692D10CBE4C9000EAD520 /* Development */,
-				4BA692D20CBE4C9000EAD520 /* Deployment */,
-				4BA692D30CBE4C9000EAD520 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BA7FEBF0D8E76270017FF73 /* Build configuration list for PBXNativeTarget "jack_server_control Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BA7FEC00D8E76270017FF73 /* Development */,
-				4BA7FEC10D8E76270017FF73 /* Deployment */,
-				4BA7FEC20D8E76270017FF73 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BD623F30CBCF0F000DE782F /* Build configuration list for PBXNativeTarget "inprocess Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BD623F40CBCF0F000DE782F /* Development */,
-				4BD623F50CBCF0F000DE782F /* Deployment */,
-				4BD623F60CBCF0F000DE782F /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BDCDB991001FB9C00B15929 /* Build configuration list for PBXNativeTarget "jack_coremidi 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BDCDB9A1001FB9C00B15929 /* Development */,
-				4BDCDB9B1001FB9C00B15929 /* Deployment */,
-				4BDCDB9C1001FB9C00B15929 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BDCDBC11001FCC000B15929 /* Build configuration list for PBXNativeTarget "jack_net 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BDCDBC21001FCC000B15929 /* Development */,
-				4BDCDBC31001FCC000B15929 /* Deployment */,
-				4BDCDBC41001FCC000B15929 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BDCDBE41001FD2D00B15929 /* Build configuration list for PBXNativeTarget "netmanager 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BDCDBE51001FD2D00B15929 /* Development */,
-				4BDCDBE61001FD2D00B15929 /* Deployment */,
-				4BDCDBE71001FD2D00B15929 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BDCDBFB1001FD7300B15929 /* Build configuration list for PBXNativeTarget "audioadapter 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BDCDBFC1001FD7300B15929 /* Development */,
-				4BDCDBFD1001FD7300B15929 /* Deployment */,
-				4BDCDBFE1001FD7300B15929 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BDCDC211001FDE300B15929 /* Build configuration list for PBXNativeTarget "netadapter 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BDCDC221001FDE300B15929 /* Development */,
-				4BDCDC231001FDE300B15929 /* Deployment */,
-				4BDCDC241001FDE300B15929 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BE6C69F0A3E096F005A203A /* Build configuration list for PBXNativeTarget "jack_test Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BE6C6A00A3E096F005A203A /* Development */,
-				4BE6C6A10A3E096F005A203A /* Deployment */,
-				4BE6C6A20A3E096F005A203A /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BE99D2C0AD7A04800C59091 /* Build configuration list for PBXNativeTarget "jack_cpu Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BE99D2D0AD7A04800C59091 /* Development */,
-				4BE99D2E0AD7A04800C59091 /* Deployment */,
-				4BE99D2F0AD7A04800C59091 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BF339080F8B864B0080FB5B /* Build configuration list for PBXNativeTarget "jack_coremidi Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BF339090F8B864B0080FB5B /* Development */,
-				4BF3390A0F8B864B0080FB5B /* Deployment */,
-				4BF3390B0F8B864B0080FB5B /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA5E940DEC4D9C00FA4CDB /* Build configuration list for PBXNativeTarget "testMutex Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA5E950DEC4D9C00FA4CDB /* Development */,
-				4BFA5E960DEC4D9C00FA4CDB /* Deployment */,
-				4BFA5E970DEC4D9C00FA4CDB /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA82880DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_evmon 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA82890DF6A9E40087B4E1 /* Development */,
-				4BFA828A0DF6A9E40087B4E1 /* Deployment */,
-				4BFA828B0DF6A9E40087B4E1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA829B0DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_bufsize 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA829C0DF6A9E40087B4E1 /* Development */,
-				4BFA829D0DF6A9E40087B4E1 /* Deployment */,
-				4BFA829E0DF6A9E40087B4E1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA82A70DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_rec 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA82A80DF6A9E40087B4E1 /* Development */,
-				4BFA82A90DF6A9E40087B4E1 /* Deployment */,
-				4BFA82AA0DF6A9E40087B4E1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA82B30DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_monitor_client 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA82B40DF6A9E40087B4E1 /* Development */,
-				4BFA82B50DF6A9E40087B4E1 /* Deployment */,
-				4BFA82B60DF6A9E40087B4E1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA82BF0DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_showtime 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA82C00DF6A9E40087B4E1 /* Development */,
-				4BFA82C10DF6A9E40087B4E1 /* Deployment */,
-				4BFA82C20DF6A9E40087B4E1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA82CB0DF6A9E40087B4E1 /* Build configuration list for PBXNativeTarget "jack_impulse_grabber 64 bits" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA82CC0DF6A9E40087B4E1 /* Development */,
-				4BFA82CD0DF6A9E40087B4E1 /* Deployment */,
-				4BFA82CE0DF6A9E40087B4E1 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		4BFA999E0AAAF3B0009E916C /* Build configuration list for PBXNativeTarget "jack_iodelay Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				4BFA999F0AAAF3B0009E916C /* Development */,
-				4BFA99A00AAAF3B0009E916C /* Deployment */,
-				4BFA99A10AAAF3B0009E916C /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		BA222ACB0DC88132001A17F4 /* Build configuration list for PBXNativeTarget "jack_net Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				BA222ACC0DC88132001A17F4 /* Development */,
-				BA222ACD0DC88132001A17F4 /* Deployment */,
-				BA222ACE0DC88132001A17F4 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-		BA222AE50DC882DB001A17F4 /* Build configuration list for PBXNativeTarget "netmanager Universal" */ = {
-			isa = XCConfigurationList;
-			buildConfigurations = (
-				BA222AE60DC882DB001A17F4 /* Development */,
-				BA222AE70DC882DB001A17F4 /* Deployment */,
-				BA222AE80DC882DB001A17F4 /* Default */,
-			);
-			defaultConfigurationIsVisible = 0;
-			defaultConfigurationName = Default;
-		};
-/* End XCConfigurationList section */
-	};
-	rootObject = 08FB7793FE84155DC02AAC07 /* Project object */;
-}
diff -pruN 1.9.14~dfsg-1/macosx/JackMachSemaphore.h 1.9.16~dfsg-1/macosx/JackMachSemaphore.h
--- 1.9.14~dfsg-1/macosx/JackMachSemaphore.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/JackMachSemaphore.h	2020-10-16 19:10:40.000000000 +0000
@@ -41,13 +41,18 @@ class SERVER_EXPORT JackMachSemaphore :
         semaphore_t fSemaphore;
         mach_port_t fBootPort;
 
+        int fSharedMem;
+        char* fSharedName;
+
+        bool recursiveBootstrapRegister(int counter);
+
     protected:
 
         void BuildName(const char* name, const char* server_name, char* res, int size);
 
     public:
 
-        JackMachSemaphore():JackSynchro(), fSemaphore(0), fBootPort(0)
+        JackMachSemaphore():JackSynchro(), fSemaphore(0), fBootPort(0), fSharedMem(0), fSharedName(NULL)
         {}
 
         bool Signal();
diff -pruN 1.9.14~dfsg-1/macosx/JackMachSemaphore.mm 1.9.16~dfsg-1/macosx/JackMachSemaphore.mm
--- 1.9.14~dfsg-1/macosx/JackMachSemaphore.mm	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/JackMachSemaphore.mm	2020-10-16 19:10:40.000000000 +0000
@@ -21,7 +21,9 @@ Foundation, Inc., 59 Temple Place - Suit
 #include "JackConstants.h"
 #include "JackTools.h"
 #include "JackError.h"
+#include <fcntl.h>
 #include <stdio.h>
+#include <sys/mman.h>
 
 namespace Jack
 {
@@ -30,7 +32,12 @@ void JackMachSemaphore::BuildName(const
 {
     char ext_client_name[SYNC_MAX_NAME_SIZE + 1];
     JackTools::RewriteName(client_name, ext_client_name);
-    snprintf(res, size, "jack_mach_sem.%d_%s_%s", JackTools::GetUID(), server_name, ext_client_name);
+
+    // make the name as small as possible, as macos has issues with long semaphore names
+    if (strcmp(server_name, "default") == 0)
+        server_name = "";
+
+    snprintf(res, std::min(size, 32), "js%d.%s%s", JackTools::GetUID(), server_name, ext_client_name);
 }
 
 bool JackMachSemaphore::Signal()
@@ -102,6 +109,39 @@ bool JackMachSemaphore::TimedWait(long u
     return (res == KERN_SUCCESS);
 }
 
+bool JackMachSemaphore::recursiveBootstrapRegister(int counter)
+{
+    if (counter == 99)
+        return false;
+
+    kern_return_t res;
+
+    if ((res = bootstrap_register(fBootPort, fSharedName, fSemaphore)) != KERN_SUCCESS) {
+        switch (res) {
+            case BOOTSTRAP_SUCCESS :
+                break;
+
+            case BOOTSTRAP_NOT_PRIVILEGED :
+            case BOOTSTRAP_NAME_IN_USE :
+            case BOOTSTRAP_UNKNOWN_SERVICE :
+            case BOOTSTRAP_SERVICE_ACTIVE :
+                // try again with next suffix 
+                snprintf(fSharedName, sizeof(fName), "%s-%d", fName, ++counter);
+                return recursiveBootstrapRegister(counter);
+                break;
+
+            default :
+                jack_log("bootstrap_register() err = %i:%s", res, bootstrap_strerror(res));
+                break;
+        }
+
+        jack_error("Allocate: can't check in mach semaphore name = %s err = %i:%s", fName, res, bootstrap_strerror(res));
+        return false;
+    }
+
+    return true;
+}
+
 // Server side : publish the semaphore in the global namespace
 bool JackMachSemaphore::Allocate(const char* name, const char* server_name, int value)
 {
@@ -116,34 +156,39 @@ bool JackMachSemaphore::Allocate(const c
         }
     }
 
-    if ((res = semaphore_create(task, &fSemaphore, SYNC_POLICY_FIFO, value)) != KERN_SUCCESS) {
-        jack_error("Allocate: can create semaphore err = %s", mach_error_string(res));
+    if ((fSharedMem = shm_open(fName, O_CREAT | O_RDWR, 0777)) < 0) {
+        jack_error("Allocate: can't check in mach shared name = %s err = %s", fName, strerror(errno));
         return false;
     }
 
-    if ((res = bootstrap_register(fBootPort, fName, fSemaphore)) != KERN_SUCCESS) {
-        jack_error("Allocate: can't check in mach semaphore name = %s err = %s", fName, mach_error_string(res));
-
-        switch (res) {
-            case BOOTSTRAP_SUCCESS :
-                /* service not currently registered, "a good thing" (tm) */
-                break;
-            case BOOTSTRAP_NOT_PRIVILEGED :
-                jack_log("bootstrap_register(): bootstrap not privileged");
-                break;
-            case BOOTSTRAP_SERVICE_ACTIVE :
-                jack_log("bootstrap_register(): bootstrap service active");
-                break;
-            default :
-                jack_log("bootstrap_register() err = %s", mach_error_string(res));
-                break;
+    struct stat st;
+    if (fstat(fSharedMem, &st) != -1 && st.st_size == 0) {
+        if (ftruncate(fSharedMem, SYNC_MAX_NAME_SIZE+1) != 0) {
+            jack_error("Allocate: can't set shared memory size in mach shared name = %s err = %s", fName, strerror(errno));
+            return false;
         }
+    }
 
+    char* const sharedName = (char*)mmap(NULL, SYNC_MAX_NAME_SIZE+1, PROT_READ|PROT_WRITE, MAP_SHARED, fSharedMem, 0);
+
+    if (sharedName == NULL || sharedName == MAP_FAILED) {
+        jack_error("Allocate: can't check in mach shared name = %s err = %s", fName, strerror(errno));
+        close(fSharedMem);
+        fSharedMem = -1;
+        shm_unlink(fName);
+        return false;
+    }
+
+    fSharedName = sharedName;
+    strcpy(fSharedName, fName);
+
+    if ((res = semaphore_create(task, &fSemaphore, SYNC_POLICY_FIFO, value)) != KERN_SUCCESS) {
+        jack_error("Allocate: can create semaphore err = %i:%s", res, mach_error_string(res));
         return false;
     }
 
     jack_log("JackMachSemaphore::Allocate name = %s", fName);
-    return true;
+    return recursiveBootstrapRegister(1);
 }
 
 // Client side : get the published semaphore from server
@@ -152,6 +197,12 @@ bool JackMachSemaphore::ConnectInput(con
     BuildName(name, server_name, fName, sizeof(fName));
     kern_return_t res;
 
+    // Temporary...
+    if (fSharedName) {
+        jack_log("Already connected name = %s", name);
+        return true;
+    }
+
     if (fBootPort == 0) {
         if ((res = task_get_bootstrap_port(mach_task_self(), &fBootPort)) != KERN_SUCCESS) {
             jack_error("Connect: can't find bootstrap port err = %s", mach_error_string(res));
@@ -159,11 +210,29 @@ bool JackMachSemaphore::ConnectInput(con
         }
     }
 
-    if ((res = bootstrap_look_up(fBootPort, fName, &fSemaphore)) != KERN_SUCCESS) {
-        jack_error("Connect: can't find mach semaphore name = %s err = %s", fName, mach_error_string(res));
+    if ((fSharedMem = shm_open(fName, O_RDWR, 0)) < 0) {
+        jack_error("Connect: can't connect mach shared name = %s err = %s", fName, strerror(errno));
         return false;
     }
 
+    char* const sharedName = (char*)mmap(NULL, SYNC_MAX_NAME_SIZE+1, PROT_READ|PROT_WRITE, MAP_SHARED, fSharedMem, 0);
+
+    if (sharedName == NULL || sharedName == MAP_FAILED) {
+        jack_error("Connect: can't connect mach shared name = %s err = %s", fName, strerror(errno));
+        close(fSharedMem);
+        fSharedMem = -1;
+        return false;
+    }
+
+    if ((res = bootstrap_look_up(fBootPort, sharedName, &fSemaphore)) != KERN_SUCCESS) {
+        jack_error("Connect: can't find mach semaphore name = %s, sname = %s, err = %s", fName, sharedName, bootstrap_strerror(res));
+        close(fSharedMem);
+        fSharedMem = -1;
+        return false;
+    }
+
+    fSharedName = sharedName;
+
     jack_log("JackMachSemaphore::Connect name = %s ", fName);
     return true;
 }
@@ -184,7 +253,16 @@ bool JackMachSemaphore::Disconnect()
         jack_log("JackMachSemaphore::Disconnect name = %s", fName);
         fSemaphore = 0;
     }
-    // Nothing to do
+
+    if (!fSharedName) {
+        return true;
+    }
+
+    munmap(fSharedName, SYNC_MAX_NAME_SIZE+1);
+    fSharedName = NULL;
+
+    close(fSharedMem);
+    fSharedMem = -1;
     return true;
 }
 
@@ -202,6 +280,18 @@ void JackMachSemaphore::Destroy()
     } else {
         jack_error("JackMachSemaphore::Destroy semaphore < 0");
     }
+
+    if (!fSharedName) {
+        return;
+    }
+
+    munmap(fSharedName, SYNC_MAX_NAME_SIZE+1);
+    fSharedName = NULL;
+
+    close(fSharedMem);
+    fSharedMem = -1;
+
+    shm_unlink(fName);
 }
 
 } // end of namespace
diff -pruN 1.9.14~dfsg-1/macosx/JackPlatformPlug_os.h 1.9.16~dfsg-1/macosx/JackPlatformPlug_os.h
--- 1.9.14~dfsg-1/macosx/JackPlatformPlug_os.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/JackPlatformPlug_os.h	2020-10-16 19:10:40.000000000 +0000
@@ -41,13 +41,6 @@ namespace Jack
     class JackSocketNotifyChannel;
 
 	class JackNetUnixSocket;
-
-#ifdef MY_TARGET_OS_IPHONE
-    class JackClient;
-    class JackGraphManager;
-    class JackEngineControl;
-    class JackSynchro;
-#endif
 }
 
 /* __JackPlatformMutex__ */
@@ -59,21 +52,13 @@ namespace Jack { typedef JackPosixMutex
 namespace Jack { typedef JackMachThread JackThread; }
 
 /* __JackPlatformSynchro__  client activation */
-#ifndef MY_TARGET_OS_IPHONE
-//#include "JackMachSemaphore.h"
-//namespace Jack { typedef JackMachSemaphore JackSynchro; }
-
-
-#include "JackPosixSemaphore.h"
-namespace Jack { typedef JackPosixSemaphore JackSynchro; }
-
-#endif
+#include "JackMachSemaphore.h"
+namespace Jack { typedef JackMachSemaphore JackSynchro; }
 
 /* __JackPlatformProcessSync__ */
 #include "JackPosixProcessSync.h"
 namespace Jack { typedef JackPosixProcessSync JackProcessSync; }
 
-#ifndef MY_TARGET_OS_IPHONE
 /* __JackPlatformServerChannel__ */
 #include "JackSocketServerChannel.h"
 namespace Jack { typedef JackSocketServerChannel JackServerChannel; }
@@ -89,7 +74,6 @@ namespace Jack { typedef JackSocketServe
 /* __JackPlatformNotifyChannel__ */
 #include "JackSocketNotifyChannel.h"
 namespace Jack { typedef JackSocketNotifyChannel JackNotifyChannel; }
-#endif
 
 /* __JackPlatformNetSocket__ */
 #include "JackNetUnixSocket.h"
diff -pruN 1.9.14~dfsg-1/macosx/package-welcome.txt.in 1.9.16~dfsg-1/macosx/package-welcome.txt.in
--- 1.9.14~dfsg-1/macosx/package-welcome.txt.in	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/package-welcome.txt.in	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,18 @@
+JACK2 is a low-latency audio server for multi-processor machines.
+It provides a basic infrastructure for audio applications to communicate with each other and with audio hardware.
+Through JACK, users are enabled to build powerful systems for signal processing and music production.
+
+This package installs jackd and the command-line tools for JACK2.
+It also includes the necessary files for developers to build with JACK support.
+
+All files will be installed under /usr/local/.
+
+
+Please note that this package will not delete previously installed jackosx contents.
+If you used that before, please run its own uninstaller before installing this package!
+
+Also, the previously packaged JackRouter plugin is not available at this point.
+
+
+For advanced/curious users, here is the full file list that this package provides:
+
diff -pruN 1.9.14~dfsg-1/macosx/package.xml.in 1.9.16~dfsg-1/macosx/package.xml.in
--- 1.9.14~dfsg-1/macosx/package.xml.in	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/macosx/package.xml.in	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="utf-8" standalone="no"?>
+<installer-gui-script minSpecVersion="1">
+    <title>JACK2</title>
+    <!--
+    <background file="@CURDIR@/package-background.png" mime-type="image/png" alignment="bottomleft" scaling="proportional" />
+    <background-darkAqua file="@CURDIR@/package-background.png" mime-type="image/png" alignment="bottomleft" scaling="proportional" />
+    -->
+    <choice id="org.jackaudio.jack2" title="JACK2" visible="false">
+        <pkg-ref id="org.jackaudio.jack2" version="0">jack2-osx-root.pkg</pkg-ref>
+    </choice>
+    <choices-outline>
+        <line choice="org.jackaudio.jack2" />
+    </choices-outline>
+    <domains enable_anywhere="false" enable_currentUserHome="false" enable_localSystem="true" />
+    <license file="@CURDIR@/../COPYING" mime-type="text/plain" />
+    <options customize="never" hostArchitectures="x86_64" require-scripts="false" rootVolumeOnly="true" />
+    <pkg-ref id="org.jackaudio.jack2" />
+    <welcome file="@CURDIR@/package-welcome.txt" mime-type="text/plain" />
+</installer-gui-script>
diff -pruN 1.9.14~dfsg-1/posix/JackFifo.cpp 1.9.16~dfsg-1/posix/JackFifo.cpp
--- 1.9.14~dfsg-1/posix/JackFifo.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/posix/JackFifo.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -132,7 +132,7 @@ bool JackFifo::Allocate(const char* name
     if (stat(fName, &statbuf) < 0) {
         if (errno == ENOENT || errno == EPERM) {
             if (mkfifo(fName, 0666) < 0) {
-                jack_error("Cannot create inter-client FIFO name = %s err = %s", name, strerror(errno));
+                jack_error("Cannot create inter-client FIFO name = %s err = %s", fName, strerror(errno));
                 return false;
             }
         } else {
diff -pruN 1.9.14~dfsg-1/posix/JackFifo.h 1.9.16~dfsg-1/posix/JackFifo.h
--- 1.9.14~dfsg-1/posix/JackFifo.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/posix/JackFifo.h	2020-10-16 19:10:40.000000000 +0000
@@ -44,7 +44,7 @@ class SERVER_EXPORT JackFifo : public de
 
     protected:
 
-        void BuildName(const char* name, const char* server_name, char* res);
+        void BuildName(const char* name, const char* server_name, char* res, int size);
 
     public:
 
diff -pruN 1.9.14~dfsg-1/posix/JackNetUnixSocket.cpp 1.9.16~dfsg-1/posix/JackNetUnixSocket.cpp
--- 1.9.14~dfsg-1/posix/JackNetUnixSocket.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/posix/JackNetUnixSocket.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -22,6 +22,7 @@ Foundation, Inc., 675 Mass Ave, Cambridg
 
 #include <unistd.h>
 #include <fcntl.h>
+#include <sys/time.h>
 
 using namespace std;
 
diff -pruN 1.9.14~dfsg-1/posix/JackPosixSemaphore.cpp 1.9.16~dfsg-1/posix/JackPosixSemaphore.cpp
--- 1.9.14~dfsg-1/posix/JackPosixSemaphore.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/posix/JackPosixSemaphore.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -17,6 +17,8 @@ Foundation, Inc., 59 Temple Place - Suit
 
 */
 
+#define _POSIX_C_SOURCE 200112L
+
 #include "JackPosixSemaphore.h"
 #include "JackTools.h"
 #include "JackConstants.h"
@@ -111,8 +113,6 @@ bool JackPosixSemaphore::Wait()
     return (res == 0);
 }
 
-#if (_POSIX_C_SOURCE >= 200112L || _XOPEN_SOURCE >= 600) // glibc feature test
-
 bool JackPosixSemaphore::TimedWait(long usec)
 {
 	int res;
@@ -140,15 +140,6 @@ bool JackPosixSemaphore::TimedWait(long
     return (res == 0);
 }
 
-#else
-#warning "JackPosixSemaphore::TimedWait is not supported: Jack in SYNC mode with JackPosixSemaphore will not run properly !!"
-
-bool JackPosixSemaphore::TimedWait(long usec)
-{
-	return Wait();
-}
-#endif
-
 // Server side : publish the semaphore in the global namespace
 bool JackPosixSemaphore::Allocate(const char* name, const char* server_name, int value)
 {
diff -pruN 1.9.14~dfsg-1/posix/JackSocketServerChannel.cpp 1.9.16~dfsg-1/posix/JackSocketServerChannel.cpp
--- 1.9.14~dfsg-1/posix/JackSocketServerChannel.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/posix/JackSocketServerChannel.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -22,7 +22,6 @@ Foundation, Inc., 59 Temple Place - Suit
 #include "JackServer.h"
 #include "JackLockedEngine.h"
 #include "JackGlobals.h"
-#include "JackServerGlobals.h"
 #include "JackClient.h"
 #include "JackTools.h"
 #include "JackNotification.h"
@@ -230,7 +229,6 @@ bool JackSocketServerChannel::Execute()
             // Poll all clients
             for (unsigned int i = 1; i < fSocketTable.size() + 1; i++) {
                 int fd = fPollTable[i].fd;
-                jack_log("JackSocketServerChannel::Execute : fPollTable i = %ld fd = %ld", i, fd);
                 if (fPollTable[i].revents & ~POLLIN) {
                     jack_log("JackSocketServerChannel::Execute : poll client error err = %s", strerror(errno));
                     ClientKill(fd);
diff -pruN 1.9.14~dfsg-1/posix/JackSocketServerNotifyChannel.cpp 1.9.16~dfsg-1/posix/JackSocketServerNotifyChannel.cpp
--- 1.9.14~dfsg-1/posix/JackSocketServerNotifyChannel.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/posix/JackSocketServerNotifyChannel.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -22,7 +22,6 @@ Foundation, Inc., 59 Temple Place - Suit
 #include "JackRequest.h"
 #include "JackConstants.h"
 #include "JackNotification.h"
-#include "JackServerGlobals.h"
 
 namespace Jack
 {
diff -pruN 1.9.14~dfsg-1/README.rst 1.9.16~dfsg-1/README.rst
--- 1.9.14~dfsg-1/README.rst	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/README.rst	2020-10-16 19:10:40.000000000 +0000
@@ -1,9 +1,11 @@
-`JACK2 <http://jackaudio.org/>`_
+`JACK2 <https://jackaudio.org/>`_
 ################################
 
 .. image:: https://travis-ci.org/jackaudio/jack2.svg?branch=master
-   :target: https://travis-ci.org/jackaudio/jack2
-
+   :target: https://travis-ci.org/jackaudio/jack2  
+.. image:: https://repology.org/badge/tiny-repos/jack-audio-connection-kit.svg
+   :target: https://repology.org/metapackage/jack-audio-connection-kit/versions
+   
 JACK2 aka jackdmp is a C++ version of the JACK low-latency audio server for
 multi-processor machines. It is a new implementation of the JACK server core
 features that aims at removing some limitations of the JACK1 design. The
@@ -34,3 +36,5 @@ and robust system.
     mode usually result in fewer (less audible) audio glitches in a loaded
     system.
 
+For further information, see the JACK `homepage <https://jackaudio.org/>`_ and `wiki <https://github.com/jackaudio/jackaudio.github.com/wiki>`_. There are also the #jack and #lad chat channels on `freenode IRC <https://freenode.net>`_.
+
diff -pruN 1.9.14~dfsg-1/tools/alias.c 1.9.16~dfsg-1/tools/alias.c
--- 1.9.14~dfsg-1/tools/alias.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/alias.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,133 @@
+/*
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
+#include <getopt.h>
+#include <jack/jack.h>
+
+char * my_name;
+
+void
+show_version (void)
+{
+	//fprintf (stderr, "%s: JACK Audio Connection Kit version " VERSION "\n", my_name);
+}
+
+void
+show_usage (void)
+{
+	show_version ();
+	fprintf (stderr, "\nUsage: %s [options] portname alias\n", my_name);
+	fprintf (stderr, "List active Jack ports, and optionally display extra information.\n\n");
+	fprintf (stderr, "Display options:\n");
+	fprintf (stderr, "        -u, --unalias         remove `alias' as an alias for `port'\n");
+	fprintf (stderr, "        -h, --help            Display this help message\n");
+	fprintf (stderr, "        --version             Output version information and exit\n\n");
+	fprintf (stderr, "For more information see http://jackaudio.org/\n");
+}
+
+int
+main (int argc, char *argv[])
+{
+	jack_client_t *client;
+	jack_status_t status;
+	char* portname;
+	char* alias;
+	int unset = 0;
+	int ret;
+	int c;
+	int option_index;
+	extern int optind;
+	jack_port_t* port;
+
+	struct option long_options[] = {
+		{ "unalias", 0, 0, 'u' },
+		{ "help", 0, 0, 'h' },
+		{ "version", 0, 0, 'v' },
+		{ 0, 0, 0, 0 }
+	};
+
+	if (argc < 3) {
+		show_usage ();
+		return 1;
+	}
+
+	my_name = strrchr(argv[0], '/');
+	if (my_name == 0) {
+		my_name = argv[0];
+	} else {
+		my_name ++;
+	}
+
+	while ((c = getopt_long (argc, argv, "uhv", long_options, &option_index)) >= 0) {
+		switch (c) {
+		case 'u':
+			unset = 1;
+			break;
+		case 'h':
+			show_usage ();
+			return 1;
+			break;
+		case 'v':
+			show_version ();
+			return 1;
+			break;
+		default:
+			show_usage ();
+			return 1;
+			break;
+		}
+	}
+
+	portname = argv[optind++];
+	alias = argv[optind];
+
+	/* Open a client connection to the JACK server.  Starting a
+	 * new server only to list its ports seems pointless, so we
+	 * specify JackNoStartServer. */
+	//JOQ: need a new server name option
+
+	client = jack_client_open ("lsp", JackNoStartServer, &status);
+
+	if (client == NULL) {
+		if (status & JackServerFailed) {
+			fprintf (stderr, "JACK server not running\n");
+		} else {
+			fprintf (stderr, "jack_client_open() failed, "
+				 "status = 0x%2.0x\n", status);
+		}
+		return 1;
+	}
+
+	if ((port = jack_port_by_name (client, portname)) == 0) {
+		fprintf (stderr, "No port named \"%s\"\n", portname);
+		return 1;
+	}
+
+	if (!unset) {
+		ret = jack_port_set_alias (port, alias);
+	} else {
+		ret = jack_port_unset_alias (port, alias);
+	}
+
+	jack_client_close (client);
+
+	return ret;
+
+}
diff -pruN 1.9.14~dfsg-1/tools/alsa_in.c 1.9.16~dfsg-1/tools/alsa_in.c
--- 1.9.14~dfsg-1/tools/alsa_in.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/alsa_in.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,846 @@
+/** @file simple_client.c
+ *
+ * @brief This simple client demonstrates the basic features of JACK
+ * as they would be used by many applications.
+ */
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <signal.h>
+
+#include <math.h>
+
+#include <jack/jack.h>
+#include <jack/jslist.h>
+#include "memops.h"
+
+#include "alsa/asoundlib.h"
+
+#include <samplerate.h>
+
+// Here are the lists of the jack ports...
+
+JSList	   *capture_ports = NULL;
+JSList	   *capture_srcs = NULL;
+JSList	   *playback_ports = NULL;
+JSList	   *playback_srcs = NULL;
+jack_client_t *client;
+
+snd_pcm_t *alsa_handle;
+
+int jack_sample_rate;
+int jack_buffer_size;
+
+int quit = 0;
+double resample_mean = 1.0;
+double static_resample_factor = 1.0;
+double resample_lower_limit = 0.25;
+double resample_upper_limit = 4.0;
+
+double *offset_array;
+double *window_array;
+int offset_differential_index = 0;
+
+double offset_integral = 0;
+
+// ------------------------------------------------------ commandline parameters
+
+int sample_rate = 0;				 /* stream rate */
+int num_channels = 2;				 /* count of channels */
+int period_size = 1024;
+int num_periods = 2;
+
+int target_delay = 0;	    /* the delay which the program should try to approach. */
+int max_diff = 0;	    /* the diff value, when a hard readpointer skip should occur */
+int catch_factor = 100000;
+int catch_factor2 = 10000;
+double pclamp = 15.0;
+double controlquant = 10000.0;
+int smooth_size = 256;
+int good_window=0;
+int verbose = 0;
+int instrument = 0;
+int samplerate_quality = 2;
+
+// Debug stuff:
+
+volatile float output_resampling_factor = 1.0;
+volatile int output_new_delay = 0;
+volatile float output_offset = 0.0;
+volatile float output_integral = 0.0;
+volatile float output_diff = 0.0;
+volatile int running_freewheel = 0;
+
+snd_pcm_uframes_t real_buffer_size;
+snd_pcm_uframes_t real_period_size;
+
+// buffers
+
+char *tmpbuf;
+char *outbuf;
+float *resampbuf;
+
+// format selection, and corresponding functions from memops in a nice set of structs.
+
+typedef struct alsa_format {
+	snd_pcm_format_t format_id;
+	size_t sample_size;
+	void (*jack_to_soundcard) (char *dst, jack_default_audio_sample_t *src, unsigned long nsamples, unsigned long dst_skip, dither_state_t *state);
+	void (*soundcard_to_jack) (jack_default_audio_sample_t *dst, char *src, unsigned long nsamples, unsigned long src_skip);
+	const char *name;
+} alsa_format_t;
+
+alsa_format_t formats[] = {
+	{ SND_PCM_FORMAT_FLOAT_LE, 4, sample_move_dS_floatLE, sample_move_floatLE_sSs, "float" },
+	{ SND_PCM_FORMAT_S32, 4, sample_move_d32u24_sS, sample_move_dS_s32u24, "32bit" },
+	{ SND_PCM_FORMAT_S24_3LE, 3, sample_move_d24_sS, sample_move_dS_s24, "24bit - real" },
+	{ SND_PCM_FORMAT_S24, 4, sample_move_d24_sS, sample_move_dS_s24, "24bit" },
+	{ SND_PCM_FORMAT_S16, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit" }
+#ifdef __ANDROID__
+	,{ SND_PCM_FORMAT_S16_LE, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit little-endian" }
+#endif
+};
+#define NUMFORMATS (sizeof(formats)/sizeof(formats[0]))
+int format=0;
+
+// Alsa stuff... i don't want to touch this bullshit in the next years.... please...
+
+static int xrun_recovery(snd_pcm_t *handle, int err) {
+//    printf( "xrun !!!.... %d\n", err );
+	if (err == -EPIPE) {	/* under-run */
+		err = snd_pcm_prepare(handle);
+		if (err < 0)
+			printf("Can't recover from underrun, prepare failed: %s\n", snd_strerror(err));
+		return 0;
+	} else if (err == -ESTRPIPE) {
+		while ((err = snd_pcm_resume(handle)) == -EAGAIN)
+			usleep(100);	/* wait until the suspend flag is released */
+		if (err < 0) {
+			err = snd_pcm_prepare(handle);
+			if (err < 0)
+				printf("Can't recover from suspend, prepare failed: %s\n", snd_strerror(err));
+		}
+		return 0;
+	}
+	return err;
+}
+
+static int set_hwformat( snd_pcm_t *handle, snd_pcm_hw_params_t *params )
+{
+#ifdef __ANDROID__
+	format = 5;
+	snd_pcm_hw_params_set_format(handle, params, formats[format].format_id);
+	return 0;
+#else
+	int i;
+	int err;
+
+	for( i=0; i<NUMFORMATS; i++ ) {
+		/* set the sample format */
+		err = snd_pcm_hw_params_set_format(handle, params, formats[i].format_id);
+		if (err == 0) {
+			format = i;
+			return 0;
+		}
+	}
+
+	return err;
+#endif
+}
+
+static int set_hwparams(snd_pcm_t *handle, snd_pcm_hw_params_t *params, snd_pcm_access_t access, int rate, int channels, int period, int nperiods ) {
+	int err, dir=0;
+	unsigned int buffer_time;
+	unsigned int period_time;
+	unsigned int rrate;
+	unsigned int rchannels;
+
+	/* choose all parameters */
+	err = snd_pcm_hw_params_any(handle, params);
+	if (err < 0) {
+		printf("Broken configuration for playback: no configurations available: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* set the interleaved read/write format */
+	err = snd_pcm_hw_params_set_access(handle, params, access);
+	if (err < 0) {
+		printf("Access type not available for playback: %s\n", snd_strerror(err));
+		return err;
+	}
+
+	/* set the sample format */
+	err = set_hwformat(handle, params);
+	if (err < 0) {
+		printf("Sample format not available for playback: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* set the count of channels */
+	rchannels = channels;
+	err = snd_pcm_hw_params_set_channels_near(handle, params, &rchannels);
+	if (err < 0) {
+		printf("Channels count (%i) not available for record: %s\n", channels, snd_strerror(err));
+		return err;
+	}
+	if (rchannels != channels) {
+		printf("WARNING: channel count does not match (requested %d got %d)\n", channels, rchannels);
+		num_channels = rchannels;
+	}
+	/* set the stream rate */
+	rrate = rate;
+	err = snd_pcm_hw_params_set_rate_near(handle, params, &rrate, 0);
+	if (err < 0) {
+		printf("Rate %iHz not available for playback: %s\n", rate, snd_strerror(err));
+		return err;
+	}
+	if (rrate != rate) {
+		printf("WARNING: Rate doesn't match (requested %iHz, get %iHz)\n", rate, rrate);
+		sample_rate = rrate;
+	}
+	/* set the buffer time */
+
+	buffer_time = 1000000*(uint64_t)period*nperiods/rate;
+	err = snd_pcm_hw_params_set_buffer_time_near(handle, params, &buffer_time, &dir);
+	if (err < 0) {
+		printf("Unable to set buffer time %i for playback: %s\n",  1000000*period*nperiods/rate, snd_strerror(err));
+		return err;
+	}
+	err = snd_pcm_hw_params_get_buffer_size( params, &real_buffer_size );
+	if (err < 0) {
+		printf("Unable to get buffer size back: %s\n", snd_strerror(err));
+		return err;
+	}
+	if( real_buffer_size != nperiods * period ) {
+	    printf( "WARNING: buffer size does not match: (requested %d, got %d)\n", nperiods * period, (int) real_buffer_size );
+	}
+	/* set the period time */
+	period_time = 1000000*(uint64_t)period/rate;
+	err = snd_pcm_hw_params_set_period_time_near(handle, params, &period_time, &dir);
+	if (err < 0) {
+		printf("Unable to set period time %i for playback: %s\n", 1000000*period/rate, snd_strerror(err));
+		return err;
+	}
+	err = snd_pcm_hw_params_get_period_size(params, &real_period_size, NULL );
+	if (err < 0) {
+		printf("Unable to get period size back: %s\n", snd_strerror(err));
+		return err;
+	}
+	if( real_period_size != period ) {
+	    printf( "WARNING: period size does not match: (requested %i, got %i)\n", period, (int)real_period_size );
+	}
+	/* write the parameters to device */
+	err = snd_pcm_hw_params(handle, params);
+	if (err < 0) {
+		printf("Unable to set hw params for playback: %s\n", snd_strerror(err));
+		return err;
+	}
+	return 0;
+}
+
+static int set_swparams(snd_pcm_t *handle, snd_pcm_sw_params_t *swparams, int period) {
+	int err;
+
+	/* get the current swparams */
+	err = snd_pcm_sw_params_current(handle, swparams);
+	if (err < 0) {
+		printf("Unable to determine current swparams for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* start the transfer when the buffer is full */
+	err = snd_pcm_sw_params_set_start_threshold(handle, swparams, period );
+	if (err < 0) {
+		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	err = snd_pcm_sw_params_set_stop_threshold(handle, swparams, -1 );
+	if (err < 0) {
+		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* allow the transfer when at least period_size samples can be processed */
+	err = snd_pcm_sw_params_set_avail_min(handle, swparams, 2*period );
+	if (err < 0) {
+		printf("Unable to set avail min for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* align all transfers to 1 sample */
+	err = snd_pcm_sw_params_set_xfer_align(handle, swparams, 1);
+	if (err < 0) {
+		printf("Unable to set transfer align for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* write the parameters to the playback device */
+	err = snd_pcm_sw_params(handle, swparams);
+	if (err < 0) {
+		printf("Unable to set sw params for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	return 0;
+}
+
+// ok... i only need this function to communicate with the alsa bloat api...
+
+static snd_pcm_t *open_audiofd( char *device_name, int capture, int rate, int channels, int period, int nperiods ) {
+  int err;
+  snd_pcm_t *handle;
+  snd_pcm_hw_params_t *hwparams;
+  snd_pcm_sw_params_t *swparams;
+
+  snd_pcm_hw_params_alloca(&hwparams);
+  snd_pcm_sw_params_alloca(&swparams);
+
+  if ((err = snd_pcm_open(&(handle), device_name, capture ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK )) < 0) {
+      printf("Capture open error: %s\n", snd_strerror(err));
+      return NULL;
+  }
+
+  if ((err = set_hwparams(handle, hwparams,SND_PCM_ACCESS_RW_INTERLEAVED, rate, channels, period, nperiods )) < 0) {
+      printf("Setting of hwparams failed: %s\n", snd_strerror(err));
+      return NULL;
+  }
+  if ((err = set_swparams(handle, swparams, period)) < 0) {
+      printf("Setting of swparams failed: %s\n", snd_strerror(err));
+      return NULL;
+  }
+
+  snd_pcm_start( handle );
+  snd_pcm_wait( handle, 200 );
+
+  return handle;
+}
+
+double hann( double x )
+{
+	return 0.5 * (1.0 - cos( 2*M_PI * x ) );
+}
+
+/**
+ * The freewheel callback.
+ */
+void freewheel (int starting, void* arg) {
+    running_freewheel = starting;
+}
+
+/**
+ * The process callback for this JACK application.
+ * It is called by JACK at the appropriate times.
+ */
+int process (jack_nframes_t nframes, void *arg) {
+
+    if (running_freewheel) {
+	JSList *node = capture_ports;
+
+	while ( node != NULL)
+	{
+	    jack_port_t *port = (jack_port_t *) node->data;
+	    float *buf = jack_port_get_buffer (port, nframes);
+
+	    memset(buf, 0, sizeof(float)*nframes);
+
+	    node = jack_slist_next (node);
+	}
+
+	return 0;
+    }
+
+    int rlen;
+    int err;
+    snd_pcm_sframes_t delay = target_delay;
+    int put_back_samples=0;
+    int i;
+
+    delay = snd_pcm_avail( alsa_handle );
+
+    delay -= round( jack_frames_since_cycle_start( client ) / static_resample_factor );
+    // Do it the hard way.
+    // this is for compensating xruns etc...
+
+    if( delay > (target_delay+max_diff) ) {
+
+	output_new_delay = (int) delay;
+
+	while ((delay-target_delay) > 0) {
+	    snd_pcm_uframes_t to_read = ((delay-target_delay) > 512) ? 512 : (delay-target_delay);
+	    snd_pcm_readi( alsa_handle, tmpbuf, to_read );
+	    delay -= to_read;
+	}
+
+	delay = target_delay;
+
+	// Set the resample_rate... we need to adjust the offset integral, to do this.
+	// first look at the PI controller, this code is just a special case, which should never execute once
+	// everything is swung in. 
+	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
+	// Also clear the array. we are beginning a new control cycle.
+	for( i=0; i<smooth_size; i++ )
+		offset_array[i] = 0.0;
+    }
+    if( delay < (target_delay-max_diff) ) {
+	snd_pcm_rewind( alsa_handle, target_delay - delay );
+	output_new_delay = (int) delay;
+	delay = target_delay;
+
+	// Set the resample_rate... we need to adjust the offset integral, to do this.
+	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
+	// Also clear the array. we are beginning a new control cycle.
+	for( i=0; i<smooth_size; i++ )
+		offset_array[i] = 0.0;
+    }
+    /* ok... now we should have target_delay +- max_diff on the alsa side.
+     *
+     * calculate the number of frames, we want to get.
+     */
+
+    double offset = delay - target_delay;
+
+    // Save offset.
+    offset_array[(offset_differential_index++)% smooth_size ] = offset;
+
+    // Build the mean of the windowed offset array
+    // basically fir lowpassing.
+    double smooth_offset = 0.0;
+    for( i=0; i<smooth_size; i++ )
+	    smooth_offset +=
+		    offset_array[ (i + offset_differential_index-1) % smooth_size] * window_array[i];
+    smooth_offset /= (double) smooth_size;
+
+    // this is the integral of the smoothed_offset
+    offset_integral += smooth_offset;
+
+    // Clamp offset.
+    // the smooth offset still contains unwanted noise
+    // which would go straight onto the resample coeff.
+    // it only used in the P component and the I component is used for the fine tuning anyways.
+    if( fabs( smooth_offset ) < pclamp )
+	    smooth_offset = 0.0;
+
+    // ok. now this is the PI controller. 
+    // u(t) = K * ( e(t) + 1/T \int e(t') dt' )
+    // K = 1/catch_factor and T = catch_factor2
+    double current_resample_factor = static_resample_factor - smooth_offset / (double) catch_factor - offset_integral / (double) catch_factor / (double)catch_factor2;
+
+    // now quantize this value around resample_mean, so that the noise which is in the integral component doesn't hurt.
+    current_resample_factor = floor( (current_resample_factor - resample_mean) * controlquant + 0.5 ) / controlquant + resample_mean;
+
+    // Output "instrumentatio" gonna change that to real instrumentation in a few.
+    output_resampling_factor = (float) current_resample_factor;
+    output_diff = (float) smooth_offset;
+    output_integral = (float) offset_integral;
+    output_offset = (float) offset;
+
+    // Clamp a bit.
+    if( current_resample_factor < resample_lower_limit ) current_resample_factor = resample_lower_limit;
+    if( current_resample_factor > resample_upper_limit ) current_resample_factor = resample_upper_limit;
+
+    // Now Calculate how many samples we need.
+    rlen = ceil( ((double)nframes) / current_resample_factor )+2;
+    assert( rlen > 2 );
+
+    // Calculate resample_mean so we can init ourselves to saner values.
+    resample_mean = 0.9999 * resample_mean + 0.0001 * current_resample_factor;
+
+    // get the data...
+again:
+    err = snd_pcm_readi(alsa_handle, outbuf, rlen);
+    if( err < 0 ) {
+	printf( "err = %d\n", err );
+	if (xrun_recovery(alsa_handle, err) < 0) {
+	    //printf("Write error: %s\n", snd_strerror(err));
+	    //exit(EXIT_FAILURE);
+	}
+	goto again;
+    }
+    if( err != rlen ) {
+	//printf( "read = %d\n", rlen );
+    }
+
+    /*
+     * render jack ports to the outbuf...
+     */
+
+    int chn = 0;
+    JSList *node = capture_ports;
+    JSList *src_node = capture_srcs;
+    SRC_DATA src;
+
+    while ( node != NULL)
+    {
+	jack_port_t *port = (jack_port_t *) node->data;
+	float *buf = jack_port_get_buffer (port, nframes);
+
+	SRC_STATE *src_state = src_node->data;
+
+	formats[format].soundcard_to_jack( resampbuf, outbuf + format[formats].sample_size * chn, rlen, num_channels*format[formats].sample_size );
+
+	src.data_in = resampbuf;
+	src.input_frames = rlen;
+
+	src.data_out = buf;
+	src.output_frames = nframes;
+	src.end_of_input = 0;
+
+	src.src_ratio = current_resample_factor;
+
+	src_process( src_state, &src );
+
+	put_back_samples = rlen-src.input_frames_used;
+
+	src_node = jack_slist_next (src_node);
+	node = jack_slist_next (node);
+	chn++;
+    }
+
+    // Put back the samples libsamplerate did not consume.
+    //printf( "putback = %d\n", put_back_samples );
+    snd_pcm_rewind( alsa_handle, put_back_samples );
+
+    return 0;      
+}
+
+/**
+ * the latency callback.
+ * sets up the latencies on the ports.
+ */
+
+void
+latency_cb (jack_latency_callback_mode_t mode, void *arg)
+{
+	jack_latency_range_t range;
+	JSList *node;
+
+	range.min = range.max = round(target_delay * static_resample_factor);
+
+	if (mode == JackCaptureLatency) {
+		for (node = capture_ports; node; node = jack_slist_next (node)) {
+			jack_port_t *port = node->data;
+			jack_port_set_latency_range (port, mode, &range);
+		}
+	} else {
+		for (node = playback_ports; node; node = jack_slist_next (node)) {
+			jack_port_t *port = node->data;
+			jack_port_set_latency_range (port, mode, &range);
+		}
+	}
+}
+
+
+/**
+ * Allocate the necessary jack ports...
+ */
+
+void alloc_ports( int n_capture, int n_playback ) {
+
+    int port_flags = JackPortIsOutput;
+    int chn;
+    jack_port_t *port;
+    char buf[32];
+
+    capture_ports = NULL;
+    for (chn = 0; chn < n_capture; chn++)
+    {
+	snprintf (buf, sizeof(buf) - 1, "capture_%u", chn+1);
+
+	port = jack_port_register (client, buf,
+		JACK_DEFAULT_AUDIO_TYPE,
+		port_flags, 0);
+
+	if (!port)
+	{
+	    printf( "jacknet_client: cannot register port for %s", buf);
+	    break;
+	}
+
+	capture_srcs = jack_slist_append( capture_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
+	capture_ports = jack_slist_append (capture_ports, port);
+    }
+
+    port_flags = JackPortIsInput;
+
+    playback_ports = NULL;
+    for (chn = 0; chn < n_playback; chn++)
+    {
+	snprintf (buf, sizeof(buf) - 1, "playback_%u", chn+1);
+
+	port = jack_port_register (client, buf,
+		JACK_DEFAULT_AUDIO_TYPE,
+		port_flags, 0);
+
+	if (!port)
+	{
+	    printf( "jacknet_client: cannot register port for %s", buf);
+	    break;
+	}
+
+	playback_srcs = jack_slist_append( playback_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
+	playback_ports = jack_slist_append (playback_ports, port);
+    }
+}
+
+/**
+ * This is the shutdown callback for this JACK application.
+ * It is called by JACK if the server ever shuts down or
+ * decides to disconnect the client.
+ */
+
+void jack_shutdown (void *arg) {
+
+	exit (1);
+}
+
+/**
+ * be user friendly.
+ * be user friendly.
+ * be user friendly.
+ */
+
+void printUsage() {
+fprintf(stderr, "usage: alsa_out [options]\n"
+		"\n"
+		"  -j <jack name> - client name\n"
+		"  -S <server name> - server to connect\n"
+		"  -d <alsa_device> \n"
+		"  -c <channels> \n"
+		"  -p <period_size> \n"
+		"  -n <num_period> \n"
+		"  -r <sample_rate> \n"
+		"  -q <sample_rate quality [0..4]\n"
+		"  -m <max_diff> \n"
+		"  -t <target_delay> \n"
+		"  -i  turns on instrumentation\n"
+		"  -v  turns on printouts\n"
+		"\n");
+}
+
+
+/**
+ * the main function....
+ */
+
+void
+sigterm_handler( int signal )
+{
+	quit = 1;
+}
+
+
+int main (int argc, char *argv[]) {
+    char jack_name[30] = "alsa_in";
+    char alsa_device[30] = "hw:0";
+    char *server_name = NULL;
+    int jack_opts = 0;
+
+    extern char *optarg;
+    extern int optind, optopt;
+    int errflg=0;
+    int c;
+
+    while ((c = getopt(argc, argv, "ivj:r:c:p:n:d:q:m:t:f:F:C:Q:s:S:")) != -1) {
+	switch(c) {
+	    case 'j':
+		strcpy(jack_name,optarg);
+		break;
+	    case 'r':
+		sample_rate = atoi(optarg);
+		break;
+	    case 'c':
+		num_channels = atoi(optarg);
+		break;
+	    case 'p':
+		period_size = atoi(optarg);
+		break;
+	    case 'n':
+		num_periods = atoi(optarg);
+		break;
+	    case 'd':
+		strcpy(alsa_device,optarg);
+		break;
+	    case 't':
+		target_delay = atoi(optarg);
+		break;
+	    case 'q':
+		samplerate_quality = atoi(optarg);
+		break;
+	    case 'm':
+		max_diff = atoi(optarg);
+		break;
+	    case 'f':
+		catch_factor = atoi(optarg);
+		break;
+	    case 'F':
+		catch_factor2 = atoi(optarg);
+		break;
+	    case 'C':
+		pclamp = (double) atoi(optarg);
+		break;
+	    case 'Q':
+		controlquant = (double) atoi(optarg);
+		break;
+	    case 'v':
+		verbose = 1;
+		break;
+	    case 'i':
+		instrument = 1;
+		break;
+	    case 's':
+		smooth_size = atoi(optarg);
+		break;
+	    case 'S':
+		server_name = optarg;
+		jack_opts |= JackServerName;
+		break;
+	    case ':':
+		fprintf(stderr,
+			"Option -%c requires an operand\n", optopt);
+		errflg++;
+		break;
+	    case '?':
+		fprintf(stderr,
+			"Unrecognized option: -%c\n", optopt);
+		errflg++;
+	}
+    }
+    if (errflg) {
+	printUsage();
+	exit(2);
+    }
+
+    if( (samplerate_quality < 0) || (samplerate_quality > 4) ) {
+	fprintf (stderr, "invalid samplerate quality\n");
+	return 1;
+    }
+    if ((client = jack_client_open (jack_name, jack_opts, NULL, server_name)) == 0) {
+	fprintf (stderr, "jack server not running?\n");
+	return 1;
+    }
+
+    /* tell the JACK server to call `process()' whenever
+       there is work to be done.
+       */
+
+    jack_set_process_callback (client, process, 0);
+
+    /* tell the JACK server to call `freewheel()' whenever
+       freewheel mode changes.
+       */
+
+    jack_set_freewheel_callback (client, freewheel, 0);
+
+    /* tell the JACK server to call `jack_shutdown()' if
+       it ever shuts down, either entirely, or if it
+       just decides to stop calling us.
+       */
+
+    jack_on_shutdown (client, jack_shutdown, 0);
+
+    if (jack_set_latency_callback)
+	    jack_set_latency_callback (client, latency_cb, 0);
+
+    // get jack sample_rate
+    
+    jack_sample_rate = jack_get_sample_rate( client );
+
+    if( !sample_rate )
+	sample_rate = jack_sample_rate;
+
+    // now open the alsa fd...
+    alsa_handle = open_audiofd( alsa_device, 1, sample_rate, num_channels, period_size, num_periods);
+    if( alsa_handle == 0 )
+	exit(20);
+
+    printf( "selected sample format: %s\n", formats[format].name );
+
+    static_resample_factor = (double) jack_sample_rate / (double) sample_rate;
+    resample_lower_limit = static_resample_factor * 0.25;
+    resample_upper_limit = static_resample_factor * 4.0;
+    resample_mean = static_resample_factor;
+
+    offset_array = malloc( sizeof(double) * smooth_size );
+    if( offset_array == NULL ) {
+	    fprintf( stderr, "no memory for offset_array !!!\n" );
+	    exit(20);
+    }
+    window_array = malloc( sizeof(double) * smooth_size );
+    if( window_array == NULL ) {
+	    fprintf( stderr, "no memory for window_array !!!\n" );
+	    exit(20);
+    }
+    int i;
+    for( i=0; i<smooth_size; i++ ) {
+	    offset_array[i] = 0.0;
+	    window_array[i] = hann( (double) i / ((double) smooth_size - 1.0) );
+    }
+
+    jack_buffer_size = jack_get_buffer_size( client );
+    // Setup target delay and max_diff for the normal user, who does not play with them...
+    if( !target_delay ) 
+	target_delay = (num_periods*period_size / 2) + jack_buffer_size/2;
+
+    if( !max_diff )
+	max_diff = num_periods*period_size - target_delay ;	
+
+    if( max_diff > target_delay ) {
+	    fprintf( stderr, "target_delay (%d) can not be smaller than max_diff(%d)\n", target_delay, max_diff );
+	    exit(20);
+    }
+    if( (target_delay+max_diff) > (num_periods*period_size) ) {
+	    fprintf( stderr, "target_delay+max_diff (%d) can not be bigger than buffersize(%d)\n", target_delay+max_diff, num_periods*period_size );
+	    exit(20);
+    }
+    // alloc input ports, which are blasted out to alsa...
+    alloc_ports( num_channels, 0 );
+
+    outbuf = malloc( num_periods * period_size * formats[format].sample_size * num_channels );
+    resampbuf = malloc( num_periods * period_size * sizeof( float ) );
+    tmpbuf = malloc( 512 * formats[format].sample_size * num_channels );
+
+    if ((outbuf == NULL) || (resampbuf == NULL) || (tmpbuf == NULL))
+    {
+	    fprintf( stderr, "no memory for buffers.\n" );
+	    exit(20);
+    }
+
+    memset( tmpbuf, 0, 512 * formats[format].sample_size * num_channels);
+
+    /* tell the JACK server that we are ready to roll */
+
+    if (jack_activate (client)) {
+	fprintf (stderr, "cannot activate client");
+	return 1;
+    }
+
+    signal( SIGTERM, sigterm_handler );
+    signal( SIGINT, sigterm_handler );
+
+    if( verbose ) {
+	    while(!quit) {
+		    usleep(500000);
+		    if( output_new_delay ) {
+			    printf( "delay = %d\n", output_new_delay );
+			    output_new_delay = 0;
+		    }
+		    printf( "res: %f, \tdiff = %f, \toffset = %f \n", output_resampling_factor, output_diff, output_offset );
+	    }
+    } else if( instrument ) {
+	    printf( "# n\tresamp\tdiff\toffseti\tintegral\n");
+	    int n=0;
+	    while(!quit) {
+		    usleep(1000);
+		    printf( "%d\t%f\t%f\t%f\t%f\n", n++, output_resampling_factor, output_diff, output_offset, output_integral );
+	    }
+    } else {
+	    while(!quit)
+	    {
+		    usleep(500000);
+		    if( output_new_delay ) {
+			    printf( "delay = %d\n", output_new_delay );
+			    output_new_delay = 0;
+		    }
+	    }
+    }
+
+    jack_deactivate( client );
+    jack_client_close (client);
+    exit (0);
+}
diff -pruN 1.9.14~dfsg-1/tools/alsa_out.c 1.9.16~dfsg-1/tools/alsa_out.c
--- 1.9.14~dfsg-1/tools/alsa_out.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/alsa_out.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,848 @@
+/** @file simple_client.c
+ *
+ * @brief This simple client demonstrates the basic features of JACK
+ * as they would be used by many applications.
+ */
+
+#include <alloca.h>
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <signal.h>
+
+#include <math.h>
+
+#include <jack/jack.h>
+#include <jack/jslist.h>
+#include "memops.h"
+
+#include "alsa/asoundlib.h"
+
+#include <samplerate.h>
+
+// Here are the lists of the jack ports...
+
+JSList	   *capture_ports = NULL;
+JSList	   *capture_srcs = NULL;
+JSList	   *playback_ports = NULL;
+JSList	   *playback_srcs = NULL;
+jack_client_t *client;
+
+snd_pcm_t *alsa_handle;
+
+int jack_sample_rate;
+int jack_buffer_size;
+
+int quit = 0;
+double resample_mean = 1.0;
+double static_resample_factor = 1.0;
+double resample_lower_limit = 0.25;
+double resample_upper_limit = 4.0;
+
+double *offset_array;
+double *window_array;
+int offset_differential_index = 0;
+
+double offset_integral = 0;
+
+// ------------------------------------------------------ commandline parameters
+
+int sample_rate = 0;				 /* stream rate */
+int num_channels = 2;				 /* count of channels */
+int period_size = 1024;
+int num_periods = 2;
+
+int target_delay = 0;	    /* the delay which the program should try to approach. */
+int max_diff = 0;	    /* the diff value, when a hard readpointer skip should occur */
+int catch_factor = 100000;
+int catch_factor2 = 10000;
+double pclamp = 15.0;
+double controlquant = 10000.0;
+int smooth_size = 256;
+int good_window=0;
+int verbose = 0;
+int instrument = 0;
+int samplerate_quality = 2;
+
+// Debug stuff:
+
+volatile float output_resampling_factor = 1.0;
+volatile int output_new_delay = 0;
+volatile float output_offset = 0.0;
+volatile float output_integral = 0.0;
+volatile float output_diff = 0.0;
+volatile int running_freewheel = 0;
+
+snd_pcm_uframes_t real_buffer_size;
+snd_pcm_uframes_t real_period_size;
+
+// buffers
+
+char *tmpbuf;
+char *outbuf;
+float *resampbuf;
+
+// format selection, and corresponding functions from memops in a nice set of structs.
+
+typedef struct alsa_format {
+	snd_pcm_format_t format_id;
+	size_t sample_size;
+	void (*jack_to_soundcard) (char *dst, jack_default_audio_sample_t *src, unsigned long nsamples, unsigned long dst_skip, dither_state_t *state);
+	void (*soundcard_to_jack) (jack_default_audio_sample_t *dst, char *src, unsigned long nsamples, unsigned long src_skip);
+	const char *name;
+} alsa_format_t;
+
+alsa_format_t formats[] = {
+	{ SND_PCM_FORMAT_FLOAT_LE, 4, sample_move_dS_floatLE, sample_move_floatLE_sSs, "float" },
+	{ SND_PCM_FORMAT_S32, 4, sample_move_d32u24_sS, sample_move_dS_s32u24, "32bit" },
+	{ SND_PCM_FORMAT_S24_3LE, 3, sample_move_d24_sS, sample_move_dS_s24, "24bit - real" },
+	{ SND_PCM_FORMAT_S24, 4, sample_move_d24_sS, sample_move_dS_s24, "24bit" },
+	{ SND_PCM_FORMAT_S16, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit" }
+#ifdef __ANDROID__
+	,{ SND_PCM_FORMAT_S16_LE, 2, sample_move_d16_sS, sample_move_dS_s16, "16bit little-endian" }
+#endif
+};
+#define NUMFORMATS (sizeof(formats)/sizeof(formats[0]))
+int format=0;
+
+// Alsa stuff... i don't want to touch this bullshit in the next years.... please...
+
+static int xrun_recovery(snd_pcm_t *handle, int err) {
+//    printf( "xrun !!!.... %d\n", err );
+	if (err == -EPIPE) {	/* under-run */
+		err = snd_pcm_prepare(handle);
+		if (err < 0)
+			printf("Can't recovery from underrun, prepare failed: %s\n", snd_strerror(err));
+		return 0;
+	} else if (err == -ESTRPIPE) {
+		while ((err = snd_pcm_resume(handle)) == -EAGAIN)
+			usleep(100);	/* wait until the suspend flag is released */
+		if (err < 0) {
+			err = snd_pcm_prepare(handle);
+			if (err < 0)
+				printf("Can't recovery from suspend, prepare failed: %s\n", snd_strerror(err));
+		}
+		return 0;
+	}
+	return err;
+}
+
+static int set_hwformat( snd_pcm_t *handle, snd_pcm_hw_params_t *params )
+{
+#ifdef __ANDROID__
+	format = 5;
+	snd_pcm_hw_params_set_format(handle, params, formats[format].format_id);
+	return 0;
+#else
+	int i;
+	int err;
+
+	for( i=0; i<NUMFORMATS; i++ ) {
+		/* set the sample format */
+		err = snd_pcm_hw_params_set_format(handle, params, formats[i].format_id);
+		if (err == 0) {
+			format = i;
+			return 0;
+		}
+	}
+
+	return err;
+#endif
+}
+
+static int set_hwparams(snd_pcm_t *handle, snd_pcm_hw_params_t *params, snd_pcm_access_t access, int rate, int channels, int period, int nperiods ) {
+	int err, dir=0;
+	unsigned int buffer_time;
+	unsigned int period_time;
+	unsigned int rrate;
+	unsigned int rchannels;
+
+	/* choose all parameters */
+	err = snd_pcm_hw_params_any(handle, params);
+	if (err < 0) {
+		printf("Broken configuration for playback: no configurations available: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* set the interleaved read/write format */
+	err = snd_pcm_hw_params_set_access(handle, params, access);
+	if (err < 0) {
+		printf("Access type not available for playback: %s\n", snd_strerror(err));
+		return err;
+	}
+
+	/* set the sample format */
+	err = set_hwformat(handle, params);
+	if (err < 0) {
+		printf("Sample format not available for playback: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* set the count of channels */
+	rchannels = channels;
+	err = snd_pcm_hw_params_set_channels_near(handle, params, &rchannels);
+	if (err < 0) {
+		printf("Channels count (%i) not available for record: %s\n", channels, snd_strerror(err));
+		return err;
+	}
+	if (rchannels != channels) {
+		printf("WARNING: channel count does not match (requested %d got %d)\n", channels, rchannels);
+		num_channels = rchannels;
+	}
+	/* set the stream rate */
+	rrate = rate;
+	err = snd_pcm_hw_params_set_rate_near(handle, params, &rrate, 0);
+	if (err < 0) {
+		printf("Rate %iHz not available for playback: %s\n", rate, snd_strerror(err));
+		return err;
+	}
+	if (rrate != rate) {
+		printf("Rate doesn't match (requested %iHz, get %iHz)\n", rate, rrate);
+		return -EINVAL;
+	}
+	/* set the buffer time */
+
+	buffer_time = 1000000*(uint64_t)period*nperiods/rate;
+	err = snd_pcm_hw_params_set_buffer_time_near(handle, params, &buffer_time, &dir);
+	if (err < 0) {
+		printf("Unable to set buffer time %i for playback: %s\n",  1000000*period*nperiods/rate, snd_strerror(err));
+		return err;
+	}
+	err = snd_pcm_hw_params_get_buffer_size( params, &real_buffer_size );
+	if (err < 0) {
+		printf("Unable to get buffer size back: %s\n", snd_strerror(err));
+		return err;
+	}
+	if( real_buffer_size != nperiods * period ) {
+	    printf( "WARNING: buffer size does not match: (requested %d, got %d)\n", nperiods * period, (int) real_buffer_size );
+	}
+	/* set the period time */
+	period_time = 1000000*(uint64_t)period/rate;
+	err = snd_pcm_hw_params_set_period_time_near(handle, params, &period_time, &dir);
+	if (err < 0) {
+		printf("Unable to set period time %i for playback: %s\n", 1000000*period/rate, snd_strerror(err));
+		return err;
+	}
+	err = snd_pcm_hw_params_get_period_size(params, &real_period_size, NULL );
+	if (err < 0) {
+		printf("Unable to get period size back: %s\n", snd_strerror(err));
+		return err;
+	}
+	if( real_period_size != period ) {
+	    printf( "WARNING: period size does not match: (requested %i, got %i)\n", period, (int)real_period_size );
+	}
+	/* write the parameters to device */
+	err = snd_pcm_hw_params(handle, params);
+	if (err < 0) {
+		printf("Unable to set hw params for playback: %s\n", snd_strerror(err));
+		return err;
+	}
+	return 0;
+}
+
+static int set_swparams(snd_pcm_t *handle, snd_pcm_sw_params_t *swparams, int period, int nperiods) {
+	int err;
+
+	/* get the current swparams */
+	err = snd_pcm_sw_params_current(handle, swparams);
+	if (err < 0) {
+		printf("Unable to determine current swparams for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* start the transfer when the buffer is full */
+	err = snd_pcm_sw_params_set_start_threshold(handle, swparams, period );
+	if (err < 0) {
+		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	err = snd_pcm_sw_params_set_stop_threshold(handle, swparams, -1 );
+	if (err < 0) {
+		printf("Unable to set start threshold mode for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* allow the transfer when at least period_size samples can be processed */
+	err = snd_pcm_sw_params_set_avail_min(handle, swparams, 1 );
+	if (err < 0) {
+		printf("Unable to set avail min for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* align all transfers to 1 sample */
+	err = snd_pcm_sw_params_set_xfer_align(handle, swparams, 1);
+	if (err < 0) {
+		printf("Unable to set transfer align for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	/* write the parameters to the playback device */
+	err = snd_pcm_sw_params(handle, swparams);
+	if (err < 0) {
+		printf("Unable to set sw params for capture: %s\n", snd_strerror(err));
+		return err;
+	}
+	return 0;
+}
+
+// ok... i only need this function to communicate with the alsa bloat api...
+
+static snd_pcm_t *open_audiofd( char *device_name, int capture, int rate, int channels, int period, int nperiods ) {
+  int err;
+  snd_pcm_t *handle;
+  snd_pcm_hw_params_t *hwparams;
+  snd_pcm_sw_params_t *swparams;
+
+  snd_pcm_hw_params_alloca(&hwparams);
+  snd_pcm_sw_params_alloca(&swparams);
+
+  if ((err = snd_pcm_open(&(handle), device_name, capture ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK )) < 0) {
+      printf("Capture open error: %s\n", snd_strerror(err));
+      return NULL;
+  }
+
+  if ((err = set_hwparams(handle, hwparams,SND_PCM_ACCESS_RW_INTERLEAVED, rate, channels, period, nperiods )) < 0) {
+      printf("Setting of hwparams failed: %s\n", snd_strerror(err));
+      return NULL;
+  }
+  if ((err = set_swparams(handle, swparams, period, nperiods)) < 0) {
+      printf("Setting of swparams failed: %s\n", snd_strerror(err));
+      return NULL;
+  }
+
+  //snd_pcm_start( handle );
+  //snd_pcm_wait( handle, 200 );
+  int num_null_samples = nperiods * period * channels;
+  char *tmp = alloca( num_null_samples * formats[format].sample_size ); 
+  memset( tmp, 0, num_null_samples * formats[format].sample_size );
+  snd_pcm_writei( handle, tmp, num_null_samples );
+  
+
+  return handle;
+}
+
+double hann( double x )
+{
+	return 0.5 * (1.0 - cos( 2*M_PI * x ) );
+}
+
+/**
+ * The freewheel callback.
+ */
+void freewheel (int starting, void* arg) {
+    running_freewheel = starting;
+}
+
+/**
+ * The process callback for this JACK application.
+ * It is called by JACK at the appropriate times.
+ */
+int process (jack_nframes_t nframes, void *arg) {
+
+    if (running_freewheel) {
+	JSList *node = playback_ports;
+
+	while ( node != NULL)
+	{
+	    jack_port_t *port = (jack_port_t *) node->data;
+	    float *buf = jack_port_get_buffer (port, nframes);
+
+	    memset(buf, 0, sizeof(float)*nframes);
+
+	    node = jack_slist_next (node);
+	}
+
+	return 0;
+    }
+
+    int rlen;
+    int err;
+    snd_pcm_sframes_t delay = target_delay;
+    int i;
+
+    delay = (num_periods*period_size)-snd_pcm_avail( alsa_handle ) ;
+
+    delay -= round( jack_frames_since_cycle_start( client ) * static_resample_factor );
+    // Do it the hard way.
+    // this is for compensating xruns etc...
+
+    if( delay > (target_delay+max_diff) ) {
+	snd_pcm_rewind( alsa_handle, delay - target_delay );
+	output_new_delay = (int) delay;
+
+	delay = target_delay;
+
+	// Set the resample_rate... we need to adjust the offset integral, to do this.
+	// first look at the PI controller, this code is just a special case, which should never execute once
+	// everything is swung in. 
+	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
+	// Also clear the array. we are beginning a new control cycle.
+	for( i=0; i<smooth_size; i++ )
+		offset_array[i] = 0.0;
+    }
+    if( delay < (target_delay-max_diff) ) {
+
+	output_new_delay = (int) delay;
+
+	while ((target_delay-delay) > 0) {
+	    snd_pcm_uframes_t to_write = ((target_delay-delay) > 512) ? 512 : (target_delay-delay);
+	    snd_pcm_writei( alsa_handle, tmpbuf, to_write );
+	    delay += to_write;
+	}
+
+	delay = target_delay;
+
+	// Set the resample_rate... we need to adjust the offset integral, to do this.
+	offset_integral = - (resample_mean - static_resample_factor) * catch_factor * catch_factor2;
+	// Also clear the array. we are beginning a new control cycle.
+	for( i=0; i<smooth_size; i++ )
+		offset_array[i] = 0.0;
+    }
+    /* ok... now we should have target_delay +- max_diff on the alsa side.
+     *
+     * calculate the number of frames, we want to get.
+     */
+
+    double offset = delay - target_delay;
+
+    // Save offset.
+    offset_array[(offset_differential_index++)% smooth_size ] = offset;
+
+    // Build the mean of the windowed offset array
+    // basically fir lowpassing.
+    double smooth_offset = 0.0;
+    for( i=0; i<smooth_size; i++ )
+	    smooth_offset +=
+		    offset_array[ (i + offset_differential_index-1) % smooth_size] * window_array[i];
+    smooth_offset /= (double) smooth_size;
+
+    // this is the integral of the smoothed_offset
+    offset_integral += smooth_offset;
+
+    // Clamp offset.
+    // the smooth offset still contains unwanted noise
+    // which would go straight onto the resample coeff.
+    // it only used in the P component and the I component is used for the fine tuning anyways.
+    if( fabs( smooth_offset ) < pclamp )
+	    smooth_offset = 0.0;
+
+    // ok. now this is the PI controller. 
+    // u(t) = K * ( e(t) + 1/T \int e(t') dt' )
+    // K = 1/catch_factor and T = catch_factor2
+    double current_resample_factor = static_resample_factor - smooth_offset / (double) catch_factor - offset_integral / (double) catch_factor / (double)catch_factor2;
+
+    // now quantize this value around resample_mean, so that the noise which is in the integral component doesn't hurt.
+    current_resample_factor = floor( (current_resample_factor - resample_mean) * controlquant + 0.5 ) / controlquant + resample_mean;
+
+    // Output "instrumentatio" gonna change that to real instrumentation in a few.
+    output_resampling_factor = (float) current_resample_factor;
+    output_diff = (float) smooth_offset;
+    output_integral = (float) offset_integral;
+    output_offset = (float) offset;
+
+    // Clamp a bit.
+    if( current_resample_factor < resample_lower_limit ) current_resample_factor = resample_lower_limit;
+    if( current_resample_factor > resample_upper_limit ) current_resample_factor = resample_upper_limit;
+
+    // Now Calculate how many samples we need.
+    rlen = ceil( ((double)nframes) * current_resample_factor )+2;
+    assert( rlen > 2 );
+
+    // Calculate resample_mean so we can init ourselves to saner values.
+    resample_mean = 0.9999 * resample_mean + 0.0001 * current_resample_factor;
+    /*
+     * now this should do it...
+     */
+
+    outbuf = alloca( rlen * formats[format].sample_size * num_channels );
+
+    resampbuf = alloca( rlen * sizeof( float ) );
+    /*
+     * render jack ports to the outbuf...
+     */
+
+    int chn = 0;
+    JSList *node = playback_ports;
+    JSList *src_node = playback_srcs;
+    SRC_DATA src;
+
+    while ( node != NULL)
+    {
+	jack_port_t *port = (jack_port_t *) node->data;
+	float *buf = jack_port_get_buffer (port, nframes);
+
+	SRC_STATE *src_state = src_node->data;
+
+	src.data_in = buf;
+	src.input_frames = nframes;
+
+	src.data_out = resampbuf;
+	src.output_frames = rlen;
+	src.end_of_input = 0;
+
+	src.src_ratio = current_resample_factor;
+
+	src_process( src_state, &src );
+
+	formats[format].jack_to_soundcard( outbuf + format[formats].sample_size * chn, resampbuf, src.output_frames_gen, num_channels*format[formats].sample_size, NULL);
+
+	src_node = jack_slist_next (src_node);
+	node = jack_slist_next (node);
+	chn++;
+    }
+
+    // now write the output...
+again:
+  err = snd_pcm_writei(alsa_handle, outbuf, src.output_frames_gen);
+  //err = snd_pcm_writei(alsa_handle, outbuf, src.output_frames_gen);
+  if( err < 0 ) {
+      printf( "err = %d\n", err );
+      if (xrun_recovery(alsa_handle, err) < 0) {
+	  printf("Write error: %s\n", snd_strerror(err));
+	  exit(EXIT_FAILURE);
+      }
+      goto again;
+  }
+
+    return 0;      
+}
+
+/**
+ * the latency callback.
+ * sets up the latencies on the ports.
+ */
+
+void
+latency_cb (jack_latency_callback_mode_t mode, void *arg)
+{
+	jack_latency_range_t range;
+	JSList *node;
+
+	range.min = range.max = round(target_delay / static_resample_factor);
+
+	if (mode == JackCaptureLatency) {
+		for (node = capture_ports; node; node = jack_slist_next (node)) {
+			jack_port_t *port = node->data;
+			jack_port_set_latency_range (port, mode, &range);
+		}
+	} else {
+		for (node = playback_ports; node; node = jack_slist_next (node)) {
+			jack_port_t *port = node->data;
+			jack_port_set_latency_range (port, mode, &range);
+		}
+	}
+}
+
+
+/**
+ * Allocate the necessary jack ports...
+ */
+
+void alloc_ports( int n_capture, int n_playback ) {
+
+    int port_flags = JackPortIsOutput | JackPortIsPhysical | JackPortIsTerminal;
+    int chn;
+    jack_port_t *port;
+    char buf[32];
+
+    capture_ports = NULL;
+    for (chn = 0; chn < n_capture; chn++)
+    {
+	snprintf (buf, sizeof(buf) - 1, "capture_%u", chn+1);
+
+	port = jack_port_register (client, buf,
+		JACK_DEFAULT_AUDIO_TYPE,
+		port_flags, 0);
+
+	if (!port)
+	{
+	    printf( "jacknet_client: cannot register port for %s", buf);
+	    break;
+	}
+
+	capture_srcs = jack_slist_append( capture_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
+	capture_ports = jack_slist_append (capture_ports, port);
+    }
+
+    port_flags = JackPortIsInput;
+
+    playback_ports = NULL;
+    for (chn = 0; chn < n_playback; chn++)
+    {
+	snprintf (buf, sizeof(buf) - 1, "playback_%u", chn+1);
+
+	port = jack_port_register (client, buf,
+		JACK_DEFAULT_AUDIO_TYPE,
+		port_flags, 0);
+
+	if (!port)
+	{
+	    printf( "jacknet_client: cannot register port for %s", buf);
+	    break;
+	}
+
+	playback_srcs = jack_slist_append( playback_srcs, src_new( 4-samplerate_quality, 1, NULL ) );
+	playback_ports = jack_slist_append (playback_ports, port);
+    }
+}
+
+/**
+ * This is the shutdown callback for this JACK application.
+ * It is called by JACK if the server ever shuts down or
+ * decides to disconnect the client.
+ */
+
+void jack_shutdown (void *arg) {
+
+	exit (1);
+}
+
+/**
+ * be user friendly.
+ * be user friendly.
+ * be user friendly.
+ */
+
+void printUsage() {
+fprintf(stderr, "usage: alsa_out [options]\n"
+		"\n"
+		"  -j <jack name> - client name\n"
+		"  -d <alsa_device> \n"
+		"  -c <channels> \n"
+		"  -p <period_size> \n"
+		"  -n <num_period> \n"
+		"  -r <sample_rate> \n"
+		"  -q <sample_rate quality [0..4]\n"
+		"  -m <max_diff> \n"
+		"  -t <target_delay> \n"
+		"  -i  turns on instrumentation\n"
+		"  -v  turns on printouts\n"
+		"\n");
+}
+
+
+/**
+ * the main function....
+ */
+
+void
+sigterm_handler( int signal )
+{
+	quit = 1;
+}
+
+
+int main (int argc, char *argv[]) {
+    char jack_name[30] = "alsa_out";
+    char alsa_device[30] = "hw:0";
+    int jack_opts = 0;
+    char *server_name = NULL;
+
+    extern char *optarg;
+    extern int optind, optopt;
+    int errflg=0;
+    int c;
+
+    while ((c = getopt(argc, argv, "ivj:r:c:p:n:d:q:m:t:f:F:C:Q:s:S:")) != -1) {
+	switch(c) {
+	    case 'j':
+		strcpy(jack_name,optarg);
+		break;
+	    case 'r':
+		sample_rate = atoi(optarg);
+		break;
+	    case 'c':
+		num_channels = atoi(optarg);
+		break;
+	    case 'p':
+		period_size = atoi(optarg);
+		break;
+	    case 'n':
+		num_periods = atoi(optarg);
+		break;
+	    case 'd':
+		strcpy(alsa_device,optarg);
+		break;
+	    case 't':
+		target_delay = atoi(optarg);
+		break;
+	    case 'q':
+		samplerate_quality = atoi(optarg);
+		break;
+	    case 'm':
+		max_diff = atoi(optarg);
+		break;
+	    case 'f':
+		catch_factor = atoi(optarg);
+		break;
+	    case 'F':
+		catch_factor2 = atoi(optarg);
+		break;
+	    case 'C':
+		pclamp = (double) atoi(optarg);
+		break;
+	    case 'Q':
+		controlquant = (double) atoi(optarg);
+		break;
+	    case 'v':
+		verbose = 1;
+		break;
+	    case 'i':
+		instrument = 1;
+		break;
+	    case 's':
+		smooth_size = atoi(optarg);
+		break;
+	    case 'S':
+		server_name = optarg;
+		jack_opts |= JackServerName;
+		break;
+	    case ':':
+		fprintf(stderr,
+			"Option -%c requires an operand\n", optopt);
+		errflg++;
+		break;
+	    case '?':
+		fprintf(stderr,
+			"Unrecognized option: -%c\n", optopt);
+		errflg++;
+	}
+    }
+    if (errflg) {
+	printUsage();
+	exit(2);
+    }
+
+    if( (samplerate_quality < 0) || (samplerate_quality > 4) ) {
+	fprintf (stderr, "invalid samplerate quality\n");
+	return 1;
+    }
+    if ((client = jack_client_open (jack_name, jack_opts, NULL, server_name)) == 0) {
+	fprintf (stderr, "jack server not running?\n");
+	return 1;
+    }
+
+    /* tell the JACK server to call `process()' whenever
+       there is work to be done.
+       */
+
+    jack_set_process_callback (client, process, 0);
+
+    /* tell the JACK server to call `freewheel()' whenever
+       freewheel mode changes.
+       */
+
+    jack_set_freewheel_callback (client, freewheel, 0);
+
+    /* tell the JACK server to call `jack_shutdown()' if
+       it ever shuts down, either entirely, or if it
+       just decides to stop calling us.
+       */
+
+    jack_on_shutdown (client, jack_shutdown, 0);
+
+    if (jack_set_latency_callback)
+	    jack_set_latency_callback (client, latency_cb, 0);
+
+    // get jack sample_rate
+    
+    jack_sample_rate = jack_get_sample_rate( client );
+
+    if( !sample_rate )
+	sample_rate = jack_sample_rate;
+
+    static_resample_factor =  (double) sample_rate / (double) jack_sample_rate;
+    resample_lower_limit = static_resample_factor * 0.25;
+    resample_upper_limit = static_resample_factor * 4.0;
+    resample_mean = static_resample_factor;
+
+    offset_array = malloc( sizeof(double) * smooth_size );
+    if( offset_array == NULL ) {
+	    fprintf( stderr, "no memory for offset_array !!!\n" );
+	    exit(20);
+    }
+    window_array = malloc( sizeof(double) * smooth_size );
+    if( window_array == NULL ) {
+	    fprintf( stderr, "no memory for window_array !!!\n" );
+	    exit(20);
+    }
+    int i;
+    for( i=0; i<smooth_size; i++ ) {
+	    offset_array[i] = 0.0;
+	    window_array[i] = hann( (double) i / ((double) smooth_size - 1.0) );
+    }
+
+    jack_buffer_size = jack_get_buffer_size( client );
+    // Setup target delay and max_diff for the normal user, who does not play with them...
+    if( !target_delay ) 
+	target_delay = (num_periods*period_size / 2) - jack_buffer_size/2;
+
+    if( !max_diff )
+	max_diff = target_delay;	
+
+    if( max_diff > target_delay ) {
+	    fprintf( stderr, "target_delay (%d) can not be smaller than max_diff(%d)\n", target_delay, max_diff );
+	    exit(20);
+    }
+    if( (target_delay+max_diff) > (num_periods*period_size) ) {
+	    fprintf( stderr, "target_delay+max_diff (%d) can not be bigger than buffersize(%d)\n", target_delay+max_diff, num_periods*period_size );
+	    exit(20);
+    }
+    // now open the alsa fd...
+    alsa_handle = open_audiofd( alsa_device, 0, sample_rate, num_channels, period_size, num_periods);
+    if( alsa_handle == 0 )
+	exit(20);
+
+    printf( "selected sample format: %s\n", formats[format].name );
+
+    // alloc input ports, which are blasted out to alsa...
+    alloc_ports( 0, num_channels );
+
+    outbuf = malloc( num_periods * period_size * formats[format].sample_size * num_channels );
+    resampbuf = malloc( num_periods * period_size * sizeof( float ) );
+    tmpbuf = malloc( 512 * formats[format].sample_size * num_channels );
+
+    if ((outbuf == NULL) || (resampbuf == NULL) || (tmpbuf == NULL))
+    {
+	    fprintf( stderr, "no memory for buffers.\n" );
+	    exit(20);
+    }
+
+
+    /* tell the JACK server that we are ready to roll */
+
+    if (jack_activate (client)) {
+	fprintf (stderr, "cannot activate client");
+	return 1;
+    }
+
+    signal( SIGTERM, sigterm_handler );
+    signal( SIGINT, sigterm_handler );
+
+    if( verbose ) {
+	    while(!quit) {
+		    usleep(500000);
+		    if( output_new_delay ) {
+			    printf( "delay = %d\n", output_new_delay );
+			    output_new_delay = 0;
+		    }
+		    printf( "res: %f, \tdiff = %f, \toffset = %f \n", output_resampling_factor, output_diff, output_offset );
+	    }
+    } else if( instrument ) {
+	    printf( "# n\tresamp\tdiff\toffseti\tintegral\n");
+	    int n=0;
+	    while(!quit) {
+		    usleep(1000);
+		    printf( "%d\t%f\t%f\t%f\t%f\n", n++, output_resampling_factor, output_diff, output_offset, output_integral );
+	    }
+    } else {
+	    while(!quit)
+	    {
+		    usleep(500000);
+		    if( output_new_delay ) {
+			    printf( "delay = %d\n", output_new_delay );
+			    output_new_delay = 0;
+		    }
+	    }
+    }
+
+    jack_deactivate( client );
+    jack_client_close (client);
+    exit (0);
+}
diff -pruN 1.9.14~dfsg-1/tools/bufsize.c 1.9.16~dfsg-1/tools/bufsize.c
--- 1.9.14~dfsg-1/tools/bufsize.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/bufsize.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,124 @@
+/*
+ *  bufsize.c -- change JACK buffer size.
+ *
+ *  Copyright (C) 2003 Jack O'Quin.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#include <jack/jack.h>
+#include <jack/transport.h>
+
+char *package;				/* program name */
+jack_client_t *client;
+jack_nframes_t nframes;
+int just_print_bufsize=0;
+
+void jack_shutdown(void *arg)
+{
+	fprintf(stderr, "JACK shut down, exiting ...\n");
+	exit(1);
+}
+
+void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+void parse_arguments(int argc, char *argv[])
+{
+	/* basename $0 */
+	package = strrchr(argv[0], '/');
+	if (package == 0)
+		package = argv[0];
+	else
+		package++;
+
+	if (argc==1) {
+		just_print_bufsize = 1;
+		return;
+	}
+	if (argc < 2) {
+		fprintf(stderr, "usage: %s <bufsize>\n", package);
+		exit(9);
+	}
+
+	if (strspn (argv[1], "0123456789") != strlen (argv[1])) {
+		fprintf(stderr, "usage: %s <bufsize>\n", package);
+		exit(8);
+	}
+
+	nframes = strtoul(argv[1], NULL, 0);
+	if (errno == ERANGE) {
+		fprintf(stderr, "%s: invalid buffer size: %s (range is 1-16384)\n",
+			package, argv[1]);
+		exit(2);
+	}
+	if (nframes < 1 || nframes > 16384) {
+		fprintf(stderr, "%s: invalid buffer size: %s (range is 1-16384)\n",
+			package, argv[1]);
+		exit(3);
+	}
+}
+
+void silent_function( const char *ignore )
+{
+}
+
+int main(int argc, char *argv[])
+{
+	int rc;
+	parse_arguments(argc, argv);
+
+	if (just_print_bufsize)
+		jack_set_info_function( silent_function );
+
+	/* become a JACK client */
+	if ((client = jack_client_open(package, JackNoStartServer, NULL)) == 0) {
+		fprintf(stderr, "JACK server not running?\n");
+		exit(1);
+	}
+
+#ifndef WIN32
+	signal(SIGQUIT, signal_handler);
+	signal(SIGHUP, signal_handler);
+#endif
+	signal(SIGTERM, signal_handler);
+	signal(SIGINT, signal_handler);
+
+	jack_on_shutdown(client, jack_shutdown, 0);
+
+	if (just_print_bufsize) {
+		fprintf(stdout, "%d\n", jack_get_buffer_size( client ) );
+		rc = 0;
+	}
+	else
+	{
+		rc = jack_set_buffer_size(client, nframes);
+		if (rc)
+			fprintf(stderr, "jack_set_buffer_size(): %s\n", strerror(rc));
+	}
+	jack_client_close(client);
+
+	return rc;
+}
diff -pruN 1.9.14~dfsg-1/tools/connect.c 1.9.16~dfsg-1/tools/connect.c
--- 1.9.14~dfsg-1/tools/connect.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/connect.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,248 @@
+/*
+    Copyright (C) 2002 Jeremy Hall
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <stdio.h>
+#include <errno.h>
+#ifndef WIN32
+#include <unistd.h>
+#endif
+#include <string.h>
+#include <stdlib.h>
+#include <getopt.h>
+
+#include <jack/jack.h>
+#include <jack/session.h>
+
+#define TRUE 1
+#define FALSE 0
+
+volatile int done = 0;
+
+void port_connect_callback(jack_port_id_t a, jack_port_id_t b, int connect, void* arg)
+{
+	done = 1;
+}
+
+void
+show_version (char *my_name)
+{
+	//fprintf (stderr, "%s: JACK Audio Connection Kit version " VERSION "\n", my_name);
+}
+
+void
+show_usage (char *my_name)
+{
+	show_version (my_name);
+	fprintf (stderr, "\nusage: %s [options] port1 port2\n", my_name);
+	fprintf (stderr, "Connects two JACK ports together.\n\n");
+	fprintf (stderr, "        -s, --server <name>   Connect to the jack server named <name>\n");
+	fprintf (stderr, "        -v, --version         Output version information and exit\n");
+	fprintf (stderr, "        -h, --help            Display this help message\n\n");
+	fprintf (stderr, "For more information see http://jackaudio.org/\n");
+}
+
+int
+main (int argc, char *argv[])
+{
+	jack_client_t *client;
+	jack_status_t status;
+	char *server_name = NULL;
+	int c;
+	int option_index;
+	jack_options_t options = JackNoStartServer;
+	char *my_name = strrchr(argv[0], '/');
+	jack_port_t *src_port = 0;
+	jack_port_t *dst_port = 0;
+	jack_port_t *port1 = 0;
+	jack_port_t *port2 = 0;
+	char portA[300];
+	char portB[300];
+	int use_uuid=0;
+	int connecting, disconnecting;
+	int port1_flags, port2_flags;
+	int rc = 1;
+
+	struct option long_options[] = {
+		{ "server", 1, 0, 's' },
+		{ "help", 0, 0, 'h' },
+		{ "version", 0, 0, 'v' },
+		{ "uuid", 0, 0, 'u' },
+		{ 0, 0, 0, 0 }
+	};
+
+	while ((c = getopt_long (argc, argv, "s:hvu", long_options, &option_index)) >= 0) {
+		switch (c) {
+		case 's':
+			server_name = (char *) malloc (sizeof (char) * (strlen(optarg) + 1));
+			strcpy (server_name, optarg);
+			options |= JackServerName;
+			break;
+		case 'u':
+			use_uuid = 1;
+			break;
+		case 'h':
+			show_usage (my_name);
+			return 1;
+			break;
+		case 'v':
+			show_version (my_name);
+			return 1;
+			break;
+		default:
+			show_usage (my_name);
+			return 1;
+			break;
+		}
+	}
+
+	connecting = disconnecting = FALSE;
+	if (my_name == 0) {
+		my_name = argv[0];
+	} else {
+		my_name ++;
+	}
+
+	if (strstr(my_name, "disconnect")) {
+		disconnecting = 1;
+	} else if (strstr(my_name, "connect")) {
+		connecting = 1;
+	} else {
+		fprintf(stderr, "ERROR! client should be called jack_connect or jack_disconnect. client is called %s\n", my_name);
+		return 1;
+	}
+
+	if (argc < 3) {
+		show_usage(my_name);
+		return 1;
+	}
+
+	/* try to become a client of the JACK server */
+
+	if ((client = jack_client_open (my_name, options, &status, server_name)) == 0) {
+		fprintf (stderr, "jack server not running?\n");
+		return 1;
+	}
+
+	jack_set_port_connect_callback(client, port_connect_callback, NULL);
+
+	/* find the two ports */
+
+	if( use_uuid ) {
+		char *tmpname;
+		char *clientname;
+		char *portname;
+		tmpname = strdup( argv[argc-1] );
+		portname = strchr( tmpname, ':' );
+		portname[0] = '\0';
+		portname+=1;
+		clientname = jack_get_client_name_by_uuid( client, tmpname );
+		if( clientname ) {
+
+			snprintf( portA, sizeof(portA), "%s:%s", clientname, portname );
+			jack_free( clientname );
+		} else {
+			snprintf( portA, sizeof(portA), "%s", argv[argc-1] );
+		}
+		free( tmpname );
+
+		tmpname = strdup( argv[argc-2] );
+		portname = strchr( tmpname, ':' );
+		portname[0] = '\0';
+		portname+=1;
+		clientname = jack_get_client_name_by_uuid( client, tmpname );
+		if( clientname ) {
+			snprintf( portB, sizeof(portB), "%s:%s", clientname, portname );
+			jack_free( clientname );
+		} else {
+			snprintf( portB, sizeof(portB), "%s", argv[argc-2] );
+		}
+
+		free( tmpname );
+
+	} else {
+		snprintf( portA, sizeof(portA), "%s", argv[argc-1] );
+		snprintf( portB, sizeof(portB), "%s", argv[argc-2] );
+	}
+	if ((port1 = jack_port_by_name(client, portA)) == 0) {
+		fprintf (stderr, "ERROR %s not a valid port\n", portA);
+		goto exit;
+	}
+	if ((port2 = jack_port_by_name(client, portB)) == 0) {
+		fprintf (stderr, "ERROR %s not a valid port\n", portB);
+		goto exit;
+	}
+
+	port1_flags = jack_port_flags (port1);
+	port2_flags = jack_port_flags (port2);
+
+	if (port1_flags & JackPortIsInput) {
+		if (port2_flags & JackPortIsOutput) {
+			src_port = port2;
+			dst_port = port1;
+		}
+	} else {
+		if (port2_flags & JackPortIsInput) {
+			src_port = port1;
+			dst_port = port2;
+		}
+	}
+
+	if (!src_port || !dst_port) {
+		fprintf (stderr, "arguments must include 1 input port and 1 output port\n");
+		goto exit;
+	}
+
+	/* tell the JACK server that we are ready to roll */
+	if (jack_activate (client)) {
+		fprintf (stderr, "cannot activate client");
+		goto exit;
+	}
+
+	/* connect the ports. Note: you can't do this before
+	   the client is activated (this may change in the future).
+	*/
+
+	if (connecting) {
+		if (jack_connect(client, jack_port_name(src_port), jack_port_name(dst_port))) {
+			fprintf (stderr, "cannot connect client, already connected?\n");
+			goto exit;
+		}
+	}
+	if (disconnecting) {
+		if (jack_disconnect(client, jack_port_name(src_port), jack_port_name(dst_port))) {
+			fprintf (stderr, "cannot disconnect client, already disconnected?\n");
+			goto exit;
+		}
+	}
+
+	// Wait for connection/disconnection to be effective
+	while(!done) {
+#ifdef WIN32
+		Sleep(10);
+#else
+		usleep(10000);
+#endif
+	}
+
+	/* everything was ok, so setting exitcode to 0 */
+	rc = 0;
+
+exit:
+	jack_client_close (client);
+	exit (rc);
+}
diff -pruN 1.9.14~dfsg-1/tools/evmon.c 1.9.16~dfsg-1/tools/evmon.c
--- 1.9.14~dfsg-1/tools/evmon.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/evmon.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,164 @@
+/*
+    Copyright (C) 2007 Paul Davis
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <stdio.h>
+#include <errno.h>
+#ifndef WIN32
+#include <unistd.h>
+#endif
+#include <string.h>
+#include <signal.h>
+#include <stdlib.h>
+
+#include <jack/jack.h>
+#include <jack/metadata.h>
+#include <jack/uuid.h>
+
+jack_client_t *client;
+
+static void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+static void
+port_rename_callback (jack_port_id_t port, const char* old_name, const char* new_name, void* arg)
+{
+	printf ("Port %d renamed from %s to %s\n", port, old_name, new_name);
+}
+
+static void
+port_callback (jack_port_id_t port, int yn, void* arg)
+{
+	printf ("Port %d %s\n", port, (yn ? "registered" : "unregistered"));
+}
+
+static void
+connect_callback (jack_port_id_t a, jack_port_id_t b, int yn, void* arg)
+{
+	printf ("Ports %d and %d %s\n", a, b, (yn ? "connected" : "disconnected"));
+}
+
+static void
+client_callback (const char* client, int yn, void* arg)
+{
+	printf ("Client %s %s\n", client, (yn ? "registered" : "unregistered"));
+}
+
+static int
+graph_callback (void* arg)
+{
+	printf ("Graph reordered\n");
+	return 0;
+}
+
+static void
+propchange (jack_uuid_t subject, const char* key, jack_property_change_t change, void* arg)
+{
+        char buf[JACK_UUID_STRING_SIZE];
+        const char* action = "";
+
+        switch (change) {
+        case PropertyCreated:
+                action = "created";
+                break;
+
+        case PropertyChanged:
+                action = "changed";
+                break;
+
+        case PropertyDeleted:
+                action = "deleted";
+                break;
+        }
+
+        if (jack_uuid_empty (subject)) {
+                printf ("All properties changed!\n");
+        } else {
+                jack_uuid_unparse (subject, buf);
+                
+                if (key) {
+                        printf ("key [%s] for %s %s\n", key, buf, action);
+                } else {
+                        printf ("all keys for %s %s\n", buf, action);
+                }
+        }
+}
+
+int
+main (int argc, char *argv[])
+{
+	jack_options_t options = JackNullOption;
+	jack_status_t status;
+
+	if ((client = jack_client_open ("event-monitor", options, &status, NULL)) == 0) {
+		fprintf (stderr, "jack_client_open() failed, "
+			 "status = 0x%2.0x\n", status);
+		if (status & JackServerFailed) {
+			fprintf (stderr, "Unable to connect to JACK server\n");
+		}
+		return 1;
+	}
+	
+	if (jack_set_port_registration_callback (client, port_callback, NULL)) {
+		fprintf (stderr, "cannot set port registration callback\n");
+		return 1;
+	}
+	if (jack_set_port_rename_callback (client, port_rename_callback, NULL)) {
+		fprintf (stderr, "cannot set port registration callback\n");
+		return 1;
+	}
+	if (jack_set_port_connect_callback (client, connect_callback, NULL)) {
+		fprintf (stderr, "cannot set port connect callback\n");
+		return 1;
+	}
+	if (jack_set_client_registration_callback (client, client_callback, NULL)) {
+		fprintf (stderr, "cannot set client registration callback\n");
+		return 1;
+	}
+	if (jack_set_graph_order_callback (client, graph_callback, NULL)) {
+		fprintf (stderr, "cannot set graph order registration callback\n");
+		return 1;
+	}
+	if (jack_set_property_change_callback (client, propchange, NULL)) {
+		fprintf (stderr, "cannot set property change callback\n");
+		return 1;
+	}
+	if (jack_activate (client)) {
+		fprintf (stderr, "cannot activate client");
+		return 1;
+	}
+
+#ifndef WIN32
+	signal(SIGINT, signal_handler);
+	signal(SIGQUIT, signal_handler);
+	signal(SIGHUP, signal_handler);
+#endif
+	signal(SIGABRT, signal_handler);
+	signal(SIGTERM, signal_handler);
+
+#ifdef WIN32
+	Sleep(INFINITE);
+#else
+	sleep (-1);
+#endif
+	exit (0);
+}
+
diff -pruN 1.9.14~dfsg-1/tools/freewheel.c 1.9.16~dfsg-1/tools/freewheel.c
--- 1.9.14~dfsg-1/tools/freewheel.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/freewheel.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ *  freewheel - start/stop JACK "freewheeling" mode
+ *
+ *  Copyright (C) 2003 Paul Davis.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#include <jack/jack.h>
+#include <jack/transport.h>
+
+char *package;				/* program name */
+jack_client_t *client;
+int onoff;
+
+static void jack_shutdown(void *arg)
+{
+	fprintf(stderr, "JACK shut down, exiting ...\n");
+	exit(1);
+}
+
+static void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+static void parse_arguments(int argc, char *argv[])
+{
+	if (argc < 2) {
+		fprintf(stderr, "usage: %s y|n\n", package);
+		exit(9);
+	}
+
+	if (argv[1][0] == 'y' || argv[1][0] == 'Y' || argv[1][0] == '1') {
+		onoff = 1;
+	} else {
+		onoff = 0;
+	}
+}
+
+int
+main (int argc, char *argv[])
+{
+	parse_arguments (argc, argv);
+
+	/* become a JACK client */
+	if ((client = jack_client_open ("freewheel", JackNullOption, NULL)) == 0) {
+		fprintf (stderr, "JACK server not running?\n");
+		exit(1);
+	}
+
+#ifndef WIN32
+	signal (SIGQUIT, signal_handler);
+	signal (SIGHUP, signal_handler);
+#endif
+	signal (SIGTERM, signal_handler);
+	signal (SIGINT, signal_handler);
+
+	jack_on_shutdown (client, jack_shutdown, 0);
+
+	if (jack_set_freewheel (client, onoff)) {
+		fprintf (stderr, "failed to reset freewheel mode\n");
+	}
+
+	jack_client_close(client);
+	return 0;
+}
diff -pruN 1.9.14~dfsg-1/tools/ipload.c 1.9.16~dfsg-1/tools/ipload.c
--- 1.9.14~dfsg-1/tools/ipload.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/ipload.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,246 @@
+/*
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <signal.h>
+#ifndef WIN32
+#include <unistd.h>
+#endif
+#include <getopt.h>
+#include <jack/jack.h>
+#include <jack/intclient.h>
+
+jack_client_t *client;
+jack_intclient_t intclient;
+char *client_name;
+char *intclient_name;
+char *load_name;
+char *load_init = "";
+char *server_name = NULL;
+int autoclose_opt = 0;
+int wait_opt = 0;
+volatile int idling = 1;
+
+static void
+signal_handler (int sig)
+{
+	/* do nothing if internal client closed itself */
+	if (idling == 0)
+		return;
+
+	jack_status_t status;
+
+	fprintf (stderr, "signal received, unloading...");
+	status = jack_internal_client_unload (client, intclient);
+	if (status & JackFailure)
+		fprintf (stderr, "(failed), status = 0x%2.0x\n", status);
+	else
+		fprintf (stderr, "(succeeded)\n");
+	if (autoclose_opt)
+		jack_deactivate(client);
+	jack_client_close (client);
+	exit (0);
+}
+
+static void
+registration_callback (const char *name, int reg, void *arg)
+{
+	if (reg || strcmp(intclient_name, name))
+		return;
+
+	/* this will stop the wait loop and thus close this application. */
+	idling = 0;
+	return;
+
+	/* unused */
+	(void)arg;
+}
+
+static void
+show_usage ()
+{
+	fprintf (stderr, "usage: %s [ options ] client-name [ load-name "
+		 "[ init-string]]\n\noptions:\n", client_name);
+	fprintf (stderr,
+		 "\t-h, --help \t\t print help message\n"
+		 "\t-a, --autoclose\t automatically close when intclient is unloaded\n"
+		 "\t-i, --init string\t initialize string\n"
+		 "\t-s, --server name\t select JACK server\n"
+		 "\t-w, --wait \t\t wait for signal, then unload\n"
+		 "\n"
+		);
+}
+
+static int
+parse_args (int argc, char *argv[])
+{
+	int c;
+	int option_index = 0;
+	char *short_options = "hai:s:w";
+	struct option long_options[] = {
+		{ "help", 0, 0, 'h' },
+		{ "autoclose", 0, 0, 'a' },
+		{ "init", required_argument, 0, 'i' },
+		{ "server", required_argument, 0, 's' },
+		{ "wait", 0, 0, 'w' },
+		{ 0, 0, 0, 0 }
+	};
+
+	client_name = strrchr(argv[0], '/');
+	if (client_name == NULL) {
+		client_name = argv[0];
+	} else {
+		client_name++;
+	}
+
+	while ((c = getopt_long (argc, argv, short_options, long_options,
+				 &option_index)) >= 0) {
+		switch (c) {
+		case 'a':
+			autoclose_opt = 1;
+			break;
+		case 'i':
+			load_init = optarg;
+			break;
+		case 's':
+			server_name = optarg;
+			break;
+		case 'w':
+			wait_opt = 1;
+			break;
+		case 'h':
+		default:
+			show_usage ();
+			return 1;
+		}
+	}
+
+	/* autoclose makes no sense without wait */
+	if (autoclose_opt && ! wait_opt)
+		autoclose_opt = 0;
+
+	if (optind == argc) {		/* no positional args? */
+		show_usage ();
+		return 1;
+	}
+	if (optind < argc)
+		load_name = intclient_name = argv[optind++];
+
+	if (optind < argc)
+		load_name = argv[optind++];
+
+	if (optind < argc)
+		load_init = argv[optind++];
+
+	//fprintf (stderr, "client-name = `%s', load-name = `%s', "
+	//	 "load-init = `%s', wait = %d\n",
+	//	 intclient_name, load_name, load_init, wait_opt);
+
+	return 0;			/* args OK */
+}
+
+int
+main (int argc, char *argv[])
+{
+	jack_status_t status;
+	char* name;
+
+	/* parse and validate command arguments */
+	if (parse_args (argc, argv))
+		exit (1);		/* invalid command line */
+
+	/* first, become a JACK client */
+	client = jack_client_open (client_name, JackServerName,
+				   &status, server_name);
+	if (client == NULL) {
+		fprintf (stderr, "jack_client_open() failed, "
+			 "status = 0x%2.0x\n", status);
+		if (status & JackServerFailed) {
+			fprintf (stderr, "Unable to connect to JACK server\n");
+		}
+		exit (1);
+	}
+	if (status & JackServerStarted) {
+		fprintf (stderr, "JACK server started\n");
+	}
+	if (status & JackNameNotUnique) {
+		client_name = jack_get_client_name(client);
+		fprintf (stderr, "unique name `%s' assigned\n", client_name);
+	}
+
+	/* then, load the internal client */
+	intclient = jack_internal_client_load (client, intclient_name,
+					       (JackLoadName|JackLoadInit),
+					       &status, load_name, load_init);
+	if (status & JackFailure) {
+		fprintf (stderr, "could not load %s, intclient = %d status = 0x%2.0x\n",
+			 load_name, (int)intclient, status);
+		return 2;
+	}
+	if (status & JackNameNotUnique) {
+		intclient_name =
+			jack_get_internal_client_name (client, intclient);
+		fprintf (stderr, "unique internal client name `%s' assigned\n",
+			 intclient_name);
+	}
+
+	fprintf (stdout, "%s is running.\n", load_name);
+
+	name = jack_get_internal_client_name(client, intclient);
+	if (name) {
+		printf("client name = %s\n", name);
+		free(name);
+	}
+	fflush(stdout);
+
+	if (autoclose_opt) {
+		jack_set_client_registration_callback(client, registration_callback, NULL);
+		jack_activate(client);
+	}
+
+	if (wait_opt) {
+		/* define a signal handler to unload the client, then
+		 * wait for it to exit */
+	#ifdef WIN32
+		signal(SIGINT, signal_handler);
+		signal(SIGABRT, signal_handler);
+		signal(SIGTERM, signal_handler);
+	#else
+		signal(SIGQUIT, signal_handler);
+		signal(SIGTERM, signal_handler);
+		signal(SIGHUP, signal_handler);
+		signal(SIGINT, signal_handler);
+	#endif
+
+		while (idling) {
+			#ifdef WIN32
+				Sleep(1000);
+			#else
+				sleep (1);
+			#endif
+		}
+	}
+
+	if (autoclose_opt) {
+		jack_deactivate(client);
+	}
+
+	jack_client_close(client);
+	return 0;
+}
+
diff -pruN 1.9.14~dfsg-1/tools/ipunload.c 1.9.16~dfsg-1/tools/ipunload.c
--- 1.9.14~dfsg-1/tools/ipunload.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/ipunload.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,93 @@
+/*
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <string.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <jack/jack.h>
+#include <jack/intclient.h>
+
+int
+main (int argc, char *argv[])
+{
+	char *my_name;
+	char *client_name;
+	jack_client_t *client;
+	jack_status_t status;
+	jack_intclient_t intclient;
+
+	/* validate args */
+	if ((argc < 2) || (argc > 3)) {
+		fprintf (stderr, "usage: %s client-name [ server-name ]]\n",
+			 argv[0]);
+		return 1;
+	}
+
+	/* use `basename $0` for my own client name */
+	my_name = strrchr(argv[0], '/');
+	if (my_name == 0) {
+		my_name = argv[0];
+	} else {
+		my_name++;
+	}
+
+	/* first, become a JACK client */
+	if (argc > 2) {
+		client = jack_client_open (my_name,
+					   (JackServerName|JackNoStartServer),
+					   &status, argv[2]);
+	} else {
+		client = jack_client_open (my_name, JackNoStartServer, &status);
+	}
+
+	if (client == NULL) {
+		if (status & JackServerFailed) {
+			fprintf (stderr, "JACK server not running.\n");
+		} else {
+			fprintf (stderr, "JACK open failed, "
+				 "status = 0x%2.0x\n", status);
+		}
+		exit (1);
+	}
+
+	/* then, get the internal client handle */
+	client_name = argv[1];
+	intclient = jack_internal_client_handle (client, client_name, &status);
+	if (status & JackFailure) {
+		fprintf (stderr, "client %s not found.\n", client_name);
+		exit (2);
+	}
+
+	/* now, unload the internal client */
+	status = jack_internal_client_unload (client, intclient);
+	if (status & JackFailure) {
+		if (status & JackNoSuchClient) {
+			fprintf (stderr, "client %s is gone.\n",
+				 client_name);
+		} else {
+			fprintf (stderr, "could not unload %s, "
+				 "returns 0x%2.0x\n", client_name, status);
+		}
+		exit (3);
+	} else {
+		fprintf (stdout, "%s unloaded.\n", client_name);
+	}
+
+    jack_client_close(client);
+	return 0;
+}
+
+
diff -pruN 1.9.14~dfsg-1/tools/jack_control 1.9.16~dfsg-1/tools/jack_control
--- 1.9.14~dfsg-1/tools/jack_control	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/jack_control	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,403 @@
+#!/usr/bin/python3
+
+from __future__ import print_function
+name_base = 'org.jackaudio'
+control_interface_name = name_base + '.JackControl'
+configure_interface_name = name_base + '.Configure'
+service_name = name_base + '.service'
+
+import sys
+import os
+from traceback import print_exc
+
+import dbus
+
+def bool_convert(str_value):
+    if str_value.lower() == "false":
+        return False
+
+    if str_value.lower() == "off":
+        return False
+
+    if str_value.lower() == "no":
+        return False
+
+    if str_value == "0":
+        return False
+
+    if str_value.lower() == "(null)":
+        return False
+
+    return bool(str_value)
+
+def dbus_type_to_python_type(dbus_value):
+    if type(dbus_value) == dbus.Boolean:
+        return bool(dbus_value)
+    if type(dbus_value) == dbus.Int32 or type(dbus_value) == dbus.UInt32:
+        return int(dbus_value)
+    return dbus_value
+
+def python_type_to_jackdbus_type(value, type_char):
+    type_char = str(type_char)
+
+    if type_char == "b":
+        return bool_convert(value);
+    elif type_char == "y":
+        return dbus.Byte(ord(value));
+    elif type_char == "i":
+        return dbus.Int32(value)
+    elif type_char == "u":
+        return dbus.UInt32(value)
+
+    return value
+
+def dbus_type_to_type_string(dbus_value):
+    if type(dbus_value) == dbus.Boolean:
+        return "bool"
+    if type(dbus_value) == dbus.Int32:
+        return "sint"
+    if type(dbus_value) == dbus.UInt32:
+        return "uint"
+    if type(dbus_value) == dbus.Byte:
+        return "char"
+    if type(dbus_value) == dbus.String:
+        return "str"
+
+    return None                         # throw exception here?
+
+def dbus_typesig_to_type_string(type_char):
+    type_char = str(type_char)
+    if type_char == 'i':
+        return "sint"
+    if type_char == 'u':
+        return "uint"
+    if type_char == 'y':
+        return "char"
+    if type_char == 's':
+        return "str"
+    if type_char == 'b':
+        return "bool"
+
+    print('shit')
+    return None                         # throw exception here?
+
+def get_parameters(iface, path):
+    params = iface.GetParametersInfo(path)
+
+    #print params
+    for param in params:
+        typestr = dbus_typesig_to_type_string(param[0])
+        name = param[1]
+        #print name
+        descr = param[2]
+        #print descr
+        isset, default, value = iface.GetParameterValue(path + [name])
+        #print typestr
+        if bool(isset):
+            isset = "set"
+        else:
+            isset = "notset"
+        value = dbus_type_to_python_type(value)
+        default = dbus_type_to_python_type(default)
+
+        print("%20s: %s (%s:%s:%s:%s)" %(name, descr, typestr, isset, default, value))
+
+def print_help():
+    print("Usage: %s [command] [command] ..." % os.path.basename(sys.argv[0]))
+    print("Commands:")
+    print("    exit                       - exit jack dbus service (stops jack server if currently running)")
+    print("    help                       - print this help text")
+    print("    status                     - check whether jack server is started, return value is 0 if running and 1 otherwise")
+    print("    start                      - start jack server if not currently started")
+    print("    stop                       - stop jack server if currently started")
+    print("    sm                         - switch master to currently selected driver")
+    print("    dl                         - get list of available drivers")
+    print("    dg                         - get currently selected driver")
+    print("    ds <driver>                - select driver")
+    print("    dp                         - get parameters of currently selected driver")
+    print("    dpd <param>                - get long description for driver parameter")
+    print("    dps <param> <value>        - set driver parameter")
+    print("    dpr <param>                - reset driver parameter to its default value")
+    print("    asd <driver>               - add slave driver")
+    print("    rsd <driver>               - remove slave driver")
+    print("    il                         - get list of available internals")
+    print("    ip <name>                  - get parameters of given internal")
+    print("    ipd <name> <param>         - get long description for internal parameter")
+    print("    ips <name> <param> <value> - set internal parameter")
+    print("    ipr <name> <param>         - reset internal parameter to its default value")
+    print("    iload <name>               - load internal")
+    print("    iunload <name>             - unload internal")
+    print("    ep                         - get engine parameters")
+    print("    epd <param>                - get long description for engine parameter")
+    print("    eps <param> <value>        - set engine parameter")
+    print("    epr <param>                - reset engine parameter to its default value")
+
+def maybe_print_param_constraint(iface, param):
+    is_range, is_strict, is_fake, values = iface.GetParameterConstraint(param)
+    if is_range:
+        print()
+        print(("allowed range: %s to %s (inclusive)" % (values[0][0], values[1][0])))
+    elif len(values):
+        print()
+        if is_strict:
+            print("allowed values:")
+        else:
+            print("suggested values:")
+
+        max_len = 0
+        for value in values:
+            if len(str(value[0])) > max_len:
+                   max_len = len(str(value[0]))
+        for value in values:
+            print(("%*s'%s' - %s" % (1 + max_len - len(str(value[0])), "", str(value[0]), str(value[1]))))
+
+def main():
+    if len(sys.argv) == 1 or sys.argv[1] in ["-h", "--help", "help"]:
+        print_help()
+        return 0
+
+    bus = dbus.SessionBus()
+
+    controller = bus.get_object(service_name, "/org/jackaudio/Controller")
+    control_iface = dbus.Interface(controller, control_interface_name)
+    configure_iface = dbus.Interface(controller, configure_interface_name)
+
+    # check arguments
+    index = 1
+    while index < len(sys.argv):
+        arg = sys.argv[index]
+        index += 1
+        try:
+            if arg == "exit":
+                print("--- exit")
+                control_iface.Exit()
+            elif arg == "status":
+                print("--- status")
+                if control_iface.IsStarted():
+                    print("started")
+                    return 0
+                else:
+                    print("stopped")
+                    return 1
+            elif arg == 'start':
+                print("--- start")
+                control_iface.StartServer()
+            elif arg == 'stop':
+                print("--- stop")
+                control_iface.StopServer()
+            elif arg == 'sm':
+                print("--- switch master driver")
+                control_iface.SwitchMaster()
+            elif arg == 'ism':
+                if control_iface.IsManuallyActivated():
+                    print("Manually activated")
+                else:
+                    print("Automatically activated")
+            elif arg == 'dl':
+                print("--- drivers list")
+                is_range, is_strict, is_fake_values, values = configure_iface.GetParameterConstraint(['engine', 'driver'])
+                for value in values:
+                    print(value[1])
+            elif arg == 'dg':
+                print("--- get selected driver")
+                isset, default, value = configure_iface.GetParameterValue(['engine', 'driver'])
+                print(value)
+            elif arg == 'ds':
+                if index >= len(sys.argv):
+                    print("driver select command requires driver name argument")
+                    return 1
+
+                arg = sys.argv[index]
+                index += 1
+
+                print("--- driver select \"%s\"" % arg)
+                configure_iface.SetParameterValue(['engine', 'driver'], dbus.String(arg))
+            elif arg == 'dp':
+                print("--- get driver parameters (type:isset:default:value)")
+                get_parameters(configure_iface, ['driver'])
+            elif arg == 'dpd':
+                if index >= len(sys.argv):
+                    print("get driver parameter long description command requires parameter name argument")
+                    return 1
+
+                param = sys.argv[index]
+                index += 1
+
+                print("--- get driver parameter description (%s)" % param)
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['driver', param])
+                print(long_descr)
+                maybe_print_param_constraint(configure_iface, ['driver', param])
+            elif arg == 'dps':
+                if index + 1 >= len(sys.argv):
+                    print("driver parameter set command requires parameter name and value arguments")
+                    return 1
+
+                param = sys.argv[index]
+                index += 1
+                value = sys.argv[index]
+                index += 1
+
+                print("--- driver param set \"%s\" -> \"%s\"" % (param, value))
+
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['driver', param])
+                configure_iface.SetParameterValue(['driver', param], python_type_to_jackdbus_type(value, type_char))
+            elif arg == 'dpr':
+                if index >= len(sys.argv):
+                    print("driver parameter reset command requires parameter name argument")
+                    return 1
+
+                param = sys.argv[index]
+                index += 1
+
+                print("--- driver param reset \"%s\"" % param)
+                configure_iface.ResetParameterValue(['driver', param])
+            elif arg == 'ep':
+                print("--- get engine parameters (type:isset:default:value)")
+                get_parameters(configure_iface, ['engine'])
+            elif arg == 'epd':
+                if index >= len(sys.argv):
+                    print("get engine parameter long description command requires parameter name argument")
+                    return 1
+
+                param_name = sys.argv[index]
+                index += 1
+
+                print("--- get engine parameter description (%s)" % param_name)
+
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['engine', param_name])
+                print(long_descr)
+                maybe_print_param_constraint(configure_iface, ['engine', param_name])
+            elif arg == 'eps':
+                if index + 1 >= len(sys.argv):
+                    print("engine parameter set command requires parameter name and value arguments")
+                    return 1
+
+                param = sys.argv[index]
+                index += 1
+                value = sys.argv[index]
+                index += 1
+
+                print("--- engine param set \"%s\" -> \"%s\"" % (param, value))
+
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['engine', param])
+                configure_iface.SetParameterValue(['engine', param], python_type_to_jackdbus_type(value, type_char))
+            elif arg == 'epr':
+                if index >= len(sys.argv):
+                    print("engine parameter reset command requires parameter name")
+                    return 1
+
+                param = sys.argv[index]
+                index += 1
+
+                print("--- engine param reset \"%s\"" % param)
+
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['engine', param])
+                configure_iface.ResetParameterValue(['engine', param])
+            elif arg == 'il':
+                print("--- internals list")
+                is_leaf, internals = configure_iface.ReadContainer(['internals'])
+                for internal in internals:
+                    print(internal)
+            elif arg == 'ip':
+                print("--- get internal parameters (type:isset:default:value)")
+
+                if index >= len(sys.argv):
+                    print("internal parameters command requires internal name argument")
+                    return 1
+
+                internal_name = sys.argv[index]
+                index += 1
+
+                get_parameters(configure_iface, ['internals', internal_name])
+            elif arg == 'ipd':
+                if index + 1 >= len(sys.argv):
+                    print("get internal parameter long description command requires internal and parameter name arguments")
+                    return 1
+
+                name = sys.argv[index]
+                index += 1
+                param = sys.argv[index]
+                index += 1
+
+                print("--- get internal parameter description (%s)" % param)
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['internals', name, param])
+                print(long_descr)
+            elif arg == 'ips':
+                if index + 2 >= len(sys.argv):
+                    print("internal parameter set command requires internal, parameter name and value arguments")
+                    return 1
+
+                internal_name = sys.argv[index]
+                index += 1
+                param = sys.argv[index]
+                index += 1
+                value = sys.argv[index]
+                index += 1
+
+                print("--- internal param set \"%s\" -> \"%s\"" % (param, value))
+
+                type_char, name, short_descr, long_descr = configure_iface.GetParameterInfo(['internals', internal_name, param])
+                configure_iface.SetParameterValue(['internals', internal_name, param], python_type_to_jackdbus_type(value, type_char))
+            elif arg == 'ipr':
+                if index + 1 >= len(sys.argv):
+                    print("reset internal parameter command requires internal and parameter name arguments")
+                    return 1
+
+                internal_name = sys.argv[index]
+                index += 1
+                param = sys.argv[index]
+                index += 1
+
+                print("--- internal param reset \"%s\"" % param)
+
+                configure_iface.ResetParameterValue(['internals', internal_name, param])
+            elif arg == 'iload':
+                print("--- load internal")
+
+                if index >= len(sys.argv):
+                    print("load internal command requires internal name argument")
+                    return 1
+
+                name = sys.argv[index]
+                index += 1
+                result = control_iface.LoadInternal(name)
+            elif arg == 'iunload':
+                print("--- unload internal")
+
+                if index >= len(sys.argv):
+                    print("unload internal command requires internal name argument")
+                    return 1
+
+                name = sys.argv[index]
+                index += 1
+                result = control_iface.UnloadInternal(name)
+            elif arg == 'asd':
+                print("--- add slave driver")
+
+                if index >= len(sys.argv):
+                    print("add slave driver command requires driver name argument")
+                    return 1
+
+                name = sys.argv[index]
+                index += 1
+                result = control_iface.AddSlaveDriver(name)
+            elif arg == 'rsd':
+                print("--- remove slave driver")
+
+                if index >= len(sys.argv):
+                    print("remove slave driver command requires driver name argument")
+                    return 1
+
+                name = sys.argv[index]
+                index += 1
+                result = control_iface.RemoveSlaveDriver(name)
+            else:
+                print("Unknown command '%s'" % arg)
+        except dbus.DBusException as e:
+            print("DBus exception: %s" % str(e))
+            return 1
+
+        return 0
+
+if __name__ == '__main__':
+    sys.exit(main())
diff -pruN 1.9.14~dfsg-1/tools/lsp.c 1.9.16~dfsg-1/tools/lsp.c
--- 1.9.14~dfsg-1/tools/lsp.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/lsp.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,291 @@
+/*
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <stdio.h>
+#include <stdlib.h>
+#ifndef WIN32
+#include <unistd.h>
+#endif
+#include <string.h>
+#include <getopt.h>
+#include <inttypes.h>
+
+#include <jack/jack.h>
+#include <jack/session.h>
+#include <jack/uuid.h>
+
+char * my_name;
+
+static void
+show_version (void)
+{
+	//fprintf (stderr, "%s: JACK Audio Connection Kit version " VERSION "\n", my_name);
+}
+
+static void
+printf_name2uuid (jack_client_t* client, const char* pname)
+{
+	char *port_component = strchr( pname, ':' );
+	size_t csize = port_component - pname + 1;
+	char client_component[csize];
+	snprintf(client_component, csize, "%s", pname);
+
+	char *uuid = jack_get_uuid_for_client_name(client, client_component);
+	if (uuid) {
+		printf("%s%s\n", uuid, port_component );
+	} else {
+		printf("%s\n",pname);
+	}
+	jack_free(uuid);
+}
+
+static void
+show_usage (void)
+{
+	show_version ();
+	fprintf (stderr, "\nUsage: %s [options] [filter string]\n", my_name);
+	fprintf (stderr, "List active Jack ports, and optionally display extra information.\n");
+	fprintf (stderr, "Optionally filter ports which match ALL strings provided after any options.\n\n");
+	fprintf (stderr, "Display options:\n");
+	fprintf (stderr, "        -s, --server <name>   Connect to the jack server named <name>\n");
+	fprintf (stderr, "        -A, --aliases         List aliases for each port\n");
+	fprintf (stderr, "        -c, --connections     List connections to/from each port\n");
+	fprintf (stderr, "        -l, --port-latency    Display per-port latency in frames at each port\n");
+	fprintf (stderr, "        -L, --total-latency   Display total latency in frames at each port\n");
+	fprintf (stderr, "        -p, --properties      Display port properties. Output may include:\n"
+			 "                              input|output, can-monitor, physical, terminal\n\n");
+	fprintf (stderr, "        -t, --type            Display port type\n");
+	fprintf (stderr, "        -u, --uuid            Display uuid instead of client name (if available)\n");
+	fprintf (stderr, "        -U, --port-uuid       Display port uuid\n");
+	fprintf (stderr, "        -h, --help            Display this help message\n");
+	fprintf (stderr, "        --version             Output version information and exit\n\n");
+	fprintf (stderr, "For more information see http://jackaudio.org/\n");
+}
+
+int
+main (int argc, char *argv[])
+{
+	jack_client_t *client;
+	jack_status_t status;
+	jack_options_t options = JackNoStartServer;
+	const char **ports, **connections;
+	unsigned int i, j, k;
+	int skip_port;
+	int show_aliases = 0;
+	int show_con = 0;
+	int show_port_latency = 0;
+	int show_total_latency = 0;
+	int show_properties = 0;
+	int show_type = 0;
+	int show_uuid = 0;
+	int show_port_uuid = 0;
+	int c;
+	int option_index;
+	char* aliases[2];
+	char *server_name = NULL;
+
+	struct option long_options[] = {
+		{ "server", 1, 0, 's' },
+		{ "aliases", 0, 0, 'A' },
+		{ "connections", 0, 0, 'c' },
+		{ "port-latency", 0, 0, 'l' },
+		{ "total-latency", 0, 0, 'L' },
+		{ "properties", 0, 0, 'p' },
+		{ "type", 0, 0, 't' },
+		{ "uuid", 0, 0, 'u' },
+		{ "port-uuid", 0, 0, 'U' },
+		{ "help", 0, 0, 'h' },
+		{ "version", 0, 0, 'v' },
+		{ 0, 0, 0, 0 }
+	};
+
+	my_name = strrchr(argv[0], '/');
+	if (my_name == 0) {
+		my_name = argv[0];
+	} else {
+		my_name ++;
+	}
+
+	while ((c = getopt_long (argc, argv, "s:AclLphvtuU", long_options, &option_index)) >= 0) {
+		switch (c) {
+		case 's':
+			server_name = (char *) malloc (sizeof (char) * strlen(optarg));
+			strcpy (server_name, optarg);
+			options |= JackServerName;
+			break;
+		case 'A':
+			aliases[0] = (char *) malloc (jack_port_name_size());
+			aliases[1] = (char *) malloc (jack_port_name_size());
+			show_aliases = 1;
+			break;
+		case 'c':
+			show_con = 1;
+			break;
+		case 'l':
+			show_port_latency = 1;
+			break;
+		case 'L':
+			show_total_latency = 1;
+			break;
+		case 'p':
+			show_properties = 1;
+			break;
+		case 't':
+			show_type = 1;
+			break;
+		case 'u':
+			show_uuid = 1;
+			break;
+		case 'U':
+			show_port_uuid = 1;
+			break;
+		case 'h':
+			show_usage ();
+			return 1;
+			break;
+		case 'v':
+			show_version ();
+			return 1;
+			break;
+		default:
+			show_usage ();
+			return 1;
+			break;
+		}
+	}
+
+	/* Open a client connection to the JACK server.  Starting a
+	 * new server only to list its ports seems pointless, so we
+	 * specify JackNoStartServer. */
+	if ((client = jack_client_open ("lsp", options, &status, server_name)) == 0) {
+		fprintf (stderr, "Error: cannot connect to JACK, ");
+		if (status & JackServerFailed) {
+			fprintf (stderr, "server is not running.\n");
+		} else {
+			fprintf (stderr, "jack_client_open() failed, status = 0x%2.0x\n", status);
+		}
+		return 1;
+	}
+
+	ports = jack_get_ports (client, NULL, NULL, 0);
+
+	for (i = 0; ports && ports[i]; ++i) {
+		// skip over any that don't match ALL of the strings presented at command line
+		skip_port = 0;
+		for (k = optind; k < argc; k++){
+			if (strstr(ports[i], argv[k]) == NULL ){
+				skip_port = 1;
+			}
+		}
+		if (skip_port) continue;
+
+		if (show_uuid) {
+			printf_name2uuid(client, ports[i]);
+		} else {
+			printf ("%s\n", ports[i]);
+		}
+
+		jack_port_t *port = jack_port_by_name (client, ports[i]);
+
+		if (show_port_uuid) {
+			char buf[JACK_UUID_STRING_SIZE];
+			jack_uuid_t uuid = jack_port_uuid (port);
+			jack_uuid_unparse (uuid, buf);
+			printf ("	uuid: %s\n", buf);
+		}
+
+		if (show_aliases) {
+			int cnt;
+			int i;
+
+			cnt = jack_port_get_aliases (port, aliases);
+			for (i = 0; i < cnt; ++i) {
+				printf ("   %s\n", aliases[i]);
+			}
+		}
+
+		if (show_con) {
+			if ((connections = jack_port_get_all_connections (client, jack_port_by_name(client, ports[i]))) != 0) {
+				for (j = 0; connections[j]; j++) {
+					printf("   ");
+					if (show_uuid) {
+						printf_name2uuid(client, connections[j]);
+					} else {
+						printf("%s\n", connections[j]);
+					}
+				}
+				jack_free (connections);
+			}
+		}
+		if (show_port_latency) {
+			if (port) {
+				jack_latency_range_t range;
+
+				jack_port_get_latency_range (port, JackPlaybackLatency, &range);
+				printf ("	port playback latency = [ %" PRIu32 " %" PRIu32 " ] frames\n",
+					range.min, range.max);
+
+				jack_port_get_latency_range (port, JackCaptureLatency, &range);
+				printf ("	port capture latency = [ %" PRIu32 " %" PRIu32 " ] frames\n",
+					range.min, range.max);
+			}
+		}
+		if (show_total_latency) {
+			if (port) {
+				printf ("	total latency = %d frames\n",
+					jack_port_get_total_latency (client, port));
+			}
+		}
+		if (show_properties) {
+			if (port) {
+				int flags = jack_port_flags (port);
+				printf ("	properties: ");
+				if (flags & JackPortIsInput) {
+					fputs ("input,", stdout);
+				}
+				if (flags & JackPortIsOutput) {
+					fputs ("output,", stdout);
+				}
+				if (flags & JackPortCanMonitor) {
+					fputs ("can-monitor,", stdout);
+				}
+				if (flags & JackPortIsPhysical) {
+					fputs ("physical,", stdout);
+				}
+				if (flags & JackPortIsTerminal) {
+					fputs ("terminal,", stdout);
+				}
+				putc ('\n', stdout);
+			}
+		}
+		if (show_type) {
+			if (port) {
+				putc ('\t', stdout);
+				fputs (jack_port_type (port), stdout);
+				putc ('\n', stdout);
+			}
+		}
+	}
+
+	if (show_aliases) {
+		free(aliases[0]);
+		free(aliases[1]);
+	}
+	if (ports)
+		jack_free (ports);
+	jack_client_close (client);
+	exit (0);
+}
diff -pruN 1.9.14~dfsg-1/tools/midi_dump.c 1.9.16~dfsg-1/tools/midi_dump.c
--- 1.9.14~dfsg-1/tools/midi_dump.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/midi_dump.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,233 @@
+// gcc -o jack_midi_dump -Wall midi_dump.c -ljack -pthread
+
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <assert.h>
+#include <inttypes.h>
+#include <jack/jack.h>
+#include <jack/midiport.h>
+#include <jack/ringbuffer.h>
+
+#ifdef __MINGW32__
+#include <pthread.h>
+#endif
+
+#ifndef WIN32
+#include <signal.h>
+#include <pthread.h>
+#include <sys/mman.h>
+#endif
+
+static jack_port_t* port;
+static jack_ringbuffer_t *rb = NULL;
+static pthread_mutex_t msg_thread_lock = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t data_ready = PTHREAD_COND_INITIALIZER;
+
+static int keeprunning = 1;
+static uint64_t monotonic_cnt = 0;
+
+#define RBSIZE 100
+#define MSG_BUFFER_SIZE 4096
+
+typedef struct {
+	uint8_t  buffer[MSG_BUFFER_SIZE];
+	uint32_t size;
+	uint32_t tme_rel;
+	uint64_t tme_mon;
+} midimsg;
+
+static void
+describe (midimsg* event)
+{
+	if (event->size == 0) {
+		return;
+	}
+
+	uint8_t type = event->buffer[0] & 0xf0;
+	uint8_t channel = event->buffer[0] & 0xf;
+
+	switch (type) {
+		case 0x90:
+			assert (event->size == 3);
+			printf (" note on  (channel %2d): pitch %3d, velocity %3d", channel, event->buffer[1], event->buffer[2]);
+			break;
+		case 0x80:
+			assert (event->size == 3);
+			printf (" note off (channel %2d): pitch %3d, velocity %3d", channel, event->buffer[1], event->buffer[2]);
+			break;
+		case 0xb0:
+			assert (event->size == 3);
+			printf (" control change (channel %2d): controller %3d, value %3d", channel, event->buffer[1], event->buffer[2]);
+			break;
+		default:
+			break;
+	}
+}
+
+int
+process (jack_nframes_t frames, void* arg)
+{
+	void* buffer;
+	jack_nframes_t N;
+	jack_nframes_t i;
+
+	buffer = jack_port_get_buffer (port, frames);
+	assert (buffer);
+
+	N = jack_midi_get_event_count (buffer);
+	for (i = 0; i < N; ++i) {
+		jack_midi_event_t event;
+		int r;
+		r = jack_midi_event_get (&event, buffer, i);
+
+		if (r != 0) {continue;}
+
+		if (event.size > MSG_BUFFER_SIZE) {
+			fprintf(stderr, "Error: MIDI message was too large, skipping event. Max. allowed size: %d bytes\n", MSG_BUFFER_SIZE);
+		}
+		else if (jack_ringbuffer_write_space (rb) >= sizeof(midimsg)) {
+			midimsg m;
+			m.tme_mon = monotonic_cnt;
+			m.tme_rel = event.time;
+			m.size    = event.size;
+			memcpy (m.buffer, event.buffer, event.size);
+			jack_ringbuffer_write (rb, (void *) &m, sizeof(midimsg));
+		}
+		else {
+			fprintf (stderr, "Error: ringbuffer was full, skipping event.\n");
+		}
+	}
+
+	monotonic_cnt += frames;
+
+	if (pthread_mutex_trylock (&msg_thread_lock) == 0) {
+		pthread_cond_signal (&data_ready);
+		pthread_mutex_unlock (&msg_thread_lock);
+	}
+
+	return 0;
+}
+
+static void wearedone(int sig) {
+	fprintf(stderr, "Shutting down\n");
+	keeprunning = 0;
+}
+
+static void usage (int status) {
+	printf ("jack_midi_dump - JACK MIDI Monitor.\n\n");
+	printf ("Usage: jack_midi_dump [ OPTIONS ] [CLIENT-NAME]\n\n");
+	printf ("Options:\n\
+  -a        use absolute timestamps relative to application start\n\
+  -h        display this help and exit\n\
+  -r        use relative timestamps to previous MIDI event\n\
+\n");
+	printf ("\n\
+This tool listens for MIDI events on a JACK MIDI port and prints\n\
+the message to stdout.\n\
+\n\
+If no client name is given it defaults to 'midi-monitor'.\n\
+\n\
+See also: jackd(1)\n\
+\n");
+	exit (status);
+}
+
+int
+main (int argc, char* argv[])
+{
+	jack_client_t* client;
+	char const default_name[] = "midi-monitor";
+	char const * client_name;
+	int time_format = 0;
+	int r;
+
+	int cn = 1;
+
+	if (argc > 1) {
+		if      (!strcmp (argv[1], "-a")) { time_format = 1; cn = 2; }
+		else if (!strcmp (argv[1], "-r")) { time_format = 2; cn = 2; }
+		else if (!strcmp (argv[1], "-h")) { usage (EXIT_SUCCESS); }
+		else if (argv[1][0] == '-')       { usage (EXIT_FAILURE); }
+	}
+
+	if (argc > cn) {
+		client_name = argv[cn];
+	} else {
+		client_name = default_name;
+	}
+
+	client = jack_client_open (client_name, JackNullOption, NULL);
+	if (client == NULL) {
+		fprintf (stderr, "Could not create JACK client.\n");
+		exit (EXIT_FAILURE);
+	}
+
+	rb = jack_ringbuffer_create (RBSIZE * sizeof(midimsg));
+
+	jack_set_process_callback (client, process, 0);
+
+	port = jack_port_register (client, "input", JACK_DEFAULT_MIDI_TYPE, JackPortIsInput, 0);
+	if (port == NULL) {
+		fprintf (stderr, "Could not register port.\n");
+		exit (EXIT_FAILURE);
+	}
+
+#ifndef WIN32
+	if (mlockall (MCL_CURRENT | MCL_FUTURE)) {
+		fprintf (stderr, "Warning: Can not lock memory.\n");
+	}
+#endif
+
+	r = jack_activate (client);
+	if (r != 0) {
+		fprintf (stderr, "Could not activate client.\n");
+		exit (EXIT_FAILURE);
+	}
+
+#ifndef WIN32
+	signal(SIGHUP, wearedone);
+	signal(SIGINT, wearedone);
+#endif
+
+	pthread_mutex_lock (&msg_thread_lock);
+
+	uint64_t prev_event = 0;
+	while (keeprunning) {
+		const int mqlen = jack_ringbuffer_read_space (rb) / sizeof(midimsg);
+		int i;
+		for (i=0; i < mqlen; ++i) {
+			size_t j;
+			midimsg m;
+			jack_ringbuffer_read(rb, (char*) &m, sizeof(midimsg));
+
+			switch(time_format) {
+				case 1:
+					printf ("%7"PRId64":", m.tme_rel + m.tme_mon);
+					break;
+				case 2:
+					printf ("%+6"PRId64":", m.tme_rel + m.tme_mon - prev_event);
+					break;
+				default:
+					printf ("%4d:", m.tme_rel);
+					break;
+			}
+			for (j = 0; j < m.size && j < sizeof(m.buffer); ++j) {
+				printf (" %02x", m.buffer[j]);
+			}
+
+			describe (&m);
+			printf("\n");
+			prev_event = m.tme_rel + m.tme_mon;
+		}
+		fflush (stdout);
+		pthread_cond_wait (&data_ready, &msg_thread_lock);
+	}
+	pthread_mutex_unlock (&msg_thread_lock);
+
+	jack_deactivate (client);
+	jack_client_close (client);
+	jack_ringbuffer_free (rb);
+
+	return 0;
+}
diff -pruN 1.9.14~dfsg-1/tools/monitor_client.c 1.9.16~dfsg-1/tools/monitor_client.c
--- 1.9.14~dfsg-1/tools/monitor_client.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/monitor_client.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,66 @@
+/*
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+*/
+
+#include <stdio.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+
+#include <jack/jack.h>
+
+#define TRUE 1
+#define FALSE 0
+
+int
+main (int argc, char *argv[])
+{
+	jack_client_t *client;
+	char *my_name = strrchr(argv[0], '/');
+
+	if (my_name == 0) {
+		my_name = argv[0];
+	} else {
+		my_name ++;
+	}
+
+	if (argc != 2) {
+		fprintf (stderr, "Usage: %s client\n", my_name);
+		return 1;
+	}
+
+	if ((client = jack_client_open ("input monitoring", JackNullOption, NULL)) == 0) {
+		fprintf (stderr, "JACK server not running?\n");
+		return 1;
+	}
+
+	if (jack_port_request_monitor_by_name (client, argv[1], TRUE)) {
+		fprintf (stderr, "could not enable monitoring for %s\n", argv[1]);
+		jack_client_close (client);
+		return 1;
+	}
+
+#ifdef WIN32
+	Sleep (30*1000);
+#else
+	sleep (30);
+#endif
+	if (jack_port_request_monitor_by_name (client, argv[1], FALSE)) {
+		fprintf (stderr, "could not disable monitoring for %s\n", argv[1]);
+	}
+	jack_client_close (client);
+	exit (0);
+}
+
diff -pruN 1.9.14~dfsg-1/tools/netsource.c 1.9.16~dfsg-1/tools/netsource.c
--- 1.9.14~dfsg-1/tools/netsource.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/netsource.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,802 @@
+/*
+NetJack Client
+
+Copyright (C) 2008 Marc-Olivier Barre <marco@marcochapeau.org>
+Copyright (C) 2008 Pieter Palmers <pieterpalmers@users.sourceforge.net>
+Copyright (C) 2006 Torben Hohn <torbenh@gmx.de>
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+*/
+
+/** @file netsource.c
+ *
+ * @brief This client connects a remote slave JACK to a local JACK server assumed to be the master
+ */
+
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <signal.h>
+
+#if defined(HAVE_CONFIG_H)
+#include "config.h"
+#endif
+
+#ifdef WIN32
+#include <winsock2.h>
+#define socklen_t int
+#include <malloc.h>
+#else
+#include <netinet/in.h>
+#include <netdb.h>
+#include <sys/socket.h>
+#endif
+
+/* These two required by FreeBSD. */
+#include <sys/types.h>
+
+#include <jack/jack.h>
+
+#include <netjack_packet.h>
+#if HAVE_SAMPLERATE
+#include <samplerate.h>
+#endif
+
+#if HAVE_CELT
+#include <celt/celt.h>
+#endif
+
+#ifndef CUSTOM_MODES
+#define CUSTOM_MODES // for opus_custom_decoder_init
+#endif
+
+#if HAVE_OPUS
+#include <opus/opus.h>
+#include <opus/opus_custom.h>
+#endif
+
+#include <math.h>
+
+JSList *capture_ports = NULL;
+JSList *capture_srcs = NULL;
+int capture_channels = 0;
+int capture_channels_audio = 2;
+int capture_channels_midi = 1;
+JSList *playback_ports = NULL;
+JSList *playback_srcs = NULL;
+int playback_channels = 0;
+int playback_channels_audio = 2;
+int playback_channels_midi = 1;
+int dont_htonl_floats = 0;
+
+int latency = 5;
+jack_nframes_t factor = 1;
+int bitdepth = 0;
+int mtu = 1400;
+int reply_port = 0;
+int bind_port = 0;
+int redundancy = 1;
+jack_client_t *client;
+packet_cache * packcache = 0;
+
+int state_connected = 0;
+int state_latency = 0;
+int state_netxruns = 0;
+int state_currentframe = 0;
+int state_recv_packet_queue_time = 0;
+
+int quit = 0;
+
+
+int outsockfd;
+int insockfd;
+#ifdef WIN32
+struct sockaddr_in destaddr;
+struct sockaddr_in bindaddr;
+#else
+struct sockaddr destaddr;
+struct sockaddr bindaddr;
+#endif
+
+int sync_state;
+jack_transport_state_t last_transport_state;
+
+int framecnt = 0;
+
+int cont_miss = 0;
+
+int freewheeling = 0;
+
+/**
+ * This Function allocates all the I/O Ports which are added the lists.
+ */
+void
+alloc_ports (int n_capture_audio, int n_playback_audio, int n_capture_midi, int n_playback_midi)
+{
+
+    int port_flags = JackPortIsOutput;
+    int chn;
+    jack_port_t *port;
+    char buf[32];
+
+    capture_ports = NULL;
+    /* Allocate audio capture channels */
+    for (chn = 0; chn < n_capture_audio; chn++) {
+        snprintf (buf, sizeof (buf) - 1, "capture_%u", chn + 1);
+        port = jack_port_register (client, buf, JACK_DEFAULT_AUDIO_TYPE, port_flags, 0);
+        if (!port) {
+            printf( "jack_netsource: cannot register %s port\n", buf);
+            break;
+        }
+        if (bitdepth == 1000) {
+#if HAVE_CELT
+#if HAVE_CELT_API_0_11
+            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate( client ), jack_get_buffer_size(client), NULL );
+            capture_srcs = jack_slist_append(capture_srcs, celt_decoder_create_custom( celt_mode, 1, NULL ) );
+#elif HAVE_CELT_API_0_7 || HAVE_CELT_API_0_8
+            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate( client ), jack_get_buffer_size(client), NULL );
+            capture_srcs = jack_slist_append(capture_srcs, celt_decoder_create( celt_mode, 1, NULL ) );
+#else
+            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate( client ), 1, jack_get_buffer_size(client), NULL );
+            capture_srcs = jack_slist_append(capture_srcs, celt_decoder_create( celt_mode ) );
+#endif
+#endif
+        } else if (bitdepth == 999) {
+#if HAVE_OPUS
+            int err;
+            OpusCustomMode *opus_mode = opus_custom_mode_create(jack_get_sample_rate( client ), jack_get_buffer_size(client), &err);
+            if (err != OPUS_OK) { printf("OPUS MODE FAILED\n"); }
+            OpusCustomDecoder *decoder = opus_custom_decoder_create(opus_mode, 1, &err);
+            if (err != OPUS_OK) { printf("OPUS DECODER FAILED\n"); }
+            opus_custom_decoder_init(decoder, opus_mode, 1);
+            capture_srcs = jack_slist_append(capture_srcs, decoder);
+#endif
+        } else {
+#if HAVE_SAMPLERATE
+            capture_srcs = jack_slist_append (capture_srcs, src_new (SRC_LINEAR, 1, NULL));
+#endif
+        }
+        capture_ports = jack_slist_append (capture_ports, port);
+    }
+
+    /* Allocate midi capture channels */
+    for (chn = n_capture_audio; chn < n_capture_midi + n_capture_audio; chn++) {
+        snprintf (buf, sizeof (buf) - 1, "capture_%u", chn + 1);
+        port = jack_port_register (client, buf, JACK_DEFAULT_MIDI_TYPE, port_flags, 0);
+        if (!port) {
+            printf ("jack_netsource: cannot register %s port\n", buf);
+            break;
+        }
+        capture_ports = jack_slist_append(capture_ports, port);
+    }
+
+    /* Allocate audio playback channels */
+    port_flags = JackPortIsInput;
+    playback_ports = NULL;
+    for (chn = 0; chn < n_playback_audio; chn++) {
+        snprintf (buf, sizeof (buf) - 1, "playback_%u", chn + 1);
+        port = jack_port_register (client, buf, JACK_DEFAULT_AUDIO_TYPE, port_flags, 0);
+        if (!port) {
+            printf ("jack_netsource: cannot register %s port\n", buf);
+            break;
+        }
+        if( bitdepth == 1000 ) {
+#if HAVE_CELT
+#if HAVE_CELT_API_0_11
+            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate (client), jack_get_buffer_size(client), NULL );
+            playback_srcs = jack_slist_append(playback_srcs, celt_encoder_create_custom( celt_mode, 1, NULL ) );
+#elif HAVE_CELT_API_0_7 || HAVE_CELT_API_0_8
+            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate (client), jack_get_buffer_size(client), NULL );
+            playback_srcs = jack_slist_append(playback_srcs, celt_encoder_create( celt_mode, 1, NULL ) );
+#else
+            CELTMode *celt_mode = celt_mode_create( jack_get_sample_rate (client), 1, jack_get_buffer_size(client), NULL );
+            playback_srcs = jack_slist_append(playback_srcs, celt_encoder_create( celt_mode ) );
+#endif
+#endif
+        } else if( bitdepth == 999 ) {
+#if HAVE_OPUS
+            const int kbps = factor;
+            printf("new opus encoder %d kbps\n", kbps);
+            int err;
+            OpusCustomMode *opus_mode = opus_custom_mode_create(jack_get_sample_rate (client), jack_get_buffer_size(client), &err ); // XXX free me
+            if (err != OPUS_OK) { printf("OPUS MODE FAILED\n"); }
+            OpusCustomEncoder *oe = opus_custom_encoder_create( opus_mode, 1, &err );
+            if (err != OPUS_OK) { printf("OPUS ENCODER FAILED\n"); }
+            opus_custom_encoder_ctl(oe, OPUS_SET_BITRATE(kbps*1024)); // bits per second
+            opus_custom_encoder_ctl(oe, OPUS_SET_COMPLEXITY(10));
+            opus_custom_encoder_ctl(oe, OPUS_SET_SIGNAL(OPUS_SIGNAL_MUSIC));
+            opus_custom_encoder_ctl(oe, OPUS_SET_SIGNAL(OPUS_APPLICATION_RESTRICTED_LOWDELAY));
+            opus_custom_encoder_init(oe, opus_mode, 1);
+            playback_srcs = jack_slist_append(playback_srcs, oe);
+#endif
+        } else {
+#if HAVE_SAMPLERATE
+            playback_srcs = jack_slist_append (playback_srcs, src_new (SRC_LINEAR, 1, NULL));
+#endif
+        }
+        playback_ports = jack_slist_append (playback_ports, port);
+    }
+
+    /* Allocate midi playback channels */
+    for (chn = n_playback_audio; chn < n_playback_midi + n_playback_audio; chn++) {
+        snprintf (buf, sizeof (buf) - 1, "playback_%u", chn + 1);
+        port = jack_port_register (client, buf, JACK_DEFAULT_MIDI_TYPE, port_flags, 0);
+        if (!port) {
+            printf ("jack_netsource: cannot register %s port\n", buf);
+            break;
+        }
+        playback_ports = jack_slist_append (playback_ports, port);
+    }
+}
+
+/**
+ * The Sync callback... sync state is set elsewhere...
+ * we will see if this is working correctly.
+ * i don't really believe in it yet.
+ */
+int
+sync_cb (jack_transport_state_t state, jack_position_t *pos, void *arg)
+{
+    static int latency_count = 0;
+    int retval = sync_state;
+
+    if (! state_connected) {
+        return 1;
+    }
+    if (latency_count) {
+        latency_count--;
+        retval = 0;
+    }
+
+    else if (state == JackTransportStarting && last_transport_state != JackTransportStarting) {
+        retval = 0;
+        latency_count = latency - 1;
+    }
+
+    last_transport_state = state;
+    return retval;
+}
+
+void
+freewheel_cb (int starting, void *arg)
+{
+    freewheeling = starting;
+}
+
+int deadline_goodness = 0;
+/**
+ * The process callback for this JACK application.
+ * It is called by JACK at the appropriate times.
+ */
+int
+process (jack_nframes_t nframes, void *arg)
+{
+    jack_nframes_t net_period;
+    int rx_bufsize, tx_bufsize;
+
+    jack_default_audio_sample_t *buf;
+    jack_port_t *port;
+    JSList *node;
+    int chn;
+    int size, i;
+    const char *porttype;
+    int input_fd;
+
+    jack_position_t local_trans_pos;
+
+    uint32_t *packet_buf_tx, *packet_bufX;
+    uint32_t *rx_packet_ptr;
+    jack_time_t packet_recv_timestamp;
+
+    if( bitdepth == 1000 || bitdepth == 999)
+        net_period = (factor * jack_get_buffer_size(client) * 1024 / jack_get_sample_rate(client) / 8) & (~1) ;
+    else
+        net_period = (float) nframes / (float) factor;
+
+    rx_bufsize =  get_sample_size (bitdepth) * capture_channels * net_period + sizeof (jacknet_packet_header);
+    tx_bufsize =  get_sample_size (bitdepth) * playback_channels * net_period + sizeof (jacknet_packet_header);
+
+    /* Allocate a buffer where both In and Out Buffer will fit */
+    packet_buf_tx = alloca (tx_bufsize);
+
+    jacknet_packet_header *pkthdr_tx = (jacknet_packet_header *) packet_buf_tx;
+
+    /*
+     * for latency==0 we need to send out the packet before we wait on the reply.
+     * but this introduces a cycle of latency, when netsource is connected to itself.
+     * so we send out before read only in zero latency mode.
+     *
+     */
+
+    if( latency == 0 ) {
+        /* reset packet_bufX... */
+        packet_bufX = packet_buf_tx + sizeof (jacknet_packet_header) / sizeof (jack_default_audio_sample_t);
+
+        /* ---------- Send ---------- */
+        render_jack_ports_to_payload (bitdepth, playback_ports, playback_srcs, nframes,
+                                      packet_bufX, net_period, dont_htonl_floats);
+
+        /* fill in packet hdr */
+        pkthdr_tx->transport_state = jack_transport_query (client, &local_trans_pos);
+        pkthdr_tx->transport_frame = local_trans_pos.frame;
+        pkthdr_tx->framecnt = framecnt;
+        pkthdr_tx->latency = latency;
+        pkthdr_tx->reply_port = reply_port;
+        pkthdr_tx->sample_rate = jack_get_sample_rate (client);
+        pkthdr_tx->period_size = nframes;
+
+        /* playback for us is capture on the other side */
+        pkthdr_tx->capture_channels_audio = playback_channels_audio;
+        pkthdr_tx->playback_channels_audio = capture_channels_audio;
+        pkthdr_tx->capture_channels_midi = playback_channels_midi;
+        pkthdr_tx->playback_channels_midi = capture_channels_midi;
+        pkthdr_tx->mtu = mtu;
+        if( freewheeling != 0 )
+            pkthdr_tx->sync_state = (jack_nframes_t)MASTER_FREEWHEELS;
+        else
+            pkthdr_tx->sync_state = (jack_nframes_t)deadline_goodness;
+        //printf("goodness=%d\n", deadline_goodness );
+
+        packet_header_hton (pkthdr_tx);
+        if (cont_miss < 3 * latency + 5) {
+            int r;
+            for( r = 0; r < redundancy; r++ )
+                netjack_sendto (outsockfd, (char *) packet_buf_tx, tx_bufsize, 0, &destaddr, sizeof (destaddr), mtu);
+        } else if (cont_miss > 50 + 5 * latency) {
+            state_connected = 0;
+            packet_cache_reset_master_address( packcache );
+            //printf ("Frame %d  \tRealy too many packets missed (%d). Let's reset the counter\n", framecnt, cont_miss);
+            cont_miss = 0;
+        }
+    }
+
+    /*
+     * ok... now the RECEIVE code.
+     *
+     */
+
+
+    if( reply_port )
+        input_fd = insockfd;
+    else
+        input_fd = outsockfd;
+
+    // for latency == 0 we can poll.
+    if( (latency == 0) || (freewheeling != 0)  ) {
+        jack_time_t deadline = jack_get_time() + 1000000 * jack_get_buffer_size(client) / jack_get_sample_rate(client);
+        // Now loop until we get the right packet.
+        while(1) {
+            jack_nframes_t got_frame;
+            if ( ! netjack_poll_deadline( input_fd, deadline ) )
+                break;
+
+            packet_cache_drain_socket(packcache, input_fd);
+
+            if (packet_cache_get_next_available_framecnt( packcache, framecnt - latency, &got_frame ))
+                if( got_frame == (framecnt - latency) )
+                    break;
+        }
+    } else {
+        // normally:
+        // only drain socket.
+        packet_cache_drain_socket(packcache, input_fd);
+    }
+
+    size = packet_cache_retreive_packet_pointer( packcache, framecnt - latency, (char**)&rx_packet_ptr, rx_bufsize, &packet_recv_timestamp );
+    /* First alternative : we received what we expected. Render the data
+     * to the JACK ports so it can be played. */
+    if (size == rx_bufsize) {
+        uint32_t *packet_buf_rx = rx_packet_ptr;
+        jacknet_packet_header *pkthdr_rx = (jacknet_packet_header *) packet_buf_rx;
+        packet_bufX = packet_buf_rx + sizeof (jacknet_packet_header) / sizeof (jack_default_audio_sample_t);
+        // calculate how much time there would have been, if this packet was sent at the deadline.
+
+        int recv_time_offset = (int) (jack_get_time() - packet_recv_timestamp);
+        packet_header_ntoh (pkthdr_rx);
+        deadline_goodness = recv_time_offset - (int)pkthdr_rx->latency;
+        //printf( "deadline goodness = %d ---> off: %d\n", deadline_goodness, recv_time_offset );
+
+        if (cont_miss) {
+            //printf("Frame %d  \tRecovered from dropouts\n", framecnt);
+            cont_miss = 0;
+        }
+        render_payload_to_jack_ports (bitdepth, packet_bufX, net_period,
+                                      capture_ports, capture_srcs, nframes, dont_htonl_floats);
+
+        state_currentframe = framecnt;
+        state_recv_packet_queue_time = recv_time_offset;
+        state_connected = 1;
+        sync_state = pkthdr_rx->sync_state;
+        packet_cache_release_packet( packcache, framecnt - latency );
+    }
+    /* Second alternative : we've received something that's not
+     * as big as expected or we missed a packet. We render silence
+     * to the output ports */
+    else {
+        jack_nframes_t latency_estimate;
+        if( packet_cache_find_latency( packcache, framecnt, &latency_estimate ) )
+            //if( (state_latency == 0) || (latency_estimate < state_latency) )
+            state_latency = latency_estimate;
+
+        // Set the counters up.
+        state_currentframe = framecnt;
+        //state_latency = framecnt - pkthdr->framecnt;
+        state_netxruns += 1;
+
+        //printf ("Frame %d  \tPacket missed or incomplete (expected: %d bytes, got: %d bytes)\n", framecnt, rx_bufsize, size);
+        //printf ("Frame %d  \tPacket missed or incomplete\n", framecnt);
+        cont_miss += 1;
+        chn = 0;
+        node = capture_ports;
+        while (node != NULL) {
+            port = (jack_port_t *) node->data;
+            buf = jack_port_get_buffer (port, nframes);
+            porttype = jack_port_type (port);
+            if (strncmp (porttype, JACK_DEFAULT_AUDIO_TYPE, jack_port_type_size ()) == 0)
+                for (i = 0; i < nframes; i++)
+                    buf[i] = 0.0;
+            else if (strncmp (porttype, JACK_DEFAULT_MIDI_TYPE, jack_port_type_size ()) == 0)
+                jack_midi_clear_buffer (buf);
+            node = jack_slist_next (node);
+            chn++;
+        }
+    }
+    if (latency != 0) {
+        /* reset packet_bufX... */
+        packet_bufX = packet_buf_tx + sizeof (jacknet_packet_header) / sizeof (jack_default_audio_sample_t);
+
+        /* ---------- Send ---------- */
+        render_jack_ports_to_payload (bitdepth, playback_ports, playback_srcs, nframes,
+                                      packet_bufX, net_period, dont_htonl_floats);
+
+        /* fill in packet hdr */
+        pkthdr_tx->transport_state = jack_transport_query (client, &local_trans_pos);
+        pkthdr_tx->transport_frame = local_trans_pos.frame;
+        pkthdr_tx->framecnt = framecnt;
+        pkthdr_tx->latency = latency;
+        pkthdr_tx->reply_port = reply_port;
+        pkthdr_tx->sample_rate = jack_get_sample_rate (client);
+        pkthdr_tx->period_size = nframes;
+
+        /* playback for us is capture on the other side */
+        pkthdr_tx->capture_channels_audio = playback_channels_audio;
+        pkthdr_tx->playback_channels_audio = capture_channels_audio;
+        pkthdr_tx->capture_channels_midi = playback_channels_midi;
+        pkthdr_tx->playback_channels_midi = capture_channels_midi;
+        pkthdr_tx->mtu = mtu;
+        if( freewheeling != 0 )
+            pkthdr_tx->sync_state = (jack_nframes_t)MASTER_FREEWHEELS;
+        else
+            pkthdr_tx->sync_state = (jack_nframes_t)deadline_goodness;
+        //printf("goodness=%d\n", deadline_goodness );
+
+        packet_header_hton (pkthdr_tx);
+        if (cont_miss < 3 * latency + 5) {
+            int r;
+            for( r = 0; r < redundancy; r++ )
+                netjack_sendto (outsockfd, (char *) packet_buf_tx, tx_bufsize, 0, &destaddr, sizeof (destaddr), mtu);
+        } else if (cont_miss > 50 + 5 * latency) {
+            state_connected = 0;
+            packet_cache_reset_master_address( packcache );
+            //printf ("Frame %d  \tRealy too many packets missed (%d). Let's reset the counter\n", framecnt, cont_miss);
+            cont_miss = 0;
+        }
+    }
+
+    framecnt++;
+    return 0;
+}
+
+/**
+ * This is the shutdown callback for this JACK application.
+ * It is called by JACK if the server ever shuts down or
+ * decides to disconnect the client.
+ */
+
+void
+jack_shutdown (void *arg)
+{
+    fprintf(stderr, "JACK shut down, exiting ...\n");
+    exit (1);
+}
+
+void
+init_sockaddr_in (struct sockaddr_in *name , const char *hostname , uint16_t port)
+{
+    name->sin_family = AF_INET ;
+    name->sin_port = htons (port);
+    if (hostname) {
+        struct hostent *hostinfo = gethostbyname (hostname);
+        if (hostinfo == NULL) {
+            fprintf (stderr, "init_sockaddr_in: unknown host: %s.\n", hostname);
+            fflush( stderr );
+        }
+#ifdef WIN32
+        name->sin_addr.s_addr = inet_addr( hostname );
+#else
+        name->sin_addr = *(struct in_addr *) hostinfo->h_addr ;
+#endif
+    } else
+        name->sin_addr.s_addr = htonl (INADDR_ANY) ;
+
+}
+
+void
+printUsage ()
+{
+    fprintf (stderr, "usage: jack_netsource [options]\n"
+             "\n"
+             "  -h this help text\n"
+             "  -H <slave host> - Host name of the slave JACK\n"
+             "  -o <num channels> - Number of audio playback channels\n"
+             "  -i <num channels> - Number of audio capture channels\n"
+             "  -O <num channels> - Number of midi playback channels\n"
+             "  -I <num channels> - Number of midi capture channels\n"
+             "  -n <periods> - Network latency in JACK periods\n"
+             "  -p <port> - UDP port that the slave is listening on\n"
+             "  -r <reply port> - UDP port that we are listening on\n"
+             "  -B <bind port> - reply port, for use in NAT environments\n"
+             "  -b <bitdepth> - Set transport to use 16bit or 8bit\n"
+             "  -c <kbits> - Use CELT encoding with <kbits> kbits per channel\n"
+             "  -P <kbits> - Use Opus encoding with <kbits> kbits per channel\n"
+             "  -m <mtu> - Assume this mtu for the link\n"
+             "  -R <N> - Redundancy: send out packets N times.\n"
+             "  -e - skip host-to-network endianness conversion\n"
+             "  -N <jack name> - Reports a different name to jack\n"
+             "  -s <server name> - The name of the local jack server\n"
+             "\n");
+}
+
+void
+sigterm_handler( int signal )
+{
+    quit = 1;
+}
+
+int
+main (int argc, char *argv[])
+{
+    /* Some startup related basics */
+    char *client_name, *server_name = NULL, *peer_ip;
+    int peer_port = 3000;
+    jack_options_t options = JackNullOption;
+    jack_status_t status;
+#ifdef WIN32
+    WSADATA wsa;
+    int rc = WSAStartup(MAKEWORD(2, 0), &wsa);
+#endif
+    /* Torben's famous state variables, aka "the reporting API" ! */
+    /* heh ? these are only the copies of them ;)                 */
+    int statecopy_connected, statecopy_latency, statecopy_netxruns;
+    jack_nframes_t net_period;
+    /* Argument parsing stuff */
+    extern char *optarg;
+    extern int optind, optopt;
+    int errflg = 0, c;
+
+    if (argc < 3) {
+        printUsage ();
+        return 1;
+    }
+
+    client_name = (char *) malloc (sizeof (char) * 10);
+    peer_ip = (char *) malloc (sizeof (char) * 10);
+    sprintf(client_name, "netjack");
+    sprintf(peer_ip, "localhost");
+
+    while ((c = getopt (argc, argv, ":h:H:o:i:O:I:n:p:r:B:b:c:m:R:e:N:s:P:")) != -1) {
+        switch (c) {
+            case 'h':
+                printUsage();
+                exit (0);
+                break;
+            case 'H':
+                free(peer_ip);
+                peer_ip = (char *) malloc (sizeof (char) * strlen (optarg) + 1);
+                strcpy (peer_ip, optarg);
+                break;
+            case 'o':
+                playback_channels_audio = atoi (optarg);
+                break;
+            case 'i':
+                capture_channels_audio = atoi (optarg);
+                break;
+            case 'O':
+                playback_channels_midi = atoi (optarg);
+                break;
+            case 'I':
+                capture_channels_midi = atoi (optarg);
+                break;
+            case 'n':
+                latency = atoi (optarg);
+                break;
+            case 'p':
+                peer_port = atoi (optarg);
+                break;
+            case 'r':
+                reply_port = atoi (optarg);
+                break;
+            case 'B':
+                bind_port = atoi (optarg);
+                break;
+            case 'f':
+                factor = atoi (optarg);
+                printf("This feature is deprecated and will be removed in future netjack versions. CELT offers a superiour way to conserve bandwidth");
+                break;
+            case 'b':
+                bitdepth = atoi (optarg);
+                break;
+            case 'c':
+#if HAVE_CELT
+                bitdepth = 1000;
+                factor = atoi (optarg);
+#else
+                printf( "not built with celt support\n" );
+                exit(10);
+#endif
+                break;
+            case 'P':
+#if HAVE_OPUS
+                bitdepth = 999;
+                factor = atoi (optarg);
+#else
+                printf( "not built with opus support\n" );
+                exit(10);
+#endif
+                break;
+            case 'm':
+                mtu = atoi (optarg);
+                break;
+            case 'R':
+                redundancy = atoi (optarg);
+                break;
+            case 'e':
+                dont_htonl_floats = 1;
+                break;
+            case 'N':
+                free(client_name);
+                client_name = (char *) malloc (sizeof (char) * strlen (optarg) + 1);
+                strcpy (client_name, optarg);
+                break;
+            case 's':
+                server_name = (char *) malloc (sizeof (char) * strlen (optarg) + 1);
+                strcpy (server_name, optarg);
+                options |= JackServerName;
+                break;
+            case ':':
+                fprintf (stderr, "Option -%c requires an operand\n", optopt);
+                errflg++;
+                break;
+            case '?':
+                fprintf (stderr, "Unrecognized option: -%c\n", optopt);
+                errflg++;
+        }
+    }
+    if (errflg) {
+        printUsage ();
+        exit (2);
+    }
+
+    capture_channels = capture_channels_audio + capture_channels_midi;
+    playback_channels = playback_channels_audio + playback_channels_midi;
+
+    outsockfd = socket (AF_INET, SOCK_DGRAM, 0);
+    insockfd = socket (AF_INET, SOCK_DGRAM, 0);
+
+    if ((outsockfd == -1) || (insockfd == -1)) {
+        fprintf (stderr, "can not open sockets\n" );
+        return 1;
+    }
+
+    init_sockaddr_in ((struct sockaddr_in *) &destaddr, peer_ip, peer_port);
+    if (bind_port) {
+        init_sockaddr_in ((struct sockaddr_in *) &bindaddr, NULL, bind_port);
+        if( bind (outsockfd, &bindaddr, sizeof (bindaddr)) ) {
+            fprintf (stderr, "bind failure\n" );
+        }
+    }
+    if (reply_port) {
+        init_sockaddr_in ((struct sockaddr_in *) &bindaddr, NULL, reply_port);
+        if( bind (insockfd, &bindaddr, sizeof (bindaddr)) ) {
+            fprintf (stderr, "bind failure\n" );
+        }
+    }
+
+    /* try to become a client of the JACK server */
+    client = jack_client_open (client_name, options, &status, server_name);
+    if (client == NULL) {
+        fprintf (stderr, "jack_client_open() failed, status = 0x%2.0x\n"
+                 "Is the JACK server running ?\n", status);
+        return 1;
+    }
+
+    /* Set up jack callbacks */
+    jack_set_process_callback (client, process, 0);
+    jack_set_sync_callback (client, sync_cb, 0);
+    jack_set_freewheel_callback (client, freewheel_cb, 0);
+    jack_on_shutdown (client, jack_shutdown, 0);
+
+    alloc_ports (capture_channels_audio, playback_channels_audio, capture_channels_midi, playback_channels_midi);
+
+    if( bitdepth == 1000 || bitdepth == 999)
+        net_period = (factor * jack_get_buffer_size(client) * 1024 / jack_get_sample_rate(client) / 8) & (~1) ;
+    else
+        net_period = ceilf((float) jack_get_buffer_size (client) / (float) factor);
+
+    int rx_bufsize =  get_sample_size (bitdepth) * capture_channels * net_period + sizeof (jacknet_packet_header);
+    packcache = packet_cache_new (latency + 50, rx_bufsize, mtu);
+
+    /* tell the JACK server that we are ready to roll */
+    if (jack_activate (client)) {
+        fprintf (stderr, "Cannot activate client");
+        return 1;
+    }
+
+    /* Now sleep forever... and evaluate the state_ vars */
+
+    signal( SIGTERM, sigterm_handler );
+    signal( SIGINT, sigterm_handler );
+
+    statecopy_connected = 2; // make it report unconnected on start.
+    statecopy_latency = state_latency;
+    statecopy_netxruns = state_netxruns;
+
+    while ( !quit ) {
+#ifdef WIN32
+        Sleep (1000);
+#else
+        sleep(1);
+#endif
+        if (statecopy_connected != state_connected) {
+            statecopy_connected = state_connected;
+            if (statecopy_connected) {
+                state_netxruns = 1; // We want to reset the netxrun count on each new connection
+                printf ("Connected :-)\n");
+            } else
+                printf ("Not Connected\n");
+
+            fflush(stdout);
+        }
+
+        if (statecopy_connected) {
+            if (statecopy_netxruns != state_netxruns) {
+                statecopy_netxruns = state_netxruns;
+                printf ("%s: at frame %06d -> total netxruns %d  (%d%%) queue time= %d\n",
+                        client_name,
+                        state_currentframe,
+                        statecopy_netxruns,
+                        100 * statecopy_netxruns / state_currentframe,
+                        state_recv_packet_queue_time);
+
+                fflush(stdout);
+            }
+        } else {
+            if (statecopy_latency != state_latency) {
+                statecopy_latency = state_latency;
+                if (statecopy_latency > 1)
+                    printf ("current latency %d\n", statecopy_latency);
+                fflush(stdout);
+            }
+        }
+    }
+
+    jack_client_close (client);
+    packet_cache_free (packcache);
+    exit (0);
+}
diff -pruN 1.9.14~dfsg-1/tools/property.c 1.9.16~dfsg-1/tools/property.c
--- 1.9.14~dfsg-1/tools/property.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/property.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,326 @@
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
+#include <getopt.h>
+
+#include <jack/jack.h>
+#include <jack/metadata.h>
+#include <jack/uuid.h>
+#include <jack/session.h>
+
+static int subject_is_client = 0;
+static int subject_is_port = 0;
+static jack_uuid_t uuid = JACK_UUID_EMPTY_INITIALIZER;
+static char* subject = NULL;
+
+static void
+show_usage (void)
+{
+        fprintf (stderr, "\nUsage: jack_property [options] UUID [ key [ value [ type ] ] ]\n");
+        fprintf (stderr, "Set/Display JACK properties (metadata).\n\n");
+        fprintf (stderr, "Set options:\n");
+        fprintf (stderr, "        -s, --set		Set property \"key\" to \"value\" for \"UUID\" with optional MIME type \"type\"\n");
+        fprintf (stderr, "        -d, --delete		Remove/delete property \"key\" for \"UUID\"\n");
+        fprintf (stderr, "        -d, --delete UUID	Remove/delete all properties for \"UUID\"\n");
+        fprintf (stderr, "        -D, --delete-all	Remove/delete all properties\n");
+        fprintf (stderr, "        --client		Interpret UUID as a client name, not a UUID\n");
+        fprintf (stderr, "        --port		\tInterpret UUID as a port name, not a UUID\n");
+        fprintf (stderr, "\nDisplay options:\n");
+        fprintf (stderr, "        -l			Show all properties\n");
+        fprintf (stderr, "        -l, --list UUID	\tShow value for all properties of UUID\n");
+        fprintf (stderr, "        -l, --list UUID key	Show value for key of UUID\n");
+        fprintf (stderr, "\nFor more information see https://jackaudio.org/\n");
+}
+
+static int
+get_subject (jack_client_t* client, char* argv[], int* optind)
+{
+        if (subject_is_client) {
+                char* cstr = argv[(*optind)++];
+                char* ustr;
+
+                if ((ustr = jack_get_uuid_for_client_name (client, cstr)) == NULL) {
+                        fprintf (stderr, "cannot get UUID for client named %s\n", cstr);
+                        return -1;
+                }
+
+                if (jack_uuid_parse (ustr, &uuid)) {
+                        fprintf (stderr, "cannot parse client UUID as UUID '%s' '%s'\n", cstr, ustr);
+                        return -1;
+                }
+
+                subject = cstr;
+
+        } else if (subject_is_port) {
+
+                char* pstr = argv[(*optind)++];
+                jack_port_t* port;
+
+                if ((port = jack_port_by_name (client, pstr)) == NULL) {
+                        fprintf (stderr, "cannot find port name %s\n", pstr);
+                        return -1;
+                }
+
+                uuid = jack_port_uuid (port);
+                subject = pstr;
+
+        } else {
+                char* str = argv[(*optind)++];
+
+                if (jack_uuid_parse (str, &uuid)) {
+                        fprintf (stderr, "cannot parse subject as UUID\n");
+                        return -1;
+                }
+
+                subject = str;
+        }
+
+        return 0;
+}
+
+int main (int argc, char* argv[])
+{
+        jack_client_t* client = NULL;
+        jack_options_t options = JackNoStartServer;
+        char* key = NULL;
+        char* value = NULL;
+        char* type = NULL;
+        int set = 1;
+        int delete = 0;
+        int delete_all = 0;
+        int c;
+        int option_index;
+        extern int optind;
+        struct option long_options[] = {
+            { "set", 0, 0, 's' },
+            { "delete", 0, 0, 'd' },
+            { "delete-all", 0, 0, 'D' },
+            { "list", 0, 0, 'l' },
+            { "client", 0, 0, 'c' },
+            { "port", 0, 0, 'p' },
+            { 0, 0, 0, 0 }
+        };
+
+        if (argc < 2) {
+                show_usage ();
+                exit (1);
+        }
+
+        while ((c = getopt_long (argc, argv, "sdDlaApc", long_options, &option_index)) >= 0) {
+            switch (c) {
+            case 's':
+                        if (argc < 5) {
+                                show_usage ();
+                                exit (1);
+                        }
+                        set = 1;
+                        break;
+                case 'd':
+                        if (argc < 3) {
+                                show_usage ();
+                                return 1;
+                        }
+                        set = 0;
+                        delete = 1;
+                        break;
+
+                case 'D':
+                        delete = 0;
+                        set = 0;
+                        delete_all = 1;
+                        break;
+
+                case 'l':
+                        set = 0;
+                        delete = 0;
+                        delete_all = 0;
+                        break;
+
+                case 'p':
+                        subject_is_port = 1;
+                        break;
+
+                case 'c':
+                        subject_is_client = 1;
+                        break;
+
+                case '?':
+                default:
+                        show_usage ();
+                        exit (1);
+                }
+        }
+
+        if ((client = jack_client_open ("jack-property", options, NULL)) == 0) {
+                fprintf (stderr, "Cannot connect to JACK server\n");
+                exit (1);
+        }
+
+        if (delete_all) {
+
+                if (jack_remove_all_properties (client) == 0) {
+                        printf ("JACK metadata successfully delete\n");
+                        exit (0);
+                }
+                exit (1);
+        }
+
+        if (delete) {
+
+                int args_left = argc - optind;
+
+                if (args_left < 1) {
+                        show_usage ();
+                        exit (1);
+                }
+
+                /* argc == 3: delete all properties for a subject
+                   argc == 4: delete value of key for subject
+                */
+
+                if (args_left >= 2) {
+
+                        if (get_subject (client, argv, &optind)) {
+                                return 1;
+                        }
+
+                        key = argv[optind++];
+
+                        if (jack_remove_property (client, uuid, key)) {
+                                fprintf (stderr, "\"%s\" property not removed for %s\n", key, subject);
+                                exit (1);
+                        }
+
+                } else {
+
+                        if (get_subject (client, argv, &optind)) {
+                                return 1;
+                        }
+
+                        if (jack_remove_properties (client, uuid) < 0) {
+                                fprintf (stderr, "cannot remove properties for UUID %s\n", subject);
+                                exit (1);
+                        }
+                }
+
+        }  else if (set) {
+
+                int args_left = argc - optind;
+
+                if (get_subject (client, argv, &optind)) {
+                        return -1;
+                }
+
+                key = argv[optind++];
+                value = argv[optind++];
+
+                if (args_left >= 3) {
+                        type = argv[optind++];
+                } else {
+                        type = "";
+                }
+
+                if (jack_set_property (client, uuid, key, value, type)) {
+                        fprintf (stderr, "cannot set value for key %s of %s\n", key, subject);
+                        exit (1);
+                }
+
+        } else {
+
+                /* list properties */
+
+                int args_left = argc - optind;
+
+                if (args_left >= 2) {
+
+                        /* list properties for a UUID/key pair */
+
+                        if (get_subject (client, argv, &optind)) {
+                                return -1;
+                        }
+
+                        key = argv[optind++];
+
+                        if (jack_get_property (uuid, key, &value, &type) == 0) {
+                                printf ("%s\n", value);
+                                free (value);
+                                if (type) {
+                                        free (type);
+                                }
+                        } else {
+                                fprintf (stderr, "Value not found for %s of %s\n", key, subject);
+                                exit (1);
+                        }
+
+                } else if (args_left == 1) {
+
+                        /* list all properties for a given UUID */
+
+                        jack_description_t description;
+                        int cnt, n;
+
+                        if (get_subject (client, argv, &optind)) {
+                                return -1;
+                        }
+
+                        if ((cnt = jack_get_properties (uuid, &description)) < 0) {
+                                fprintf (stderr, "could not retrieve properties for %s\n", subject);
+                                exit (1);
+                        }
+
+                        for (n = 0; n < cnt; ++n) {
+                                if (description.properties[n].type) {
+                                        printf ("key: %s value: %s type: %s\n",
+                                                description.properties[n].key,
+                                                description.properties[n].data,
+                                                description.properties[n].type);
+                                } else {
+                                        printf ("key: %s value: %s\n",
+                                                description.properties[n].key,
+                                                description.properties[n].data);
+                                }
+                        }
+
+                        jack_free_description (&description, 0);
+
+                } else {
+
+                        /* list all properties */
+
+                        jack_description_t* description;
+                        int cnt, n;
+                        size_t p;
+                        char buf[JACK_UUID_STRING_SIZE];
+
+                        if ((cnt = jack_get_all_properties (&description)) < 0) {
+                                fprintf (stderr, "could not retrieve all properties\n");
+                                exit (1);
+                        }
+
+                        for (n = 0; n < cnt; ++n) {
+                                jack_uuid_unparse (description[n].subject, buf);
+                                printf ("%s\n", buf);
+                                for (p = 0; p < description[n].property_cnt; ++p) {
+                                        if (description[n].properties[p].type) {
+                                                printf ("key: %s value: %s type: %s\n",
+                                                        description[n].properties[p].key,
+                                                        description[n].properties[p].data,
+                                                        description[n].properties[p].type);
+                                        } else {
+                                                printf ("key: %s value: %s\n",
+                                                        description[n].properties[p].key,
+                                                        description[n].properties[p].data);
+                                        }
+                                }
+                                jack_free_description (&description[n], 0);
+                        }
+
+                        free (description);
+                }
+        }
+
+
+        (void) jack_client_close (client);
+        return 0;
+}
diff -pruN 1.9.14~dfsg-1/tools/samplerate.c 1.9.16~dfsg-1/tools/samplerate.c
--- 1.9.14~dfsg-1/tools/samplerate.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/samplerate.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,87 @@
+/*
+ *  smaplerate.c -- get current samplerate
+ *
+ *  Copyright (C) 2003 Jack O'Quin.
+ *  
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#include <jack/jack.h>
+#include <jack/transport.h>
+
+char *package;				/* program name */
+jack_client_t *client;
+
+void jack_shutdown(void *arg)
+{
+	fprintf(stderr, "JACK shut down, exiting ...\n");
+	exit(1);
+}
+
+void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+void parse_arguments(int argc, char *argv[])
+{
+
+	/* basename $0 */
+	package = strrchr(argv[0], '/');
+	if (package == 0)
+		package = argv[0];
+	else
+		package++;
+
+	if (argc==1) {
+		return;
+	}
+	fprintf(stderr, "usage: %s\n", package);
+	exit(9);
+}
+
+int main(int argc, char *argv[])
+{
+	parse_arguments(argc, argv);
+
+	/* become a JACK client */
+	if ((client = jack_client_open(package, JackNullOption, NULL)) == 0) {
+		fprintf(stderr, "JACK server not running?\n");
+		exit(1);
+	}
+
+#ifndef WIN32
+	signal(SIGQUIT, signal_handler);
+	signal(SIGHUP, signal_handler);
+#endif
+	signal(SIGTERM, signal_handler);
+	signal(SIGINT, signal_handler);
+
+	jack_on_shutdown(client, jack_shutdown, 0);
+
+	fprintf(stdout, "%d\n", jack_get_sample_rate( client ) );
+
+	jack_client_close(client);
+
+	return 0;
+}
diff -pruN 1.9.14~dfsg-1/tools/session_notify.c 1.9.16~dfsg-1/tools/session_notify.c
--- 1.9.14~dfsg-1/tools/session_notify.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/session_notify.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,186 @@
+/*
+ *  session_notify.c -- ultra minimal session manager
+ *
+ *  Copyright (C) 2018 Karl Linden <karl.j.linden@gmail.com>
+ *  Copyright (C) 2010 Torben Hohn.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <alloca.h>
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#include <jack/jack.h>
+#include <jack/jslist.h>
+#include <jack/transport.h>
+#include <jack/session.h>
+
+char *package;				/* program name */
+jack_client_t *client;
+
+jack_session_event_type_t notify_type;
+char *save_path = NULL;
+
+void jack_shutdown(void *arg)
+{
+	fprintf(stderr, "JACK shut down, exiting ...\n");
+	exit(1);
+}
+
+void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+void parse_arguments(int argc, char *argv[])
+{
+
+	/* basename $0 */
+	package = strrchr(argv[0], '/');
+	if (package == 0)
+		package = argv[0];
+	else
+		package++;
+
+	if (argc==2) {
+		if( !strcmp( argv[1], "quit" ) ) {
+			notify_type = JackSessionSaveAndQuit;
+			return;
+		}
+	}
+	if (argc==3) {
+		if( !strcmp( argv[1], "save" ) ) {
+			notify_type = JackSessionSave;
+			save_path = argv[2];
+			return;
+		}
+
+	}
+	fprintf(stderr, "usage: %s quit|save [path]\n", package);
+	exit(9);
+}
+
+typedef struct {
+	char name[32];
+	char uuid[16];
+} uuid_map_t;
+
+JSList *uuid_map = NULL;
+
+void add_uuid_mapping( const char *uuid ) {
+	char *clientname = jack_get_client_name_by_uuid( client, uuid );
+	if( !clientname ) {
+		printf( "error... can not find client for uuid" );
+		return;
+	}
+
+	uuid_map_t *mapping = malloc( sizeof(uuid_map_t) );
+	snprintf( mapping->uuid, sizeof(mapping->uuid), "%s", uuid );
+	snprintf( mapping->name, sizeof(mapping->name), "%s", clientname );
+	uuid_map = jack_slist_append( uuid_map, mapping );
+}
+
+char *map_port_name_to_uuid_port( const char *port_name )
+{
+	JSList *node;
+	char retval[300];
+	char *port_component = strchr( port_name,':' );
+	char *client_component = strdup( port_name );
+	strchr( client_component, ':' )[0] = '\0';
+
+	sprintf( retval, "%s", port_name );
+
+	for( node=uuid_map; node; node=jack_slist_next(node) ) {
+		uuid_map_t *mapping = node->data;
+		if( !strcmp( mapping->name, client_component ) ) {
+			sprintf( retval, "%s%s", mapping->uuid, port_component );
+			break;
+		}
+	}
+
+	return strdup(retval);
+}
+
+int main(int argc, char *argv[])
+{
+	parse_arguments(argc, argv);
+	jack_session_command_t *retval;
+	int k,i,j;
+
+
+	/* become a JACK client */
+	if ((client = jack_client_open(package, JackNullOption, NULL)) == 0) {
+		fprintf(stderr, "JACK server not running?\n");
+		exit(1);
+	}
+
+#ifndef WIN32
+	signal(SIGQUIT, signal_handler);
+	signal(SIGHUP, signal_handler);
+#endif
+
+	signal(SIGTERM, signal_handler);
+	signal(SIGINT, signal_handler);
+
+	jack_on_shutdown(client, jack_shutdown, 0);
+
+	jack_activate(client);
+
+
+	retval = jack_session_notify( client, NULL, notify_type, save_path );
+	for (i = 0; retval[i].uuid; i++) {
+		printf( "export SESSION_DIR=\"%s%s/\"\n", save_path, retval[i].client_name );
+		printf( "%s &\n", retval[i].command );
+		add_uuid_mapping(retval[i].uuid);
+	}
+
+	printf( "sleep 10\n" );
+
+	for (k = 0; retval[k].uuid; k++) {
+
+		char* port_regexp = alloca( jack_client_name_size()+3 );
+		char* client_name = jack_get_client_name_by_uuid( client, retval[k].uuid );
+		snprintf( port_regexp, jack_client_name_size()+3, "%s:.*", client_name );
+		jack_free(client_name);
+		const char **ports = jack_get_ports( client, port_regexp, NULL, 0 );
+		if( !ports ) {
+			continue;
+		}
+		for (i = 0; ports[i]; ++i) {
+			const char **connections;
+			if ((connections = jack_port_get_all_connections (client, jack_port_by_name(client, ports[i]))) != 0) {
+				for (j = 0; connections[j]; j++) {
+					char *src = map_port_name_to_uuid_port( ports[i] );
+					char *dst = map_port_name_to_uuid_port( connections[j] );
+					printf( "jack_connect -u \"%s\" \"%s\"\n", src, dst );
+				}
+				jack_free (connections);
+			}
+		}
+		jack_free(ports);
+
+	}
+	jack_session_commands_free(retval);
+
+	jack_client_close(client);
+
+	return 0;
+}
diff -pruN 1.9.14~dfsg-1/tools/transport.c 1.9.16~dfsg-1/tools/transport.c
--- 1.9.14~dfsg-1/tools/transport.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/transport.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,508 @@
+/*
+ *  transport.c -- JACK transport master example client.
+ *
+ *  Copyright (C) 2003 Jack O'Quin.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <string.h>
+#if HAVE_READLINE
+#include <readline/readline.h>
+#include <readline/history.h>
+#endif
+#include <jack/jack.h>
+#include <jack/transport.h>
+
+/* Use a copy of the readline macro whitespace if it does not exist.
+ * Not all readline compatible libraries supply the whitespace macro
+ * (libedit for example), so pull in the copy in those cases too. */
+#if !HAVE_READLINE || !defined(whitespace)
+#define whitespace(c) (((c) == ' ') || ((c) == '\t'))
+#endif
+
+char *package;				/* program name */
+int done = 0;
+jack_client_t *client;
+
+/* Time and tempo variables.  These are global to the entire,
+ * transport timeline.  There is no attempt to keep a true tempo map.
+ * The default time signature is: "march time", 4/4, 120bpm
+ */
+float time_beats_per_bar = 4.0;
+float time_beat_type = 4.0;
+double time_ticks_per_beat = 1920.0;
+double time_beats_per_minute = 120.0;
+volatile int time_reset = 1;		/* true when time values change */
+
+/* JACK timebase callback.
+ *
+ * Runs in the process thread.  Realtime, must not wait.
+ */
+static void timebase(jack_transport_state_t state, jack_nframes_t nframes,
+	      jack_position_t *pos, int new_pos, void *arg)
+{
+	double min;			/* minutes since frame 0 */
+	long abs_tick;			/* ticks since frame 0 */
+	long abs_beat;			/* beats since frame 0 */
+
+	if (new_pos || time_reset) {
+
+		pos->valid = JackPositionBBT;
+		pos->beats_per_bar = time_beats_per_bar;
+		pos->beat_type = time_beat_type;
+		pos->ticks_per_beat = time_ticks_per_beat;
+		pos->beats_per_minute = time_beats_per_minute;
+
+		time_reset = 0;		/* time change complete */
+
+		/* Compute BBT info from frame number.  This is relatively
+		 * simple here, but would become complex if we supported tempo
+		 * or time signature changes at specific locations in the
+		 * transport timeline. */
+
+		min = pos->frame / ((double) pos->frame_rate * 60.0);
+		abs_tick = min * pos->beats_per_minute * pos->ticks_per_beat;
+		abs_beat = abs_tick / pos->ticks_per_beat;
+
+		pos->bar = abs_beat / pos->beats_per_bar;
+		pos->beat = abs_beat - (pos->bar * pos->beats_per_bar) + 1;
+		pos->tick = abs_tick - (abs_beat * pos->ticks_per_beat);
+		pos->bar_start_tick = pos->bar * pos->beats_per_bar *
+			pos->ticks_per_beat;
+		pos->bar++;		/* adjust start to bar 1 */
+
+#if 0
+		/* some debug code... */
+		fprintf(stderr, "\nnew position: %" PRIu32 "\tBBT: %3"
+			PRIi32 "|%" PRIi32 "|%04" PRIi32 "\n",
+			pos->frame, pos->bar, pos->beat, pos->tick);
+#endif
+
+	} else {
+
+		/* Compute BBT info based on previous period. */
+		pos->tick +=
+			nframes * pos->ticks_per_beat * pos->beats_per_minute
+			/ (pos->frame_rate * 60);
+
+		while (pos->tick >= pos->ticks_per_beat) {
+			pos->tick -= pos->ticks_per_beat;
+			if (++pos->beat > pos->beats_per_bar) {
+				pos->beat = 1;
+				++pos->bar;
+				pos->bar_start_tick +=
+					pos->beats_per_bar
+					* pos->ticks_per_beat;
+			}
+		}
+	}
+}
+
+static void jack_shutdown(void *arg)
+{
+#if defined(RL_READLINE_VERSION) && RL_READLINE_VERSION >= 0x0400
+	rl_cleanup_after_signal();
+#endif
+	fprintf(stderr, "JACK shut down, exiting ...\n");
+	exit(1);
+}
+
+static void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+/* Command functions: see commands[] table following. */
+
+static void com_activate(char *arg)
+{
+	if (jack_activate(client)) {
+		fprintf(stderr, "cannot activate client");
+	}
+}
+
+static void com_deactivate(char *arg)
+{
+	if (jack_deactivate(client)) {
+		fprintf(stderr, "cannot deactivate client");
+	}
+}
+
+static void com_exit(char *arg)
+{
+	done = 1;
+}
+
+static void com_help(char *);			/* forward declaration */
+
+static void com_locate(char *arg)
+{
+	jack_nframes_t frame = 0;
+
+	if (*arg != '\0')
+		frame = atoi(arg);
+
+	jack_transport_locate(client, frame);
+}
+
+static void com_master(char *arg)
+{
+	int cond = (*arg != '\0');
+	if (jack_set_timebase_callback(client, cond, timebase, NULL) != 0)
+		fprintf(stderr, "Unable to take over timebase.\n");
+}
+
+static void com_play(char *arg)
+{
+	jack_transport_start(client);
+}
+
+static void com_release(char *arg)
+{
+	jack_release_timebase(client);
+}
+
+static void com_stop(char *arg)
+{
+	jack_transport_stop(client);
+}
+
+/* Change the tempo for the entire timeline, not just from the current
+ * location. */
+static void com_tempo(char *arg)
+{
+	float tempo = 120.0;
+
+	if (*arg != '\0')
+		tempo = atof(arg);
+
+	time_beats_per_minute = tempo;
+	time_reset = 1;
+}
+
+/* Set sync timeout in seconds. */
+static void com_timeout(char *arg)
+{
+	double timeout = 2.0;
+
+	if (*arg != '\0')
+		timeout = atof(arg);
+
+	jack_set_sync_timeout(client, (jack_time_t) (timeout*1000000));
+}
+
+/* Toggle between play and stop state */
+static void com_toggle(char *arg)
+{
+	jack_position_t current;
+	jack_transport_state_t transport_state;
+
+	transport_state = jack_transport_query (client, &current);
+
+	switch (transport_state) {
+	case JackTransportStopped:
+		com_play( arg );
+		break;
+	case JackTransportRolling:
+		com_stop( arg );
+		break;
+	case JackTransportStarting:
+		fprintf(stderr, "state: Starting - no transport toggling");
+		break;
+	default:
+		fprintf(stderr, "unexpected state: no transport toggling");
+	}
+}
+
+
+/* Command parsing based on GNU readline info examples. */
+
+typedef void cmd_function_t(char *);	/* command function type */
+
+/* Transport command table. */
+typedef struct {
+	char *name;			/* user printable name */
+	cmd_function_t *func;		/* function to call */
+	char *doc;			/* documentation  */
+} command_t;
+
+/* command table must be in alphabetical order */
+command_t commands[] = {
+	{"activate",	com_activate,	"Call jack_activate()"},
+	{"exit",	com_exit,	"Exit transport program"},
+	{"deactivate",	com_deactivate,	"Call jack_deactivate()"},
+	{"help",	com_help,	"Display help text [<command>]"},
+	{"locate",	com_locate,	"Locate to frame <position>"},
+	{"master",	com_master,	"Become timebase master "
+					"[<conditionally>]"},
+	{"play",	com_play,	"Start transport rolling"},
+	{"quit",	com_exit,	"Synonym for `exit'"},
+	{"release",	com_release,	"Release timebase"},
+	{"stop",	com_stop,	"Stop transport"},
+	{"tempo",	com_tempo,	"Set beat tempo <beats_per_min>"},
+	{"timeout",	com_timeout,	"Set sync timeout in <seconds>"},
+	{"toggle",	com_toggle,	"Toggle transport rolling"},
+	{"?",		com_help,	"Synonym for `help'" },
+	{(char *)NULL, (cmd_function_t *)NULL, (char *)NULL }
+};
+
+static command_t *find_command(char *name)
+{
+	register int i;
+	size_t namelen;
+
+	if ((name == NULL) || (*name == '\0'))
+		return ((command_t *)NULL);
+
+	namelen = strlen(name);
+	for (i = 0; commands[i].name; i++)
+		if (strncmp(name, commands[i].name, namelen) == 0) {
+
+			/* make sure the match is unique */
+			if ((commands[i+1].name) &&
+			    (strncmp(name, commands[i+1].name, namelen) == 0))
+				return ((command_t *)NULL);
+			else
+				return (&commands[i]);
+		}
+
+	return ((command_t *)NULL);
+}
+
+static void com_help(char *arg)
+{
+	register int i;
+	command_t *cmd;
+
+	if (!*arg) {
+		/* print help for all commands */
+		for (i = 0; commands[i].name; i++) {
+			printf("%s\t\t%s.\n", commands[i].name,
+			       commands[i].doc);
+		}
+
+	} else if ((cmd = find_command(arg))) {
+		printf("%s\t\t%s.\n", cmd->name, cmd->doc);
+
+	} else {
+		int printed = 0;
+
+		printf("No `%s' command.  Valid command names are:\n", arg);
+
+		for (i = 0; commands[i].name; i++) {
+			/* Print in six columns. */
+			if (printed == 6) {
+				printed = 0;
+				printf ("\n");
+			}
+
+			printf ("%s\t", commands[i].name);
+			printed++;
+		}
+
+		printf("\n\nTry `help [command]\' for more information.\n");
+	}
+}
+
+static void execute_command(char *line)
+{
+	register int i;
+	command_t *command;
+	char *word;
+
+	/* Isolate the command word. */
+	i = 0;
+	while (line[i] && whitespace(line[i]))
+		i++;
+	word = line + i;
+
+	while (line[i] && !whitespace(line[i]))
+		i++;
+
+	if (line[i])
+		line[i++] = '\0';
+
+	command = find_command(word);
+
+	if (!command) {
+		fprintf(stderr, "%s: No such command.  There is `help\'.\n",
+			word);
+		return;
+	}
+
+	/* Get argument to command, if any. */
+	while (whitespace(line[i]))
+		i++;
+
+	word = line + i;
+
+	/* invoke the command function. */
+	(*command->func)(word);
+}
+
+
+/* Strip whitespace from the start and end of string. */
+static char *stripwhite(char *string)
+{
+	register char *s, *t;
+
+	s = string;
+	while (whitespace(*s))
+		s++;
+
+	if (*s == '\0')
+		return s;
+
+	t = s + strlen (s) - 1;
+	while (t > s && whitespace(*t))
+		t--;
+	*++t = '\0';
+
+	return s;
+}
+
+static char *dupstr(char *s)
+{
+	char *r = malloc(strlen(s) + 1);
+	strcpy(r, s);
+	return r;
+}
+
+/* Readline generator function for command completion. */
+static char *command_generator (const char *text, int state)
+{
+	static int list_index, len;
+	char *name;
+
+	/* If this is a new word to complete, initialize now.  This
+	   includes saving the length of TEXT for efficiency, and
+	   initializing the index variable to 0. */
+	if (!state) {
+		list_index = 0;
+		len = strlen (text);
+	}
+
+	/* Return the next name which partially matches from the
+	   command list. */
+	while ((name = commands[list_index].name)) {
+		list_index++;
+
+		if (strncmp(name, text, len) == 0)
+			return dupstr(name);
+	}
+
+	return (char *) NULL;		/* No names matched. */
+}
+
+static void command_loop()
+{
+#if HAVE_READLINE
+	char *line, *cmd;
+	char prompt[32];
+
+	snprintf(prompt, sizeof(prompt), "%s> ", package);
+
+	/* Allow conditional parsing of the ~/.inputrc file. */
+	rl_readline_name = package;
+
+	/* Define a custom completion function. */
+	rl_completion_entry_function = command_generator;
+#else
+	char line[64] = {0,};
+	char *cmd = NULL;
+#endif
+
+	/* Read and execute commands until the user quits. */
+	while (!done) {
+
+#if HAVE_READLINE
+		line = readline(prompt);
+
+		if (line == NULL) {	/* EOF? */
+			printf("\n");	/* close out prompt */
+			done = 1;
+			break;
+		}
+#else
+		printf("%s> ", package);
+		fgets(line, sizeof(line), stdin);
+		line[strlen(line)-1] = '\0';
+#endif
+
+		/* Remove leading and trailing whitespace from the line. */
+		cmd = stripwhite(line);
+
+		/* If anything left, add to history and execute it. */
+		if (*cmd)
+		{
+#if HAVE_READLINE
+			add_history(cmd);
+#endif
+			execute_command(cmd);
+		}
+
+#if HAVE_READLINE
+		free(line);		/* realine() called malloc() */
+#endif
+	}
+}
+
+int main(int argc, char *argv[])
+{
+	jack_status_t status;
+
+	/* basename $0 */
+	package = strrchr(argv[0], '/');
+	if (package == 0)
+		package = argv[0];
+	else
+		package++;
+
+	/* open a connection to the JACK server */
+	client = jack_client_open (package, JackNullOption, &status);
+	if (client == NULL) {
+		fprintf (stderr, "jack_client_open() failed, "
+			 "status = 0x%2.0x\n", status);
+		return 1;
+	}
+
+#if !WIN32
+	signal(SIGQUIT, signal_handler);
+	signal(SIGHUP, signal_handler);
+#endif
+	signal(SIGTERM, signal_handler);
+	signal(SIGINT, signal_handler);
+
+	jack_on_shutdown(client, jack_shutdown, 0);
+
+	if (jack_activate(client)) {
+		fprintf(stderr, "cannot activate client");
+		return 1;
+	}
+
+	/* execute commands until done */
+	command_loop();
+
+	jack_client_close(client);
+	exit(0);
+}
diff -pruN 1.9.14~dfsg-1/tools/tw.c 1.9.16~dfsg-1/tools/tw.c
--- 1.9.14~dfsg-1/tools/tw.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/tw.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,264 @@
+/** @file tw.c
+ *
+ * @brief This simple client demonstrates the basic features of JACK
+ * as they would be used by many applications.
+ */
+
+#include <stdio.h>
+#include <errno.h>
+#include <unistd.h>
+#include <stdlib.h>
+#include <string.h>
+#include <signal.h>
+
+#include <jack/jack.h>
+
+jack_port_t *input_port;
+jack_port_t *output_port;
+jack_client_t *client;
+
+/* a simple state machine for this client */
+volatile enum {
+	Init,
+	Run,
+	Exit
+} client_state = Init;
+
+static void signal_handler(int sig)
+{
+	jack_client_close(client);
+	fprintf(stderr, "signal received, exiting ...\n");
+	exit(0);
+}
+
+/**
+ * The process callback for this JACK application is called in a
+ * special realtime thread once for each audio cycle.
+ *
+ * This client follows a simple rule: when the JACK transport is
+ * running, copy the input port to the output.  When it stops, exit.
+ */
+static int
+_process (jack_nframes_t nframes)
+{
+	jack_default_audio_sample_t *in, *out;
+	jack_transport_state_t ts = jack_transport_query(client, NULL);
+
+	if (ts == JackTransportRolling) {
+
+		if (client_state == Init)
+			client_state = Run;
+
+		in = jack_port_get_buffer (input_port, nframes);
+		out = jack_port_get_buffer (output_port, nframes);
+		memcpy (out, in,
+			sizeof (jack_default_audio_sample_t) * nframes);
+
+	} else if (ts == JackTransportStopped) {
+
+		if (client_state == Run) {
+			client_state = Exit;
+			return -1;  // to stop the thread
+		}
+	}
+
+	return 0;
+}
+
+static void* jack_thread(void *arg)
+{
+	jack_client_t* client = (jack_client_t*) arg;
+
+	while (1) {
+
+		jack_nframes_t frames = jack_cycle_wait (client);
+		int status = _process(frames);
+		jack_cycle_signal (client, status);
+
+        /*
+            Possibly do something else after signaling next clients in the graph
+        */
+
+        /* End condition */
+        if (status != 0)
+            return 0;
+	}
+
+    /* not reached*/
+	return 0;
+}
+
+/*
+static void* jack_thread(void *arg)
+{
+	jack_client_t* client = (jack_client_t*) arg;
+
+	while (1) {
+		jack_nframes_t frames;
+		int status;
+		// cycle 1
+		frames = jack_cycle_wait (client);
+		status = _process(frames);
+		jack_cycle_signal (client, status);
+		// cycle 2
+		frames = jack_cycle_wait (client);
+		status = _process(frames);
+		jack_cycle_signal (client, status);
+		// cycle 3
+		frames = jack_cycle_wait (client);
+		status = _process(frames);
+		jack_cycle_signal (client, status);
+		// cycle 4
+		frames = jack_cycle_wait (client);
+		status = _process(frames);
+		jack_cycle_signal (client, status);
+	}
+
+	return 0;
+}
+*/
+
+/**
+ * JACK calls this shutdown_callback if the server ever shuts down or
+ * decides to disconnect the client.
+ */
+static void
+jack_shutdown (void *arg)
+{
+    fprintf(stderr, "JACK shut down, exiting ...\n");
+	exit (1);
+}
+
+int
+main (int argc, char *argv[])
+{
+	const char **ports;
+	const char *client_name;
+	const char *server_name = NULL;
+	jack_options_t options = JackNullOption;
+	jack_status_t status;
+
+	if (argc >= 2) {		/* client name specified? */
+		client_name = argv[1];
+		if (argc >= 3) {	/* server name specified? */
+			server_name = argv[2];
+			options |= JackServerName;
+		}
+	} else {			/* use basename of argv[0] */
+		client_name = strrchr(argv[0], '/');
+		if (client_name == 0) {
+			client_name = argv[0];
+		} else {
+			client_name++;
+		}
+	}
+
+	/* open a client connection to the JACK server */
+
+	client = jack_client_open (client_name, options, &status, server_name);
+	if (client == NULL) {
+		fprintf (stderr, "jack_client_open() failed, "
+			 "status = 0x%2.0x\n", status);
+		if (status & JackServerFailed) {
+			fprintf (stderr, "Unable to connect to JACK server\n");
+		}
+		exit (1);
+	}
+	if (status & JackServerStarted) {
+		fprintf (stderr, "JACK server started\n");
+	}
+	if (status & JackNameNotUnique) {
+		client_name = jack_get_client_name(client);
+		fprintf (stderr, "unique name `%s' assigned\n", client_name);
+	}
+
+	/* tell the JACK server to call `process()' whenever
+	   there is work to be done.
+	*/
+    if (jack_set_process_thread(client, jack_thread, client) < 0)
+		exit(1);
+
+	/* tell the JACK server to call `jack_shutdown()' if
+	   it ever shuts down, either entirely, or if it
+	   just decides to stop calling us.
+	*/
+
+	jack_on_shutdown (client, jack_shutdown, 0);
+
+	/* display the current sample rate.
+	 */
+
+	printf ("engine sample rate: %" PRIu32 "\n",
+		jack_get_sample_rate (client));
+
+	/* create two ports */
+
+	input_port = jack_port_register (client, "input",
+					 JACK_DEFAULT_AUDIO_TYPE,
+					 JackPortIsInput, 0);
+	output_port = jack_port_register (client, "output",
+					  JACK_DEFAULT_AUDIO_TYPE,
+					  JackPortIsOutput, 0);
+
+	if ((input_port == NULL) || (output_port == NULL)) {
+		fprintf(stderr, "no more JACK ports available\n");
+		exit (1);
+	}
+
+	/* Tell the JACK server that we are ready to roll.  Our
+	 * process() callback will start running now. */
+
+	if (jack_activate (client)) {
+		fprintf (stderr, "cannot activate client");
+		exit (1);
+	}
+
+	/* Connect the ports.  You can't do this before the client is
+	 * activated, because we can't make connections to clients
+	 * that aren't running.  Note the confusing (but necessary)
+	 * orientation of the driver backend ports: playback ports are
+	 * "input" to the backend, and capture ports are "output" from
+	 * it.
+	 */
+
+	ports = jack_get_ports (client, NULL, NULL,
+				JackPortIsPhysical|JackPortIsOutput);
+	if (ports == NULL) {
+		fprintf(stderr, "no physical capture ports\n");
+		exit (1);
+	}
+
+	if (jack_connect (client, ports[0], jack_port_name (input_port))) {
+		fprintf (stderr, "cannot connect input ports\n");
+	}
+
+	jack_free (ports);
+
+	ports = jack_get_ports (client, NULL, NULL,
+				JackPortIsPhysical|JackPortIsInput);
+	if (ports == NULL) {
+		fprintf(stderr, "no physical playback ports\n");
+		exit (1);
+	}
+
+	if (jack_connect (client, jack_port_name (output_port), ports[0])) {
+		fprintf (stderr, "cannot connect output ports\n");
+	}
+
+	jack_free (ports);
+
+    /* install a signal handler to properly quits jack client */
+    signal(SIGQUIT, signal_handler);
+	signal(SIGTERM, signal_handler);
+	signal(SIGHUP, signal_handler);
+	signal(SIGINT, signal_handler);
+
+	/* keep running until the transport stops */
+
+	while (client_state != Exit) {
+		sleep (1);
+	}
+
+	jack_client_close (client);
+	exit (0);
+}
diff -pruN 1.9.14~dfsg-1/tools/wait.c 1.9.16~dfsg-1/tools/wait.c
--- 1.9.14~dfsg-1/tools/wait.c	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/wait.c	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,152 @@
+#include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <string.h>
+#include <getopt.h>
+
+#include <time.h>
+
+#include <jack/jack.h>
+
+char * my_name;
+
+void
+show_usage(void)
+{
+	fprintf(stderr, "\nUsage: %s [options]\n", my_name);
+	fprintf(stderr, "Check for jack existence, or wait, until it either quits, or gets started\n");
+	fprintf(stderr, "options:\n");
+	fprintf(stderr, "        -s, --server <name>   Connect to the jack server named <name>\n");
+	fprintf(stderr, "        -n, --name <name>     Set client name to <name>\n");
+	fprintf(stderr, "        -w, --wait            Wait for server to become available\n");
+	fprintf(stderr, "        -q, --quit            Wait until server is quit\n");
+	fprintf(stderr, "        -c, --check           Check whether server is running\n");
+	fprintf(stderr, "        -t, --timeout         Wait timeout in seconds\n");
+	fprintf(stderr, "        -h, --help            Display this help message\n");
+	fprintf(stderr, "For more information see http://jackaudio.org/\n");
+}
+
+int
+main(int argc, char *argv[])
+{
+	jack_client_t *client;
+	jack_status_t status;
+	jack_options_t options = JackNoStartServer;
+	int c;
+	int option_index;
+	char *server_name = NULL;
+	char *client_name = NULL;
+	int wait_for_start = 0;
+	int wait_for_quit = 0;
+	int just_check = 0;
+	int wait_timeout = 0;
+	time_t start_timestamp;
+
+
+	struct option long_options[] = {
+		{ "server", 1, 0, 's' },
+		{ "wait", 0, 0, 'w' },
+		{ "name", 1, 0, 'n'}, 
+		{ "quit", 0, 0, 'q' },
+		{ "check", 0, 0, 'c' },
+		{ "timeout", 1, 0, 't' },
+		{ "help", 0, 0, 'h' },
+		{ 0, 0, 0, 0 }
+	};
+
+	my_name = strrchr(argv[0], '/');
+	if (my_name == 0) {
+		my_name = argv[0];
+	} else {
+		my_name ++;
+	}
+
+	while ((c = getopt_long (argc, argv, "s:n:wqct:hv", long_options, &option_index)) >= 0) {
+		switch (c) {
+		case 's':
+			server_name = (char *) malloc (sizeof (char) * (strlen(optarg) + 1));
+			strcpy (server_name, optarg);
+			options |= JackServerName;
+			break;
+		case 'n':
+			client_name = (char *) malloc (sizeof (char) * (strlen(optarg) + 1));
+			strcpy (client_name, optarg);
+			break;
+		case 'w':
+			wait_for_start = 1;
+			break;
+		case 'q':
+			wait_for_quit = 1;
+			break;
+		case 'c':
+			just_check = 1;
+			break;
+		case 't':
+			wait_timeout = atoi(optarg);
+			break;
+		case 'h':
+			show_usage();
+			return 1;
+			break;
+		default:
+			show_usage();
+			return 1;
+			break;
+		}
+	}
+
+	/* try to open server in a loop. breaking under certein conditions */
+
+	start_timestamp = time(NULL);
+
+	while (1) {
+		if (client_name) {
+			client = jack_client_open (client_name, options, &status, server_name);
+		}
+		else {
+			client = jack_client_open ("wait", options, &status, server_name);
+		}
+		/* check for some real error and bail out */
+		if ((client == NULL) && !(status & JackServerFailed)) {
+			fprintf (stderr, "jack_client_open() failed, "
+					"status = 0x%2.0x\n", status);
+			return 1;
+		}
+
+		if (client == NULL) {
+			if (wait_for_quit) {
+				fprintf(stdout, "server is gone\n");
+				break;
+			}
+			if (just_check) {
+				fprintf(stdout, "not running\n");
+				break;
+			}
+		} else {
+			jack_client_close(client);
+			if (wait_for_start) {
+				fprintf(stdout, "server is available\n");
+				break;
+			}
+			if (just_check) {
+				fprintf(stdout, "running\n");
+				break;
+			}
+		}
+		if (wait_timeout) {
+			if ((time(NULL) - start_timestamp) > wait_timeout) {
+				fprintf(stdout, "timeout\n");
+				exit(EXIT_FAILURE);
+			}
+		}
+
+		// Wait a second, and repeat
+#ifdef WIN32
+		Sleep(1*1000);
+#else
+		sleep(1);
+#endif
+	}
+
+	exit(0);
+}
diff -pruN 1.9.14~dfsg-1/tools/wscript 1.9.16~dfsg-1/tools/wscript
--- 1.9.14~dfsg-1/tools/wscript	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/tools/wscript	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,94 @@
+#! /usr/bin/python3
+# encoding: utf-8
+
+example_tools = {
+    'jack_alias' : 'alias.c',
+    'jack_bufsize' : 'bufsize.c',
+    'jack_connect' : 'connect.c',
+    'jack_evmon' : 'evmon.c',
+    'jack_freewheel' : 'freewheel.c',
+    'jack_load' : 'ipload.c',
+    'jack_lsp' : 'lsp.c',
+    'jack_midi_dump' : 'midi_dump.c',
+    'jack_monitor_client' : 'monitor_client.c',
+    'jack_property' : 'property.c',
+    'jack_samplerate' : 'samplerate.c',
+    'jack_session_notify' : 'session_notify.c',
+    'jack_unload' : 'ipunload.c',
+    'jack_wait' : 'wait.c',
+    }
+
+def configure(conf):
+    conf.env['BUILD_EXAMPLE_ALSA_IO'] = conf.env['SAMPLERATE'] and conf.env['BUILD_DRIVER_ALSA']
+    conf.env['BUILD_EXAMPLE_CLIENT_TRANSPORT'] = conf.env['READLINE']
+
+def build(bld):
+    if bld.env['IS_LINUX']:
+        os_incdir = ['../linux', '../posix']
+    if bld.env['IS_MACOSX']:
+        os_incdir = ['../macosx', '../posix']
+    if bld.env['IS_SUN']:
+        os_incdir = ['../solaris', '../posix']
+    if bld.env['IS_WINDOWS']:
+        os_incdir = ['../windows']
+    for example_tool, example_tool_source in list(example_tools.items()):
+        if bld.env['IS_MACOSX']:
+            prog = bld(features='c cprogram', framework = ['Foundation'])
+        else:
+            prog = bld(features='c cprogram')
+        prog.includes = os_incdir + ['../common/jack', '../common']
+        prog.source = example_tool_source
+        prog.use = ['clientlib']
+        if bld.env['IS_LINUX']:
+            prog.use += ['RT', 'M']
+        if bld.env['IS_SUN']:
+            prog.use += ['M']
+        if bld.env['IS_WINDOWS'] and bld.env['BUILD_STATIC']:
+            prog.env['LIB_PTHREAD'] = [':libwinpthread.a']
+        #prog.cflags = ['-Wno-deprecated-declarations', '-Wno-misleading-indentation']
+        #prog.cxxflags = ['-Wno-deprecated-declarations', '-Wno-misleading-indentation']
+
+        prog.target = example_tool
+
+    if bld.env['BUILD_EXAMPLE_CLIENT_TRANSPORT']:
+        prog = bld(features = 'c cprogram')
+        prog.includes = os_incdir + ['../common/jack', '../common']
+        prog.source = 'transport.c'
+        prog.use = ['clientlib']
+        if bld.env['IS_LINUX']:
+            prog.use += ['RT', 'READLINE']
+        if bld.env['IS_MACOSX']:
+            prog.use += ['READLINE']
+        if bld.env['IS_WINDOWS']:
+            prog.use += ['READLINE']
+            if bld.env['BUILD_STATIC']:
+                prog.env['LIB_PTHREAD'] = [':libwinpthread.a']
+        prog.target = 'jack_transport'
+
+    if bld.env['IS_LINUX'] or bld.env['IS_MACOSX']:
+        prog = bld(features = 'c cprogram')
+        prog.includes = os_incdir + ['.', '..', '../common/jack', '../common']
+        prog.source = ['netsource.c', '../common/netjack_packet.c']
+        prog.env.append_value('CFLAGS', '-DNO_JACK_ERROR')
+        prog.use = ['CELT', 'SAMPLERATE', 'OPUS', 'M', 'clientlib']
+        prog.target = 'jack_netsource'
+        prog.defines = ['HAVE_CONFIG_H']
+
+    if bld.env['IS_LINUX'] and bld.env['BUILD_EXAMPLE_ALSA_IO']:
+        prog = bld(features = 'c cprogram')
+        prog.includes = os_incdir + ['../common/jack', '../common']
+        prog.source = ['alsa_in.c', '../common/memops.c']
+        prog.env.append_value('CFLAGS', '-DNO_JACK_ERROR')
+        prog.use = ['clientlib', 'ALSA', 'SAMPLERATE', 'M']
+        prog.target = 'alsa_in'
+
+        prog = bld(features = 'c cprogram')
+        prog.includes = os_incdir + ['../common/jack', '../common']
+        prog.source = ['alsa_out.c', '../common/memops.c']
+        prog.env.append_value('CFLAGS', '-DNO_JACK_ERROR')
+        prog.use = ['clientlib', 'ALSA', 'SAMPLERATE', 'M']
+        prog.target = 'alsa_out'
+
+    if not bld.env['IS_WINDOWS']:
+        bld.symlink_as('${PREFIX}/bin/jack_disconnect', 'jack_connect')
+        bld.install_files('${PREFIX}/bin', 'jack_control', chmod=0o755)
diff -pruN 1.9.14~dfsg-1/.travis.yml 1.9.16~dfsg-1/.travis.yml
--- 1.9.14~dfsg-1/.travis.yml	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/.travis.yml	2020-10-16 19:10:40.000000000 +0000
@@ -4,6 +4,18 @@ sudo: required
 
 matrix:
   include:
+    # linux with gcc 9
+    - os: linux
+      addons:
+        apt:
+          sources:
+            - ubuntu-toolchain-r-test
+          install:
+            - gcc-9
+      dist: bionic
+      env:
+        - MATRIX_EVAL="CC=gcc-9 CXX=g++-9"
+      compiler: gcc
     # linux with gcc 8
     - os: linux
       addons:
@@ -12,7 +24,7 @@ matrix:
             - ubuntu-toolchain-r-test
           install:
             - gcc-8
-      dist: xenial
+      dist: bionic
       env:
         - MATRIX_EVAL="CC=gcc-8 CXX=g++-8"
       compiler: gcc
@@ -24,7 +36,7 @@ matrix:
             - ubuntu-toolchain-r-test
           install:
             - gcc-7
-      dist: xenial
+      dist: bionic
       env:
         - MATRIX_EVAL="CC=gcc-7 CXX=g++-7"
       compiler: gcc
@@ -36,17 +48,45 @@ matrix:
             - ubuntu-toolchain-r-test
           install:
             - gcc-6
-      dist: xenial
+      dist: bionic
       env:
         - MATRIX_EVAL="CC=gcc-6 CXX=g++-6"
       compiler: gcc
-    # linux with gcc default (4.8)
+    # linux with gcc 5
     - os: linux
-      dist: xenial
+      dist: bionic
+      env:
+        - MATRIX_EVAL="CC=gcc CXX=g++"
       compiler: gcc
-    # linux with clang default (3.5)
+    # linux with gcc 4
     - os: linux
       dist: xenial
+      env:
+        - MATRIX_EVAL="CC=gcc CXX=g++"
+      compiler: gcc
+    # linux with clang 8
+    - os: linux
+      addons:
+        apt:
+          sources:
+            - ubuntu-toolchain-r-test
+          install:
+            - clang-8
+      dist: bionic
+      env:
+        - MATRIX_EVAL="CC=clang-8 CXX=clang++-8"
+      compiler: clang
+    # linux with clang 6
+    - os: linux
+      addons:
+        apt:
+          sources:
+            - ubuntu-toolchain-r-test
+          install:
+            - clang-6.0
+      dist: bionic
+      env:
+        - MATRIX_EVAL="CC=clang-6.0 CXX=clang++-6.0"
       compiler: clang
     # linux with clang 3.8
     - os: linux
@@ -60,31 +100,31 @@ matrix:
       env:
         - MATRIX_EVAL="CC=clang-3.8 CXX=clang++-3.8"
       compiler: clang
-    # osx with xcode8.3/clang
-    - os: osx
-      osx_image: xcode8.3
-      compiler: clang
-    # osx with xcode9.2/clang
-    - os: osx
-      osx_image: xcode9.2
-      compiler: clang
-    # osx with xcode10.0/clang
-    - os: osx
-      osx_image: xcode10
-      compiler: clang
-    # osx with xcode10.1/clang
-    - os: osx
-      osx_image: xcode10.1
-      compiler: clang
-    # osx with xcode/clang (default)
-    - os: osx
-      compiler: clang
+    ## osx with xcode8.3/clang
+    #- os: osx
+      #osx_image: xcode8.3
+      #compiler: clang
+    ## osx with xcode9.2/clang
+    #- os: osx
+      #osx_image: xcode9.2
+      #compiler: clang
+    ## osx with xcode10.0/clang
+    #- os: osx
+      #osx_image: xcode10
+      #compiler: clang
+    ## osx with xcode10.1/clang
+    #- os: osx
+      #osx_image: xcode10.1
+      #compiler: clang
+    ## osx with xcode/clang (default)
+    #- os: osx
+      #compiler: clang
 
 before_install:
   - eval "${MATRIX_EVAL}"
     # uninstalling oclint, as it's preinstalled and conflicts with all versions of gcc
   - if [[ "$TRAVIS_OS_NAME" == "osx" ]]; then
-    brew cask uninstall oclint || true
+    brew cask uninstall oclint || true;
     brew update;
     fi
   - if [[ "$TRAVIS_OS_NAME" == "linux" ]]; then sudo apt-get -qq update; fi
@@ -99,12 +139,13 @@ script:
     - if [ "$TRAVIS_OS_NAME" == "linux" ]; then
         ./waf configure --prefix=/usr --alsa --classic --dbus --systemd-unit;
         ./waf -v build;
+        sudo ./waf -v install;
       fi
     - if [ "$TRAVIS_OS_NAME" == "osx" ]; then
-        CXXFLAGS="${CXXFLAGS} -flax-vector-conversions" ./waf configure;
-        CXXFLAGS="${CXXFLAGS} -flax-vector-conversions" ./waf -v build;
+        CXXFLAGS="${CXXFLAGS} -flax-vector-conversions" python2 ./waf configure;
+        CXXFLAGS="${CXXFLAGS} -flax-vector-conversions" python2 ./waf -v build;
+        sudo python2 ./waf -v install;
       fi
-    - sudo ./waf -v install
 # run very basic tests
     - sudo .ci/test_run.sh
 
Binary files 1.9.14~dfsg-1/windows/inno/jack.ico and 1.9.16~dfsg-1/windows/inno/jack.ico differ
diff -pruN 1.9.14~dfsg-1/windows/inno/win32.iss 1.9.16~dfsg-1/windows/inno/win32.iss
--- 1.9.14~dfsg-1/windows/inno/win32.iss	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/windows/inno/win32.iss	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,53 @@
+#include "version.iss"
+
+[Setup]
+AppName=JACK2
+AppPublisher=jackaudio.org
+AppPublisherURL=https://github.com/jackaudio/jack2/
+AppSupportURL=https://github.com/jackaudio/jack2/issues/
+AppUpdatesURL=https://github.com/jackaudio/jack2-releases/releases/
+AppVersion={#VERSION}
+DefaultDirName={commonpf32}\JACK2
+DisableDirPage=yes
+OutputBaseFilename=jack2-win32-{#VERSION}
+OutputDir=.
+UsePreviousAppDir=no
+
+[Types]
+Name: "full"; Description: "Full installation";
+Name: "custom"; Description: "Custom installation"; Flags: iscustom;
+
+[Components]
+Name: qjackctl; Description: "QJackCtl application (recommended)"; Types: full;
+Name: dev; Description: "Developer resources"; Types: full;
+
+[Files]
+; icon
+Source: "jack.ico"; DestDir: "{app}";
+; jackd and server libs
+Source: "win32\bin\jackd.exe"; DestDir: "{app}";
+Source: "win32\lib\libjacknet.dll"; DestDir: "{app}";
+Source: "win32\lib\libjackserver.dll"; DestDir: "{app}";
+; drivers
+Source: "win32\lib\jack\*.dll"; DestDir: "{app}\jack";
+; tools
+Source: "win32\bin\jack_*.exe"; DestDir: "{app}\tools";
+; jack client lib (NOTE goes into windir)
+Source: "win32\lib\libjack.dll"; DestDir: "{win}";
+; qjackctl
+Source: "win32\bin\qjackctl.exe"; DestDir: "{app}\qjackctl"; Components: qjackctl;
+Source: "Qt5*.dll"; DestDir: "{app}\qjackctl"; Components: qjackctl;
+Source: "qwindows.dll"; DestDir: "{app}\qjackctl\platforms"; Components: qjackctl;
+; dev
+Source: "win32\include\jack\*.h"; DestDir: "{app}\include\jack"; Components: dev;
+Source: "win32\lib\*.a"; DestDir: "{app}\lib"; Components: dev;
+Source: "win32\lib\*.def"; DestDir: "{app}\lib"; Components: dev;
+Source: "win32\lib\*.lib"; DestDir: "{app}\lib"; Components: dev;
+Source: "win32\lib\jack\*.a"; DestDir: "{app}\lib\jack"; Components: dev;
+
+[Icons]
+Name: "{commonprograms}\QJackCtl"; Filename: "{app}\qjackctl\qjackctl.exe"; IconFilename: "{app}\jack.ico"; WorkingDir: "{app}"; Comment: "Graphical Interface for JACK"; Components: qjackctl;
+
+[Registry]
+Root: HKLM; Subkey: "Software\JACK"; Flags: deletevalue uninsdeletekeyifempty uninsdeletevalue; ValueType: string; ValueName: "Location"; ValueData: "{app}\jackd.exe"
+Root: HKLM; Subkey: "Software\JACK"; Flags: deletevalue uninsdeletekeyifempty uninsdeletevalue; ValueType: string; ValueName: "Version"; ValueData: "{#VERSION}"
diff -pruN 1.9.14~dfsg-1/windows/inno/win64.iss 1.9.16~dfsg-1/windows/inno/win64.iss
--- 1.9.14~dfsg-1/windows/inno/win64.iss	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/windows/inno/win64.iss	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,58 @@
+#include "version.iss"
+
+[Setup]
+ArchitecturesInstallIn64BitMode=x64
+AppName=JACK2
+AppPublisher=jackaudio.org
+AppPublisherURL=https://github.com/jackaudio/jack2/
+AppSupportURL=https://github.com/jackaudio/jack2/issues/
+AppUpdatesURL=https://github.com/jackaudio/jack2-releases/releases/
+AppVersion={#VERSION}
+DefaultDirName={commonpf64}\JACK2
+DisableDirPage=yes
+OutputBaseFilename=jack2-win64-{#VERSION}
+OutputDir=.
+UsePreviousAppDir=no
+
+[Types]
+Name: "full"; Description: "Full installation";
+Name: "custom"; Description: "Custom installation"; Flags: iscustom;
+
+[Components]
+Name: qjackctl; Description: "QJackCtl application (recommended)"; Types: full;
+Name: dev; Description: "Developer resources"; Types: full;
+
+[Files]
+; icon
+Source: "jack.ico"; DestDir: "{app}";
+; jackd and server libs
+Source: "win64\bin\jackd.exe"; DestDir: "{app}";
+Source: "win64\lib\libjacknet64.dll"; DestDir: "{app}";
+Source: "win64\lib\libjackserver64.dll"; DestDir: "{app}";
+; drivers
+Source: "win64\lib\jack\*.dll"; DestDir: "{app}\jack";
+; tools
+Source: "win64\bin\jack_*.exe"; DestDir: "{app}\tools";
+; jack client lib (NOTE goes into windir)
+Source: "win64\lib\libjack64.dll"; DestDir: "{win}";
+Source: "win64\lib32\libjack.dll"; DestDir: "{win}";
+; qjackctl
+Source: "win64\bin\qjackctl.exe"; DestDir: "{app}\qjackctl"; Components: qjackctl;
+Source: "Qt5*.dll"; DestDir: "{app}\qjackctl"; Components: qjackctl;
+Source: "qwindows.dll"; DestDir: "{app}\qjackctl\platforms"; Components: qjackctl;
+; dev
+Source: "win64\include\jack\*.h"; DestDir: "{app}\include\jack"; Components: dev;
+Source: "win64\lib\*.a"; DestDir: "{app}\lib"; Components: dev;
+Source: "win64\lib\*.def"; DestDir: "{app}\lib"; Components: dev;
+Source: "win64\lib\*.lib"; DestDir: "{app}\lib"; Components: dev;
+Source: "win64\lib32\*.a"; DestDir: "{app}\lib32"; Components: dev;
+Source: "win64\lib32\*.def"; DestDir: "{app}\lib32"; Components: dev;
+Source: "win64\lib32\*.lib"; DestDir: "{app}\lib32"; Components: dev;
+Source: "win64\lib\jack\*.a"; DestDir: "{app}\lib\jack"; Components: dev;
+
+[Icons]
+Name: "{commonprograms}\QJackCtl"; Filename: "{app}\qjackctl\qjackctl.exe"; IconFilename: "{app}\jack.ico"; WorkingDir: "{app}"; Comment: "Graphical Interface for JACK"; Components: qjackctl;
+
+[Registry]
+Root: HKLM; Subkey: "Software\JACK"; Flags: deletevalue uninsdeletekeyifempty uninsdeletevalue; ValueType: string; ValueName: "Location"; ValueData: "{app}\jackd.exe"
+Root: HKLM; Subkey: "Software\JACK"; Flags: deletevalue uninsdeletekeyifempty uninsdeletevalue; ValueType: string; ValueName: "Version"; ValueData: "{#VERSION}"
diff -pruN 1.9.14~dfsg-1/windows/jack_audioadapter.cbp 1.9.16~dfsg-1/windows/jack_audioadapter.cbp
--- 1.9.14~dfsg-1/windows/jack_audioadapter.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_audioadapter.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,215 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_audioadapter" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\audioadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-D__SMP__" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libportaudio_x86_64.a" />
-					<Add library="libsamplerate_x86_64.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\audioadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-D__SMP__" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libportaudio_x86_64.a" />
-					<Add library="libsamplerate_x86_64.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\audioadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libportaudio_x86_64.a" />
-					<Add library="libsamplerate_x86_64.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\audioadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-D__SMP__" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libportaudio_x86.a" />
-					<Add library="libsamplerate_x86.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackaudioadapter.res jackaudioadapter.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\audioadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-D__SMP__" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libportaudio_x86.a" />
-					<Add library="libsamplerate_x86.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackaudioadapter.res jackaudioadapter.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\audioadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libportaudio_x86.a" />
-					<Add library="libsamplerate_x86.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackaudioadapter.res jackaudioadapter.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\common\JackAudioAdapter.cpp" />
-		<Unit filename="..\common\JackAudioAdapterFactory.cpp" />
-		<Unit filename="..\common\JackAudioAdapterInterface.cpp" />
-		<Unit filename="..\common\JackLibSampleRateResampler.cpp" />
-		<Unit filename="..\common\JackResampler.cpp" />
-		<Unit filename="jackaudioadapter.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Unit filename="portaudio\JackPortAudioAdapter.cpp" />
-		<Unit filename="portaudio\JackPortAudioDevices.cpp" />
-		<Extensions>
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-			<code_completion />
-			<envvars />
-			<debugger />
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackaudioadapter.rc 1.9.16~dfsg-1/windows/jackaudioadapter.rc
--- 1.9.14~dfsg-1/windows/jackaudioadapter.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackaudioadapter.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp Audio Adapter for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "audioadapter\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "audioadapter.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "audioadapter\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jack_connect.cbp 1.9.16~dfsg-1/windows/jack_connect.cbp
--- 1.9.14~dfsg-1/windows/jack_connect.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_connect.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,163 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_connect" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_connect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_connect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_connect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_connect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_connect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_connect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\connect.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt1.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-			<envvars />
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackd.cbp 1.9.16~dfsg-1/windows/jackd.cbp
--- 1.9.14~dfsg-1/windows/jackd.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackd.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,215 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jackd" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jackd" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Option parameters="-R -S -d net" />
-				<Option host_application="jackdmp.exe" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-Wl,-subsystem,windows" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_POSIX" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jackd" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Option parameters="-R -S -d net" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_POSIX" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jackd" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Option parameters="-R -S -d net" />
-				<Option host_application="jackdmp.exe" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-D_POSIX" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jackd" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Option parameters="-R -S -d net" />
-				<Option host_application="jackdmp.exe" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-Wl,-subsystem,windows" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_POSIX" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackd.res jackd.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jackd" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Option parameters="-R -S -d net" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_POSIX" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackd.res jackd.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jackd" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Option parameters="-R -S -d net" />
-				<Option host_application="jackdmp.exe" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-D_POSIX" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackd.res jackd.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\common\Jackdmp.cpp" />
-		<Unit filename="getopt.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt1.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="jackd.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_disconnect.cbp 1.9.16~dfsg-1/windows/jack_disconnect.cbp
--- 1.9.14~dfsg-1/windows/jack_disconnect.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_disconnect.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,167 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_disconnect" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_disconnect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_disconnect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_disconnect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_disconnect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_disconnect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Debug\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_disconnect" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-			<Add directory="..\example-clients" />
-			<Add directory="..\windows" />
-			<Add directory="..\common\jack" />
-			<Add directory="..\common" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\connect.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt1.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<debugger />
-			<envvars />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackd.rc 1.9.16~dfsg-1/windows/jackd.rc
--- 1.9.14~dfsg-1/windows/jackd.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackd.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_APP
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jack server for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jackd\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jackd.exe\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jackd\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
-
-
-//
-// Icon resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-IDI_ICON1          ICON           ".\\Setup\\src\\jack.ico"
diff -pruN 1.9.14~dfsg-1/windows/jack_dummy.cbp 1.9.16~dfsg-1/windows/jack_dummy.cbp
--- 1.9.14~dfsg-1/windows/jack_dummy.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_dummy.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,173 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_dummy" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\jack_dummy" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\jack_dummy" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\jack_dummy" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\jack_dummy" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackdummydriver.res jackdummydriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\jack_dummy" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackdummydriver.res jackdummydriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\jack_dummy" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackdummydriver.res jackdummydriver.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\common\JackDummyDriver.cpp" />
-		<Unit filename="jackdummydriver.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-			<code_completion />
-			<envvars />
-			<debugger />
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackdummydriver.rc 1.9.16~dfsg-1/windows/jackdummydriver.rc
--- 1.9.14~dfsg-1/windows/jackdummydriver.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackdummydriver.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp Dummy Driver for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jack_dummy\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jack_dummy.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jack_dummy\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jackd.workspace 1.9.16~dfsg-1/windows/jackd.workspace
--- 1.9.14~dfsg-1/windows/jackd.workspace	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackd.workspace	1970-01-01 00:00:00.000000000 +0000
@@ -1,30 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_workspace_file>
-	<Workspace title="jack">
-		<Project filename="libjack.cbp" />
-		<Project filename="libjacknet.cbp" />
-		<Project filename="libjackserver.cbp" />
-		<Project filename="jack_portaudio.cbp" />
-		<Project filename="jack_netdriver.cbp" />
-		<Project filename="jack_netonedriver.cbp" />
-		<Project filename="jack_dummy.cbp" />
-		<Project filename="jack_netmanager.cbp" />
-		<Project filename="jack_audioadapter.cbp" />
-		<Project filename="jack_load.cbp" />
-		<Project filename="jack_unload.cbp" />
-		<Project filename="jack_lsp.cbp" />
-		<Project filename="jack_latent_client.cbp" />
-		<Project filename="jack_metro.cbp" />
-		<Project filename="jack_connect.cbp" />
-		<Project filename="jack_disconnect.cbp" />
-		<Project filename="jack_test.cbp" />
-		<Project filename="multiple_metro.cbp" />
-		<Project filename="jack_winmme.cbp" />
-		<Project filename="jack_loopback.cbp" />
-		<Project filename="jackd.cbp" />
-		<Project filename="jack_midi_latency_test.cbp" />
-		<Project filename="jack_netadapter.cbp" active="1" />
-		<Project filename="jack_netsource.cbp" />
-		<Project filename="jack_midi_dump.cbp" />
-	</Workspace>
-</CodeBlocks_workspace_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_latent_client.cbp 1.9.16~dfsg-1/windows/jack_latent_client.cbp
--- 1.9.14~dfsg-1/windows/jack_latent_client.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_latent_client.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_latent_client" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_latent_client" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_latent_client" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_latent_client" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_latent_client" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_latent_client" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Debug\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_latent_client" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\latent_client.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_load.cbp 1.9.16~dfsg-1/windows/jack_load.cbp
--- 1.9.14~dfsg-1/windows/jack_load.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_load.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,155 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_load" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_load" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_load" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_load" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_load" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_load" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Debug\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_load" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\ipload.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_loopback.cbp 1.9.16~dfsg-1/windows/jack_loopback.cbp
--- 1.9.14~dfsg-1/windows/jack_loopback.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_loopback.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,173 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_loopback" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\jack_loopback" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-                			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\jack_loopback" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-              			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\jack_loopback" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-             			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\jack_loopback" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                   			 <Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-                 			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackloopbackdriver.res jackloopbackdriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\jack_loopback" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-                			<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-              				<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Debug\bin" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackloopbackdriver.res jackloopbackdriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\jack_loopback" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                 			<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-                			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackloopbackdriver.res jackloopbackdriver.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="jackloopbackdriver.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Unit filename="..\common\JackLoopbackDriver.cpp" />
-		<Extensions>
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-			<code_completion />
-			<envvars />
-			<debugger />
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackloopbackdriver.rc 1.9.16~dfsg-1/windows/jackloopbackdriver.rc
--- 1.9.14~dfsg-1/windows/jackloopbackdriver.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackloopbackdriver.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp Loopback Driver for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jack_loopback\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jack_loopback.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jack_loopback\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jack_lsp.cbp 1.9.16~dfsg-1/windows/jack_lsp.cbp
--- 1.9.14~dfsg-1/windows/jack_lsp.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_lsp.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_lsp" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_lsp" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_lsp" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_lsp" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_lsp" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_lsp" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Debug\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_lsp" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\lsp.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_metro.cbp 1.9.16~dfsg-1/windows/jack_metro.cbp
--- 1.9.14~dfsg-1/windows/jack_metro.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_metro.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,158 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_metro" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\metro.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_midi_dump.cbp 1.9.16~dfsg-1/windows/jack_midi_dump.cbp
--- 1.9.14~dfsg-1/windows/jack_midi_dump.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_midi_dump.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,114 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_midi_dump" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_midi_dump" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_midi_dump" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_midi_dump" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Debug\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_midi_dump" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\midi_dump.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jack_midi_latency_test.cbp 1.9.16~dfsg-1/windows/jack_midi_latency_test.cbp
--- 1.9.14~dfsg-1/windows/jack_midi_latency_test.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_midi_latency_test.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_midi_latency_test" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_midi_latency_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_midi_latency_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_midi_latency_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_midi_latency_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_midi_latency_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Debug\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_midi_latency_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\midi_latency_test.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/JackMMCSS.h 1.9.16~dfsg-1/windows/JackMMCSS.h
--- 1.9.14~dfsg-1/windows/JackMMCSS.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackMMCSS.h	2020-10-16 19:10:40.000000000 +0000
@@ -24,6 +24,9 @@
 
 #include "JackSystemDeps.h"
 #include "JackCompilerDeps.h"
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 #include <map>
 
diff -pruN 1.9.14~dfsg-1/windows/jack_netadapter.cbp 1.9.16~dfsg-1/windows/jack_netadapter.cbp
--- 1.9.14~dfsg-1/windows/jack_netadapter.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_netadapter.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,187 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_netadapter" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\netadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-                   			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libsamplerate_x86_64.a" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\netadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-                   			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libsamplerate_x86_64.a" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\netadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-                 			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libsamplerate_x86_64.a" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\netadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-                  			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libsamplerate_x86.a" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetadapter.res jacknetadapter.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\netadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-                			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libsamplerate_x86.a" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jacknetadapter.res jacknetadapter.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\netadapter" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-               				<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libsamplerate_x86.a" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetadapter.res jacknetadapter.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-			<Add directory="..\windows" />
-			<Add directory="..\common\jack" />
-			<Add directory="..\common" />
-		</Compiler>
-		<Linker>
-			<Add option="-enable-auto-import" />
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\common\JackAudioAdapter.cpp" />
-		<Unit filename="..\common\JackAudioAdapterInterface.cpp" />
-		<Unit filename="..\common\JackLibSampleRateResampler.cpp" />
-		<Unit filename="..\common\JackNetAdapter.cpp" />
-		<Unit filename="..\common\JackResampler.cpp" />
-		<Unit filename="jacknetadapter.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-			<code_completion />
-			<envvars />
-			<debugger />
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jacknetadapter.rc 1.9.16~dfsg-1/windows/jacknetadapter.rc
--- 1.9.14~dfsg-1/windows/jacknetadapter.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jacknetadapter.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp NetAdapter for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "netadapter\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "netadapter.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "netadapter\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jack_netdriver.cbp 1.9.16~dfsg-1/windows/jack_netdriver.cbp
--- 1.9.14~dfsg-1/windows/jack_netdriver.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_netdriver.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,176 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_netdriver" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\jack_net" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\jack_net" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\jack_net" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\jack_net" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetdriver.res jacknetdriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\jack_net" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jacknetdriver.res jacknetdriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\jack_net" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetdriver.res jacknetdriver.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add option="-enable-auto-import" />
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="ws2_32" />
-		</Linker>
-		<Unit filename="..\common\JackNetDriver.cpp" />
-		<Unit filename="jacknetdriver.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jacknetdriver.rc 1.9.16~dfsg-1/windows/jacknetdriver.rc
--- 1.9.14~dfsg-1/windows/jacknetdriver.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jacknetdriver.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp NetDriver for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jack_netdriver\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jack_netdriver.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jack_netdriver\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jack_netmanager.cbp 1.9.16~dfsg-1/windows/jack_netmanager.cbp
--- 1.9.14~dfsg-1/windows/jack_netmanager.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_netmanager.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,169 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_netmanager" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\netmanager" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DSERVER_SIDE" />
-                   			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\netmanager" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DSERVER_SIDE" />
-                			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\netmanager" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-              			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\netmanager" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    			<Add option="-m32" />
-					<Add option="-DSERVER_SIDE" />
-                 			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetmanager.res jacknetmanager.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\netmanager" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-                   			 <Add option="-m32" />
-					<Add option="-DSERVER_SIDE" />
-                 			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jacknetmanager.res jacknetmanager.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\netmanager" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    			<Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-                 			<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetmanager.res jacknetmanager.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add option="-enable-auto-import" />
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="ws2_32" />
-        </Linker>
-		<Unit filename="..\common\JackNetManager.cpp" />
-		<Unit filename="jacknetmanager.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jacknetmanager.rc 1.9.16~dfsg-1/windows/jacknetmanager.rc
--- 1.9.14~dfsg-1/windows/jacknetmanager.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jacknetmanager.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp NetManager for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "netmanager\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "netmanager.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "netmanager\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jack_netonedriver.cbp 1.9.16~dfsg-1/windows/jack_netonedriver.cbp
--- 1.9.14~dfsg-1/windows/jack_netonedriver.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_netonedriver.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,182 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_netonedriver" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\jack_netone" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\jack_netone" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\jack_netone" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\jack_netone" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jacknetonedriver.res jacknetonedriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\jack_netone" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jacknetonedriver.res jacknetonedriver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\jack_netone" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DBUILD_DLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jacknetonedriver.res jacknetonedriver.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add option="-enable-auto-import" />
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="ws2_32" />
-		</Linker>
-		<Unit filename="..\common\JackNetOneDriver.cpp" />
-		<Unit filename="..\common\netjack.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="..\common\netjack_packet.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="jacknetonedriver.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jacknetonedriver.rc 1.9.16~dfsg-1/windows/jacknetonedriver.rc
--- 1.9.14~dfsg-1/windows/jacknetonedriver.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jacknetonedriver.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp NetOne Driver for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jack_netonedriver\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jack_netonedriver.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jack_netonedriver\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/jack_netsource.cbp 1.9.16~dfsg-1/windows/jack_netsource.cbp
--- 1.9.14~dfsg-1/windows/jack_netsource.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_netsource.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,183 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_netsource" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_netsource" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\netsource" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DNO_JACK_ERROR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add library="libsamplerate_x86_64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_netsource" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\netsource" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DNO_JACK_ERROR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add library="libsamplerate_x86_64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_netsource" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\netsource" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DNO_JACK_ERROR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add library="libsamplerate_x86_64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_netsource" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\netsource" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DNO_JACK_ERROR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add library="libsamplerate_x86" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_netsource" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\netsource" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DNO_JACK_ERROR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add library="libsamplerate_x86" />
-					<Add directory="Debug\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_netsource" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\netsource" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DNO_JACK_ERROR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add library="libsamplerate_x86" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-			<Add directory="..\example-clients" />
-			<Add directory="..\windows" />
-			<Add directory="..\common\jack" />
-			<Add directory="..\common" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="ws2_32" />
-		</Linker>
-		<Unit filename="..\common\netjack_packet.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="..\example-clients\netsource.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt1.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/JackPlatformPlug_os.h 1.9.16~dfsg-1/windows/JackPlatformPlug_os.h
--- 1.9.14~dfsg-1/windows/JackPlatformPlug_os.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackPlatformPlug_os.h	2020-10-16 19:10:40.000000000 +0000
@@ -24,12 +24,17 @@
 #define jack_server_dir "server"
 #define jack_client_dir "client"
 #define JACK_DEFAULT_DRIVER "portaudio"
-#define JACK_LOCATION "C:/Program Files/Jack"
+#define JACK_LOCATION "C:\\Program Files\\JACK2"
 
 #ifndef ADDON_DIR
     #define ADDON_DIR "jack"
 #endif
 
+#define MAKE_WIDECHAR_CONSTANT2(Quote) L##Quote
+#define MAKE_WIDECHAR_CONSTANT(Quote) MAKE_WIDECHAR_CONSTANT2(Quote)
+#define ADDON_DIRW MAKE_WIDECHAR_CONSTANT(ADDON_DIR)
+
+
 namespace Jack
 {
     struct JackRequest;
diff -pruN 1.9.14~dfsg-1/windows/jack_portaudio.cbp 1.9.16~dfsg-1/windows/jack_portaudio.cbp
--- 1.9.14~dfsg-1/windows/jack_portaudio.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_portaudio.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,241 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_portaudio" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\jack_portaudio" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-                    <Add option="-DHAVE_ASIO" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libportaudio_x86_64.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="..\windows" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\jack_portaudio" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add option="-W" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-                    <Add option="-DHAVE_ASIO" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libportaudio_x86_64.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Debug64\bin" />
-					<Add directory="..\windows" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\jack_portaudio" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-                    <Add option="-DHAVE_ASIO" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add library="libjackserver64" />
-					<Add library="libportaudio_x86_64.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Release64\bin" />
-					<Add directory="..\windows" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\jack_portaudio" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-                    <Add option="-DHAVE_ASIO" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libportaudio_x86.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="..\windows" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackportaudio.res jackportaudio.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\jack_portaudio" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add option="-W" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-                    <Add option="-DHAVE_ASIO" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libportaudio_x86.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Debug\bin" />
-					<Add directory="..\windows" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackportaudio.res jackportaudio.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\jack_portaudio" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-                    <Add option="-DHAVE_ASIO" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="portaudio" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjackserver" />
-					<Add library="libportaudio_x86.a" />
-					<Add library="winmm" />
-					<Add library="ole32" />
-					<Add directory="Release\bin" />
-					<Add directory="..\windows" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackportaudio.res jackportaudio.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="jackportaudio.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Unit filename="portaudio\JackPortAudioDevices.cpp" />
-		<Unit filename="portaudio\JackPortAudioDriver.cpp" />
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackportaudio.rc 1.9.16~dfsg-1/windows/jackportaudio.rc
--- 1.9.14~dfsg-1/windows/jackportaudio.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackportaudio.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp PortAudio Driver for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jack_portaudio\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jack_portaudio.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jack_portaudio\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.cpp 1.9.16~dfsg-1/windows/JackRouter/JackRouter.cpp
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,1002 +0,0 @@
-/*
- Copyright (C) 2006-2011 Grame
-
- Permission is hereby granted, free of charge, to any person obtaining
- a copy of this software and associated documentation files
- (the "Software"), to deal in the Software without restriction,
- including without limitation the rights to use, copy, modify, merge,
- publish, distribute, sublicense, and/or sell copies of the Software,
- and to permit persons to whom the Software is furnished to do so,
- subject to the following conditions:
-
- The above copyright notice and this permission notice shall be
- included in all copies or substantial portions of the Software.
-
- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
- ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
- CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
- WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-*/
-
-#ifdef WIN32
-#pragma warning (disable : 4786)
-#endif
-
-#include <stdio.h>
-#include <string.h>
-#include <assert.h>
-#include <process.h>
-#include "JackRouter.h"
-#include "profport.h"
-
-/*
-	08/07/2007 SL : Use jack_client_open instead of jack_client_new (automatic client renaming).
-	09/08/2007 SL : Add JackRouter.ini parameter file.
-	09/20/2007 SL : Better error report in DllRegisterServer (for Vista).
-	09/27/2007 SL : Add AUDO_CONNECT property in JackRouter.ini file.
-	10/10/2007 SL : Use ASIOSTInt32LSB instead of ASIOSTInt16LSB.
-	12/04/2011 SL : Compilation on Windows 64.
-	12/04/2011 SL : Dynamic port allocation. Correct JACK port naming.
- */
-
-//------------------------------------------------------------------------------------------
-// extern
-void getNanoSeconds(ASIOTimeStamp *time);
-
-// local
-double AsioSamples2double (ASIOSamples* samples);
-
-static const double twoRaisedTo32 = 4294967296.;
-static const double twoRaisedTo32Reciprocal = 1. / twoRaisedTo32;
-
-//------------------------------------------------------------------------------------------
-// on windows, we do the COM stuff.
-
-#if WINDOWS
-#include "windows.h"
-#include "mmsystem.h"
-#ifdef _WIN64
-#define JACK_ROUTER "JackRouter.dll"
-#include <psapi.h>
-#else
-#define JACK_ROUTER "JackRouter.dll"
-#include "./psapi.h"
-#endif
-
-using namespace std;
-
-//#define JACK_LOG 1
-
-#ifdef JACK_LOG
-#include <fstream>
-static std::ofstream* fStream;
-#endif
-
-// class id.
-// {838FE50A-C1AB-4b77-B9B6-0A40788B53F3}
-CLSID IID_ASIO_DRIVER = { 0x838fe50a, 0xc1ab, 0x4b77, { 0xb9, 0xb6, 0xa, 0x40, 0x78, 0x8b, 0x53, 0xf3 } };
-
-
-CFactoryTemplate g_Templates[1] = {
-    {L"ASIOJACK", &IID_ASIO_DRIVER, JackRouter::CreateInstance}
-};
-int g_cTemplates = sizeof(g_Templates) / sizeof(g_Templates[0]);
-
-CUnknown* JackRouter::CreateInstance(LPUNKNOWN pUnk, HRESULT *phr)
-{
-	return (CUnknown*)new JackRouter(pUnk,phr);
-};
-
-STDMETHODIMP JackRouter::NonDelegatingQueryInterface(REFIID riid, void ** ppv)
-{
-	if (riid == IID_ASIO_DRIVER) {
-		return GetInterface(this, ppv);
-	}
-	return CUnknown::NonDelegatingQueryInterface(riid, ppv);
-}
-
-// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//		Register ASIO Driver
-// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-extern LONG RegisterAsioDriver(CLSID,char *,char *,char *,char *);
-extern LONG UnregisterAsioDriver(CLSID,char *,char *);
-
-//
-// Server registration, called on REGSVR32.EXE "the dllname.dll"
-//
-HRESULT _stdcall DllRegisterServer()
-{
-	LONG	rc;
-	char	errstr[128];
-
-	rc = RegisterAsioDriver (IID_ASIO_DRIVER, JACK_ROUTER,"JackRouter","JackRouter","Apartment");
-
-	if (rc) {
-		memset(errstr,0,128);
-		sprintf(errstr,"Register Server failed ! (%d)", rc);
-		MessageBox(0,(LPCTSTR)errstr,(LPCTSTR)"JackRouter",MB_OK);
-		return -1;
-	}
-
-	return S_OK;
-}
-
-//
-// Server unregistration
-//
-HRESULT _stdcall DllUnregisterServer()
-{
-	LONG	rc;
-	char	errstr[128];
-
-	rc = UnregisterAsioDriver (IID_ASIO_DRIVER,JACK_ROUTER,"JackRouter");
-
-	if (rc) {
-		memset(errstr,0,128);
-		sprintf(errstr,"Unregister Server failed ! (%d)",rc);
-		MessageBox(0,(LPCTSTR)errstr,(LPCTSTR)"JackRouter",MB_OK);
-		return -1;
-	}
-
-	return S_OK;
-}
-
-// Globals
-list<pair<string, string> > JackRouter::fConnections;
-
-//------------------------------------------------------------------------------------------
-//------------------------------------------------------------------------------------------
-JackRouter::JackRouter (LPUNKNOWN pUnk, HRESULT *phr)
-	: CUnknown("ASIOJACK", pUnk, phr)
-
-//------------------------------------------------------------------------------------------
-
-#else
-
-// when not on windows, we derive from AsioDriver
-JackRouter::JackRouter() : AsioDriver()
-
-#endif
-{
-	long i;
-	fSamplePosition = 0;
-	fRunning = false;
-	fTimeInfoMode = false;
-	fTcRead = false;
-	fClient = NULL;
-	fAutoConnectIn = true;
-	fAutoConnectOut = true;
-	fCallbacks = 0;
-	fActiveInputs = fActiveOutputs = 0;
-	fToggle = 0;
-	fBufferSize = 512;
-	fSampleRate = 44100;
-    fFloatSample = true;    // float by default
-	fFirstActivate = true;
-
-#ifdef JACK_LOG 
-	fStream = new ofstream(name_log, ios_base::ate);
-    *fStream << "======================" << std::endl;
-    *fStream << "JackRouter::JackRouter" <<  std::endl;
-    *fStream << "======================" << std::endl;
-#endif
-
-	// Use "jackrouter.ini" parameters if available
-	HMODULE handle = LoadLibrary(JACK_ROUTER);
-
-	if (handle) {
-
-		// Get JackRouter.dll path
-		char dllName[512];
-		string confPath;
-		DWORD res = GetModuleFileName(handle, dllName, 512);
-
-		// Compute .ini file path
-		string fullPath = dllName;
-		int lastPos = fullPath.find_last_of(PATH_SEP);
-		string  dllFolder =  fullPath.substr(0, lastPos);
-		confPath = dllFolder + PATH_SEP + "JackRouter.ini";
-
-		// Get parameters
-		kNumInputs = get_private_profile_int("IO", "input", 2, confPath.c_str());
-		kNumOutputs = get_private_profile_int("IO", "output", 2, confPath.c_str());
-
-		fAutoConnectIn = get_private_profile_int("AUTO_CONNECT", "input", 1, confPath.c_str());
-		fAutoConnectOut = get_private_profile_int("AUTO_CONNECT", "output", 1, confPath.c_str());
-        
-        fFloatSample = get_private_profile_int("IO", "float-sample", 0, confPath.c_str());
-        fAliasSystem = get_private_profile_int("AUTO_CONNECT", "alias", 0, confPath.c_str());
-
-		FreeLibrary(handle);
- 
-	} else {
-    #ifdef JACK_LOG 
-        *fStream << "JackRouter::JackRouter : loadLibrary error" <<  std::endl;
-    #endif
-	}
-    
-    if (!fFloatSample) {
-        fInputBuffers = (void**)new long*[kNumInputs];
-        fOutputBuffers = (void**)new long*[kNumOutputs];
-    } else {
-        fInputBuffers = (void**)new float*[kNumInputs];
-        fOutputBuffers = (void**)new float*[kNumOutputs];
-    }
-
-    fInMap = new long[kNumInputs];
-	fOutMap = new long[kNumOutputs];
-    
-    fInputPorts = new jack_port_t*[kNumInputs];
-    fOutputPorts = new jack_port_t*[kNumOutputs];
- 
-	for (i = 0; i < kNumInputs; i++) {
-		fInputBuffers[i] = 0;
-		fInputPorts[i] = 0;
-		fInMap[i] = 0;
-	}
-	for (i = 0; i < kNumOutputs; i++) {
-		fOutputBuffers[i] = 0;
-		fOutputPorts[i] = 0;
-		fOutMap[i] = 0;
-	}
-}
-
-//------------------------------------------------------------------------------------------
-JackRouter::~JackRouter()
-{
-#ifdef JACK_LOG 
-    *fStream << "=======================" << std::endl;
-    *fStream << "JackRouter::~JackRouter" <<  std::endl;
-    *fStream << "=======================" << std::endl;
-#endif
-	stop();
-	disposeBuffers();
-	jack_client_close(fClient);
-	delete[] fInputBuffers;
-    delete[] fOutputBuffers;
-    delete[] fInputPorts;
-    delete[] fOutputPorts;
-    delete[] fInMap;
-    delete[] fOutMap;
-#ifdef JACK_LOG  
-    delete fStream;
-#endif
-}
-
-//------------------------------------------------------------------------------------------
-
-static bool GetEXEName(DWORD dwProcessID, char* name)
-{
-    DWORD aProcesses [1024], cbNeeded, cProcesses;
-    unsigned int i;
-
-    // Enumerate all processes
-    if (!EnumProcesses(aProcesses, sizeof(aProcesses), &cbNeeded))
-        return false;
-
-    // Calculate how many process identifiers were returned.
-    cProcesses = cbNeeded / sizeof(DWORD);
-
-    TCHAR szEXEName[MAX_PATH];
-    // Loop through all process to find the one that matches
-    // the one we are looking for
-
-    for (i = 0; i < cProcesses; i++) {
-        if (aProcesses [i] == dwProcessID) {
-            // Get a handle to the process
-            HANDLE hProcess = OpenProcess(PROCESS_QUERY_INFORMATION |
-                              PROCESS_VM_READ, FALSE, dwProcessID);
-
-            // Get the process name
-            if (NULL != hProcess) {
-                HMODULE hMod;
-                DWORD cbNeeded;
-
-                if (EnumProcessModules(hProcess, &hMod,
-                                      sizeof(hMod), &cbNeeded)) {
-                    //Get the name of the exe file
-                    GetModuleBaseName(hProcess, hMod, szEXEName,
-                        sizeof(szEXEName)/sizeof(TCHAR));
-					int len = strlen((char*)szEXEName) - 4; // remove ".exe"
-					strncpy(name, (char*)szEXEName, len);
-					name[len] = '\0';
-					return true;
-                 }
-            }
-        }
-    }
-
-    return false;
-}
-
- //------------------------------------------------------------------------------------------
-static inline jack_default_audio_sample_t ClipFloat(jack_default_audio_sample_t sample)
-{
-     return (sample < jack_default_audio_sample_t(-1.0)) ? jack_default_audio_sample_t(-1.0) : (sample > jack_default_audio_sample_t(1.0)) ? jack_default_audio_sample_t(1.0) : sample;
-}
-
-//------------------------------------------------------------------------------------------
-void JackRouter::connectCallback(jack_port_id_t a, jack_port_id_t b, int connect, void* arg)
-{
-    JackRouter* driver = (JackRouter*)arg;
-}
-
-//------------------------------------------------------------------------------------------
-void JackRouter::shutdownCallback(void* arg)
-{
-	JackRouter* driver = (JackRouter*)arg;
-	/*
-	char errstr[128];
-	memset(errstr,0,128);
-	sprintf(errstr,"JACK server has quit");
-	MessageBox(0,(LPCTSTR)errstr,(LPCTSTR)"JackRouter",MB_OK);
-	*/
-}
-
-//------------------------------------------------------------------------------------------
-void JackRouter::processInputs()
-{
-    int pos = (fToggle) ? 0 : fBufferSize;
-    
-    for (int i = 0; i < fActiveInputs; i++) {
-        if (!fFloatSample) {
-            jack_default_audio_sample_t* buffer = (jack_default_audio_sample_t*)jack_port_get_buffer(fInputPorts[i], fBufferSize);
-            long* in = (long*)fInputBuffers[i] + pos;
-            for (int j = 0; j < fBufferSize; j++) {
-                in[j] = buffer[j] * jack_default_audio_sample_t(0x7fffffff);
-            }
-        } else {
-            memcpy((float*)fInputBuffers[i] + pos,
-                    jack_port_get_buffer(fInputPorts[i], fBufferSize),
-                    fBufferSize * sizeof(jack_default_audio_sample_t));
-        }
-    }
-}
-
-//------------------------------------------------------------------------------------------
-void JackRouter::processOutputs()
-{
-    int pos = (fToggle) ? 0 : fBufferSize;
-    
-    for (int i = 0; i < fActiveOutputs; i++) {
-        if (!fFloatSample) {
-            jack_default_audio_sample_t* buffer = (jack_default_audio_sample_t*)jack_port_get_buffer(fOutputPorts[i], fBufferSize);
-            long* out = (long*)fOutputBuffers[i] + pos;
-            jack_default_audio_sample_t gain = jack_default_audio_sample_t(1)/jack_default_audio_sample_t(0x7fffffff);
-            for (int j = 0; j < fBufferSize; j++) {
-                buffer[j] = out[j] * gain;
-            }
-        } else {
-            memcpy(jack_port_get_buffer(fOutputPorts[i], fBufferSize),
-                    (float*)fOutputBuffers[i] + pos,
-                    fBufferSize * sizeof(jack_default_audio_sample_t));
-        }
-    }
-}
-
-//------------------------------------------------------------------------------------------
-int JackRouter::processCallback(jack_nframes_t nframes, void* arg)
-{
-	JackRouter* driver = (JackRouter*)arg;
-  	driver->bufferSwitch();
-	return 0;
-}
-
-//------------------------------------------------------------------------------------------
-void JackRouter::getDriverName(char *name)
-{
-	strcpy(name, "JackRouter");
-}
-
-//------------------------------------------------------------------------------------------
-long JackRouter::getDriverVersion()
-{
-	return 0x00000001L;
-}
-
-//------------------------------------------------------------------------------------------
-void JackRouter::getErrorMessage(char *string)
-{
-	strcpy (string, fErrorMessage);
-}
-
-//------------------------------------------------------------------------------------------
-ASIOBool JackRouter::init(void* sysRef)
-{
-	char name[MAX_PATH];
-	char name_log[MAX_PATH];
-	sysRef = sysRef;
-
-	if (fClient) {
-    #ifdef JACK_LOG 
-        *fStream << "JackRouter::init : JACK client still present..." <<  std::endl;
-    #endif
-		return true;
-	}
-
-	HANDLE win = (HANDLE)sysRef;
-	int	my_pid = _getpid();
-
-	if (!GetEXEName(my_pid, name)) { // If getting the .exe name fails, takes a generic one.
-		_snprintf(name, sizeof(name) - 1, "JackRouter_%d", my_pid);
-	}
-
-	_snprintf(name_log, sizeof(name_log) - 1, "JackRouter_%s.log", name);
-
-	fClient = jack_client_open(name, JackNoStartServer, NULL);
-	if (fClient == NULL) {
-		strcpy(fErrorMessage, "Open error: is JACK server running?");
-		printf("Open error: is JACK server running?\n");
-		return false;
-	}
-
-	fBufferSize = jack_get_buffer_size(fClient);
-	fSampleRate = jack_get_sample_rate(fClient);
-    
-	jack_set_process_callback(fClient, processCallback, this);
-	jack_on_shutdown(fClient, shutdownCallback, this);
-    jack_set_port_connect_callback(fClient, connectCallback, this);
-
-	fInputLatency = fBufferSize;		// typically
-	fOutputLatency = fBufferSize * 2;
-	fMilliSeconds = (long)((double)(fBufferSize * 1000) / fSampleRate);
-
-	// Typically fBufferSize * 2; try to get 1 by offering direct buffer
-	// access, and using asioPostOutput for lower latency
-
-#ifdef JACK_LOG 
-    *fStream << "JackRouter::init" <<  std::endl;
-#endif
-	return true;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::start()
-{
-	if (fCallbacks) {
-		fSamplePosition = 0;
-		fTheSystemTime.lo = fTheSystemTime.hi = 0;
-		fToggle = 0;
-		
-    #ifdef JACK_LOG 
-        *fStream << "JackRouter::start" <<  std::endl;
-    #endif
-
-		if (jack_activate(fClient) == 0) {
-
-			if (fFirstActivate) {
-				autoConnect();
-				fFirstActivate = false;
-			} else {
-				restoreConnections();
-			}
-
-			fRunning = true;
-			return ASE_OK;
-
-		} else {
-			return ASE_NotPresent;
-		}
-	}
-
-	return ASE_NotPresent;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::stop()
-{
-#ifdef JACK_LOG 
-    *fStream << "JackRouter::stop" <<  std::endl;
-#endif
-	fRunning = false;
-	saveConnections();
-	if (jack_deactivate(fClient) == 0) {
-		fFirstActivate = true;
-	}
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getChannels(long *numInputChannels, long *numOutputChannels)
-{
-	*numInputChannels = kNumInputs;
-	*numOutputChannels = kNumOutputs;
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getLatencies(long *_inputLatency, long *_outputLatency)
-{
-	*_inputLatency = fInputLatency;
-	*_outputLatency = fOutputLatency;
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getBufferSize(long *minSize, long *maxSize, long *preferredSize, long *granularity)
-{
-	*minSize = *maxSize = *preferredSize = fBufferSize;		// Allows this size only
-	*granularity = 0;
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::canSampleRate(ASIOSampleRate sampleRate)
-{
-	return (sampleRate == fSampleRate) ? ASE_OK : ASE_NoClock;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getSampleRate(ASIOSampleRate *sampleRate)
-{
-	*sampleRate = fSampleRate;
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::setSampleRate(ASIOSampleRate sampleRate)
-{
-	return (sampleRate == fSampleRate) ? ASE_OK : ASE_NoClock;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getClockSources(ASIOClockSource *clocks, long *numSources)
-{
-	// Internal
-	if (clocks && numSources) {
-		clocks->index = 0;
-		clocks->associatedChannel = -1;
-		clocks->associatedGroup = -1;
-		clocks->isCurrentSource = ASIOTrue;
-		strcpy(clocks->name, "Internal");
-		*numSources = 1;
-		return ASE_OK;
-	} else {
-		return ASE_InvalidParameter;
-	}
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::setClockSource(long index)
-{
-	if (!index) {
-		fAsioTime.timeInfo.flags |= kClockSourceChanged;
-		return ASE_OK;
-	} else {
-		return ASE_NotPresent;
-	}
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getSamplePosition(ASIOSamples *sPos, ASIOTimeStamp *tStamp)
-{
-	tStamp->lo = fTheSystemTime.lo;
-	tStamp->hi = fTheSystemTime.hi;
-
-	if (fSamplePosition >= twoRaisedTo32) {
-		sPos->hi = (unsigned long)(fSamplePosition * twoRaisedTo32Reciprocal);
-		sPos->lo = (unsigned long)(fSamplePosition - (sPos->hi * twoRaisedTo32));
-	} else {
-		sPos->hi = 0;
-		sPos->lo = (unsigned long)fSamplePosition;
-	}
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::getChannelInfo(ASIOChannelInfo *info)
-{
-	if (info->channel < 0 || (info->isInput ? info->channel >= kNumInputs : info->channel >= kNumOutputs)) {
-		return ASE_InvalidParameter;
-    }
-    
-    if (!fFloatSample) {
-        info->type = ASIOSTInt32LSB;
-    } else {
-        info->type = ASIOSTFloat32LSB;
-    }
-
-#ifdef JACK_LOG    
-	*fStream << "==========================" << std::endl;
-    *fStream << "JackRouter::getChannelInfo" << std::endl;
-	*fStream << "==========================" << std::endl;
-#endif
-
-	info->channelGroup = 0;
-	info->isActive = ASIOFalse;
-	long i;
-	char buf[32];
-    const char** ports;
-
-	char* aliases[2];
-	aliases[0] = (char*)malloc(jack_port_name_size());
-	aliases[1] = (char*)malloc(jack_port_name_size());
-
-	if (!aliases[0] || !aliases[1]) {
-		return ASE_NoMemory;
-    }
-
-	if (info->isInput) {
-		for (i = 0; i < fActiveInputs; i++) {
-			if (fInMap[i] == info->channel) {
-				info->isActive = ASIOTrue;
-				break;
-			}
-		}
-		
-        // A alias on system is wanted
-        if (fAliasSystem && fAutoConnectIn && (ports = jack_get_ports(fClient, NULL, NULL, JackPortIsPhysical | JackPortIsOutput))) {
-            jack_port_t* port = jack_port_by_name(fClient, ports[info->channel]);
-            if (port) {	
-                if (jack_port_get_aliases(port, aliases) == 2) {
-                    strncpy(info->name, aliases[1], 32);
-                #ifdef JACK_LOG
-                    *fStream << "Input " << "fActiveInputs = " << i << " ASIO_channel = " << info->channel <<  std::endl;
-                #endif
-                    goto end;
-                }	
-            }
-        } 
-            
-        _snprintf(buf, sizeof(buf) - 1, "In%d", info->channel + 1);
-        strcpy(info->name, buf);
-         
-	} else {
-		for (i = 0; i < fActiveOutputs; i++) {
-			if (fOutMap[i] == info->channel) {  
-				info->isActive = ASIOTrue;
-				break;
-			}
-		}
-        
-        // A alias on system is wanted
-        if (fAliasSystem && fAutoConnectOut && (ports = jack_get_ports(fClient, NULL, NULL, JackPortIsPhysical | JackPortIsInput))) {
-            jack_port_t* port = jack_port_by_name(fClient, ports[info->channel]);
-            if (port) {	
-                if (jack_port_get_aliases(port, aliases) == 2) {
-                    strncpy(info->name, aliases[1], 32);
-                #ifdef JACK_LOG
-                    *fStream << "Output " << "fActiveOutputs = " << i << " ASIO_channel = " << info->channel <<  std::endl;
-                #endif    
-                    goto end;
-                }	
-            }
-        } 
-        _snprintf(buf, sizeof(buf) - 1, "Out%d", info->channel + 1);
-        strcpy(info->name, buf);
-    }
-    
-end:
-
-	free(aliases[0]);
-	free(aliases[1]);
-	return ASE_OK;
-}
-
-//------------------------------------------------------------------------------------------
-ASIOError JackRouter::createBuffers(ASIOBufferInfo *bufferInfos, long numChannels,
-	long bufferSize, ASIOCallbacks *callbacks)
-{
-	ASIOBufferInfo *info = bufferInfos;
-	long i;
-	bool notEnoughMem = false;
-	char buf[256];
-	fActiveInputs = 0;
-	fActiveOutputs = 0;
-
-#ifdef JACK_LOG    
-	*fStream << "==========================" << std::endl;
-    *fStream << "JackRouter::createBuffers" << std::endl;
-	*fStream << "==========================" << std::endl;
-#endif
-
-	for (i = 0; i < numChannels; i++, info++) {
-		if (info->isInput) {
-            
-			if (info->channelNum < 0 || info->channelNum >= kNumInputs) {
-				goto error;
-            }
-			fInMap[fActiveInputs] = info->channelNum;
-            
-            if (!fFloatSample) {
-                fInputBuffers[fActiveInputs] = new long[fBufferSize * 2];	// double buffer
-            } else {
-                fInputBuffers[fActiveInputs] = new jack_default_audio_sample_t[fBufferSize * 2];	// double buffer
-            }
-            
-			if (fInputBuffers[fActiveInputs]) {
-				info->buffers[0] = fInputBuffers[fActiveInputs];
-				info->buffers[1] = (fFloatSample) ? (void*)((float*)fInputBuffers[fActiveInputs] + fBufferSize) : (void*)((long*)fInputBuffers[fActiveInputs] + fBufferSize);
-			} else {
-				info->buffers[0] = info->buffers[1] = 0;
-				notEnoughMem = true;
-			}
-        #ifdef JACK_LOG
-            *fStream << "Input " << "fActiveInputs = " << i << " ASIO_channel = " << info->channelNum <<  std::endl;
-        #endif
-			_snprintf(buf, sizeof(buf) - 1, "in%d", info->channelNum + 1);
-			fInputPorts[fActiveInputs]
-				= jack_port_register(fClient, buf, JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput,0);
-			if (fInputPorts[fActiveInputs] == NULL) {
-				goto error;
-            }
-
-			fActiveInputs++;
-			if (fActiveInputs > kNumInputs) {
-error:
-				disposeBuffers();
-				return ASE_InvalidParameter;
-			}
-		} else {	
-        
-     		if (info->channelNum < 0 || info->channelNum >= kNumOutputs) {
-				goto error;
-            }
-			fOutMap[fActiveOutputs] = info->channelNum;
-
-            if (!fFloatSample) {
-                fOutputBuffers[fActiveOutputs] = new long[fBufferSize * 2];	// double buffer
-            } else {
-                fOutputBuffers[fActiveOutputs] = new jack_default_audio_sample_t[fBufferSize * 2];	// double buffer
-            }
-
-			if (fOutputBuffers[fActiveOutputs]) {
-				info->buffers[0] = fOutputBuffers[fActiveOutputs];
-				info->buffers[1] = (fFloatSample) ? (void*)((float*)fOutputBuffers[fActiveOutputs] + fBufferSize) : (void*)((long*)fOutputBuffers[fActiveOutputs] + fBufferSize);
-			} else {
-				info->buffers[0] = info->buffers[1] = 0;
-				notEnoughMem = true;
-			}
-        #ifdef JACK_LOG
-            *fStream << "Input " << "fActiveOutputs = " << i << " ASIO_channel = " << info->channelNum <<  std::endl;
-		#endif	
-			_snprintf(buf, sizeof(buf) - 1, "out%d", info->channelNum + 1);
-			fOutputPorts[fActiveOutputs]
-				= jack_port_register(fClient, buf, JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput,0);
-			if (fOutputPorts[fActiveOutputs] == NULL) {
-				goto error;
-            }
-
-			fActiveOutputs++;
-			if (fActiveOutputs > kNumOutputs) {
-				fActiveOutputs--;
-				disposeBuffers();
-				return ASE_InvalidParameter;
-			}
-		}
-	}
-
-	if (notEnoughMem) {
-		disposeBuffers();
-		return ASE_NoMemory;
-	}
-
-	this->fCallbacks = callbacks;
-	if (callbacks->asioMessage (kAsioSupportsTimeInfo, 0, 0, 0)) {
-		fTimeInfoMode = true;
-		fAsioTime.timeInfo.speed = 1.;
-		fAsioTime.timeInfo.systemTime.hi = fAsioTime.timeInfo.systemTime.lo = 0;
-		fAsioTime.timeInfo.samplePosition.hi = fAsioTime.timeInfo.samplePosition.lo = 0;
-		fAsioTime.timeInfo.sampleRate = fSampleRate;
-		fAsioTime.timeInfo.flags = kSystemTimeValid | kSamplePositionValid | kSampleRateValid;
-		fAsioTime.timeCode.speed = 1.;
-		fAsioTime.timeCode.timeCodeSamples.lo = fAsioTime.timeCode.timeCodeSamples.hi = 0;
-		fAsioTime.timeCode.flags = kTcValid | kTcRunning ;
-	} else {
-		fTimeInfoMode = false;
-	}
-
-	if (fRunning) { 
-		autoConnect();
-	}
-	return ASE_OK;
-}
-
-//---------------------------------------------------------------------------------------------
-ASIOError JackRouter::disposeBuffers()
-{
-	long i;
-
-	fCallbacks = 0;
-	stop();
-
-	for (i = 0; i < fActiveInputs; i++) {
-		delete[] fInputBuffers[i];
-		jack_port_unregister(fClient, fInputPorts[i]);
-	}
-	fActiveInputs = 0;
-
-	for (i = 0; i < fActiveOutputs; i++) {
-		delete[] fOutputBuffers[i];
-		jack_port_unregister(fClient, fOutputPorts[i]);
-	}
-	fActiveOutputs = 0;
-
-	return ASE_OK;
-}
-
-//---------------------------------------------------------------------------------------------
-ASIOError JackRouter::controlPanel()
-{
-	return ASE_NotPresent;
-}
-
-//---------------------------------------------------------------------------------------------
-ASIOError JackRouter::future(long selector, void* opt)	// !!! check properties
-{
-	ASIOTransportParameters* tp = (ASIOTransportParameters*)opt;
-    
-	switch (selector) {
-		case kAsioEnableTimeCodeRead:	fTcRead = true;	return ASE_SUCCESS;
-		case kAsioDisableTimeCodeRead:	fTcRead = false; return ASE_SUCCESS;
-		case kAsioSetInputMonitor:		return ASE_SUCCESS;	// for testing!!!
-		case kAsioCanInputMonitor:		return ASE_SUCCESS;	// for testing!!!
-		case kAsioCanTimeInfo:			return ASE_SUCCESS;
-		case kAsioCanTimeCode:			return ASE_SUCCESS;
-	}
-    
-	return ASE_NotPresent;
-}
-
-//--------------------------------------------------------------------------------------------------------
-// private methods
-//--------------------------------------------------------------------------------------------------------
-
-//---------------------------------------------------------------------------------------------
-void JackRouter::bufferSwitch()
-{
-	if (fRunning && fCallbacks) {
-		getNanoSeconds(&fTheSystemTime);			// latch system time
-        processInputs();
-        processOutputs();
-		fSamplePosition += fBufferSize;
-		if (fTimeInfoMode) {
-			bufferSwitchX();
-		} else {
-			fCallbacks->bufferSwitch(fToggle, ASIOFalse);
-		}
-		fToggle = fToggle ? 0 : 1;
-	}
-}
-
-//---------------------------------------------------------------------------------------------
-// asio2 buffer switch
-void JackRouter::bufferSwitchX()
-{
-	getSamplePosition (&fAsioTime.timeInfo.samplePosition, &fAsioTime.timeInfo.systemTime);
-	long offset = fToggle ? fBufferSize : 0;
-	if (fTcRead) {
-		// Create a fake time code, which is 10 minutes ahead of the card's sample position
-		// Please note that for simplicity here time code will wrap after 32 bit are reached
-		fAsioTime.timeCode.timeCodeSamples.lo = fAsioTime.timeInfo.samplePosition.lo + 600.0 * fSampleRate;
-		fAsioTime.timeCode.timeCodeSamples.hi = 0;
-	}
-	fCallbacks->bufferSwitchTimeInfo(&fAsioTime, fToggle, ASIOFalse);
-	fAsioTime.timeInfo.flags &= ~(kSampleRateChanged | kClockSourceChanged);
-}
-
-//---------------------------------------------------------------------------------------------
-ASIOError JackRouter::outputReady()
-{
-	return ASE_NotPresent;
-}
-
-//---------------------------------------------------------------------------------------------
-double AsioSamples2double(ASIOSamples* samples)
-{
-	double a = (double)(samples->lo);
-	if (samples->hi) {
-		a += (double)(samples->hi) * twoRaisedTo32;
-    }
-	return a;
-}
-
-//---------------------------------------------------------------------------------------------
-void getNanoSeconds(ASIOTimeStamp* ts)
-{
-	double nanoSeconds = (double)((unsigned long)timeGetTime ()) * 1000000.;
-	ts->hi = (unsigned long)(nanoSeconds / twoRaisedTo32);
-	ts->lo = (unsigned long)(nanoSeconds - (ts->hi * twoRaisedTo32));
-}
-
-//------------------------------------------------------------------------
-void JackRouter::saveConnections()
-{
-    const char** connections;
- 	int i;
-
-    for (i = 0; i < fActiveInputs; ++i) {
-        if (fInputPorts[i] && (connections = jack_port_get_connections(fInputPorts[i])) != 0) {
-            for (int j = 0; connections[j]; j++) {
-                fConnections.push_back(make_pair(connections[j], jack_port_name(fInputPorts[i])));
-            }
-            jack_free(connections);
-        }
-    }
-
-    for (i = 0; i < fActiveOutputs; ++i) {
-        if (fOutputPorts[i] && (connections = jack_port_get_connections(fOutputPorts[i])) != 0) {
-            for (int j = 0; connections[j]; j++) {
-                fConnections.push_back(make_pair(jack_port_name(fOutputPorts[i]), connections[j]));
-            }
-            jack_free(connections);
-        }
-    }
-}
-
-//------------------------------------------------------------------------
-void JackRouter::restoreConnections()
-{
-    list<pair<string, string> >::const_iterator it;
-
-    for (it = fConnections.begin(); it != fConnections.end(); it++) {
-        pair<string, string> connection = *it;
-        jack_connect(fClient, connection.first.c_str(), connection.second.c_str());
-    }
-
-    fConnections.clear();
-}
-
-
-//------------------------------------------------------------------------------------------
-void JackRouter::autoConnect()
-{
-	const char** ports;
-
-#ifdef JACK_LOG    
-	*fStream << "=======================" << std::endl;
-    *fStream << "JackRouter::autoConnect" << std::endl;
-	*fStream << "=======================" << std::endl;
-#endif
-
-	if ((ports = jack_get_ports(fClient, NULL, NULL, JackPortIsPhysical | JackPortIsOutput)) == NULL) {
-    #ifdef JACK_LOG 
-        *fStream << "JackRouter::autoConnect : cannot find any physical capture ports" << std::endl;
-    #endif
-	} else {
-		if (fAutoConnectIn) {
-        	for (int i = 0; i < fActiveInputs; i++) {
-                long ASIO_channel = fInMap[i];
-                if (!ports[ASIO_channel]) {
-					printf("source port is null ASIO_channel = %ld\n", ASIO_channel);
-					break;
-				} else if (jack_connect(fClient, ports[ASIO_channel], jack_port_name(fInputPorts[i])) != 0) {
-					printf("Cannot connect input ports\n");
-				} else {
-                #ifdef JACK_LOG
-                    *fStream << "Input " << "fActiveInputs = " << i << " ASIO_channel = " << ASIO_channel <<  std::endl;
-                #endif
-                }
-			}
-		}
-		jack_free(ports);
-	}
-
-	if ((ports = jack_get_ports(fClient, NULL, NULL, JackPortIsPhysical | JackPortIsInput)) == NULL) {
-    #ifdef JACK_LOG 
-        *fStream << "JackRouter::autoConnect : cannot find any physical playback ports" << std::endl;
-    #endif
-	} else {
-		if (fAutoConnectOut) {
-			for (int i = 0; i < fActiveOutputs; i++) {
-                long ASIO_channel = fOutMap[i];
-				if (!ports[ASIO_channel]) {
-					printf("destination port is null ASIO_channel = %ld\n", ASIO_channel);
-					break;
-				} else if (jack_connect(fClient, jack_port_name(fOutputPorts[i]), ports[ASIO_channel]) != 0) {
-					printf("Cannot connect output ports\n");
-				} else {
-                #ifdef JACK_LOG
-                    *fStream << "Output " << "fActiveOutputs = " << i << " ASIO_channel = " << ASIO_channel <<  std::endl;
-                #endif
-                }
-			}
-		}
-		jack_free(ports);
-	}
-}
-
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.def 1.9.16~dfsg-1/windows/JackRouter/JackRouter.def
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.def	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.def	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-LIBRARY			JackRouter
-DESCRIPTION		'ASIO Jack Driver'
-PROTMODE
-EXPORTS	
-				DllMain
-				DllGetClassObject
-				DllCanUnloadNow
-				DllRegisterServer
-				DllUnregisterServer
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.dsp 1.9.16~dfsg-1/windows/JackRouter/JackRouter.dsp
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.dsp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.dsp	1970-01-01 00:00:00.000000000 +0000
@@ -1,163 +0,0 @@
-# Microsoft Developer Studio Project File - Name="JackRouter" - Package Owner=<4>
-# Microsoft Developer Studio Generated Build File, Format Version 6.00
-# ** DO NOT EDIT **
-
-# TARGTYPE "Win32 (x86) Dynamic-Link Library" 0x0102
-
-CFG=JackRouter - Win32 Debug
-!MESSAGE This is not a valid makefile. To build this project using NMAKE,
-!MESSAGE use the Export Makefile command and run
-!MESSAGE 
-!MESSAGE NMAKE /f "JackRouter.mak".
-!MESSAGE 
-!MESSAGE You can specify a configuration when running NMAKE
-!MESSAGE by defining the macro CFG on the command line. For example:
-!MESSAGE 
-!MESSAGE NMAKE /f "JackRouter.mak" CFG="JackRouter - Win32 Debug"
-!MESSAGE 
-!MESSAGE Possible choices for configuration are:
-!MESSAGE 
-!MESSAGE "JackRouter - Win32 Release" (based on "Win32 (x86) Dynamic-Link Library")
-!MESSAGE "JackRouter - Win32 Debug" (based on "Win32 (x86) Dynamic-Link Library")
-!MESSAGE 
-
-# Begin Project
-# PROP AllowPerConfigDependencies 0
-# PROP Scc_ProjName ""
-# PROP Scc_LocalPath ""
-CPP=cl.exe
-MTL=midl.exe
-RSC=rc.exe
-
-!IF  "$(CFG)" == "JackRouter - Win32 Release"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 0
-# PROP BASE Output_Dir "Release"
-# PROP BASE Intermediate_Dir "Release"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 0
-# PROP Output_Dir "Release"
-# PROP Intermediate_Dir "Release"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /MT /W3 /GX /O2 /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /YX /FD /c
-# ADD CPP /nologo /MD /W3 /GX /O2 /I "..\..\..\..\..\ASIOSDK2\common" /I "..\..\common" /I "..\..\common\jack" /D "WIN32" /D "NDEBUG" /D "_WINDOWS" /FR /YX /FD /c
-# ADD BASE MTL /nologo /D "NDEBUG" /mktyplib203 /win32
-# ADD MTL /nologo /D "NDEBUG" /mktyplib203 /win32
-# ADD BASE RSC /l 0x409 /d "NDEBUG"
-# ADD RSC /l 0x409 /d "NDEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:windows /dll /machine:I386
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib /nologo /subsystem:windows /dll /machine:I386
-
-!ELSEIF  "$(CFG)" == "JackRouter - Win32 Debug"
-
-# PROP BASE Use_MFC 0
-# PROP BASE Use_Debug_Libraries 1
-# PROP BASE Output_Dir "Debug"
-# PROP BASE Intermediate_Dir "Debug"
-# PROP BASE Target_Dir ""
-# PROP Use_MFC 0
-# PROP Use_Debug_Libraries 1
-# PROP Output_Dir "Debug"
-# PROP Intermediate_Dir "Debug"
-# PROP Ignore_Export_Lib 0
-# PROP Target_Dir ""
-# ADD BASE CPP /nologo /MTd /W3 /Gm /GX /ZI /Od /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /YX /FD /GZ /c
-# ADD CPP /nologo /G5 /MDd /W3 /Gm /GX /Zi /Od /I "..\..\..\..\..\ASIOSDK2\common" /I "..\..\common" /I "..\..\common\jack" /D "WIN32" /D "_DEBUG" /D "_WINDOWS" /FR /YX /FD /GZ /c
-# ADD BASE MTL /nologo /D "_DEBUG" /mktyplib203 /win32
-# ADD MTL /nologo /D "_DEBUG" /mktyplib203 /win32
-# ADD BASE RSC /l 0x409 /d "_DEBUG"
-# ADD RSC /l 0x409 /d "_DEBUG"
-BSC32=bscmake.exe
-# ADD BASE BSC32 /nologo
-# ADD BSC32 /nologo
-LINK32=link.exe
-# ADD BASE LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib /nologo /subsystem:windows /dll /debug /machine:I386 /pdbtype:sept
-# ADD LINK32 kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib odbc32.lib odbccp32.lib winmm.lib /nologo /subsystem:windows /dll /debug /machine:I386 /out:"Debug/JackRouter_debug.dll" /pdbtype:sept
-
-!ENDIF 
-
-# Begin Target
-
-# Name "JackRouter - Win32 Release"
-# Name "JackRouter - Win32 Debug"
-# Begin Group "Source Files"
-
-# PROP Default_Filter "cpp;c;cxx;rc;def;r;odl;idl;hpj;bat"
-# Begin Source File
-
-SOURCE=..\..\..\..\..\ASIOSDK2\common\combase.cpp
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\..\..\..\ASIOSDK2\common\dllentry.cpp
-# End Source File
-# Begin Source File
-
-SOURCE=.\JackRouter.cpp
-# End Source File
-# Begin Source File
-
-SOURCE=.\JackRouter.def
-# End Source File
-# Begin Source File
-
-SOURCE=.\profport.cpp
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\..\..\..\ASIOSDK2\common\register.cpp
-# End Source File
-# Begin Source File
-
-SOURCE=.\resource.rc
-# End Source File
-# End Group
-# Begin Group "Header Files"
-
-# PROP Default_Filter "h;hpp;hxx;hm;inl"
-# Begin Source File
-
-SOURCE=..\..\..\common\asio.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\Common\Asiodrvr.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\asiosmpl.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\..\common\asiosys.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\..\common\combase.h
-# End Source File
-# Begin Source File
-
-SOURCE=..\..\..\common\iasiodrv.h
-# End Source File
-# End Group
-# Begin Group "Resource Files"
-
-# PROP Default_Filter "ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe"
-# End Group
-# Begin Source File
-
-SOURCE=.\Psapi.Lib
-# End Source File
-# Begin Source File
-
-SOURCE=..\Release\bin\libjack.lib
-# End Source File
-# End Target
-# End Project
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.dsw 1.9.16~dfsg-1/windows/JackRouter/JackRouter.dsw
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.dsw	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.dsw	1970-01-01 00:00:00.000000000 +0000
@@ -1,29 +0,0 @@
-Microsoft Developer Studio Workspace File, Format Version 6.00
-# WARNING: DO NOT EDIT OR DELETE THIS WORKSPACE FILE!
-
-###############################################################################
-
-Project: "JackRouter"=".\JackRouter.dsp" - Package Owner=<4>
-
-Package=<5>
-{{{
-}}}
-
-Package=<4>
-{{{
-}}}
-
-###############################################################################
-
-Global:
-
-Package=<5>
-{{{
-}}}
-
-Package=<3>
-{{{
-}}}
-
-###############################################################################
-
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.h 1.9.16~dfsg-1/windows/JackRouter/JackRouter.h
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,174 +0,0 @@
-/*
- Copyright (C) 2006-2011 Grame
-
- Permission is hereby granted, free of charge, to any person obtaining
- a copy of this software and associated documentation files
- (the "Software"), to deal in the Software without restriction,
- including without limitation the rights to use, copy, modify, merge,
- publish, distribute, sublicense, and/or sell copies of the Software,
- and to permit persons to whom the Software is furnished to do so,
- subject to the following conditions:
-
- The above copyright notice and this permission notice shall be
- included in all copies or substantial portions of the Software.
-
- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
- ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
- CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
- WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-
-*/
-
-#ifndef _asiosmpl_
-#define _asiosmpl_
-
-#include "asiosys.h"
-
-// Globals
-static int	kBlockFrames = 256;
-static int	kNumInputs = 4;
-static int	kNumOutputs = 4;
-
-#if WINDOWS
-
-#include "jack.h"
-#include "rpc.h"
-#include "rpcndr.h"
-#ifndef COM_NO_WINDOWS_H
-#include <windows.h>
-#include "ole2.h"
-
-#endif
-
-#include "combase.h"
-#include "iasiodrv.h"
-
-#define PATH_SEP "\\"
-
-#include <list>
-#include <string>
-
-class JackRouter : public IASIO, public CUnknown
-{
-public:
-	JackRouter(LPUNKNOWN pUnk, HRESULT *phr);
-	~JackRouter();
-
-	DECLARE_IUNKNOWN
-    //STDMETHODIMP QueryInterface(REFIID riid, void **ppv) {      \
-    //    return GetOwner()->QueryInterface(riid,ppv);            \
-    //};                                                          \
-    //STDMETHODIMP_(ULONG) AddRef() {                             \
-    //    return GetOwner()->AddRef();                            \
-    //};                                                          \
-    //STDMETHODIMP_(ULONG) Release() {                            \
-    //    return GetOwner()->Release();                           \
-    //};
-
-	// Factory method
-	static CUnknown *CreateInstance(LPUNKNOWN pUnk, HRESULT *phr);
-	// IUnknown
-	virtual HRESULT STDMETHODCALLTYPE NonDelegatingQueryInterface(REFIID riid,void **ppvObject);
-#else
-
-#include "asiodrvr.h"
-
-//---------------------------------------------------------------------------------------------
-class JackRouter : public AsioDriver
-{
-public:
-	JackRouter();
-	~JackRouter();
-#endif
-
-	static int processCallback(jack_nframes_t nframes, void* arg);
-    static void connectCallback(jack_port_id_t a, jack_port_id_t b, int connect, void* arg);
-	static void shutdownCallback(void* arg);
-
-	ASIOBool init(void* sysRef);
-	void getDriverName(char *name);		// max 32 bytes incl. terminating zero
-	long getDriverVersion();
-	void getErrorMessage(char *string);	// max 128 bytes incl.
-
-	ASIOError start();
-	ASIOError stop();
-
-	ASIOError getChannels(long *numInputChannels, long *numOutputChannels);
-	ASIOError getLatencies(long *inputLatency, long *outputLatency);
-	ASIOError getBufferSize(long *minSize, long *maxSize,
-		long *preferredSize, long *granularity);
-
-	ASIOError canSampleRate(ASIOSampleRate sampleRate);
-	ASIOError getSampleRate(ASIOSampleRate *sampleRate);
-	ASIOError setSampleRate(ASIOSampleRate sampleRate);
-	ASIOError getClockSources(ASIOClockSource *clocks, long *numSources);
-	ASIOError setClockSource(long index);
-
-	ASIOError getSamplePosition(ASIOSamples *sPos, ASIOTimeStamp *tStamp);
-	ASIOError getChannelInfo(ASIOChannelInfo *info);
-
-	ASIOError createBuffers(ASIOBufferInfo *bufferInfos, long numChannels,
-		long bufferSize, ASIOCallbacks *callbacks);
-	ASIOError disposeBuffers();
-
-	ASIOError controlPanel();
-	ASIOError future(long selector, void *opt);
-	ASIOError outputReady();
-
-	void bufferSwitch();
-	long getMilliSeconds() {return fMilliSeconds;}
-
-	static std::list<std::pair<std::string, std::string> > fConnections;  // Connections list
-
-private:
-
-	void bufferSwitchX();
-
-	double fSamplePosition;
-	ASIOCallbacks* fCallbacks;
-	ASIOTime fAsioTime;
-	ASIOTimeStamp fTheSystemTime;
-
-	void** fInputBuffers;
-	void** fOutputBuffers;
-
-	long* fInMap;
-	long* fOutMap;
-
-	long fInputLatency;
-	long fOutputLatency;
-	long fActiveInputs;
-	long fActiveOutputs;
-	long fToggle;
-	long fMilliSeconds;
-	bool fRunning;
-	bool fFirstActivate;
-    bool fFloatSample;
-    bool fAliasSystem;
-	bool fTimeInfoMode, fTcRead;
-	char fErrorMessage[128];
-
-	bool fAutoConnectIn;
-	bool fAutoConnectOut;
-
-	// Jack part
-	jack_client_t* fClient;
-	jack_port_t** fInputPorts;
-	jack_port_t** fOutputPorts;
-	long fBufferSize;
-	ASIOSampleRate fSampleRate;
-
-	void autoConnect();
-	void saveConnections();
-    void restoreConnections();
-    
-    void processInputs();
-    void processOutputs();
-
-};
-
-#endif
-
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.vcxproj 1.9.16~dfsg-1/windows/JackRouter/JackRouter.vcxproj
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.vcxproj	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.vcxproj	1970-01-01 00:00:00.000000000 +0000
@@ -1,280 +0,0 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project DefaultTargets="Build" ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup Label="ProjectConfigurations">
-    <ProjectConfiguration Include="Debug|Win32">
-      <Configuration>Debug</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Debug|x64">
-      <Configuration>Debug</Configuration>
-      <Platform>x64</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|Win32">
-      <Configuration>Release</Configuration>
-      <Platform>Win32</Platform>
-    </ProjectConfiguration>
-    <ProjectConfiguration Include="Release|x64">
-      <Configuration>Release</Configuration>
-      <Platform>x64</Platform>
-    </ProjectConfiguration>
-  </ItemGroup>
-  <PropertyGroup Label="Globals">
-    <SccProjectName />
-    <SccLocalPath />
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.Default.props" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'" Label="Configuration">
-    <ConfigurationType>DynamicLibrary</ConfigurationType>
-    <UseOfMfc>false</UseOfMfc>
-  </PropertyGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.props" />
-  <ImportGroup Label="ExtensionSettings">
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.Cpp.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.Cpp.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.Cpp.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <ImportGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'" Label="PropertySheets">
-    <Import Project="$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props" Condition="exists('$(UserRootDir)\Microsoft.Cpp.$(Platform).user.props')" Label="LocalAppDataPlatform" />
-    <Import Project="$(VCTargetsPath)Microsoft.Cpp.UpgradeFromVC60.props" />
-  </ImportGroup>
-  <PropertyGroup Label="UserMacros" />
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <OutDir>.\Debug\</OutDir>
-    <IntDir>.\Debug\</IntDir>
-    <LinkIncremental>true</LinkIncremental>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
-    <OutDir>.\Debug\</OutDir>
-    <IntDir>.\Debug\</IntDir>
-    <LinkIncremental>true</LinkIncremental>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <OutDir>.\Release\</OutDir>
-    <IntDir>.\Release\</IntDir>
-    <LinkIncremental>false</LinkIncremental>
-  </PropertyGroup>
-  <PropertyGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
-    <OutDir>.\Release64\</OutDir>
-    <IntDir>.\Release64\</IntDir>
-    <LinkIncremental>false</LinkIncremental>
-  </PropertyGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|Win32'">
-    <ClCompile>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <InlineFunctionExpansion>Default</InlineFunctionExpansion>
-      <FunctionLevelLinking>false</FunctionLevelLinking>
-      <Optimization>Disabled</Optimization>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <WarningLevel>Level3</WarningLevel>
-      <MinimalRebuild>true</MinimalRebuild>
-      <AdditionalIncludeDirectories>..\..\..\..\..\ASIOSDK2\common;..\..\common;..\..\common\jack;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AssemblerListingLocation>.\Debug\</AssemblerListingLocation>
-      <BrowseInformation>true</BrowseInformation>
-      <PrecompiledHeaderOutputFile>.\Debug\JackRouter.pch</PrecompiledHeaderOutputFile>
-      <ObjectFileName>.\Debug\</ObjectFileName>
-      <ProgramDataBaseFileName>.\Debug\</ProgramDataBaseFileName>
-      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
-    </ClCompile>
-    <Midl>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <TypeLibraryName>.\Debug\JackRouter.tlb</TypeLibraryName>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <TargetEnvironment>Win32</TargetEnvironment>
-    </Midl>
-    <ResourceCompile>
-      <Culture>0x0409</Culture>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ResourceCompile>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Debug\JackRouter.bsc</OutputFile>
-    </Bscmake>
-    <Link>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <LinkDLL>true</LinkDLL>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <OutputFile>Debug/JackRouter_debug.dll</OutputFile>
-      <ImportLibrary>.\Debug\JackRouter_debug.lib</ImportLibrary>
-      <AdditionalDependencies>odbc32.lib;odbccp32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <ModuleDefinitionFile>.\JackRouter.def</ModuleDefinitionFile>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Debug|x64'">
-    <ClCompile>
-      <RuntimeLibrary>MultiThreadedDebugDLL</RuntimeLibrary>
-      <InlineFunctionExpansion>Default</InlineFunctionExpansion>
-      <FunctionLevelLinking>false</FunctionLevelLinking>
-      <Optimization>Disabled</Optimization>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <WarningLevel>Level3</WarningLevel>
-      <AdditionalIncludeDirectories>..\..\..\..\..\ASIOSDK2\common;..\..\common;..\..\common\jack;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;_DEBUG;_WINDOWS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AssemblerListingLocation>.\Debug\</AssemblerListingLocation>
-      <BrowseInformation>true</BrowseInformation>
-      <PrecompiledHeaderOutputFile>.\Debug\JackRouter.pch</PrecompiledHeaderOutputFile>
-      <ObjectFileName>.\Debug\</ObjectFileName>
-      <ProgramDataBaseFileName>.\Debug\</ProgramDataBaseFileName>
-      <BasicRuntimeChecks>EnableFastChecks</BasicRuntimeChecks>
-    </ClCompile>
-    <Midl>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <TypeLibraryName>.\Debug\JackRouter.tlb</TypeLibraryName>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-    </Midl>
-    <ResourceCompile>
-      <Culture>0x0409</Culture>
-      <PreprocessorDefinitions>_DEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ResourceCompile>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Debug\JackRouter.bsc</OutputFile>
-    </Bscmake>
-    <Link>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <LinkDLL>true</LinkDLL>
-      <GenerateDebugInformation>true</GenerateDebugInformation>
-      <SubSystem>Windows</SubSystem>
-      <OutputFile>Debug/JackRouter_debug.dll</OutputFile>
-      <ImportLibrary>.\Debug\JackRouter_debug.lib</ImportLibrary>
-      <AdditionalDependencies>odbc32.lib;odbccp32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <ModuleDefinitionFile>.\JackRouter.def</ModuleDefinitionFile>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|Win32'">
-    <ClCompile>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <InlineFunctionExpansion>OnlyExplicitInline</InlineFunctionExpansion>
-      <StringPooling>true</StringPooling>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <Optimization>MaxSpeed</Optimization>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <WarningLevel>Level3</WarningLevel>
-      <AdditionalIncludeDirectories>..\..\..\..\..\ASIOSDK2\common;..\..\common;..\..\common\jack;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AssemblerListingLocation>.\Release\</AssemblerListingLocation>
-      <BrowseInformation>true</BrowseInformation>
-      <PrecompiledHeaderOutputFile>.\Release\JackRouter.pch</PrecompiledHeaderOutputFile>
-      <ObjectFileName>.\Release\</ObjectFileName>
-      <ProgramDataBaseFileName>.\Release\</ProgramDataBaseFileName>
-    </ClCompile>
-    <Midl>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <TypeLibraryName>.\Release\JackRouter.tlb</TypeLibraryName>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-      <TargetEnvironment>Win32</TargetEnvironment>
-    </Midl>
-    <ResourceCompile>
-      <Culture>0x0409</Culture>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ResourceCompile>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Release\JackRouter.bsc</OutputFile>
-    </Bscmake>
-    <Link>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <LinkDLL>true</LinkDLL>
-      <SubSystem>Windows</SubSystem>
-      <OutputFile>.\Release\JackRouter.dll</OutputFile>
-      <ImportLibrary>.\Release\JackRouter.lib</ImportLibrary>
-      <AdditionalDependencies>odbc32.lib;odbccp32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <ModuleDefinitionFile>.\JackRouter.def</ModuleDefinitionFile>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemDefinitionGroup Condition="'$(Configuration)|$(Platform)'=='Release|x64'">
-    <ClCompile>
-      <RuntimeLibrary>MultiThreadedDLL</RuntimeLibrary>
-      <InlineFunctionExpansion>OnlyExplicitInline</InlineFunctionExpansion>
-      <StringPooling>true</StringPooling>
-      <FunctionLevelLinking>true</FunctionLevelLinking>
-      <Optimization>MaxSpeed</Optimization>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <WarningLevel>Level3</WarningLevel>
-      <AdditionalIncludeDirectories>..\..\..\..\..\ASIOSDK2\common;..\..\common;..\..\common\jack;%(AdditionalIncludeDirectories)</AdditionalIncludeDirectories>
-      <PreprocessorDefinitions>WIN32;NDEBUG;_WINDOWS;PSAPI_VERSION=2;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <AssemblerListingLocation>.\Release\</AssemblerListingLocation>
-      <BrowseInformation>true</BrowseInformation>
-      <PrecompiledHeaderOutputFile>.\Release\JackRouter.pch</PrecompiledHeaderOutputFile>
-      <ObjectFileName>.\Release\</ObjectFileName>
-      <ProgramDataBaseFileName>.\Release\</ProgramDataBaseFileName>
-    </ClCompile>
-    <Midl>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-      <TypeLibraryName>.\Release\JackRouter.tlb</TypeLibraryName>
-      <MkTypLibCompatible>true</MkTypLibCompatible>
-    </Midl>
-    <ResourceCompile>
-      <Culture>0x0409</Culture>
-      <PreprocessorDefinitions>NDEBUG;%(PreprocessorDefinitions)</PreprocessorDefinitions>
-    </ResourceCompile>
-    <Bscmake>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <OutputFile>.\Release\JackRouter64.bsc</OutputFile>
-    </Bscmake>
-    <Link>
-      <SuppressStartupBanner>true</SuppressStartupBanner>
-      <LinkDLL>true</LinkDLL>
-      <SubSystem>Windows</SubSystem>
-      <OutputFile>.\Release64\JackRouter.dll</OutputFile>
-      <ImportLibrary>.\Release\JackRouter64.lib</ImportLibrary>
-      <AdditionalDependencies>odbc32.lib;odbccp32.lib;winmm.lib;%(AdditionalDependencies)</AdditionalDependencies>
-      <ModuleDefinitionFile>.\JackRouter.def</ModuleDefinitionFile>
-    </Link>
-  </ItemDefinitionGroup>
-  <ItemGroup>
-    <ClCompile Include="..\..\..\..\..\ASIOSDK2\common\combase.cpp" />
-    <ClCompile Include="..\..\..\..\..\ASIOSDK2\common\dllentry.cpp" />
-    <ClCompile Include="JackRouter.cpp" />
-    <ClCompile Include="profport.cpp" />
-    <ClCompile Include="..\..\..\..\..\ASIOSDK2\common\register.cpp" />
-  </ItemGroup>
-  <ItemGroup>
-    <CustomBuild Include="JackRouter.def" />
-  </ItemGroup>
-  <ItemGroup>
-    <ResourceCompile Include="resource.rc" />
-  </ItemGroup>
-  <ItemGroup>
-    <ClInclude Include="..\..\..\common\asio.h" />
-    <ClInclude Include="..\..\Common\Asiodrvr.h" />
-    <ClInclude Include="..\asiosmpl.h" />
-    <ClInclude Include="..\..\..\common\asiosys.h" />
-    <ClInclude Include="..\..\..\common\combase.h" />
-    <ClInclude Include="..\..\..\common\iasiodrv.h" />
-  </ItemGroup>
-  <ItemGroup>
-    <Library Include="..\Release64\bin\libjack64.lib" />
-    <Library Include="..\Release\bin\libjack.lib" />
-    <Library Include="Psapi.Lib" />
-  </ItemGroup>
-  <Import Project="$(VCTargetsPath)\Microsoft.Cpp.targets" />
-  <ImportGroup Label="ExtensionTargets">
-  </ImportGroup>
-</Project>
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.vcxproj.filters 1.9.16~dfsg-1/windows/JackRouter/JackRouter.vcxproj.filters
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.vcxproj.filters	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.vcxproj.filters	1970-01-01 00:00:00.000000000 +0000
@@ -1,69 +0,0 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <ItemGroup>
-    <Filter Include="Source Files">
-      <UniqueIdentifier>{72f2b2b0-dbea-4574-94fa-0c1ea89a3c8e}</UniqueIdentifier>
-      <Extensions>cpp;c;cxx;rc;def;r;odl;idl;hpj;bat</Extensions>
-    </Filter>
-    <Filter Include="Header Files">
-      <UniqueIdentifier>{9590ca0b-94c8-4c22-88b2-66724eb0ea21}</UniqueIdentifier>
-      <Extensions>h;hpp;hxx;hm;inl</Extensions>
-    </Filter>
-    <Filter Include="Resource Files">
-      <UniqueIdentifier>{9742e150-2741-4bf4-9b81-bea4aab464af}</UniqueIdentifier>
-      <Extensions>ico;cur;bmp;dlg;rc2;rct;bin;rgs;gif;jpg;jpeg;jpe</Extensions>
-    </Filter>
-  </ItemGroup>
-  <ItemGroup>
-    <ClCompile Include="..\..\..\..\..\ASIOSDK2\common\combase.cpp">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\..\..\..\..\ASIOSDK2\common\dllentry.cpp">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="JackRouter.cpp">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="profport.cpp">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-    <ClCompile Include="..\..\..\..\..\ASIOSDK2\common\register.cpp">
-      <Filter>Source Files</Filter>
-    </ClCompile>
-  </ItemGroup>
-  <ItemGroup>
-    <ResourceCompile Include="resource.rc">
-      <Filter>Source Files</Filter>
-    </ResourceCompile>
-  </ItemGroup>
-  <ItemGroup>
-    <ClInclude Include="..\..\..\common\asio.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\..\Common\Asiodrvr.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\asiosmpl.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\..\..\common\asiosys.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\..\..\common\combase.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-    <ClInclude Include="..\..\..\common\iasiodrv.h">
-      <Filter>Header Files</Filter>
-    </ClInclude>
-  </ItemGroup>
-  <ItemGroup>
-    <Library Include="..\Release\bin\libjack.lib" />
-    <Library Include="..\Release64\bin\libjack64.lib" />
-    <Library Include="Psapi.Lib" />
-  </ItemGroup>
-  <ItemGroup>
-    <CustomBuild Include="JackRouter.def">
-      <Filter>Source Files</Filter>
-    </CustomBuild>
-  </ItemGroup>
-</Project>
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/JackRouter.vcxproj.user 1.9.16~dfsg-1/windows/JackRouter/JackRouter.vcxproj.user
--- 1.9.14~dfsg-1/windows/JackRouter/JackRouter.vcxproj.user	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/JackRouter.vcxproj.user	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-﻿<?xml version="1.0" encoding="utf-8"?>
-<Project ToolsVersion="4.0" xmlns="http://schemas.microsoft.com/developer/msbuild/2003">
-  <PropertyGroup>
-    <ShowAllFiles>false</ShowAllFiles>
-  </PropertyGroup>
-</Project>
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/profport.cpp 1.9.16~dfsg-1/windows/JackRouter/profport.cpp
--- 1.9.14~dfsg-1/windows/JackRouter/profport.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/profport.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,315 +0,0 @@
-/*
-History : 
-01-28-02 : Change the location of temporary files created in write_private_profile_string
-		   now done in TmpDirectory.
-01-29-02 : Correct bug when the '=' character is not present.
-06-18-02 : Return default value if file does not exist, new write_private_profile_int function.
-*/
-
-/***** Routines to read profile strings --  by Joseph J. Graf ******/
-/***** corrections and improvements -- by D. Fober - Grame ******/
-/*
-	corrections: buffer sizes control
-	improvements: behavior more similar to windows
-*/
-
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <errno.h>
-
-#include <string>
-
-#include <ctype.h> 
-#include "profport.h"   /* function prototypes in here */
-
-#ifndef _WIN32
-
-static int read_line (FILE *fp, char *bp, int size);
-static int read_section(FILE *fp, char *section);
-static int read_entry (FILE *fp, char *entry, char *buff, int size);
-static char * read_value (char *buff);
-static int read_int_value (char *buff, int def);
-static char * read_file (char *file);
-static char * str_search (char * buff, char * str, int stopCond);
-
-/*****************************************************************
-* Function:     read_line()
-* Arguments:    <FILE *> fp - a pointer to the file to be read from
-*               <char *> bp - a pointer to the copy buffer
-*               <int>  size - size of the copy buffer
-* Returns:      the line length if successful -1 otherwise
-******************************************************************/
-static int read_line(FILE *fp, char *bp, int size)
-{  
-	char c = '\0';
-	int i = 0, limit = size-2;
-
-	/* Read one line from the source file */
-	while (((c = getc(fp)) != '\n') && (i < limit)) {
-		if (c == EOF) {
-			if (!i) return -1;
-			else break;
-		}
-		bp[i++] = c;
-	}
-	bp[i] = '\0';
-	return i;
-}
-
-static int read_section (FILE *fp, char *section)
-{  
-	char buff[MAX_LINE_LENGTH];
-	char t_section[MAX_LINE_LENGTH];
-	int n, slen;
-
-	sprintf(t_section,"[%s]", section); /* Format the section name */
-	slen = strlen (t_section);
-	/*  Move through file 1 line at a time until a section is matched or EOF */
-	do {
-		n = read_line(fp, buff, MAX_LINE_LENGTH); 
-		if (n == -1)   
-			return 0;
-	} while (strncmp (buff,t_section, slen));
-	return 1;
- }
-
-static int read_entry (FILE *fp, char *entry, char *buff, int size)
-{  
-	int n, elen = strlen (entry);
-
-	do {
-		n = read_line(fp, buff, size); 
-		if (n == -1) 
-			return 0;
-		else if (*buff == '[')
-			return 0;	
-	} while (strncmp (buff, entry, elen));
-	return 1;
- }
-
-#define isBlank(c)	((c == ' ') || (c == '\t'))
-static char * read_value (char *buff)
-{  
-    char * eq = strrchr (buff,'=');    /* Parse out the equal sign */
-    if (eq) {
-    	eq++;
-    	while (*eq && isBlank(*eq))
-    		eq++;
-//    	return *eq ? eq : 0;
-    	return eq;
-    }
-    return eq;
- }
-
-#define isSignedDigit(c)	(isdigit(c) || (c == '+') || (c == '-'))
-static int read_int_value (char *buff, int def)
-{  
-    char * val = read_value (buff);
-    char value[20]; int i;
-    
-    if (!*val) return def;
-    
-	for (i = 0; isSignedDigit(*val) && (i <= 10); i++ )
-		value[i] = *val++;
-	value[i] = '\0';
-    return value[0] ? atoi(value) : def;
-}
- 
-static char * read_file (char *file)
-{
-	FILE *fd = fopen (file,"r");
-	int size; char * buff = 0;
-	
-	if (!fd) return 0;
-	if (fseek (fd, 0, SEEK_END) == -1) goto err;
-	size = ftell (fd);
-	if (size < 0) goto err;
-	if (fseek (fd, 0, SEEK_SET) == -1) goto err;
-	buff = (char *) malloc (size+1);
-	if (buff) {
-		*buff = 0;
-		fread (buff, 1, size, fd);
-		buff[size] = 0;
-	}
-err:
-	fclose (fd);
-	return buff;
-}
- 
-static char * str_search (char * buff, char * str, int stopCond)
-{
-	char *ptr = buff;
-	int len = strlen (str);
-	while (*ptr && strncmp (ptr, str, len)) {
-		while (*ptr && (*ptr++ != '\n')) 
-			;
-		if (*ptr == stopCond)
-			return 0;
-	}
-	return *ptr ? ptr : 0;
-}
-
-/**************************************************************************
-* Function:     get_private_profile_int()
-* Arguments:    <char *> section - the name of the section to search for
-*               <char *> entry - the name of the entry to find the value of
-*               <int> def - the default value in the event of a failed read
-*               <char *> file_name - the name of the .ini file to read from
-* Returns:      the value located at entry
-***************************************************************************/
-int get_private_profile_int(char *section,
-    char *entry, int def, char *file_name)
-{   
-    FILE *fp = fopen(file_name,"r");
-    char buff[MAX_LINE_LENGTH];
-    
-    if( !fp ) return def; /* Return default value if file does not exist */
-    if (!read_section (fp, section)) goto err;
-    if (!read_entry (fp, entry, buff, MAX_LINE_LENGTH)) goto err;
-	def = read_int_value (buff, def);
-err:
-	fclose (fp);
-	return def;
-}
-
-/**************************************************************************
-* Function:     get_private_profile_string()
-* Arguments:    <char *> section - the name of the section to search for
-*               <char *> entry - the name of the entry to find the value of
-*               <char *> def - default string in the event of a failed read
-*               <char *> buffer - a pointer to the buffer to copy into
-*               <int> buffer_len - the max number of characters to copy
-*               <char *> file_name - the name of the .ini file to read from
-* Returns:      the number of characters copied into the supplied buffer
-***************************************************************************/
-
-int get_private_profile_string(char *section, char *entry, char *def,
-    char *buffer, int buffer_len, char *file_name)
-{   
-    FILE *fp = fopen (file_name,"r");
-    char buff[MAX_LINE_LENGTH];
-    char *val;
-    
-    if( !fp ) goto err; /* Return default value if file does not exist */
-    if (!read_section (fp, section)) goto err;
-    if (!read_entry (fp, entry, buff, MAX_LINE_LENGTH)) goto err;
-	val = read_value (buff);
-    if(val) def = val;
-
-err:
-	if (fp) fclose (fp);
-	if (def) {
-		strncpy (buffer, def, buffer_len - 1);
-		buffer[buffer_len] = '\0';
-	}
-	else buffer[buffer_len] = '\0';
-	return strlen (buffer);
-}
-
-
-/***************************************************************************
- * Function:    write_private_profile_string()
- * Arguments:   <char *> section - the name of the section to search for
- *              <char *> entry - the name of the entry to find the value of
- *              <char *> buffer - pointer to the buffer that holds the string
- *              <char *> file_name - the name of the .ini file to read from
- * Returns:     TRUE if successful, otherwise FALSE
- ***************************************************************************/
-int write_private_profile_string(char *section,
-    char *entry, char *buffer, char *file_name)
-
-{
-	char * content = read_file(file_name);
-	FILE * fd = fopen(file_name,"w");
-    char t_section[MAX_LINE_LENGTH], *ptr;
-    int ret = 0;
-	
-	if (!fd) goto end;
-	if (!content) {
-    	fprintf (fd, "[%s]\n%s = %s\n", section, entry, buffer);
-    	ret = 1;
-    	goto end;
-	}
-    sprintf(t_section,"[%s]",section);         /* Format the section name */
-    ptr = str_search (content, t_section, 0);  /* look for the section start */
-    if (!ptr) {
-    	/* no such section: add the new section at end of file */
-    	fprintf (fd, "%s\n[%s]\n%s = %s\n", content, section, entry, buffer);
-    }
-    else {
-    	char * eptr;
-    	eptr = str_search (ptr, entry, '[');
-    	if (!eptr) {
-    		/* no such entry: looks for next section */
-    		eptr = str_search (++ptr, "[", 0);
-	    	if (!eptr) {
-    			/* section is the last one */
-	    		fprintf (fd, "%s\n%s = %s\n", content, entry, buffer);
-	    	}
-	    	else {
-	    		while (*ptr && (*ptr != '\n')) ptr++;
-	    		*ptr = 0;
-	    		fprintf (fd, "%s\n%s = %s", content, entry, buffer);
-	    		*ptr = '\n';
-	    		fprintf (fd, "%s", ptr);
-	    	}
-	    }
-	    else {
-	    	*eptr++ = 0;
-	    	fprintf (fd, "%s%s = %s", content, entry, buffer);
-	    	while (*eptr && (*eptr != '\n')) eptr++;
-	    	if (eptr) fprintf (fd, "%s", eptr);
-	    }
-    }
-    ret = 1;
-
-end:
-	if (content) free(content);
-	if (fd) fclose(fd);
-	return 0;
-}
-
-/***************************************************************************
- * Function:    write_private_profile_int()
- * Arguments:   <char *> section - the name of the section to search for
- *              <char *> entry - the name of the entry to find the value of
- *              <int> buffer - the value to be written
- *              <char *> file_name - the name of the .ini file to read from
- * Returns:     TRUE if successful, otherwise FALSE
- ***************************************************************************/
-int write_private_profile_int(char *section,
-    char *entry, int val, char *file_name)
-{
-    char buffer [64];
-    sprintf(buffer, "%d", val);
-    return write_private_profile_string (section,entry, buffer, file_name);
-}
-
-#endif // #ifndef WIN32
-
-
-/**************************************************************************
-* Function:     get_private_profile_float()
-* Arguments:    <char *> section - the name of the section to search for
-*               <char *> entry - the name of the entry to find the value of
-*               <float> def - the default value in the event of a failed read
-*               <char *> file_name - the name of the .ini file to read from
-* Returns:      the value located at entry
-* Warning:		The float value to be read must not contain more than 100 digits.
-* Author:		CD, 15/11/2006.
-***************************************************************************/
-#define maxFloatLen	100
-float get_private_profile_float	(char * section, char * entry, float def, char * file_name)
-{
-	float result = def;
-	char buffer[ maxFloatLen ], *endptr;
-
-	if ( get_private_profile_string(section, entry, "", buffer, maxFloatLen, file_name) > 0 )
-	{
-		result = (float)strtod(buffer, &endptr);
-		if ((result==0) && (endptr==buffer))
-			result = def;
-	}
-	return result;
-}
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/profport.h 1.9.16~dfsg-1/windows/JackRouter/profport.h
--- 1.9.14~dfsg-1/windows/JackRouter/profport.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/profport.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,37 +0,0 @@
-
-/******************************************************************************
- PORTABLE ROUTINES FOR WRITING PRIVATE PROFILE STRINGS --  by Joseph J. Graf
- Header file containing prototypes and compile-time configuration.
- 
- [09/05/02] D. Fober - Windows definitions added
-******************************************************************************/
-
-#ifndef __profport__
-#define __profport__
-
-#define MAX_LINE_LENGTH    1024
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#ifdef WIN32
-#include "Windows.h"
-#define get_private_profile_int        GetPrivateProfileInt
-#define get_private_profile_string     GetPrivateProfileString
-#define write_private_profile_string   WritePrivateProfileString
-#define write_private_profile_int      WritePrivateProfileInt
-#else
-int get_private_profile_int      (char * section, char * entry, int def, char * file_name);
-int get_private_profile_string   (char * section, char * entry, char * def, char * buffer, int buffer_len, char * file_name);
-int write_private_profile_string (char * section, char * entry, char * buffer, char * file_name);
-int write_private_profile_int    (char * section, char * entry, int val, char * file_name);
-#endif
-
-float get_private_profile_float	(char * section, char * entry, float def, char * file_name);
-
-#ifdef __cplusplus
-}
-#endif
-
-#endif //__profport__
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/psapi.h 1.9.16~dfsg-1/windows/JackRouter/psapi.h
--- 1.9.14~dfsg-1/windows/JackRouter/psapi.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/psapi.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,95 +0,0 @@
-/*
-	psapi.h - Include file for PSAPI.DLL APIs
-
-	Written by Mumit Khan <khan@nanotech.wisc.edu>
-
-	This file is part of a free library for the Win32 API.
-
-	NOTE: This strictly does not belong in the Win32 API since it's
-	really part of Platform SDK. However,GDB needs it and we might
-	as well provide it here.
-
-	This library is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-
-*/
-#ifndef _PSAPI_H
-#define _PSAPI_H
-#if __GNUC__ >=3
-#pragma GCC system_header
-#endif
-
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-#ifndef RC_INVOKED
-
-typedef struct _MODULEINFO {
-	LPVOID lpBaseOfDll;
-	DWORD SizeOfImage;
-	LPVOID EntryPoint;
-} MODULEINFO,*LPMODULEINFO;
-
-typedef struct _PSAPI_WS_WATCH_INFORMATION {
-	LPVOID FaultingPc;
-	LPVOID FaultingVa;
-} PSAPI_WS_WATCH_INFORMATION,*PPSAPI_WS_WATCH_INFORMATION;
-
-typedef struct _PROCESS_MEMORY_COUNTERS {
-	DWORD cb;
-	DWORD PageFaultCount;
-	DWORD PeakWorkingSetSize;
-	DWORD WorkingSetSize;
-	DWORD QuotaPeakPagedPoolUsage;
-	DWORD QuotaPagedPoolUsage;
-	DWORD QuotaPeakNonPagedPoolUsage;
-	DWORD QuotaNonPagedPoolUsage;
-	DWORD PagefileUsage;
-	DWORD PeakPagefileUsage;
-} PROCESS_MEMORY_COUNTERS,*PPROCESS_MEMORY_COUNTERS;
-
-/* Grouped by application,not in alphabetical order. */
-BOOL WINAPI EnumProcesses(DWORD *,DWORD,DWORD *);
-BOOL WINAPI EnumProcessModules(HANDLE,HMODULE *,DWORD,LPDWORD);
-DWORD WINAPI GetModuleBaseNameA(HANDLE,HMODULE,LPSTR,DWORD);
-DWORD WINAPI GetModuleBaseNameW(HANDLE,HMODULE,LPWSTR,DWORD);
-DWORD WINAPI GetModuleFileNameExA(HANDLE,HMODULE,LPSTR,DWORD);
-DWORD WINAPI GetModuleFileNameExW(HANDLE,HMODULE,LPWSTR,DWORD);
-BOOL WINAPI GetModuleInformation(HANDLE,HMODULE,LPMODULEINFO,DWORD);
-BOOL WINAPI EmptyWorkingSet(HANDLE);
-BOOL WINAPI QueryWorkingSet(HANDLE,PVOID,DWORD);
-BOOL WINAPI InitializeProcessForWsWatch(HANDLE);
-BOOL WINAPI GetWsChanges(HANDLE,PPSAPI_WS_WATCH_INFORMATION,DWORD);
-DWORD WINAPI GetMappedFileNameW(HANDLE,LPVOID,LPWSTR,DWORD);
-DWORD WINAPI GetMappedFileNameA(HANDLE,LPVOID,LPSTR,DWORD);
-BOOL WINAPI EnumDeviceDrivers(LPVOID *,DWORD,LPDWORD);
-DWORD WINAPI GetDeviceDriverBaseNameA(LPVOID,LPSTR,DWORD);
-DWORD WINAPI GetDeviceDriverBaseNameW(LPVOID,LPWSTR,DWORD);
-DWORD WINAPI GetDeviceDriverFileNameA(LPVOID,LPSTR,DWORD);
-DWORD WINAPI GetDeviceDriverFileNameW(LPVOID,LPWSTR,DWORD);
-BOOL WINAPI GetProcessMemoryInfo(HANDLE,PPROCESS_MEMORY_COUNTERS,DWORD);
-
-#endif /* not RC_INVOKED */
-
-#ifdef UNICODE
-#define GetModuleBaseName GetModuleBaseNameW
-#define GetModuleFileNameEx GetModuleFileNameExW
-#define GetMappedFilenameEx GetMappedFilenameExW
-#define GetDeviceDriverBaseName GetDeviceDriverBaseNameW
-#define GetDeviceDriverFileName GetDeviceDriverFileNameW
-#else
-#define GetModuleBaseName GetModuleBaseNameA
-#define GetModuleFileNameEx GetModuleFileNameExA
-#define GetMappedFilenameEx GetMappedFilenameExA
-#define GetDeviceDriverBaseName GetDeviceDriverBaseNameA
-#define GetDeviceDriverFileName GetDeviceDriverFileNameA
-#endif
-
-#ifdef __cplusplus
-}
-#endif
-
-#endif /* _PSAPI_H */
-
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/README 1.9.16~dfsg-1/windows/JackRouter/README
--- 1.9.14~dfsg-1/windows/JackRouter/README	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/README	1970-01-01 00:00:00.000000000 +0000
@@ -1,7 +0,0 @@
-This folder contains the sources for ASIO/JACK bridge ASIO driver called "JackRouter". The included project is a Microsoft VC++ 6 one. 
-It requires some files (combase.cpp, dllentry.cpp, register.cpp) that are part on the ASIO driver SDK. The produced "JackRouter.dll" file
-has to be registered in the system using the "regsvr32" tool.
-
-64 bits compilation
-====================
-A Visual Studio 10 project has been added to compile 64 and 32 bits targets.
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/resource.h 1.9.16~dfsg-1/windows/JackRouter/resource.h
--- 1.9.14~dfsg-1/windows/JackRouter/resource.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/resource.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-//{{NO_DEPENDENCIES}}
-// Microsoft Developer Studio generated include file.
-// Used by resource.rc
-//
-
-// Next default values for new objects
-//
-#ifdef APSTUDIO_INVOKED
-#ifndef APSTUDIO_READONLY_SYMBOLS
-#define _APS_NEXT_RESOURCE_VALUE        102
-#define _APS_NEXT_COMMAND_VALUE         40001
-#define _APS_NEXT_CONTROL_VALUE         1000
-#define _APS_NEXT_SYMED_VALUE           101
-#endif
-#endif
diff -pruN 1.9.14~dfsg-1/windows/JackRouter/resource.rc 1.9.16~dfsg-1/windows/JackRouter/resource.rc
--- 1.9.14~dfsg-1/windows/JackRouter/resource.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackRouter/resource.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,100 +0,0 @@
-// Microsoft Visual C++ generated resource script.
-//
-#include "resource.h"
-
-#define APSTUDIO_READONLY_SYMBOLS
-/////////////////////////////////////////////////////////////////////////////
-//
-// Generated from the TEXTINCLUDE 2 resource.
-//
-#include "afxres.h"
-
-/////////////////////////////////////////////////////////////////////////////
-#undef APSTUDIO_READONLY_SYMBOLS
-
-/////////////////////////////////////////////////////////////////////////////
-// Franais (France) resources
-
-#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_FRA)
-LANGUAGE LANG_FRENCH, SUBLANG_FRENCH
-#pragma code_page(1252)
-
-/////////////////////////////////////////////////////////////////////////////
-//
-// Version
-//
-
-VS_VERSION_INFO VERSIONINFO
- FILEVERSION 0,2,1,0
- PRODUCTVERSION 0,2,1,0
- FILEFLAGSMASK 0x3fL
-#ifdef _DEBUG
- FILEFLAGS 0x1L
-#else
- FILEFLAGS 0x0L
-#endif
- FILEOS 0x40004L
- FILETYPE 0x2L
- FILESUBTYPE 0x0L
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "CompanyName", "Grame"
-            VALUE "FileDescription", "JackRouter ASIO driver"
-            VALUE "FileVersion", "0, 2, 1, 0"
-            VALUE "InternalName", "JackRouter"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2011"
-            VALUE "OriginalFilename", "JackRouter.dll"
-            VALUE "ProductName", "JackRouter"
-            VALUE "ProductVersion", "0, 2, 1, 0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 0x40c, 1200
-    END
-END
-
-
-#ifdef APSTUDIO_INVOKED
-/////////////////////////////////////////////////////////////////////////////
-//
-// TEXTINCLUDE
-//
-
-1 TEXTINCLUDE 
-BEGIN
-    "resource.h\0"
-END
-
-2 TEXTINCLUDE 
-BEGIN
-    "#include ""afxres.h""\r\n"
-    "\0"
-END
-
-3 TEXTINCLUDE 
-BEGIN
-    "\r\n"
-    "\0"
-END
-
-#endif    // APSTUDIO_INVOKED
-
-#endif    // Franais (France) resources
-/////////////////////////////////////////////////////////////////////////////
-
-
-
-#ifndef APSTUDIO_INVOKED
-/////////////////////////////////////////////////////////////////////////////
-//
-// Generated from the TEXTINCLUDE 3 resource.
-//
-
-
-/////////////////////////////////////////////////////////////////////////////
-#endif    // not APSTUDIO_INVOKED
-
diff -pruN 1.9.14~dfsg-1/windows/JackShmMem_os.h 1.9.16~dfsg-1/windows/JackShmMem_os.h
--- 1.9.14~dfsg-1/windows/JackShmMem_os.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackShmMem_os.h	2020-10-16 19:10:40.000000000 +0000
@@ -20,6 +20,9 @@
 #ifndef __JackShmMem_WIN32__
 #define __JackShmMem_WIN32__
 
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 
 inline bool CHECK_MLOCK(void* ptr, size_t size)
diff -pruN 1.9.14~dfsg-1/windows/JackSystemDeps_os.h 1.9.16~dfsg-1/windows/JackSystemDeps_os.h
--- 1.9.14~dfsg-1/windows/JackSystemDeps_os.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackSystemDeps_os.h	2020-10-16 19:10:40.000000000 +0000
@@ -21,6 +21,9 @@
 #ifndef __JackSystemDeps_WIN32__
 #define __JackSystemDeps_WIN32__
 
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 #include "JackCompilerDeps.h"
 
@@ -28,10 +31,12 @@
 #define PATH_MAX   512
 #endif
 
+#ifndef UINT32_MAX
 #define UINT32_MAX 4294967295U
+#endif
 
 #define DRIVER_HANDLE HINSTANCE
-#define LoadDriverModule(name) LoadLibrary((name))
+#define LoadDriverModule(name) LoadLibraryW((name))
 #define UnloadDriverModule(handle) (FreeLibrary(((HMODULE)handle)))
 #define GetDriverProc(handle, name) GetProcAddress(((HMODULE)handle), (name))
 
diff -pruN 1.9.14~dfsg-1/windows/jack_test.cbp 1.9.16~dfsg-1/windows/jack_test.cbp
--- 1.9.14~dfsg-1/windows/jack_test.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_test.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,158 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_test" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Debug\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_test" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-                    <Add option="-m32" />
-					<Add directory="Release\bin" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\tests\test.cpp">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/JackTypes_os.h 1.9.16~dfsg-1/windows/JackTypes_os.h
--- 1.9.14~dfsg-1/windows/JackTypes_os.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackTypes_os.h	2020-10-16 19:10:40.000000000 +0000
@@ -21,12 +21,19 @@
 #ifndef __JackTypes_WIN32__
 #define __JackTypes_WIN32__
 
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 
-typedef ULONGLONG UInt64;
+typedef ULONGLONG UInt64;
 typedef UInt64 uint64_t;
 typedef unsigned short uint16_t;
-typedef DWORD jack_tls_key;
+typedef DWORD jack_tls_key;
+
+#if defined(__MINGW32__)
+#define PRIu64 "llu"
+#endif
 
 #endif
 
diff -pruN 1.9.14~dfsg-1/windows/jack_unload.cbp 1.9.16~dfsg-1/windows/jack_unload.cbp
--- 1.9.14~dfsg-1/windows/jack_unload.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_unload.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,152 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_unload" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack_unload" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack_unload" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack_unload" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libjack64" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack_unload" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack_unload" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Debug\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack_unload" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libjack" />
-					<Add directory="Release\bin" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\example-clients\ipunload.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/JackWinEvent.h 1.9.16~dfsg-1/windows/JackWinEvent.h
--- 1.9.14~dfsg-1/windows/JackWinEvent.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackWinEvent.h	2020-10-16 19:10:40.000000000 +0000
@@ -21,6 +21,10 @@
 #define __JackWinEvent__
 
 #include "JackSynchro.h"
+
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 
 namespace Jack
diff -pruN 1.9.14~dfsg-1/windows/jack_winmme.cbp 1.9.16~dfsg-1/windows/jack_winmme.cbp
--- 1.9.14~dfsg-1/windows/jack_winmme.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jack_winmme.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,223 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="jack_winmme" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\jack\jack_winmme" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-                			<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="winmme" />
-				</Compiler>
-				<Linker>
-					<Add directory="..\windows" />
-					<Add directory="Release64\bin" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\jack\jack_winmme" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-W" />
-					<Add option="-g" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-               			<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="winmme" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-					<Add directory="..\windows" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\jack\jack_winmme" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-             				<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="winmme" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-					<Add directory="..\windows" />
-                    <Add library="libjackserver64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\jack\jack_winmme" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                     			<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-            				<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="winmme" />
-				</Compiler>
-				<Linker>
-					<Add directory="..\windows" />
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/jackwinmme.res jackwinmme.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\jack\jack_winmme" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-W" />
-					<Add option="-g" />
-                    			<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DSERVER_SIDE" />
-              			<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="winmme" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug\bin" />
-					<Add directory="..\windows" />
-                    <Add option="-m32" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackwinmme.res jackwinmme.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\jack\jack_winmme" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    			<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DSERVER_SIDE" />
-              				<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="winmme" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-					<Add directory="..\windows" />
-                    <Add option="-m32" />
-                    <Add library="libjackserver" />
-				</Linker>
-                <ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/jackwinmme.res jackwinmme.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="winmm" />
-		</Linker>
-		<Unit filename="jackwinmme.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Unit filename="winmme\JackWinMMEDriver.cpp" />
-		<Unit filename="winmme\JackWinMMEDriver.h" />
-		<Unit filename="winmme\JackWinMMEInputPort.cpp" />
-		<Unit filename="winmme\JackWinMMEInputPort.h" />
-		<Unit filename="winmme\JackWinMMEOutputPort.cpp" />
-		<Unit filename="winmme\JackWinMMEOutputPort.h" />
-		<Unit filename="winmme\JackWinMMEPort.cpp" />
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<lib_finder disable_auto="1" />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/jackwinmme.rc 1.9.16~dfsg-1/windows/jackwinmme.rc
--- 1.9.14~dfsg-1/windows/jackwinmme.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/jackwinmme.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jackmp WinMME Driver for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "jack_portaudio\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "jack_winmme.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "jack_winmme\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/JackWinMutex.h 1.9.16~dfsg-1/windows/JackWinMutex.h
--- 1.9.14~dfsg-1/windows/JackWinMutex.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackWinMutex.h	2020-10-16 19:10:40.000000000 +0000
@@ -23,6 +23,9 @@
 
 #include "JackCompilerDeps.h"
 #include "JackException.h"
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 #include <stdio.h>
 
@@ -71,13 +74,13 @@ class SERVER_EXPORT JackWinMutex
 
         JackWinMutex(const char* name = NULL)
         {
-            // In recursive mode by default
+            // In recursive mode by default
             if (name) {
                 char buffer[MAX_PATH];
                 snprintf(buffer, sizeof(buffer), "%s_%s", "JackWinMutex", name);
-                fMutex = CreateMutex(NULL, FALSE, buffer);
-            } else {
-                fMutex = CreateMutex(NULL, FALSE, NULL);
+                fMutex = CreateMutex(NULL, FALSE, buffer);
+            } else {
+                fMutex = CreateMutex(NULL, FALSE, NULL);
             }
 
             ThrowIf((fMutex == 0), JackException("JackWinMutex: could not init the mutex"));
diff -pruN 1.9.14~dfsg-1/windows/JackWinNamedPipe.h 1.9.16~dfsg-1/windows/JackWinNamedPipe.h
--- 1.9.14~dfsg-1/windows/JackWinNamedPipe.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackWinNamedPipe.h	2020-10-16 19:10:40.000000000 +0000
@@ -21,6 +21,9 @@
 #ifndef __JackWinNamedPipe__
 #define __JackWinNamedPipe__
 
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 
 #include "JackChannel.h"
diff -pruN 1.9.14~dfsg-1/windows/JackWinSemaphore.h 1.9.16~dfsg-1/windows/JackWinSemaphore.h
--- 1.9.14~dfsg-1/windows/JackWinSemaphore.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackWinSemaphore.h	2020-10-16 19:10:40.000000000 +0000
@@ -22,6 +22,9 @@
 #define __JackWinSemaphore__
 
 #include "JackSynchro.h"
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 #include <assert.h>
 
diff -pruN 1.9.14~dfsg-1/windows/JackWinThread.h 1.9.16~dfsg-1/windows/JackWinThread.h
--- 1.9.14~dfsg-1/windows/JackWinThread.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/JackWinThread.h	2020-10-16 19:10:40.000000000 +0000
@@ -24,6 +24,9 @@
 #include "JackMMCSS.h"
 #include "JackCompilerDeps.h"
 #include "JackSystemDeps.h"
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 
 namespace Jack
diff -pruN 1.9.14~dfsg-1/windows/libjack.cbp 1.9.16~dfsg-1/windows/libjack.cbp
--- 1.9.14~dfsg-1/windows/libjack.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/libjack.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,403 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="libjack" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\libjack64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\libjack" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add library="kernel32" />
-					<Add library="user32" />
-					<Add library="gdi32" />
-					<Add library="winspool" />
-					<Add library="comdlg32" />
-					<Add library="advapi32" />
-					<Add library="shell32" />
-					<Add library="ole32" />
-					<Add library="oleaut32" />
-					<Add library="uuid" />
-					<Add library="odbc32" />
-					<Add library="odbccp32" />
-					<Add library="psapi" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\libjack64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\libjack" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add library="kernel32" />
-					<Add library="user32" />
-					<Add library="gdi32" />
-					<Add library="winspool" />
-					<Add library="comdlg32" />
-					<Add library="advapi32" />
-					<Add library="shell32" />
-					<Add library="ole32" />
-					<Add library="oleaut32" />
-					<Add library="uuid" />
-					<Add library="odbc32" />
-					<Add library="odbccp32" />
-					<Add library="psapi" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\libjack64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\libjack" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add library="kernel32" />
-					<Add library="user32" />
-					<Add library="gdi32" />
-					<Add library="winspool" />
-					<Add library="comdlg32" />
-					<Add library="advapi32" />
-					<Add library="shell32" />
-					<Add library="ole32" />
-					<Add library="oleaut32" />
-					<Add library="uuid" />
-					<Add library="odbc32" />
-					<Add library="odbccp32" />
-					<Add library="psapi" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\libjack" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\libjack" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="kernel32" />
-					<Add library="user32" />
-					<Add library="gdi32" />
-					<Add library="winspool" />
-					<Add library="comdlg32" />
-					<Add library="advapi32" />
-					<Add library="shell32" />
-					<Add library="ole32" />
-					<Add library="oleaut32" />
-					<Add library="uuid" />
-					<Add library="odbc32" />
-					<Add library="odbccp32" />
-					<Add library="psapi" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/libjack/libjack.res libjack.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\libjack" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\libjack" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="kernel32" />
-					<Add library="user32" />
-					<Add library="gdi32" />
-					<Add library="winspool" />
-					<Add library="comdlg32" />
-					<Add library="advapi32" />
-					<Add library="shell32" />
-					<Add library="ole32" />
-					<Add library="oleaut32" />
-					<Add library="uuid" />
-					<Add library="odbc32" />
-					<Add library="odbccp32" />
-					<Add library="psapi" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/libjack/libjack.res libjack.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\libjack" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\libjack" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="kernel32" />
-					<Add library="user32" />
-					<Add library="gdi32" />
-					<Add library="winspool" />
-					<Add library="comdlg32" />
-					<Add library="advapi32" />
-					<Add library="shell32" />
-					<Add library="ole32" />
-					<Add library="oleaut32" />
-					<Add library="uuid" />
-					<Add library="odbc32" />
-					<Add library="odbccp32" />
-					<Add library="psapi" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/libjack/libjack.res libjack.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="winmm" />
-		</Linker>
-		<Unit filename="..\common\JackAPI.cpp" />
-		<Unit filename="..\common\JackActivationCount.cpp" />
-		<Unit filename="..\common\JackAudioPort.cpp" />
-		<Unit filename="..\common\JackClient.cpp" />
-		<Unit filename="..\common\JackConnectionManager.cpp" />
-		<Unit filename="..\common\JackDebugClient.cpp">
-			<Option target="Win32 Debug 64bits" />
-			<Option target="Win32 Debug 32bits" />
-		</Unit>
-		<Unit filename="..\common\JackEngineControl.cpp" />
-		<Unit filename="..\common\JackEngineProfiling.cpp">
-			<Option target="Win32 Profiling" />
-		</Unit>
-		<Unit filename="..\common\JackError.cpp" />
-		<Unit filename="..\common\JackException.cpp" />
-		<Unit filename="..\common\JackFrameTimer.cpp" />
-		<Unit filename="..\common\JackGenericClientChannel.cpp" />
-		<Unit filename="..\common\JackGlobals.cpp" />
-		<Unit filename="..\common\JackGraphManager.cpp" />
-		<Unit filename="..\common\JackLibAPI.cpp" />
-		<Unit filename="..\common\JackLibClient.cpp" />
-		<Unit filename="..\common\JackMessageBuffer.cpp" />
-		<Unit filename="..\common\JackMidiAPI.cpp" />
-		<Unit filename="..\common\JackMidiPort.cpp" />
-		<Unit filename="..\common\JackPort.cpp" />
-		<Unit filename="..\common\JackPortType.cpp" />
-		<Unit filename="..\common\JackShmMem.cpp" />
-		<Unit filename="..\common\JackTools.cpp" />
-		<Unit filename="..\common\JackTransportEngine.cpp" />
-		<Unit filename="..\common\ringbuffer.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="..\common\shm.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="JackMMCSS.cpp" />
-		<Unit filename="JackWinMutex.cpp" />
-		<Unit filename="JackWinNamedPipe.cpp" />
-		<Unit filename="JackWinNamedPipeClientChannel.cpp" />
-		<Unit filename="JackWinProcessSync.cpp" />
-		<Unit filename="JackWinSemaphore.cpp" />
-		<Unit filename="JackWinServerLaunch.cpp" />
-		<Unit filename="JackWinThread.cpp" />
-		<Unit filename="JackWinTime.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="libjack.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\regcomp.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\regerror.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\regex.h" />
-		<Unit filename="tre-0.8.0\lib\regexec.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-ast.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-ast.h" />
-		<Unit filename="tre-0.8.0\lib\tre-compile.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-compile.h" />
-		<Unit filename="tre-0.8.0\lib\tre-internal.h" />
-		<Unit filename="tre-0.8.0\lib\tre-match-approx.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-match-backtrack.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-match-parallel.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-match-utils.h" />
-		<Unit filename="tre-0.8.0\lib\tre-mem.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-mem.h" />
-		<Unit filename="tre-0.8.0\lib\tre-parse.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-parse.h" />
-		<Unit filename="tre-0.8.0\lib\tre-stack.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-stack.h" />
-		<Unit filename="tre-0.8.0\lib\tre.h" />
-		<Unit filename="tre-0.8.0\lib\xmalloc.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\xmalloc.h" />
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/libjacknet.cbp 1.9.16~dfsg-1/windows/libjacknet.cbp
--- 1.9.14~dfsg-1/windows/libjacknet.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/libjacknet.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,254 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="libjacknet" />
-		<Option pch_mode="2" />
-		<Option compiler="gcc" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\libjacknet64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\libjacknet" />
-				<Option type="3" />
-				<Option compiler="gcc" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DLIBJACKDMP_EXPORTS" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libsamplerate_x86_64.a" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\libjacknet64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\libjacknet" />
-				<Option type="3" />
-				<Option compiler="gcc" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DLIBJACKDMP_EXPORTS" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libsamplerate_x86_64.a" />
-					<Add directory="Debug64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\libjacknet64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\libjacknet" />
-				<Option type="3" />
-				<Option compiler="gcc" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DLIBJACKDMP_EXPORTS" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add library="libsamplerate_x86_64.a" />
-					<Add directory="Release64\bin" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\libjacknet" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\libjacknet" />
-				<Option type="3" />
-				<Option compiler="gcc" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DLIBJACKDMP_EXPORTS" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libsamplerate_x86.a" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/libjacknet/libjacknet.res libjacknet.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\libjacknet" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\libjacknet" />
-				<Option type="3" />
-				<Option compiler="gcc" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DLIBJACKDMP_EXPORTS" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libsamplerate_x86.a" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/libjacknet/libjacknet.res libjacknet.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\libjacknet" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\libjacknet" />
-				<Option type="3" />
-				<Option compiler="gcc" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DLIBJACKDMP_EXPORTS" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="libsamplerate_x86.a" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/libjacknet/libjacknet.res libjacknet.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-			<Add directory="." />
-			<Add directory="..\common" />
-			<Add directory="..\common\jack" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="ws2_32" />
-			<Add library="winmm" />
-		</Linker>
-		<Unit filename="..\common\JackAudioAdapterInterface.cpp" />
-		<Unit filename="..\common\JackException.cpp" />
-		<Unit filename="..\common\JackGlobals.cpp" />
-		<Unit filename="..\common\JackLibSampleRateResampler.cpp" />
-		<Unit filename="..\common\JackNetAPI.cpp" />
-		<Unit filename="..\common\JackNetInterface.cpp" />
-		<Unit filename="..\common\JackNetTool.cpp" />
-		<Unit filename="..\common\JackResampler.cpp" />
-		<Unit filename="..\common\ringbuffer.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="JackMMCSS.cpp" />
-		<Unit filename="JackNetWinSocket.cpp" />
-		<Unit filename="JackWinThread.cpp" />
-		<Unit filename="JackWinTime.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="libjacknet.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="0" date_declarations="0" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/libjacknet.rc 1.9.16~dfsg-1/windows/libjacknet.rc
--- 1.9.14~dfsg-1/windows/libjacknet.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/libjacknet.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jack Net library for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "libjacknet\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "libjacknet.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "libjacknet\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/libjack.rc 1.9.16~dfsg-1/windows/libjack.rc
--- 1.9.14~dfsg-1/windows/libjack.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/libjack.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jack client library for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "libjack\0"
-            VALUE "LegalCopyright", "Copyright Grame  2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "libjack.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "libjack\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/libjackserver.cbp 1.9.16~dfsg-1/windows/libjackserver.cbp
--- 1.9.14~dfsg-1/windows/libjackserver.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/libjackserver.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,381 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="libjackserver" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\libjackserver64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\libjackserver" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-DSERVER_SIDE" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add library="psapi" />
-					<Add directory="Release\bin64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\libjackserver64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\libjackserver" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-DSERVER_SIDE" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add library="psapi" />
-					<Add directory="Debug\bin64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\libjackserver64" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\libjackserver" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-DSERVER_SIDE" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add library="psapi" />
-					<Add directory="Release\bin64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Release 32bits">
-				<Option output="Release\bin\libjackserver" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\libjackserver" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-DSERVER_SIDE" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="psapi" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/libjackserver/libjackserver.res libjackserver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\libjackserver" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\libjackserver" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-Wall" />
-					<Add option="-g" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-D_DEBUG" />
-					<Add option="-D_CONSOLE" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-DSERVER_SIDE" />
-					<Add option="-D__SMP__" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="psapi" />
-					<Add directory="Debug\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Debug/libjackserver/libjackserver.res libjackserver.rc" />
-				</ExtraCommands>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\libjackserver" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\libjackserver" />
-				<Option type="3" />
-				<Option compiler="mingw_64" />
-				<Option createDefFile="1" />
-				<Option createStaticLib="1" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-m32" />
-					<Add option="-DWIN32" />
-					<Add option="-DNDEBUG" />
-					<Add option="-D_WINDOWS" />
-					<Add option="-D_MBCS" />
-					<Add option="-D_USRDLL" />
-					<Add option="-DREGEX_MALLOC" />
-					<Add option="-DSTDC_HEADERS" />
-					<Add option="-DSERVER_SIDE" />
-					<Add option="-D__SMP__" />
-					<Add option="-DJACK_MONITOR" />
-					<Add option="-DHAVE_CONFIG_H" />
-					<Add directory="." />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-					<Add directory="tre-0.8.0\win32" />
-					<Add directory="tre-0.8.0\lib" />
-				</Compiler>
-				<Linker>
-					<Add option="-m32" />
-					<Add library="psapi" />
-					<Add directory="Release\bin" />
-				</Linker>
-				<ExtraCommands>
-					<Add before="windres -F pe-i386 -O coff -o Release/libjackserver/libjackserver.res libjackserver.rc" />
-				</ExtraCommands>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-			<Add directory="." />
-			<Add directory="..\common" />
-			<Add directory="..\common\jack" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-			<Add library="ws2_32" />
-			<Add library="winmm" />
-		</Linker>
-		<Unit filename="..\common\JackAPI.cpp" />
-		<Unit filename="..\common\JackActivationCount.cpp" />
-		<Unit filename="..\common\JackArgParser.cpp" />
-		<Unit filename="..\common\JackAudioDriver.cpp" />
-		<Unit filename="..\common\JackAudioPort.cpp" />
-		<Unit filename="..\common\JackClient.cpp" />
-		<Unit filename="..\common\JackConnectionManager.cpp" />
-		<Unit filename="..\common\JackControlAPI.cpp" />
-		<Unit filename="..\common\JackDebugClient.cpp">
-			<Option target="Win32 Debug 64bits" />
-			<Option target="Win32 Debug 32bits" />
-		</Unit>
-		<Unit filename="..\common\JackDriver.cpp" />
-		<Unit filename="..\common\JackDriverLoader.cpp" />
-		<Unit filename="..\common\JackEngine.cpp" />
-		<Unit filename="..\common\JackEngineControl.cpp" />
-		<Unit filename="..\common\JackEngineProfiling.cpp">
-			<Option target="Win32 Profiling" />
-		</Unit>
-		<Unit filename="..\common\JackError.cpp" />
-		<Unit filename="..\common\JackException.cpp" />
-		<Unit filename="..\common\JackExternalClient.cpp" />
-		<Unit filename="..\common\JackFrameTimer.cpp" />
-		<Unit filename="..\common\JackFreewheelDriver.cpp" />
-		<Unit filename="..\common\JackGenericClientChannel.cpp" />
-		<Unit filename="..\common\JackGlobals.cpp" />
-		<Unit filename="..\common\JackGraphManager.cpp" />
-		<Unit filename="..\common\JackInternalClient.cpp" />
-		<Unit filename="..\common\JackLoopbackDriver.cpp" />
-		<Unit filename="..\common\JackMessageBuffer.cpp" />
-		<Unit filename="..\common\JackMidiAPI.cpp" />
-		<Unit filename="..\common\JackMidiAsyncQueue.cpp" />
-		<Unit filename="..\common\JackMidiBufferReadQueue.cpp" />
-		<Unit filename="..\common\JackMidiBufferWriteQueue.cpp" />
-		<Unit filename="..\common\JackMidiDriver.cpp" />
-		<Unit filename="..\common\JackMidiPort.cpp" />
-		<Unit filename="..\common\JackMidiReadQueue.cpp" />
-		<Unit filename="..\common\JackMidiUtil.cpp" />
-		<Unit filename="..\common\JackMidiWriteQueue.cpp" />
-		<Unit filename="..\common\JackNetInterface.cpp" />
-		<Unit filename="..\common\JackNetTool.cpp" />
-		<Unit filename="..\common\JackPort.cpp" />
-		<Unit filename="..\common\JackPortType.cpp" />
-		<Unit filename="..\common\JackRequestDecoder.cpp" />
-		<Unit filename="..\common\JackRestartThreadedDriver.cpp" />
-		<Unit filename="..\common\JackServer.cpp" />
-		<Unit filename="..\common\JackServerAPI.cpp" />
-		<Unit filename="..\common\JackServerGlobals.cpp" />
-		<Unit filename="..\common\JackShmMem.cpp" />
-		<Unit filename="..\common\JackThreadedDriver.cpp" />
-		<Unit filename="..\common\JackTimedDriver.cpp" />
-		<Unit filename="..\common\JackTools.cpp" />
-		<Unit filename="..\common\JackTransportEngine.cpp" />
-		<Unit filename="..\common\JackWaitThreadedDriver.cpp" />
-		<Unit filename="..\common\ringbuffer.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="..\common\shm.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="JackMMCSS.cpp" />
-		<Unit filename="JackNetWinSocket.cpp" />
-		<Unit filename="JackWinMutex.cpp" />
-		<Unit filename="JackWinNamedPipe.cpp" />
-		<Unit filename="JackWinNamedPipeClientChannel.cpp" />
-		<Unit filename="JackWinNamedPipeNotifyChannel.cpp" />
-		<Unit filename="JackWinNamedPipeServerChannel.cpp" />
-		<Unit filename="JackWinNamedPipeServerNotifyChannel.cpp" />
-		<Unit filename="JackWinProcessSync.cpp" />
-		<Unit filename="JackWinSemaphore.cpp" />
-		<Unit filename="JackWinThread.cpp" />
-		<Unit filename="JackWinTime.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="getopt1.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="libjackserver.rc">
-			<Option compilerVar="WINDRES" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\regcomp.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\regerror.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\regex.h" />
-		<Unit filename="tre-0.8.0\lib\regexec.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-ast.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-ast.h" />
-		<Unit filename="tre-0.8.0\lib\tre-compile.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-compile.h" />
-		<Unit filename="tre-0.8.0\lib\tre-internal.h" />
-		<Unit filename="tre-0.8.0\lib\tre-match-approx.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-match-backtrack.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-match-parallel.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-match-utils.h" />
-		<Unit filename="tre-0.8.0\lib\tre-mem.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-mem.h" />
-		<Unit filename="tre-0.8.0\lib\tre-parse.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-parse.h" />
-		<Unit filename="tre-0.8.0\lib\tre-stack.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\tre-stack.h" />
-		<Unit filename="tre-0.8.0\lib\tre.h" />
-		<Unit filename="tre-0.8.0\lib\xmalloc.c">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Unit filename="tre-0.8.0\lib\xmalloc.h" />
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="0" date_declarations="0" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/libjackserver.rc 1.9.16~dfsg-1/windows/libjackserver.rc
--- 1.9.14~dfsg-1/windows/libjackserver.rc	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/libjackserver.rc	1970-01-01 00:00:00.000000000 +0000
@@ -1,41 +0,0 @@
-// Generated by ResEdit 1.4.3
-// Copyright (C) 2006-2008
-// http://www.resedit.net
-
-#include "resource.h"
-#include "afxres.h"
-
-
-//
-// Version Information resources
-//
-LANGUAGE LANG_FRENCH, SUBLANG_DEFAULT
-1 VERSIONINFO
-    FILEVERSION     1,9,11,0
-    PRODUCTVERSION  1,9,11,0
-    FILEOS          VOS_UNKNOWN
-    FILETYPE        VFT_DLL
-BEGIN
-    BLOCK "StringFileInfo"
-    BEGIN
-        BLOCK "040c04b0"
-        BEGIN
-            VALUE "Comments", "\0"
-            VALUE "CompanyName", "Grame\0"
-            VALUE "FileDescription", "Jack server library for Windows\0"
-            VALUE "FileVersion", "1, 9, 11\0"
-            VALUE "InternalName", "libjackserver\0"
-            VALUE "LegalCopyright", "Copyright Grame © 2006-2014\0"
-            VALUE "LegalTrademarks", "\0"
-            VALUE "OriginalFilename", "libjackserver.dll\0"
-            VALUE "PrivateBuild", "\0"
-            VALUE "ProductName", "libjackserver\0"
-            VALUE "ProductVersion", "1, 9, 11\0"
-            VALUE "SpecialBuild", "\0"
-        END
-    END
-    BLOCK "VarFileInfo"
-    BEGIN
-        VALUE "Translation", 1036, 1200
-    END
-END
diff -pruN 1.9.14~dfsg-1/windows/multiple_metro.cbp 1.9.16~dfsg-1/windows/multiple_metro.cbp
--- 1.9.14~dfsg-1/windows/multiple_metro.cbp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/multiple_metro.cbp	1970-01-01 00:00:00.000000000 +0000
@@ -1,155 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
-<CodeBlocks_project_file>
-	<FileVersion major="1" minor="6" />
-	<Project>
-		<Option title="multiple_metro" />
-		<Option pch_mode="2" />
-		<Option compiler="mingw_64" />
-		<Build>
-			<Target title="Win32 Release 64bits">
-				<Option output="Release64\bin\multiple_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 64bits">
-				<Option output="Debug64\bin\multiple_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-					<Add directory="..\tests" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 64bits">
-				<Option output="Release64\bin\multiple_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release64\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\tests" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release64\bin" />
-                    <Add library="libjack64" />
-				</Linker>
-			</Target>
-            <Target title="Win32 Release 32bits">
-				<Option output="Release\bin\multiple_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add directory="..\example-clients" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Debug 32bits">
-				<Option output="Debug\bin\multiple_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Debug\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-g" />
-                    <Add option="-m32" />
-					<Add directory="..\tests" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Debug\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-			<Target title="Win32 Profiling 32bits">
-				<Option output="Release\bin\multiple_metro" prefix_auto="1" extension_auto="1" />
-				<Option object_output="Release\" />
-				<Option type="1" />
-				<Option compiler="mingw_64" />
-				<Compiler>
-					<Add option="-O2" />
-					<Add option="-Wall" />
-                    <Add option="-m32" />
-					<Add option="-DJACK_MONITOR" />
-					<Add directory="..\tests" />
-					<Add directory="..\windows" />
-					<Add directory="..\common\jack" />
-					<Add directory="..\common" />
-				</Compiler>
-				<Linker>
-					<Add directory="Release\bin" />
-                    <Add option="-m32" />
-                    <Add library="libjack" />
-				</Linker>
-			</Target>
-		</Build>
-		<Compiler>
-			<Add option="-Wall" />
-		</Compiler>
-		<Linker>
-			<Add library="kernel32" />
-			<Add library="user32" />
-			<Add library="gdi32" />
-			<Add library="winspool" />
-			<Add library="comdlg32" />
-			<Add library="advapi32" />
-			<Add library="shell32" />
-			<Add library="ole32" />
-			<Add library="oleaut32" />
-			<Add library="uuid" />
-			<Add library="odbc32" />
-			<Add library="odbccp32" />
-		</Linker>
-		<Unit filename="..\tests\external_metro.cpp">
-			<Option compilerVar="CC" />
-		</Unit>
-		<Extensions>
-			<code_completion />
-			<envvars />
-			<debugger />
-			<AutoVersioning>
-				<Scheme minor_max="10" build_max="0" rev_max="0" rev_rand_max="10" build_times_to_increment_minor="100" />
-				<Settings autoincrement="1" date_declarations="1" do_auto_increment="0" ask_to_increment="0" language="C++" svn="0" svn_directory="" header_path="version.h" />
-				<Changes_Log show_changes_editor="0" app_title="released version %M.%m.%b of %p" changeslog_path="ChangesLog.txt" />
-			</AutoVersioning>
-		</Extensions>
-	</Project>
-</CodeBlocks_project_file>
diff -pruN 1.9.14~dfsg-1/windows/portaudio/JackPortAudioDevices.h 1.9.16~dfsg-1/windows/portaudio/JackPortAudioDevices.h
--- 1.9.14~dfsg-1/windows/portaudio/JackPortAudioDevices.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/portaudio/JackPortAudioDevices.h	2020-10-16 19:10:40.000000000 +0000
@@ -23,8 +23,8 @@ Foundation, Inc., 675 Mass Ave, Cambridg
 #include <cstdio>
 #include <string>
 
-#include "portaudio.h"
-#include "pa_asio.h"
+#include <portaudio.h>
+#include <pa_asio.h>
 
 /*!
 \brief A PortAudio Devices manager.
diff -pruN 1.9.14~dfsg-1/windows/portaudio/pa_asio.h 1.9.16~dfsg-1/windows/portaudio/pa_asio.h
--- 1.9.14~dfsg-1/windows/portaudio/pa_asio.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/portaudio/pa_asio.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,150 +0,0 @@
-#ifndef PA_ASIO_H
-#define PA_ASIO_H
-/*
- * $Id: pa_asio.h 1667 2011-05-02 15:49:20Z rossb $
- * PortAudio Portable Real-Time Audio Library
- * ASIO specific extensions
- *
- * Copyright (c) 1999-2000 Ross Bencina and Phil Burk
- *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of this software and associated documentation files
- * (the "Software"), to deal in the Software without restriction,
- * including without limitation the rights to use, copy, modify, merge,
- * publish, distribute, sublicense, and/or sell copies of the Software,
- * and to permit persons to whom the Software is furnished to do so,
- * subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be
- * included in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
- * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
- * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
- * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
- */
-
-/*
- * The text above constitutes the entire PortAudio license; however, 
- * the PortAudio community also makes the following non-binding requests:
- *
- * Any person wishing to distribute modifications to the Software is
- * requested to send the modifications to the original developer so that
- * they can be incorporated into the canonical version. It is also 
- * requested that these non-binding requests be included along with the 
- * license above.
- */
-
-
-/** @file
- @ingroup public_header
- @brief ASIO-specific PortAudio API extension header file.
-*/
-
-#include "portaudio.h"
-
-#ifdef __cplusplus
-extern "C"
-{
-#endif /* __cplusplus */
-
-
-/** Retrieve legal native buffer sizes for the specified device, in sample frames.
-
- @param device The global index of the device about which the query is being made.
- @param minBufferSizeFrames A pointer to the location which will receive the minimum buffer size value.
- @param maxBufferSizeFrames A pointer to the location which will receive the maximum buffer size value.
- @param preferredBufferSizeFrames A pointer to the location which will receive the preferred buffer size value.
- @param granularity A pointer to the location which will receive the "granularity". This value determines
- the step size used to compute the legal values between minBufferSizeFrames and maxBufferSizeFrames.
- If granularity is -1 then available buffer size values are powers of two.
-
- @see ASIOGetBufferSize in the ASIO SDK.
-
- @note: this function used to be called PaAsio_GetAvailableLatencyValues. There is a
- #define that maps PaAsio_GetAvailableLatencyValues to this function for backwards compatibility.
-*/
-PaError PaAsio_GetAvailableBufferSizes( PaDeviceIndex device,
-		long *minBufferSizeFrames, long *maxBufferSizeFrames, long *preferredBufferSizeFrames, long *granularity );
-
-
-/** Backwards compatibility alias for PaAsio_GetAvailableBufferSizes
-
- @see PaAsio_GetAvailableBufferSizes
-*/
-#define PaAsio_GetAvailableLatencyValues PaAsio_GetAvailableBufferSizes
-
-
-/** Display the ASIO control panel for the specified device.
-
-  @param device The global index of the device whose control panel is to be displayed.
-  @param systemSpecific On Windows, the calling application's main window handle,
-  on Macintosh this value should be zero.
-*/
-PaError PaAsio_ShowControlPanel( PaDeviceIndex device, void* systemSpecific );
-
-
-
-
-/** Retrieve a pointer to a string containing the name of the specified
- input channel. The string is valid until Pa_Terminate is called.
-
- The string will be no longer than 32 characters including the null terminator.
-*/
-PaError PaAsio_GetInputChannelName( PaDeviceIndex device, int channelIndex,
-        const char** channelName );
-
-        
-/** Retrieve a pointer to a string containing the name of the specified
- input channel. The string is valid until Pa_Terminate is called.
-
- The string will be no longer than 32 characters including the null terminator.
-*/
-PaError PaAsio_GetOutputChannelName( PaDeviceIndex device, int channelIndex,
-        const char** channelName );
-
-
-/** Set the sample rate of an open paASIO stream.
- 
- @param stream The stream to operate on.
- @param sampleRate The new sample rate. 
-
- Note that this function may fail if the stream is already running and the 
- ASIO driver does not support switching the sample rate of a running stream.
-
- Returns paIncompatibleStreamHostApi if stream is not a paASIO stream.
-*/
-PaError PaAsio_SetStreamSampleRate( PaStream* stream, double sampleRate );
-
-
-#define paAsioUseChannelSelectors      (0x01)
-
-typedef struct PaAsioStreamInfo{
-    unsigned long size;             /**< sizeof(PaAsioStreamInfo) */
-    PaHostApiTypeId hostApiType;    /**< paASIO */
-    unsigned long version;          /**< 1 */
-
-    unsigned long flags;
-
-    /* Support for opening only specific channels of an ASIO device.
-        If the paAsioUseChannelSelectors flag is set, channelSelectors is a
-        pointer to an array of integers specifying the device channels to use.
-        When used, the length of the channelSelectors array must match the
-        corresponding channelCount parameter to Pa_OpenStream() otherwise a
-        crash may result.
-        The values in the selectors array must specify channels within the
-        range of supported channels for the device or paInvalidChannelCount will
-        result.
-    */
-    int *channelSelectors;
-}PaAsioStreamInfo;
-
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
-#endif /* PA_ASIO_H */
diff -pruN 1.9.14~dfsg-1/windows/portaudio/portaudio.h 1.9.16~dfsg-1/windows/portaudio/portaudio.h
--- 1.9.14~dfsg-1/windows/portaudio/portaudio.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/portaudio/portaudio.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,1127 +0,0 @@
-
-#ifndef PORTAUDIO_H
-#define PORTAUDIO_H
-/*
- * $Id: portaudio.h,v 1.1.2.2 2006/06/20 14:44:48 letz Exp $
- * PortAudio Portable Real-Time Audio Library
- * PortAudio API Header File
- * Latest version available at: http://www.portaudio.com/
- *
- * Copyright (c) 1999-2002 Ross Bencina and Phil Burk
- *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of this software and associated documentation files
- * (the "Software"), to deal in the Software without restriction,
- * including without limitation the rights to use, copy, modify, merge,
- * publish, distribute, sublicense, and/or sell copies of the Software,
- * and to permit persons to whom the Software is furnished to do so,
- * subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be
- * included in all copies or substantial portions of the Software.
- *
- * Any person wishing to distribute modifications to the Software is
- * requested to send the modifications to the original developer so that
- * they can be incorporated into the canonical version.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
- * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
- * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
- * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
- */
-
-/** @file
- @brief The PortAudio API.
-*/
-
-
-#ifdef __cplusplus
-extern "C"
-{
-#endif /* __cplusplus */
-
-
-    /** Retrieve the release number of the currently running PortAudio build,
-     eg 1900.
-    */
-    int Pa_GetVersion( void );
-
-
-    /** Retrieve a textual description of the current PortAudio build,
-     eg "PortAudio V19-devel 13 October 2002".
-    */
-    const char* Pa_GetVersionText( void );
-
-
-    /** Error codes returned by PortAudio functions.
-     Note that with the exception of paNoError, all PaErrorCodes are negative.
-    */
-
-    typedef int PaError;
-    typedef enum PaErrorCode {
-        paNoError = 0,
-
-        paNotInitialized = -10000,
-        paUnanticipatedHostError,
-        paInvalidChannelCount,
-        paInvalidSampleRate,
-        paInvalidDevice,
-        paInvalidFlag,
-        paSampleFormatNotSupported,
-        paBadIODeviceCombination,
-        paInsufficientMemory,
-        paBufferTooBig,
-        paBufferTooSmall,
-        paNullCallback,
-        paBadStreamPtr,
-        paTimedOut,
-        paInternalError,
-        paDeviceUnavailable,
-        paIncompatibleHostApiSpecificStreamInfo,
-        paStreamIsStopped,
-        paStreamIsNotStopped,
-        paInputOverflowed,
-        paOutputUnderflowed,
-        paHostApiNotFound,
-        paInvalidHostApi,
-        paCanNotReadFromACallbackStream,       /**< @todo review error code name */
-        paCanNotWriteToACallbackStream,        /**< @todo review error code name */
-        paCanNotReadFromAnOutputOnlyStream,    /**< @todo review error code name */
-        paCanNotWriteToAnInputOnlyStream,      /**< @todo review error code name */
-        paIncompatibleStreamHostApi,
-        paBadBufferPtr
-    }
-    PaErrorCode;
-
-
-    /** Translate the supplied PortAudio error code into a human readable
-     message.
-    */
-    const char *Pa_GetErrorText( PaError errorCode );
-
-
-    /** Library initialization function - call this before using PortAudio.
-     This function initialises internal data structures and prepares underlying
-     host APIs for use. This function MUST be called before using any other
-     PortAudio API functions.
-     
-     If Pa_Initialize() is called multiple times, each successful 
-     call must be matched with a corresponding call to Pa_Terminate(). 
-     Pairs of calls to Pa_Initialize()/Pa_Terminate() may overlap, and are not 
-     required to be fully nested.
-     
-     Note that if Pa_Initialize() returns an error code, Pa_Terminate() should
-     NOT be called.
-     
-     @return paNoError if successful, otherwise an error code indicating the cause
-     of failure.
-     
-     @see Pa_Terminate
-    */
-    PaError Pa_Initialize( void );
-
-
-    /** Library termination function - call this when finished using PortAudio.
-     This function deallocates all resources allocated by PortAudio since it was
-     initializied by a call to Pa_Initialize(). In cases where Pa_Initialise() has
-     been called multiple times, each call must be matched with a corresponding call
-     to Pa_Terminate(). The final matching call to Pa_Terminate() will automatically
-     close any PortAudio streams that are still open.
-     
-     Pa_Terminate() MUST be called before exiting a program which uses PortAudio.
-     Failure to do so may result in serious resource leaks, such as audio devices
-     not being available until the next reboot.
-     
-     @return paNoError if successful, otherwise an error code indicating the cause
-     of failure.
-     
-     @see Pa_Initialize
-    */
-    PaError Pa_Terminate( void );
-
-
-
-    /** The type used to refer to audio devices. Values of this type usually
-     range from 0 to (Pa_DeviceCount-1), and may also take on the PaNoDevice
-     and paUseHostApiSpecificDeviceSpecification values.
-     
-     @see Pa_DeviceCount, paNoDevice, paUseHostApiSpecificDeviceSpecification
-    */
-    typedef int PaDeviceIndex;
-
-
-    /** A special PaDeviceIndex value indicating that no device is available,
-     or should be used.
-     
-     @see PaDeviceIndex
-    */
-#define paNoDevice ((PaDeviceIndex)-1)
-
-
-    /** A special PaDeviceIndex value indicating that the device(s) to be used
-     are specified in the host api specific stream info structure.
-     
-     @see PaDeviceIndex
-    */
-#define paUseHostApiSpecificDeviceSpecification ((PaDeviceIndex)-2)
-
-
-    /* Host API enumeration mechanism */
-
-    /** The type used to enumerate to host APIs at runtime. Values of this type
-     range from 0 to (Pa_GetHostApiCount()-1).
-     
-     @see Pa_GetHostApiCount
-    */
-    typedef int PaHostApiIndex;
-
-
-    /** Retrieve the number of available host APIs. Even if a host API is
-     available it may have no devices available.
-     
-     @return A non-negative value indicating the number of available host APIs
-     or, a PaErrorCode (which are always negative) if PortAudio is not initialized
-     or an error is encountered.
-     
-     @see PaHostApiIndex
-    */
-    PaHostApiIndex Pa_GetHostApiCount( void );
-
-
-    /** Retrieve the index of the default host API. The default host API will be
-     the lowest common denominator host API on the current platform and is
-     unlikely to provide the best performance.
-     
-     @return A non-negative value ranging from 0 to (Pa_GetHostApiCount()-1)
-     indicating the default host API index or, a PaErrorCode (which are always
-     negative) if PortAudio is not initialized or an error is encountered.
-    */
-    PaHostApiIndex Pa_GetDefaultHostApi( void );
-
-
-    /** Unchanging unique identifiers for each supported host API. This type
-     is used in the PaHostApiInfo structure. The values are guaranteed to be
-     unique and to never change, thus allowing code to be written that
-     conditionally uses host API specific extensions.
-     
-     New type ids will be allocated when support for a host API reaches
-     "public alpha" status, prior to that developers should use the
-     paInDevelopment type id.
-     
-     @see PaHostApiInfo
-    */
-    typedef enum PaHostApiTypeId {
-        paInDevelopment = 0,  /* use while developing support for a new host API */
-        paDirectSound = 1,
-        paMME = 2,
-        paASIO = 3,
-        paSoundManager = 4,
-        paCoreAudio = 5,
-        paOSS = 7,
-        paALSA = 8,
-        paAL = 9,
-        paBeOS = 10,
-        paWDMKS = 11,
-        paJACK = 12,
-        paWASAPI = 13
-    }
-    PaHostApiTypeId;
-
-
-    /** A structure containing information about a particular host API. */
-
-    typedef struct PaHostApiInfo {
-        /** this is struct version 1 */
-        int structVersion;
-        /** The well known unique identifier of this host API @see PaHostApiTypeId */
-        PaHostApiTypeId type;
-        /** A textual description of the host API for display on user interfaces. */
-        const char *name;
-
-        /**  The number of devices belonging to this host API. This field may be
-         used in conjunction with Pa_HostApiDeviceIndexToDeviceIndex() to enumerate
-         all devices for this host API.
-         @see Pa_HostApiDeviceIndexToDeviceIndex
-        */
-        int deviceCount;
-
-        /** The default input device for this host API. The value will be a
-         device index ranging from 0 to (Pa_GetDeviceCount()-1), or paNoDevice
-         if no default input device is available.
-        */
-        PaDeviceIndex defaultInputDevice;
-
-        /** The default output device for this host API. The value will be a
-         device index ranging from 0 to (Pa_GetDeviceCount()-1), or paNoDevice
-         if no default output device is available.
-        */
-        PaDeviceIndex defaultOutputDevice;
-
-    }
-    PaHostApiInfo;
-
-
-    /** Retrieve a pointer to a structure containing information about a specific
-     host Api.
-     
-     @param hostApi A valid host API index ranging from 0 to (Pa_GetHostApiCount()-1)
-     
-     @return A pointer to an immutable PaHostApiInfo structure describing
-     a specific host API. If the hostApi parameter is out of range or an error
-     is encountered, the function returns NULL.
-     
-     The returned structure is owned by the PortAudio implementation and must not
-     be manipulated or freed. The pointer is only guaranteed to be valid between
-     calls to Pa_Initialize() and Pa_Terminate().
-    */
-    const PaHostApiInfo * Pa_GetHostApiInfo( PaHostApiIndex hostApi );
-
-
-    /** Convert a static host API unique identifier, into a runtime
-     host API index.
-     
-     @param type A unique host API identifier belonging to the PaHostApiTypeId
-     enumeration.
-     
-     @return A valid PaHostApiIndex ranging from 0 to (Pa_GetHostApiCount()-1) or,
-     a PaErrorCode (which are always negative) if PortAudio is not initialized
-     or an error is encountered.
-     
-     The paHostApiNotFound error code indicates that the host API specified by the
-     type parameter is not available.
-     
-     @see PaHostApiTypeId
-    */
-    PaHostApiIndex Pa_HostApiTypeIdToHostApiIndex( PaHostApiTypeId type );
-
-
-    /** Convert a host-API-specific device index to standard PortAudio device index.
-     This function may be used in conjunction with the deviceCount field of
-     PaHostApiInfo to enumerate all devices for the specified host API.
-     
-     @param hostApi A valid host API index ranging from 0 to (Pa_GetHostApiCount()-1)
-     
-     @param hostApiDeviceIndex A valid per-host device index in the range
-     0 to (Pa_GetHostApiInfo(hostApi)->deviceCount-1)
-     
-     @return A non-negative PaDeviceIndex ranging from 0 to (Pa_GetDeviceCount()-1)
-     or, a PaErrorCode (which are always negative) if PortAudio is not initialized
-     or an error is encountered.
-     
-     A paInvalidHostApi error code indicates that the host API index specified by
-     the hostApi parameter is out of range.
-     
-     A paInvalidDevice error code indicates that the hostApiDeviceIndex parameter
-     is out of range.
-     
-     @see PaHostApiInfo
-    */
-    PaDeviceIndex Pa_HostApiDeviceIndexToDeviceIndex( PaHostApiIndex hostApi,
-            int hostApiDeviceIndex );
-
-
-
-    /** Structure used to return information about a host error condition.
-    */
-    typedef struct PaHostErrorInfo {
-        PaHostApiTypeId hostApiType;    /**< the host API which returned the error code */
-        long errorCode;                 /**< the error code returned */
-        const char *errorText;          /**< a textual description of the error if available, otherwise a zero-length string */
-    }
-    PaHostErrorInfo;
-
-
-    /** Return information about the last host error encountered. The error
-     information returned by Pa_GetLastHostErrorInfo() will never be modified
-     asynchronously by errors occurring in other PortAudio owned threads
-     (such as the thread that manages the stream callback.)
-     
-     This function is provided as a last resort, primarily to enhance debugging
-     by providing clients with access to all available error information.
-     
-     @return A pointer to an immutable structure constaining information about
-     the host error. The values in this structure will only be valid if a
-     PortAudio function has previously returned the paUnanticipatedHostError
-     error code.
-    */
-    const PaHostErrorInfo* Pa_GetLastHostErrorInfo( void );
-
-
-
-    /* Device enumeration and capabilities */
-
-    /** Retrieve the number of available devices. The number of available devices
-     may be zero.
-     
-     @return A non-negative value indicating the number of available devices or,
-     a PaErrorCode (which are always negative) if PortAudio is not initialized
-     or an error is encountered.
-    */
-    PaDeviceIndex Pa_GetDeviceCount( void );
-
-
-    /** Retrieve the index of the default input device. The result can be
-     used in the inputDevice parameter to Pa_OpenStream().
-     
-     @return The default input device index for the default host API, or paNoDevice
-     if no default input device is available or an error was encountered.
-    */
-    PaDeviceIndex Pa_GetDefaultInputDevice( void );
-
-
-    /** Retrieve the index of the default output device. The result can be
-     used in the outputDevice parameter to Pa_OpenStream().
-     
-     @return The default output device index for the default host API, or paNoDevice
-     if no default output device is available or an error was encountered.
-     
-     @note
-     On the PC, the user can specify a default device by
-     setting an environment variable. For example, to use device #1.
-    <pre>
-     set PA_RECOMMENDED_OUTPUT_DEVICE=1
-    </pre>
-     The user should first determine the available device ids by using
-     the supplied application "pa_devs".
-    */
-    PaDeviceIndex Pa_GetDefaultOutputDevice( void );
-
-
-    /** The type used to represent monotonic time in seconds that can be used
-     for syncronisation. The type is used for the outTime argument to the
-     PaStreamCallback and as the result of Pa_GetStreamTime().
-        
-     @see PaStreamCallback, Pa_GetStreamTime
-    */
-    typedef double PaTime;
-
-
-    /** A type used to specify one or more sample formats. Each value indicates
-     a possible format for sound data passed to and from the stream callback,
-     Pa_ReadStream and Pa_WriteStream.
-     
-     The standard formats paFloat32, paInt16, paInt32, paInt24, paInt8
-     and aUInt8 are usually implemented by all implementations.
-     
-     The floating point representation (paFloat32) uses +1.0 and -1.0 as the
-     maximum and minimum respectively.
-     
-     paUInt8 is an unsigned 8 bit format where 128 is considered "ground"
-     
-     The paNonInterleaved flag indicates that a multichannel buffer is passed
-     as a set of non-interleaved pointers.
-     
-     @see Pa_OpenStream, Pa_OpenDefaultStream, PaDeviceInfo
-     @see paFloat32, paInt16, paInt32, paInt24, paInt8
-     @see paUInt8, paCustomFormat, paNonInterleaved
-    */
-    typedef unsigned long PaSampleFormat;
-
-
-#define paFloat32        ((PaSampleFormat) 0x00000001) /**< @see PaSampleFormat */
-#define paInt32          ((PaSampleFormat) 0x00000002) /**< @see PaSampleFormat */
-#define paInt24          ((PaSampleFormat) 0x00000004) /**< Packed 24 bit format. @see PaSampleFormat */
-#define paInt16          ((PaSampleFormat) 0x00000008) /**< @see PaSampleFormat */
-#define paInt8           ((PaSampleFormat) 0x00000010) /**< @see PaSampleFormat */
-#define paUInt8          ((PaSampleFormat) 0x00000020) /**< @see PaSampleFormat */
-#define paCustomFormat   ((PaSampleFormat) 0x00010000)/**< @see PaSampleFormat */
-
-#define paNonInterleaved ((PaSampleFormat) 0x80000000)
-
-    /** A structure providing information and capabilities of PortAudio devices.
-     Devices may support input, output or both input and output.
-    */
-    typedef struct PaDeviceInfo {
-        int structVersion;  /* this is struct version 2 */
-        const char *name;
-        PaHostApiIndex hostApi; /* note this is a host API index, not a type id*/
-
-        int maxInputChannels;
-        int maxOutputChannels;
-
-        /* Default latency values for interactive performance. */
-        PaTime defaultLowInputLatency;
-        PaTime defaultLowOutputLatency;
-        /* Default latency values for robust non-interactive applications (eg. playing sound files). */
-        PaTime defaultHighInputLatency;
-        PaTime defaultHighOutputLatency;
-
-        double defaultSampleRate;
-    }
-    PaDeviceInfo;
-
-
-    /** Retrieve a pointer to a PaDeviceInfo structure containing information
-     about the specified device.
-     @return A pointer to an immutable PaDeviceInfo structure. If the device
-     parameter is out of range the function returns NULL.
-     
-     @param device A valid device index in the range 0 to (Pa_GetDeviceCount()-1)
-     
-     @note PortAudio manages the memory referenced by the returned pointer,
-     the client must not manipulate or free the memory. The pointer is only
-     guaranteed to be valid between calls to Pa_Initialize() and Pa_Terminate().
-     
-     @see PaDeviceInfo, PaDeviceIndex
-    */
-    const PaDeviceInfo* Pa_GetDeviceInfo( PaDeviceIndex device );
-
-
-    /** Parameters for one direction (input or output) of a stream.
-    */
-    typedef struct PaStreamParameters {
-        /** A valid device index in the range 0 to (Pa_GetDeviceCount()-1)
-         specifying the device to be used or the special constant
-         paUseHostApiSpecificDeviceSpecification which indicates that the actual
-         device(s) to use are specified in hostApiSpecificStreamInfo.
-         This field must not be set to paNoDevice.
-        */
-        PaDeviceIndex device;
-
-        /** The number of channels of sound to be delivered to the
-         stream callback or accessed by Pa_ReadStream() or Pa_WriteStream().
-         It can range from 1 to the value of maxInputChannels in the
-         PaDeviceInfo record for the device specified by the device parameter.
-        */
-        int channelCount;
-
-        /** The sample format of the buffer provided to the stream callback,
-         a_ReadStream() or Pa_WriteStream(). It may be any of the formats described
-         by the PaSampleFormat enumeration.
-        */
-        PaSampleFormat sampleFormat;
-
-        /** The desired latency in seconds. Where practical, implementations should
-         configure their latency based on these parameters, otherwise they may
-         choose the closest viable latency instead. Unless the suggested latency
-         is greater than the absolute upper limit for the device implementations
-         should round the suggestedLatency up to the next practical value - ie to
-         provide an equal or higher latency than suggestedLatency wherever possible.
-         Actual latency values for an open stream may be retrieved using the
-         inputLatency and outputLatency fields of the PaStreamInfo structure
-         returned by Pa_GetStreamInfo().
-         @see default*Latency in PaDeviceInfo, *Latency in PaStreamInfo
-        */
-        PaTime suggestedLatency;
-
-        /** An optional pointer to a host api specific data structure
-         containing additional information for device setup and/or stream processing.
-         hostApiSpecificStreamInfo is never required for correct operation,
-         if not used it should be set to NULL.
-        */
-        void *hostApiSpecificStreamInfo;
-
-    }
-    PaStreamParameters;
-
-
-    /** Return code for Pa_IsFormatSupported indicating success. */
-#define paFormatIsSupported (0)
-
-    /** Determine whether it would be possible to open a stream with the specified
-     parameters.
-     
-     @param inputParameters A structure that describes the input parameters used to
-     open a stream. The suggestedLatency field is ignored. See PaStreamParameters
-     for a description of these parameters. inputParameters must be NULL for
-     output-only streams.
-     
-     @param outputParameters A structure that describes the output parameters used
-     to open a stream. The suggestedLatency field is ignored. See PaStreamParameters
-     for a description of these parameters. outputParameters must be NULL for
-     input-only streams.
-     
-     @param sampleRate The required sampleRate. For full-duplex streams it is the
-     sample rate for both input and output
-     
-     @return Returns 0 if the format is supported, and an error code indicating why
-     the format is not supported otherwise. The constant paFormatIsSupported is
-     provided to compare with the return value for success.
-     
-     @see paFormatIsSupported, PaStreamParameters
-    */
-    PaError Pa_IsFormatSupported( const PaStreamParameters *inputParameters,
-                                  const PaStreamParameters *outputParameters,
-                                  double sampleRate );
-
-
-
-    /* Streaming types and functions */
-
-
-    /**
-     A single PaStream can provide multiple channels of real-time
-     streaming audio input and output to a client application. A stream
-     provides access to audio hardware represented by one or more
-     PaDevices. Depending on the underlying Host API, it may be possible 
-     to open multiple streams using the same device, however this behavior 
-     is implementation defined. Portable applications should assume that 
-     a PaDevice may be simultaneously used by at most one PaStream.
-     
-     Pointers to PaStream objects are passed between PortAudio functions that
-     operate on streams.
-     
-     @see Pa_OpenStream, Pa_OpenDefaultStream, Pa_OpenDefaultStream, Pa_CloseStream,
-     Pa_StartStream, Pa_StopStream, Pa_AbortStream, Pa_IsStreamActive,
-     Pa_GetStreamTime, Pa_GetStreamCpuLoad
-     
-    */
-    typedef void PaStream;
-
-
-    /** Can be passed as the framesPerBuffer parameter to Pa_OpenStream()
-     or Pa_OpenDefaultStream() to indicate that the stream callback will
-     accept buffers of any size.
-    */
-#define paFramesPerBufferUnspecified  (0)
-
-
-    /** Flags used to control the behavior of a stream. They are passed as
-     parameters to Pa_OpenStream or Pa_OpenDefaultStream. Multiple flags may be
-     ORed together.
-     
-     @see Pa_OpenStream, Pa_OpenDefaultStream
-     @see paNoFlag, paClipOff, paDitherOff, paNeverDropInput,
-      paPrimeOutputBuffersUsingStreamCallback, paPlatformSpecificFlags
-    */
-    typedef unsigned long PaStreamFlags;
-
-    /** @see PaStreamFlags */
-#define   paNoFlag          ((PaStreamFlags) 0)
-
-    /** Disable default clipping of out of range samples.
-     @see PaStreamFlags
-    */
-#define   paClipOff         ((PaStreamFlags) 0x00000001)
-
-    /** Disable default dithering.
-     @see PaStreamFlags
-    */
-#define   paDitherOff       ((PaStreamFlags) 0x00000002)
-
-    /** Flag requests that where possible a full duplex stream will not discard
-     overflowed input samples without calling the stream callback. This flag is
-     only valid for full duplex callback streams and only when used in combination
-     with the paFramesPerBufferUnspecified (0) framesPerBuffer parameter. Using
-     this flag incorrectly results in a paInvalidFlag error being returned from
-     Pa_OpenStream and Pa_OpenDefaultStream.
-     
-     @see PaStreamFlags, paFramesPerBufferUnspecified
-    */
-#define   paNeverDropInput  ((PaStreamFlags) 0x00000004)
-
-    /** Call the stream callback to fill initial output buffers, rather than the
-     default behavior of priming the buffers with zeros (silence). This flag has
-     no effect for input-only and blocking read/write streams.
-     
-     @see PaStreamFlags
-    */
-#define   paPrimeOutputBuffersUsingStreamCallback ((PaStreamFlags) 0x00000008)
-
-    /** A mask specifying the platform specific bits.
-     @see PaStreamFlags
-    */
-#define   paPlatformSpecificFlags ((PaStreamFlags)0xFFFF0000)
-
-    /**
-     Timing information for the buffers passed to the stream callback.
-    */
-    typedef struct PaStreamCallbackTimeInfo {
-        PaTime inputBufferAdcTime;
-        PaTime currentTime;
-        PaTime outputBufferDacTime;
-    }
-    PaStreamCallbackTimeInfo;
-
-
-    /**
-     Flag bit constants for the statusFlags to PaStreamCallback.
-     
-     @see paInputUnderflow, paInputOverflow, paOutputUnderflow, paOutputOverflow,
-     paPrimingOutput
-    */
-    typedef unsigned long PaStreamCallbackFlags;
-
-    /** In a stream opened with paFramesPerBufferUnspecified, indicates that
-     input data is all silence (zeros) because no real data is available. In a
-     stream opened without paFramesPerBufferUnspecified, it indicates that one or
-     more zero samples have been inserted into the input buffer to compensate
-     for an input underflow.
-     @see PaStreamCallbackFlags
-    */
-#define paInputUnderflow   ((PaStreamCallbackFlags) 0x00000001)
-
-    /** In a stream opened with paFramesPerBufferUnspecified, indicates that data
-     prior to the first sample of the input buffer was discarded due to an
-     overflow, possibly because the stream callback is using too much CPU time.
-     Otherwise indicates that data prior to one or more samples in the
-     input buffer was discarded.
-     @see PaStreamCallbackFlags
-    */
-#define paInputOverflow    ((PaStreamCallbackFlags) 0x00000002)
-
-    /** Indicates that output data (or a gap) was inserted, possibly because the
-     stream callback is using too much CPU time.
-     @see PaStreamCallbackFlags
-    */
-#define paOutputUnderflow  ((PaStreamCallbackFlags) 0x00000004)
-
-    /** Indicates that output data will be discarded because no room is available.
-     @see PaStreamCallbackFlags
-    */
-#define paOutputOverflow   ((PaStreamCallbackFlags) 0x00000008)
-
-    /** Some of all of the output data will be used to prime the stream, input
-     data may be zero.
-     @see PaStreamCallbackFlags
-    */
-#define paPrimingOutput    ((PaStreamCallbackFlags) 0x00000010)
-
-    /**
-     Allowable return values for the PaStreamCallback.
-     @see PaStreamCallback
-    */
-    typedef enum PaStreamCallbackResult
-    {
-        paContinue = 0,
-        paComplete = 1,
-        paAbort = 2
-    } PaStreamCallbackResult;
-
-
-    /**
-     Functions of type PaStreamCallback are implemented by PortAudio clients.
-     They consume, process or generate audio in response to requests from an
-     active PortAudio stream.
-        
-     @param input and @param output are arrays of interleaved samples,
-     the format, packing and number of channels used by the buffers are
-     determined by parameters to Pa_OpenStream().
-        
-     @param frameCount The number of sample frames to be processed by
-     the stream callback.
-     
-     @param timeInfo The time in seconds when the first sample of the input
-     buffer was received at the audio input, the time in seconds when the first
-     sample of the output buffer will begin being played at the audio output, and
-     the time in seconds when the stream callback was called.
-     See also Pa_GetStreamTime()
-     
-     @param statusFlags Flags indicating whether input and/or output buffers
-     have been inserted or will be dropped to overcome underflow or overflow
-     conditions.
-     
-     @param userData The value of a user supplied pointer passed to
-     Pa_OpenStream() intended for storing synthesis data etc.
-     
-     @return
-     The stream callback should return one of the values in the
-     PaStreamCallbackResult enumeration. To ensure that the callback continues
-     to be called, it should return paContinue (0). Either paComplete or paAbort
-     can be returned to finish stream processing, after either of these values is
-     returned the callback will not be called again. If paAbort is returned the
-     stream will finish as soon as possible. If paComplete is returned, the stream
-     will continue until all buffers generated by the callback have been played.
-     This may be useful in applications such as soundfile players where a specific
-     duration of output is required. However, it is not necessary to utilise this
-     mechanism as Pa_StopStream(), Pa_AbortStream() or Pa_CloseStream() can also
-     be used to stop the stream. The callback must always fill the entire output
-     buffer irrespective of its return value.
-     
-     @see Pa_OpenStream, Pa_OpenDefaultStream
-     
-     @note With the exception of Pa_GetStreamCpuLoad() it is not permissible to call
-     PortAudio API functions from within the stream callback.
-    */
-    typedef int PaStreamCallback(
-        const void *input, void *output,
-        unsigned long frameCount,
-        const PaStreamCallbackTimeInfo* timeInfo,
-        PaStreamCallbackFlags statusFlags,
-        void *userData );
-
-
-    /** Opens a stream for either input, output or both.
-        
-     @param stream The address of a PaStream pointer which will receive
-     a pointer to the newly opened stream.
-        
-     @param inputParameters A structure that describes the input parameters used by
-     the opened stream. See PaStreamParameters for a description of these parameters.
-     inputParameters must be NULL for output-only streams.
-     
-     @param outputParameters A structure that describes the output parameters used by
-     the opened stream. See PaStreamParameters for a description of these parameters.
-     outputParameters must be NULL for input-only streams.
-     
-     @param sampleRate The desired sampleRate. For full-duplex streams it is the
-     sample rate for both input and output
-        
-     @param framesPerBuffer The number of frames passed to the stream callback
-     function, or the preferred block granularity for a blocking read/write stream.
-     The special value paFramesPerBufferUnspecified (0) may be used to request that
-     the stream callback will receive an optimal (and possibly varying) number of
-     frames based on host requirements and the requested latency settings.
-     Note: With some host APIs, the use of non-zero framesPerBuffer for a callback
-     stream may introduce an additional layer of buffering which could introduce
-     additional latency. PortAudio guarantees that the additional latency
-     will be kept to the theoretical minimum however, it is strongly recommended
-     that a non-zero framesPerBuffer value only be used when your algorithm
-     requires a fixed number of frames per stream callback.
-     
-     @param streamFlags Flags which modify the behaviour of the streaming process.
-     This parameter may contain a combination of flags ORed together. Some flags may
-     only be relevant to certain buffer formats.
-        
-     @param streamCallback A pointer to a client supplied function that is responsible
-     for processing and filling input and output buffers. If this parameter is NULL
-     the stream will be opened in 'blocking read/write' mode. In blocking mode,
-     the client can receive sample data using Pa_ReadStream and write sample data
-     using Pa_WriteStream, the number of samples that may be read or written
-     without blocking is returned by Pa_GetStreamReadAvailable and
-     Pa_GetStreamWriteAvailable respectively.
-     
-     @param userData A client supplied pointer which is passed to the stream callback
-     function. It could for example, contain a pointer to instance data necessary
-     for processing the audio buffers. This parameter is ignored if streamCallback
-     is NULL.
-        
-     @return
-     Upon success Pa_OpenStream() returns paNoError and places a pointer to a
-     valid PaStream in the stream argument. The stream is inactive (stopped).
-     If a call to Pa_OpenStream() fails, a non-zero error code is returned (see
-     PaError for possible error codes) and the value of stream is invalid.
-     
-     @see PaStreamParameters, PaStreamCallback, Pa_ReadStream, Pa_WriteStream,
-     Pa_GetStreamReadAvailable, Pa_GetStreamWriteAvailable
-    */
-    PaError Pa_OpenStream( PaStream** stream,
-                           const PaStreamParameters *inputParameters,
-                           const PaStreamParameters *outputParameters,
-                           double sampleRate,
-                           unsigned long framesPerBuffer,
-                           PaStreamFlags streamFlags,
-                           PaStreamCallback *streamCallback,
-                           void *userData );
-
-
-    /** A simplified version of Pa_OpenStream() that opens the default input
-     and/or output devices.
-     
-     @param stream The address of a PaStream pointer which will receive
-     a pointer to the newly opened stream.
-     
-     @param numInputChannels  The number of channels of sound that will be supplied
-     to the stream callback or returned by Pa_ReadStream. It can range from 1 to
-     the value of maxInputChannels in the PaDeviceInfo record for the default input
-     device. If 0 the stream is opened as an output-only stream.
-     
-     @param numOutputChannels The number of channels of sound to be delivered to the
-     stream callback or passed to Pa_WriteStream. It can range from 1 to the value
-     of maxOutputChannels in the PaDeviceInfo record for the default output dvice.
-     If 0 the stream is opened as an output-only stream.
-     
-     @param sampleFormat The sample format of both the input and output buffers
-     provided to the callback or passed to and from Pa_ReadStream and Pa_WriteStream.
-     sampleFormat may be any of the formats described by the PaSampleFormat
-     enumeration.
-     
-     @param sampleRate Same as Pa_OpenStream parameter of the same name.
-     @param framesPerBuffer Same as Pa_OpenStream parameter of the same name.
-     @param streamCallback Same as Pa_OpenStream parameter of the same name.
-     @param userData Same as Pa_OpenStream parameter of the same name.
-     
-     @return As for Pa_OpenStream
-     
-     @see Pa_OpenStream, PaStreamCallback
-    */
-    PaError Pa_OpenDefaultStream( PaStream** stream,
-                                  int numInputChannels,
-                                  int numOutputChannels,
-                                  PaSampleFormat sampleFormat,
-                                  double sampleRate,
-                                  unsigned long framesPerBuffer,
-                                  PaStreamCallback *streamCallback,
-                                  void *userData );
-
-
-    /** Closes an audio stream. If the audio stream is active it
-     discards any pending buffers as if Pa_AbortStream() had been called.
-    */
-    PaError Pa_CloseStream( PaStream *stream );
-
-
-    /** Functions of type PaStreamFinishedCallback are implemented by PortAudio
-     clients. They can be registered with a stream using the Pa_SetStreamFinishedCallback
-     function. Once registered they are called when the stream becomes inactive
-     (ie once a call to Pa_StopStream() will not block).
-     A stream will become inactive after the stream callback returns non-zero,
-     or when Pa_StopStream or Pa_AbortStream is called. For a stream providing audio
-     output, if the stream callback returns paComplete, or Pa_StopStream is called,
-     the stream finished callback will not be called until all generated sample data
-     has been played.
-     
-     @param userData The userData parameter supplied to Pa_OpenStream()
-     
-     @see Pa_SetStreamFinishedCallback
-    */
-    typedef void PaStreamFinishedCallback( void *userData );
-
-
-    /** Register a stream finished callback function which will be called when the
-     stream becomes inactive. See the description of PaStreamFinishedCallback for 
-     further details about when the callback will be called.
-     
-     @param stream a pointer to a PaStream that is in the stopped state - if the
-     stream is not stopped, the stream's finished callback will remain unchanged 
-     and an error code will be returned.
-     
-     @param streamFinishedCallback a pointer to a function with the same signature
-     as PaStreamFinishedCallback, that will be called when the stream becomes
-     inactive. Passing NULL for this parameter will un-register a previously
-     registered stream finished callback function.
-     
-     @return on success returns paNoError, otherwise an error code indicating the cause
-     of the error.
-     
-     @see PaStreamFinishedCallback
-    */
-    PaError Pa_SetStreamFinishedCallback( PaStream *stream, PaStreamFinishedCallback* streamFinishedCallback );
-
-
-    /** Commences audio processing.
-    */
-    PaError Pa_StartStream( PaStream *stream );
-
-
-    /** Terminates audio processing. It waits until all pending
-     audio buffers have been played before it returns.
-    */
-    PaError Pa_StopStream( PaStream *stream );
-
-
-    /** Terminates audio processing immediately without waiting for pending
-     buffers to complete.
-    */
-    PaError Pa_AbortStream( PaStream *stream );
-
-
-    /** Determine whether the stream is stopped.
-     A stream is considered to be stopped prior to a successful call to
-     Pa_StartStream and after a successful call to Pa_StopStream or Pa_AbortStream.
-     If a stream callback returns a value other than paContinue the stream is NOT
-     considered to be stopped.
-     
-     @return Returns one (1) when the stream is stopped, zero (0) when
-     the stream is running or, a PaErrorCode (which are always negative) if
-     PortAudio is not initialized or an error is encountered.
-     
-     @see Pa_StopStream, Pa_AbortStream, Pa_IsStreamActive
-    */
-    PaError Pa_IsStreamStopped( PaStream *stream );
-
-
-    /** Determine whether the stream is active.
-     A stream is active after a successful call to Pa_StartStream(), until it
-     becomes inactive either as a result of a call to Pa_StopStream() or
-     Pa_AbortStream(), or as a result of a return value other than paContinue from
-     the stream callback. In the latter case, the stream is considered inactive
-     after the last buffer has finished playing.
-     
-     @return Returns one (1) when the stream is active (ie playing or recording
-     audio), zero (0) when not playing or, a PaErrorCode (which are always negative)
-     if PortAudio is not initialized or an error is encountered.
-     
-     @see Pa_StopStream, Pa_AbortStream, Pa_IsStreamStopped
-    */
-    PaError Pa_IsStreamActive( PaStream *stream );
-
-
-
-    /** A structure containing unchanging information about an open stream.
-     @see Pa_GetStreamInfo
-    */
-
-    typedef struct PaStreamInfo {
-        /** this is struct version 1 */
-        int structVersion;
-
-        /** The input latency of the stream in seconds. This value provides the most
-         accurate estimate of input latency available to the implementation. It may
-         differ significantly from the suggestedLatency value passed to Pa_OpenStream().
-         The value of this field will be zero (0.) for output-only streams.
-         @see PaTime
-        */
-        PaTime inputLatency;
-
-        /** The output latency of the stream in seconds. This value provides the most
-         accurate estimate of output latency available to the implementation. It may
-         differ significantly from the suggestedLatency value passed to Pa_OpenStream().
-         The value of this field will be zero (0.) for input-only streams.
-         @see PaTime
-        */
-        PaTime outputLatency;
-
-        /** The sample rate of the stream in Hertz (samples per second). In cases
-         where the hardware sample rate is inaccurate and PortAudio is aware of it,
-         the value of this field may be different from the sampleRate parameter
-         passed to Pa_OpenStream(). If information about the actual hardware sample
-         rate is not available, this field will have the same value as the sampleRate
-         parameter passed to Pa_OpenStream().
-        */
-        double sampleRate;
-
-    }
-    PaStreamInfo;
-
-
-    /** Retrieve a pointer to a PaStreamInfo structure containing information
-     about the specified stream.
-     @return A pointer to an immutable PaStreamInfo structure. If the stream
-     parameter invalid, or an error is encountered, the function returns NULL.
-     
-     @param stream A pointer to an open stream previously created with Pa_OpenStream.
-     
-     @note PortAudio manages the memory referenced by the returned pointer,
-     the client must not manipulate or free the memory. The pointer is only
-     guaranteed to be valid until the specified stream is closed.
-     
-     @see PaStreamInfo
-    */
-    const PaStreamInfo* Pa_GetStreamInfo( PaStream *stream );
-
-
-    /** Determine the current time for the stream according to the same clock used
-     to generate buffer timestamps. This time may be used for synchronising other
-     events to the audio stream, for example synchronizing audio to MIDI.
-        
-     @return The stream's current time in seconds, or 0 if an error occurred.
-     
-     @see PaTime, PaStreamCallback
-    */
-    PaTime Pa_GetStreamTime( PaStream *stream );
-
-
-    /** Retrieve CPU usage information for the specified stream.
-     The "CPU Load" is a fraction of total CPU time consumed by a callback stream's
-     audio processing routines including, but not limited to the client supplied
-     stream callback. This function does not work with blocking read/write streams.
-     
-     This function may be called from the stream callback function or the
-     application.
-        
-     @return
-     A floating point value, typically between 0.0 and 1.0, where 1.0 indicates
-     that the stream callback is consuming the maximum number of CPU cycles possible
-     to maintain real-time operation. A value of 0.5 would imply that PortAudio and
-     the stream callback was consuming roughly 50% of the available CPU time. The
-     return value may exceed 1.0. A value of 0.0 will always be returned for a
-     blocking read/write stream, or if an error occurs.
-    */
-    double Pa_GetStreamCpuLoad( PaStream* stream );
-
-
-    /** Read samples from an input stream. The function doesn't return until
-     the entire buffer has been filled - this may involve waiting for the operating
-     system to supply the data.
-     
-     @param stream A pointer to an open stream previously created with Pa_OpenStream.
-     
-     @param buffer A pointer to a buffer of sample frames. The buffer contains
-     samples in the format specified by the inputParameters->sampleFormat field
-     used to open the stream, and the number of channels specified by
-     inputParameters->numChannels. If non-interleaved samples were requested,
-     buffer is a pointer to the first element of an array of non-interleaved
-     buffer pointers, one for each channel.
-     
-     @param frames The number of frames to be read into buffer. This parameter
-     is not constrained to a specific range, however high performance applications
-     will want to match this parameter to the framesPerBuffer parameter used
-     when opening the stream.
-     
-     @return On success PaNoError will be returned, or PaInputOverflowed if input
-     data was discarded by PortAudio after the previous call and before this call.
-    */
-    PaError Pa_ReadStream( PaStream* stream,
-                           void *buffer,
-                           unsigned long frames );
-
-
-    /** Write samples to an output stream. This function doesn't return until the
-     entire buffer has been consumed - this may involve waiting for the operating
-     system to consume the data.
-     
-     @param stream A pointer to an open stream previously created with Pa_OpenStream.
-     
-     @param buffer A pointer to a buffer of sample frames. The buffer contains
-     samples in the format specified by the outputParameters->sampleFormat field
-     used to open the stream, and the number of channels specified by
-     outputParameters->numChannels. If non-interleaved samples were requested,
-     buffer is a pointer to the first element of an array of non-interleaved
-     buffer pointers, one for each channel.
-     
-     @param frames The number of frames to be written from buffer. This parameter
-     is not constrained to a specific range, however high performance applications
-     will want to match this parameter to the framesPerBuffer parameter used
-     when opening the stream.
-     
-     @return On success PaNoError will be returned, or paOutputUnderflowed if
-     additional output data was inserted after the previous call and before this
-     call.
-    */
-    PaError Pa_WriteStream( PaStream* stream,
-                            const void *buffer,
-                            unsigned long frames );
-
-
-    /** Retrieve the number of frames that can be read from the stream without
-     waiting.
-     
-     @return Returns a non-negative value representing the maximum number of frames
-     that can be read from the stream without blocking or busy waiting or, a
-     PaErrorCode (which are always negative) if PortAudio is not initialized or an
-     error is encountered.
-    */
-    signed long Pa_GetStreamReadAvailable( PaStream* stream );
-
-
-    /** Retrieve the number of frames that can be written to the stream without
-     waiting.
-     
-     @return Returns a non-negative value representing the maximum number of frames
-     that can be written to the stream without blocking or busy waiting or, a
-     PaErrorCode (which are always negative) if PortAudio is not initialized or an
-     error is encountered.
-    */
-    signed long Pa_GetStreamWriteAvailable( PaStream* stream );
-
-
-    /* Miscellaneous utilities */
-
-
-    /** Retrieve the size of a given sample format in bytes.
-     
-     @return The size in bytes of a single sample in the specified format,
-     or paSampleFormatNotSupported if the format is not supported.
-    */
-    PaError Pa_GetSampleSize( PaSampleFormat format );
-
-
-    /** Put the caller to sleep for at least 'msec' milliseconds. This function is
-     provided only as a convenience for authors of portable code (such as the tests
-     and examples in the PortAudio distribution.)
-     
-     The function may sleep longer than requested so don't rely on this for accurate
-     musical timing.
-    */
-    void Pa_Sleep( long msec );
-
-
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-#endif /* PORTAUDIO_H */
Binary files 1.9.14~dfsg-1/windows/Psapi.Lib and 1.9.16~dfsg-1/windows/Psapi.Lib differ
diff -pruN 1.9.14~dfsg-1/windows/README_MINGW 1.9.16~dfsg-1/windows/README_MINGW
--- 1.9.14~dfsg-1/windows/README_MINGW	1970-01-01 00:00:00.000000000 +0000
+++ 1.9.16~dfsg-1/windows/README_MINGW	2020-10-16 19:10:40.000000000 +0000
@@ -0,0 +1,270 @@
+HOW TO COMPILE JACK USING WAF AND MINGW
+=======================================
+
+Rev. 1 - 2019-09-01 - First version
+Rev. 2 - 2019-09-18 - Include contributions from @Schroedingers-Cat
+Rev. 3 - 2019-12-14 - Include contributions from @Schroedingers-Cat
+
+
+
+Introduction
+------------
+
+This guide contains detailed instructions for building JACK on a modern MinGW
+installation. It was conceived as the starting point for unifying the JACK build
+process across all platforms.
+
+As this is work in progress, there are still a couple of caveats:
+
+- Asynchronous mode is unusable with low latencies
+- JackRouter still builds using a Visual Studio project
+- Lots of real world testing is needed
+
+
+
+Creating the development environment
+------------------------------------
+
+This guide uses MSYS2 as the toolchain, it can be found at https://www.msys2.org/
+It comes as a handy installer called msys2-x86_64-{version}.exe. Once installed:
+
+- Open "MSYS2 MinGW 64-bit terminal" from the MSYS2 start menu shortcuts
+
+- Upgrade base MSYS2 packages
+
+pacman -Suy
+
+It is possible pacman ends with the following banner:
+
+warning: terminate MSYS2 without returning to shell and check for updates again
+warning: for example close your terminal window instead of calling exit
+
+In such case close the MSYS2 window, re-open, and run pacman -Suy again.
+
+- Install required packages
+
+pacman -S mingw-w64-x86_64-toolchain patch autoconf make \
+gettext-devel automake libtool pkgconfig p7zip unzip git python
+
+- Replace the GCC compiler with a version configured for SJLJ exceptions, as
+instructed by the original Windows build instructions (windows/README)
+
+Prebuilt binaries can be found at
+https://sourceforge.net/projects/mingw-w64/files/Toolchains%20targetting%20Win64/
+
+Look for "x86_64-posix-sjlj" under "MinGW-W64 GCC-{version}", the file should be
+called x86_64-{version}-release-posix-sjlj-rt_v6-rev0.7z
+
+Or just download from a direct link (GCC 8.1.0):
+
+wget https://downloads.sourceforge.net/project/mingw-w64/Toolchains%20targetting%20Win64/Personal%20Builds/mingw-builds/8.1.0/threads-posix/sjlj/x86_64-8.1.0-release-posix-sjlj-rt_v6-rev0.7z
+
+Once downloaded:
+
+p7zip -d x86_64-8.1.0-release-posix-sjlj-rt_v6-rev0.7z
+
+That will decompress to a folder called mingw64 in the working directory.
+Now replace the files from the previous mingw-w64-x86_64-toolchain package
+installation:
+
+mv /mingw64 /mingw64.bak   -> backup original
+rm /mingw64                -> see explanation below
+mv mingw64 /               -> sjlj toolchain
+
+The first step results in a new file called mingw64 file being created in /. The
+file is not visible to the Windows File Explorer when inspecting C:\msys64, so
+it is probably an artifact and safe to delete it in the second step. Otherwise
+the last mv step will fail with:
+
+mv: cannot overwrite non-directory '/mingw64' with directory 'mingw64'
+
+An alternate solution consists in closing the MSYS2 window and replicating the
+above procedure using the File Explorer. The following assumes the toolchain 7z
+file was decompressed to the home directory:
+
+Rename C:\msys64\mingw64 to C:\msys64\mingw64.bak
+Move C:\msys64\home\{username}\mingw64 to C:\msys64
+
+Make sure gcc runs and it is the expected version:
+
+$ gcc --version
+gcc.exe (x86_64-posix-sjlj-rev0, Built by MinGW-W64 project) {version}
+
+
+
+Preparing JACK dependencies
+---------------------------
+
+There are prebuilt MinGW binaries for all the libraries that can be installed
+using the pacman package manager, but since we are using a compiler that is not
+the default version shipped by MinGW, it seems better idea to build from source
+to avoid any linker and runtime issues. A good technical explanation and/or
+evidence for this statement is currently missing from this guide.
+
+Fortunately there are PKGBUILD files for doing so together with a nice guide at
+https://github.com/msys2/MINGW-packages
+
+git clone https://github.com/msys2/MINGW-packages.git
+
+Before building libraries, adjust the includes path:
+
+export C_INCLUDE_PATH=/mingw64/include
+
+The basic procedure for building and installing libraries is:
+
+cd MINGW-packages/mingw-w64-{libname}
+MINGW_INSTALLS=mingw64 makepkg-mingw -sLf
+pacman -U mingw-w64-{libname}-{suffix}.pkg.tar.xz
+
+Repeat the procedure for each library listed below replacing {libname} with the
+appropriate name and {suffix} with whatever the above process creates. Keep the
+recommended build order, for example libsamplerate depends on libsndfile, and
+libsystre depends on libtre-git. libsystre is a wrapper around libtre that
+allows including <regex.h> later.
+
+Some libraries like libsndfile and libsamplerate will ask for installing extra
+dependencies, it is ok to do so.
+
+For low latency audio it is recommended to build portaudio with ASIO support, so
+the Steinberg ASIO SDK should be manually downloaded beforehand. It can be found
+at https://www.steinberg.net/en/company/developers.html. The waf script will
+later check if the SDK is present at /opt/asiosdk
+
+wget https://www.steinberg.net/asiosdk -O /tmp/asiosdk.zip
+unzip /tmp/asiosdk.zip -d /tmp
+mkdir /opt   <- MinGW does not create /opt during installation
+mv /tmp/asiosdk_{version}_{date} /opt/asiosdk
+
+The description file in portaudio (MINGW-packages/mingw-w64-portaudio/PKGBUILD)
+needs to be patched so configure is called with the necessary flags for ASIO:
+
+--with-asiodir=/opt/asiosdk   <- new option     
+--with-winapi=wmme,directx,wasapi,vdmks,asio   <- append 'asio' to existing
+
+Both static and shared library versions of portaudio are built. To prevent
+errors while building the shared version or recompiling static, also insert the
+following lines in PKGBUILD after the first make call (around line 60) and after
+second make (around line 70):
+
+find /opt/asiosdk -name "*.lo" -type f -delete
+find /opt/asiosdk -name "*.o" -type f -delete
+
+Finally here is the list of libraries to build:
+
+db
+libsndfile
+libsamplerate
+libtre-git
+libsystre
+portaudio
+
+
+
+Compiling JACK
+--------------
+
+- Clone repo
+
+git clone https://github.com/jackaudio/jack2
+
+- Build and install
+
+cd jack2
+./waf configure --prefix=/opt/jack && ./waf -p install
+
+The resulting files can be found at /c/opt/jack/bin, or C:\msys64\opt\jack\bin
+
+
+
+Compiling JackRouter
+--------------------
+
+Visual Studio with MFC support is needed to build the included JackRouter VS
+project. The project was tested to successfully generate a 64bit version of
+JackRouter.dll using Visual Studio 2017 and 2019. MFC support can be added from
+the VS installer, by selecting Workloads/Visual C++ build tools/Visual C++ MFC
+for x86 and x64 (valid for VS 2017). Once ready, just open and build the project
+
+windows/JackRouter/JackRouter_MinGW_deps.vcxproj
+
+Differences from the original JackRouter.vcxproj:
+
+- Depends on the asiosdk files from the previous MinGW JACK installation (i.e.,
+  it points to absolute paths starting with C:\msys64\opt)
+- Links to the jack.dll.a created by the previous build, instead of libjack.lib
+  This means JackRouter.dll will currently depend on libjack-0.dll
+- Force includes stdint.h and defines _STDINT_H to avoid int8_t, int32_t and
+  uint32_t basic types redefinition during compilation
+
+
+
+Running and distributing
+------------------------
+
+An automated installation process should copy files to two destinations. One for
+the JACK server binary and standalone tools, and another for the client library.
+The latter is needed by JACK enabled applications in order to be able to connect
+to the server.
+
+- Create a directory named C:\Program Files\Jack (can be anything else)
+- Copy all files in C:\msys64\opt\jack\bin to C:\Program Files\Jack
+- Copy the following DLLs from C:\msys64\mingw64\bin to C:\Program Files\Jack,
+these are dependencies for the JACK server and tools:
+
+libstdc++-6.dll
+libdb-6.0.dll
+libsndfile-1.dll
+libsamplerate-0.dll
+libportaudio-2.dll
+libgcc_s_sjlj-1.dll
+libwinpthread-1.dll
+libtre-5.dll
+libsystre-0.dll
+
+- Copy and rename the following files from C:\msys64\opt\jack\bin to C:\Windows
+to make libjack available to clients:
+
+libjackserver-0.dll   -> libjackserver64.dll
+libjack-0.dll         -> libjack64.dll
+
+- Copy the following files from C:\msys64\mingw64\bin to C:\Windows, these are
+dependencies for libjack. C:\Windows is the directory the current official JACK
+1.9.11 binary installer targets, a better solution should be devised to avoid
+cluttering the Windows directory:
+
+libgcc_s_sjlj-1.dll
+libwinpthread-1.dll
+libtre-5.dll
+libsystre-0.dll
+
+- Copy JackRouter.dll from windows\JackRouter\Release64 to C:\Program Files\Jack
+This allows non-JACK applications to connect to the server through a special
+ASIO driver that routes audio to JACK instead of a physical audio device.
+Also copy libjack-0.dll from C:\msys64\mingw64\bin to C:\Program Files\Jack
+because JackRouter depends on libjack but will check for libjack-0.dll instead
+of the system-wide libjack64.dll previously copied to C:\Windows. Once done,
+JackRouter needs to be registered:
+
+regsvr32 JackRouter.dll
+
+Tested working clients:
+Ardour
+Bitwig Studio
+QJackCtl
+JackRouter
+
+Example of starting the JACK server including MIDI support for a Focusrite USB
+audio device using ASIO:
+jackd -R -S -X winmme -d portaudio -p 32 -r 48000 -d "ASIO::Focusrite USB ASIO"
+
+
+
+Development tools and links
+---------------------------
+
+http://www.dependencywalker.com/
+https://docs.microsoft.com/en-us/sysinternals/downloads/procmon
+https://docs.microsoft.com/en-us/windows-hardware/drivers/debugger/gflags
+https://blogs.msdn.microsoft.com/junfeng/2006/11/20/debugging-loadlibrary-failures/
+https://stackoverflow.com/questions/15852677/static-and-dynamic-shared-linking-with-mingw
+https://github.com/EddieRingle/portaudio/blob/master/src/hostapi/asio/ASIO-README.txt
diff -pruN 1.9.14~dfsg-1/windows/samplerate.h 1.9.16~dfsg-1/windows/samplerate.h
--- 1.9.14~dfsg-1/windows/samplerate.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/samplerate.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,197 +0,0 @@
-/*
-** Copyright (C) 2002-2008 Erik de Castro Lopo <erikd@mega-nerd.com>
-**
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
-**
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-** GNU General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
-*/
-
-/*
-** This code is part of Secret Rabibt Code aka libsamplerate. A commercial
-** use license for this code is available, please see:
-**		http://www.mega-nerd.com/SRC/procedure.html
-*/
-
-/*
-** API documentation is available here:
-**     http://www.mega-nerd.com/SRC/api.html
-*/
-
-#ifndef SAMPLERATE_H
-#define SAMPLERATE_H
-
-#ifdef __cplusplus
-extern "C" {
-#endif	/* __cplusplus */
-
-
-/* Opaque data type SRC_STATE. */
-typedef struct SRC_STATE_tag SRC_STATE ;
-
-/* SRC_DATA is used to pass data to src_simple() and src_process(). */
-typedef struct
-{	float	*data_in, *data_out ;
-
-	long	input_frames, output_frames ;
-	long	input_frames_used, output_frames_gen ;
-
-	int		end_of_input ;
-
-	double	src_ratio ;
-} SRC_DATA ;
-
-/* SRC_CB_DATA is used with callback based API. */
-typedef struct
-{	long	frames ;
-	float	*data_in ;
-} SRC_CB_DATA ;
-
-/*
-** User supplied callback function type for use with src_callback_new()
-** and src_callback_read(). First parameter is the same pointer that was
-** passed into src_callback_new(). Second parameter is pointer to a
-** pointer. The user supplied callback function must modify *data to
-** point to the start of the user supplied float array. The user supplied
-** function must return the number of frames that **data points to.
-*/
-
-typedef long (*src_callback_t) (void *cb_data, float **data) ;
-
-/*
-**	Standard initialisation function : return an anonymous pointer to the
-**	internal state of the converter. Choose a converter from the enums below.
-**	Error returned in *error.
-*/
-
-SRC_STATE* src_new (int converter_type, int channels, int *error) ;
-
-/*
-**	Initialisation for callback based API : return an anonymous pointer to the
-**	internal state of the converter. Choose a converter from the enums below.
-**	The cb_data pointer can point to any data or be set to NULL. Whatever the
-**	value, when processing, user supplied function "func" gets called with
-**	cb_data as first parameter.
-*/
-
-SRC_STATE* src_callback_new (src_callback_t func, int converter_type, int channels,
-				int *error, void* cb_data) ;
-
-/*
-**	Cleanup all internal allocations.
-**	Always returns NULL.
-*/
-
-SRC_STATE* src_delete (SRC_STATE *state) ;
-
-/*
-**	Standard processing function.
-**	Returns non zero on error.
-*/
-
-int src_process (SRC_STATE *state, SRC_DATA *data) ;
-
-/*
-**	Callback based processing function. Read up to frames worth of data from
-**	the converter int *data and return frames read or -1 on error.
-*/
-long src_callback_read (SRC_STATE *state, double src_ratio, long frames, float *data) ;
-
-/*
-**	Simple interface for performing a single conversion from input buffer to
-**	output buffer at a fixed conversion ratio.
-**	Simple interface does not require initialisation as it can only operate on
-**	a single buffer worth of audio.
-*/
-
-int src_simple (SRC_DATA *data, int converter_type, int channels) ;
-
-/*
-** This library contains a number of different sample rate converters,
-** numbered 0 through N.
-**
-** Return a string giving either a name or a more full description of each
-** sample rate converter or NULL if no sample rate converter exists for
-** the given value. The converters are sequentially numbered from 0 to N.
-*/
-
-const char *src_get_name (int converter_type) ;
-const char *src_get_description (int converter_type) ;
-const char *src_get_version (void) ;
-
-/*
-**	Set a new SRC ratio. This allows step responses
-**	in the conversion ratio.
-**	Returns non zero on error.
-*/
-
-int src_set_ratio (SRC_STATE *state, double new_ratio) ;
-
-/*
-**	Reset the internal SRC state.
-**	Does not modify the quality settings.
-**	Does not free any memory allocations.
-**	Returns non zero on error.
-*/
-
-int src_reset (SRC_STATE *state) ;
-
-/*
-** Return TRUE if ratio is a valid conversion ratio, FALSE
-** otherwise.
-*/
-
-int src_is_valid_ratio (double ratio) ;
-
-/*
-**	Return an error number.
-*/
-
-int src_error (SRC_STATE *state) ;
-
-/*
-**	Convert the error number into a string.
-*/
-const char* src_strerror (int error) ;
-
-/*
-** The following enums can be used to set the interpolator type
-** using the function src_set_converter().
-*/
-
-enum
-{
-	SRC_SINC_BEST_QUALITY		= 0,
-	SRC_SINC_MEDIUM_QUALITY		= 1,
-	SRC_SINC_FASTEST			= 2,
-	SRC_ZERO_ORDER_HOLD			= 3,
-	SRC_LINEAR					= 4,
-} ;
-
-/*
-** Extra helper functions for converting from short to float and
-** back again.
-*/
-
-void src_short_to_float_array (const short *in, float *out, int len) ;
-void src_float_to_short_array (const float *in, short *out, int len) ;
-
-void src_int_to_float_array (const int *in, float *out, int len) ;
-void src_float_to_int_array (const float *in, int *out, int len) ;
-
-
-#ifdef __cplusplus
-}		/* extern "C" */
-#endif	/* __cplusplus */
-
-#endif	/* SAMPLERATE_H */
-
diff -pruN 1.9.14~dfsg-1/windows/Setup/jack64.ci 1.9.16~dfsg-1/windows/Setup/jack64.ci
--- 1.9.14~dfsg-1/windows/Setup/jack64.ci	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/jack64.ci	1970-01-01 00:00:00.000000000 +0000
@@ -1,157 +0,0 @@
-<*project
-      version = 4 civer = "Free v4.14.5" winver = "2.8/6.1.7600" > 
-   <output> .</>
-   <exename> Jack_v1.9.12_64_setup.exe</>
-   <digitsign> </>
-   <appname> Jack</>
-   <password> </>
-   <addlang> </>
-   <icon> Default - 2</>
-   <selfextr> 1</>
-   <voltype> nolimit</>
-   <volsize> </>
-   <volpattern> disk%i.pak</>
-   <load> </>
-   <loadtime> 1000</>
-   <checktype> admin</>
-   <chkname> </>
-   <chkmsg> </>
-   <dlgfont> Verdana,8</>
-   <lang> English</>
-   <theme> Green</>
-   <iface> leftlogo</>
-   <leftlogo> .\src\logo_installer.bmp</>
-   <logo> </>
-   <vb> </>
-   <dao> </>
-   <background> 0</>
-   <dlgwelcome> 1</>
-   <dlgreadme> .\src\README</>
-   <dlglic> .\src\gpl_installer.rtf</>
-   <dlgcustpath> </>
-   <dlgenfpath> 0</>
-   <dlgsavepath> 1</>
-   <dlgautoprog> 1</>
-   <dlgfinish> 1</>
-   <comptype> defnorm</>
-   <solid> 0</>
-   <srcfolder> </>
-   <ifexist> over</>
-   <runafter> </>
-   <runconfirm> 1</>
-   <uninclude> 1</>
-   <unicon> Uninstall - 2</>
-   <unshortcut> 1</>
-   <unrun> </>
-   <silent> 0</>
-   <unfeed> </>
-   <unautoclose> 1</>
-   <unfinish> 1</>
-   <bl> My Demo</>
-   <blurl> </>
-   <bghead> </>
-   <bgfoot> </> 
-   <bgback> </>
-   <files listview >
-<_><src>..\Release64\bin\libjack64.a</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjack64.lib</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjack64.def</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjack64.dll</><dest>win</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjackserver64.a</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjackserver64.lib</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjackserver64.def</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\libjackserver64.dll</><dest>win</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.a</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.lib</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.def</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.dll</><dest>sys</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.a</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.lib</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.def</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.dll</><dest>sys</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\portaudio_x86.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_connect.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_disconnect.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_load.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_lsp.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_metro.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_unload.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_midi_latency_test.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jackd.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\jack_net.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\jack_netone.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_netsource.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\jack_dummy.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\jack_loopback.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\jack_winmme.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\jack_portaudio.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\netmanager.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\audioadapter.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack\netadapter.dll</><dest>win</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release64\bin\jack_midi_dump.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\control.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\intclient.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\jack.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\jslist.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\midiport.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\ringbuffer.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\session.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\statistics.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\systemdeps.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>1</></>
-<_><src>..\..\common\jack\thread.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\transport.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\types.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\weakjack.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>1</></>
-<_><src>..\..\common\jack\weakmacros.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>1</></>
-<_><src>.\src\32bits\JackRouter.dll</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\JackRouter.ini</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\msvcr100.dll</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\msvcp100.dll</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\64bits\JackRouter.dll</><dest>inst</><custom>64bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\64bits\JackRouter.ini</><dest>inst</><custom>64bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\64bits\msvcr100.dll</><dest>inst</><custom>64bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\64bits\msvcp100.dll</><dest>inst</><custom>64bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\mingwm10.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\qjackctl.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\QtCore4.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\QtGui4.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\QtXml4.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\libgcc_s_dw2-1.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\COPYING</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\README</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-
-   </files>
-   <runx listview >
-    </runx>
-   <registry listview >
-      
-   </registry>
-   <shcut listview >
-      <_><shpath>prog</><shname>Jack NetDriver</><tarpath>inst</><tarname>jackd.exe</><cmdline>-R -S -d net</><workpath>inst</><workcust></><icon></></>
-<_><shpath>prog</><shname>Jack PortAudio</><tarpath>inst</><tarname>jackd.exe</><cmdline>-R -S -d portaudio</><workpath>inst</><workcust></><icon></></>
-<_><shpath>prog</><shname>Jack Control</><tarpath>inst</><tarname>qjackctl.exe</><cmdline></><workpath>inst</><workcust></><icon>jackdmp.exe</></>
-<_><shpath>prog</><shname>Jack Command</><tarpath>sys</><tarname>cmd.exe</><cmdline></><workpath>inst</><workcust></><icon></></>
-
-   </shcut>
-   <ini listview >
-      
-   </ini>
-   <copy listview >
-      
-   </copy>
-   <activex listview >
-	  <_><path>inst</><name>32bits\JackRouter.dll</></>
- 	  <_><path>inst</><name>64bits\JackRouter.dll</></>
-
-   </activex>
-   <font listview >
-      
-   </font>
-   <ext listview >
-      
-   </ext>
-   <mreg listview >
-      
-   </mreg>
-   <macros> Pathadd=</>
-</project>
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/Setup/jack.ci 1.9.16~dfsg-1/windows/Setup/jack.ci
--- 1.9.14~dfsg-1/windows/Setup/jack.ci	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/jack.ci	1970-01-01 00:00:00.000000000 +0000
@@ -1,144 +0,0 @@
-<*project
-      version = 4 civer = "Free v4.14.5" winver = "2.6/5.1.2600" > 
-   <output> .</>
-   <exename> Jack_v1.9.12_32_setup.exe</>
-   <digitsign> </>
-   <appname> Jack</>
-   <password> </>
-   <addlang> </>
-   <icon> Default - 2</>
-   <selfextr> 1</>
-   <voltype> nolimit</>
-   <volsize> </>
-   <volpattern> disk%i.pak</>
-   <load> </>
-   <loadtime> 1000</>
-   <checktype> admin</>
-   <chkname> </>
-   <chkmsg> </>
-   <dlgfont> Verdana,8</>
-   <lang> English</>
-   <theme> Green</>
-   <iface> leftlogo</>
-   <leftlogo> .\src\logo_installer.bmp</>
-   <logo> </>
-   <vb> </>
-   <dao> </>
-   <background> 0</>
-   <dlgwelcome> 1</>
-   <dlgreadme> .\src\README</>
-   <dlglic> .\src\gpl_installer.rtf</>
-   <dlgcustpath> </>
-   <dlgenfpath> 0</>
-   <dlgsavepath> 1</>
-   <dlgautoprog> 1</>
-   <dlgfinish> 1</>
-   <comptype> defnorm</>
-   <solid> 0</>
-   <srcfolder> </>
-   <ifexist> over</>
-   <runafter> </>
-   <runconfirm> 1</>
-   <uninclude> 1</>
-   <unicon> Uninstall - 2</>
-   <unshortcut> 1</>
-   <unrun> </>
-   <silent> 0</>
-   <unfeed> </>
-   <unautoclose> 1</>
-   <unfinish> 1</>
-   <bl> My Demo</>
-   <blurl> </>
-   <bghead> </>
-   <bgfoot> </> 
-   <bgback> </>
-   <files listview >
-<_><src>..\Release\bin\libjack.a</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.lib</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.def</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.a</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.lib</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.def</><dest>inst</><custom>lib</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_connect.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_disconnect.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_load.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_lsp.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_metro.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_unload.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_midi_latency_test.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jackd.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjack.dll</><dest>sys</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\libjackserver.dll</><dest>sys</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\jack_net.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\jack_netone.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_netsource.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\jack_dummy.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\jack_loopback.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\jack_winmme.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\jack_portaudio.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\netmanager.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\audioadapter.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack\netadapter.dll</><dest>sys</><custom>jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\Release\bin\jack_midi_dump.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\portaudio_x86.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\control.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\intclient.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\jack.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\jslist.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\midiport.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\ringbuffer.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\session.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\statistics.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\systemdeps.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>1</></>
-<_><src>..\..\common\jack\thread.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\transport.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\types.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>0</></>
-<_><src>..\..\common\jack\weakjack.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>1</></>
-<_><src>..\..\common\jack\weakmacros.h</><dest>inst</><custom>includes\jack</><ifexist>overnewer</><recurs>1</></>
-<_><src>.\src\32bits\JackRouter.dll</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\JackRouter.ini</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\msvcr100.dll</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\32bits\msvcp100.dll</><dest>inst</><custom>32bits</><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\mingwm10.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\qjackctl.exe</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\QtCore4.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\QtGui4.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\QtXml4.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\qjackctl\libgcc_s_dw2-1.dll</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\COPYING</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-<_><src>.\src\README</><dest>inst</><custom></><ifexist>overnewer</><recurs>0</></>
-
-   </files>
-   <runx listview >
-   </runx>
-   <registry listview >
-      
-   </registry>
-   <shcut listview >
-      <_><shpath>prog</><shname>Jack NetDriver</><tarpath>inst</><tarname>jackd.exe</><cmdline>-R -S -d net</><workpath>inst</><workcust></><icon></></>
-<_><shpath>prog</><shname>Jack PortAudio</><tarpath>inst</><tarname>jackd.exe</><cmdline>-R -S -d portaudio</><workpath>inst</><workcust></><icon></></>
-<_><shpath>prog</><shname>Jack Control</><tarpath>inst</><tarname>qjackctl.exe</><cmdline></><workpath>inst</><workcust></><icon>jackdmp.exe</></>
-<_><shpath>prog</><shname>Jack Command</><tarpath>sys</><tarname>cmd.exe</><cmdline></><workpath>inst</><workcust></><icon></></>
-
-   </shcut>
-   <ini listview >
-      
-   </ini>
-   <copy listview >
-      
-   </copy>
-   <activex listview >
-      <_><path>inst</><name>32bits\JackRouter.dll</></>
-
-   </activex>
-   <font listview >
-      
-   </font>
-   <ext listview >
-      
-   </ext>
-   <mreg listview >
-      
-   </mreg>
-   <macros> Pathadd=</>
-</project>
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/Setup/README 1.9.16~dfsg-1/windows/Setup/README
--- 1.9.14~dfsg-1/windows/Setup/README	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/README	1970-01-01 00:00:00.000000000 +0000
@@ -1,24 +0,0 @@
-This folder contains a script to create an installer for windows.
-It uses 'CreateInstall Free'(http://www.createinstall.com), a little software allowing to make simple installers.
-
-You can use the 'jack.ci' script to make the installer. For that, you need to build the Code::Blocks workspace in order to have '.exe' and libraries. 
-You also need 'qjackctl' binaries and libraries ('qjackctl.exe', 'mingwm10.dll', 'QtCore4.dll', 'QtGui.dll' and 'QtXml4.dll'). 
-You can recompile qjackctl with qt4 or directly get the binaries. The five files are expected in the 'qjackctl' folder.
-
-You also need the Microsoft Visual C++ 2008 Redistributable Package (x86) (the vcrdist_x86.exe file) to be in src folder.
-
-If you need libjack.lib and libjackserver.lib to link with in MS Visual Studio, you can use the MS Tool lib.exe to create the .lib file from de .def.
-Just use : 'lib /DEF:libjackserver.def /OUT:libjackserver.lib' and 'lib /DEF:libjack.def /OUT:libjack.lib' to create the lib file.
-Or you can also use dlltool, from mingw suite :
-Just use : 'dlltool -l libjackserver.lib -D libjackserver.dll -d libjackserver.def' and 'dlltool -l libjack.lib -D libjack.dll -d libjack.def'
-
-Once all binaries are available, just execute the script in 'CreateInstall' to make 'setup.exe'.
-The setup will copy all binaries to a specified folder, register the JackRouter (in order to have it in the ASIO drivers list) and create some shortcuts in the start menu.
-It's a good and proper way to get jack installed on windows.
-
-64 bits compilation
-====================
-
-- for some reasons CodeBlocks create libjack.dll.a and libjack.dll.def names. So the ".dll" part has to be removed before using "lib" tool to create ".lib" files.
-
-- to create 64 bits ".lib" files, the "/MACHINE:X64 option has to be used.
diff -pruN 1.9.14~dfsg-1/windows/Setup/src/32bits/JackRouter.ini 1.9.16~dfsg-1/windows/Setup/src/32bits/JackRouter.ini
--- 1.9.14~dfsg-1/windows/Setup/src/32bits/JackRouter.ini	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/src/32bits/JackRouter.ini	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-[IO]
-input=4
-output=4
-float-sample=0
-
-[AUTO_CONNECT]
-input=1
-output=1
-alias=0
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/Setup/src/64bits/JackRouter.ini 1.9.16~dfsg-1/windows/Setup/src/64bits/JackRouter.ini
--- 1.9.14~dfsg-1/windows/Setup/src/64bits/JackRouter.ini	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/src/64bits/JackRouter.ini	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-[IO]
-input=4
-output=4
-float-sample=0
-
-[AUTO_CONNECT]
-input=1
-output=1
-alias=0
diff -pruN 1.9.14~dfsg-1/windows/Setup/src/COPYING 1.9.16~dfsg-1/windows/Setup/src/COPYING
--- 1.9.14~dfsg-1/windows/Setup/src/COPYING	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/src/COPYING	1970-01-01 00:00:00.000000000 +0000
@@ -1,674 +0,0 @@
-                    GNU GENERAL PUBLIC LICENSE
-                       Version 3, 29 June 2007
-
- Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>
- Everyone is permitted to copy and distribute verbatim copies
- of this license document, but changing it is not allowed.
-
-                            Preamble
-
-  The GNU General Public License is a free, copyleft license for
-software and other kinds of works.
-
-  The licenses for most software and other practical works are designed
-to take away your freedom to share and change the works.  By contrast,
-the GNU General Public License is intended to guarantee your freedom to
-share and change all versions of a program--to make sure it remains free
-software for all its users.  We, the Free Software Foundation, use the
-GNU General Public License for most of our software; it applies also to
-any other work released this way by its authors.  You can apply it to
-your programs, too.
-
-  When we speak of free software, we are referring to freedom, not
-price.  Our General Public Licenses are designed to make sure that you
-have the freedom to distribute copies of free software (and charge for
-them if you wish), that you receive source code or can get it if you
-want it, that you can change the software or use pieces of it in new
-free programs, and that you know you can do these things.
-
-  To protect your rights, we need to prevent others from denying you
-these rights or asking you to surrender the rights.  Therefore, you have
-certain responsibilities if you distribute copies of the software, or if
-you modify it: responsibilities to respect the freedom of others.
-
-  For example, if you distribute copies of such a program, whether
-gratis or for a fee, you must pass on to the recipients the same
-freedoms that you received.  You must make sure that they, too, receive
-or can get the source code.  And you must show them these terms so they
-know their rights.
-
-  Developers that use the GNU GPL protect your rights with two steps:
-(1) assert copyright on the software, and (2) offer you this License
-giving you legal permission to copy, distribute and/or modify it.
-
-  For the developers' and authors' protection, the GPL clearly explains
-that there is no warranty for this free software.  For both users' and
-authors' sake, the GPL requires that modified versions be marked as
-changed, so that their problems will not be attributed erroneously to
-authors of previous versions.
-
-  Some devices are designed to deny users access to install or run
-modified versions of the software inside them, although the manufacturer
-can do so.  This is fundamentally incompatible with the aim of
-protecting users' freedom to change the software.  The systematic
-pattern of such abuse occurs in the area of products for individuals to
-use, which is precisely where it is most unacceptable.  Therefore, we
-have designed this version of the GPL to prohibit the practice for those
-products.  If such problems arise substantially in other domains, we
-stand ready to extend this provision to those domains in future versions
-of the GPL, as needed to protect the freedom of users.
-
-  Finally, every program is threatened constantly by software patents.
-States should not allow patents to restrict development and use of
-software on general-purpose computers, but in those that do, we wish to
-avoid the special danger that patents applied to a free program could
-make it effectively proprietary.  To prevent this, the GPL assures that
-patents cannot be used to render the program non-free.
-
-  The precise terms and conditions for copying, distribution and
-modification follow.
-
-                       TERMS AND CONDITIONS
-
-  0. Definitions.
-
-  "This License" refers to version 3 of the GNU General Public License.
-
-  "Copyright" also means copyright-like laws that apply to other kinds of
-works, such as semiconductor masks.
-
-  "The Program" refers to any copyrightable work licensed under this
-License.  Each licensee is addressed as "you".  "Licensees" and
-"recipients" may be individuals or organizations.
-
-  To "modify" a work means to copy from or adapt all or part of the work
-in a fashion requiring copyright permission, other than the making of an
-exact copy.  The resulting work is called a "modified version" of the
-earlier work or a work "based on" the earlier work.
-
-  A "covered work" means either the unmodified Program or a work based
-on the Program.
-
-  To "propagate" a work means to do anything with it that, without
-permission, would make you directly or secondarily liable for
-infringement under applicable copyright law, except executing it on a
-computer or modifying a private copy.  Propagation includes copying,
-distribution (with or without modification), making available to the
-public, and in some countries other activities as well.
-
-  To "convey" a work means any kind of propagation that enables other
-parties to make or receive copies.  Mere interaction with a user through
-a computer network, with no transfer of a copy, is not conveying.
-
-  An interactive user interface displays "Appropriate Legal Notices"
-to the extent that it includes a convenient and prominently visible
-feature that (1) displays an appropriate copyright notice, and (2)
-tells the user that there is no warranty for the work (except to the
-extent that warranties are provided), that licensees may convey the
-work under this License, and how to view a copy of this License.  If
-the interface presents a list of user commands or options, such as a
-menu, a prominent item in the list meets this criterion.
-
-  1. Source Code.
-
-  The "source code" for a work means the preferred form of the work
-for making modifications to it.  "Object code" means any non-source
-form of a work.
-
-  A "Standard Interface" means an interface that either is an official
-standard defined by a recognized standards body, or, in the case of
-interfaces specified for a particular programming language, one that
-is widely used among developers working in that language.
-
-  The "System Libraries" of an executable work include anything, other
-than the work as a whole, that (a) is included in the normal form of
-packaging a Major Component, but which is not part of that Major
-Component, and (b) serves only to enable use of the work with that
-Major Component, or to implement a Standard Interface for which an
-implementation is available to the public in source code form.  A
-"Major Component", in this context, means a major essential component
-(kernel, window system, and so on) of the specific operating system
-(if any) on which the executable work runs, or a compiler used to
-produce the work, or an object code interpreter used to run it.
-
-  The "Corresponding Source" for a work in object code form means all
-the source code needed to generate, install, and (for an executable
-work) run the object code and to modify the work, including scripts to
-control those activities.  However, it does not include the work's
-System Libraries, or general-purpose tools or generally available free
-programs which are used unmodified in performing those activities but
-which are not part of the work.  For example, Corresponding Source
-includes interface definition files associated with source files for
-the work, and the source code for shared libraries and dynamically
-linked subprograms that the work is specifically designed to require,
-such as by intimate data communication or control flow between those
-subprograms and other parts of the work.
-
-  The Corresponding Source need not include anything that users
-can regenerate automatically from other parts of the Corresponding
-Source.
-
-  The Corresponding Source for a work in source code form is that
-same work.
-
-  2. Basic Permissions.
-
-  All rights granted under this License are granted for the term of
-copyright on the Program, and are irrevocable provided the stated
-conditions are met.  This License explicitly affirms your unlimited
-permission to run the unmodified Program.  The output from running a
-covered work is covered by this License only if the output, given its
-content, constitutes a covered work.  This License acknowledges your
-rights of fair use or other equivalent, as provided by copyright law.
-
-  You may make, run and propagate covered works that you do not
-convey, without conditions so long as your license otherwise remains
-in force.  You may convey covered works to others for the sole purpose
-of having them make modifications exclusively for you, or provide you
-with facilities for running those works, provided that you comply with
-the terms of this License in conveying all material for which you do
-not control copyright.  Those thus making or running the covered works
-for you must do so exclusively on your behalf, under your direction
-and control, on terms that prohibit them from making any copies of
-your copyrighted material outside their relationship with you.
-
-  Conveying under any other circumstances is permitted solely under
-the conditions stated below.  Sublicensing is not allowed; section 10
-makes it unnecessary.
-
-  3. Protecting Users' Legal Rights From Anti-Circumvention Law.
-
-  No covered work shall be deemed part of an effective technological
-measure under any applicable law fulfilling obligations under article
-11 of the WIPO copyright treaty adopted on 20 December 1996, or
-similar laws prohibiting or restricting circumvention of such
-measures.
-
-  When you convey a covered work, you waive any legal power to forbid
-circumvention of technological measures to the extent such circumvention
-is effected by exercising rights under this License with respect to
-the covered work, and you disclaim any intention to limit operation or
-modification of the work as a means of enforcing, against the work's
-users, your or third parties' legal rights to forbid circumvention of
-technological measures.
-
-  4. Conveying Verbatim Copies.
-
-  You may convey verbatim copies of the Program's source code as you
-receive it, in any medium, provided that you conspicuously and
-appropriately publish on each copy an appropriate copyright notice;
-keep intact all notices stating that this License and any
-non-permissive terms added in accord with section 7 apply to the code;
-keep intact all notices of the absence of any warranty; and give all
-recipients a copy of this License along with the Program.
-
-  You may charge any price or no price for each copy that you convey,
-and you may offer support or warranty protection for a fee.
-
-  5. Conveying Modified Source Versions.
-
-  You may convey a work based on the Program, or the modifications to
-produce it from the Program, in the form of source code under the
-terms of section 4, provided that you also meet all of these conditions:
-
-    a) The work must carry prominent notices stating that you modified
-    it, and giving a relevant date.
-
-    b) The work must carry prominent notices stating that it is
-    released under this License and any conditions added under section
-    7.  This requirement modifies the requirement in section 4 to
-    "keep intact all notices".
-
-    c) You must license the entire work, as a whole, under this
-    License to anyone who comes into possession of a copy.  This
-    License will therefore apply, along with any applicable section 7
-    additional terms, to the whole of the work, and all its parts,
-    regardless of how they are packaged.  This License gives no
-    permission to license the work in any other way, but it does not
-    invalidate such permission if you have separately received it.
-
-    d) If the work has interactive user interfaces, each must display
-    Appropriate Legal Notices; however, if the Program has interactive
-    interfaces that do not display Appropriate Legal Notices, your
-    work need not make them do so.
-
-  A compilation of a covered work with other separate and independent
-works, which are not by their nature extensions of the covered work,
-and which are not combined with it such as to form a larger program,
-in or on a volume of a storage or distribution medium, is called an
-"aggregate" if the compilation and its resulting copyright are not
-used to limit the access or legal rights of the compilation's users
-beyond what the individual works permit.  Inclusion of a covered work
-in an aggregate does not cause this License to apply to the other
-parts of the aggregate.
-
-  6. Conveying Non-Source Forms.
-
-  You may convey a covered work in object code form under the terms
-of sections 4 and 5, provided that you also convey the
-machine-readable Corresponding Source under the terms of this License,
-in one of these ways:
-
-    a) Convey the object code in, or embodied in, a physical product
-    (including a physical distribution medium), accompanied by the
-    Corresponding Source fixed on a durable physical medium
-    customarily used for software interchange.
-
-    b) Convey the object code in, or embodied in, a physical product
-    (including a physical distribution medium), accompanied by a
-    written offer, valid for at least three years and valid for as
-    long as you offer spare parts or customer support for that product
-    model, to give anyone who possesses the object code either (1) a
-    copy of the Corresponding Source for all the software in the
-    product that is covered by this License, on a durable physical
-    medium customarily used for software interchange, for a price no
-    more than your reasonable cost of physically performing this
-    conveying of source, or (2) access to copy the
-    Corresponding Source from a network server at no charge.
-
-    c) Convey individual copies of the object code with a copy of the
-    written offer to provide the Corresponding Source.  This
-    alternative is allowed only occasionally and noncommercially, and
-    only if you received the object code with such an offer, in accord
-    with subsection 6b.
-
-    d) Convey the object code by offering access from a designated
-    place (gratis or for a charge), and offer equivalent access to the
-    Corresponding Source in the same way through the same place at no
-    further charge.  You need not require recipients to copy the
-    Corresponding Source along with the object code.  If the place to
-    copy the object code is a network server, the Corresponding Source
-    may be on a different server (operated by you or a third party)
-    that supports equivalent copying facilities, provided you maintain
-    clear directions next to the object code saying where to find the
-    Corresponding Source.  Regardless of what server hosts the
-    Corresponding Source, you remain obligated to ensure that it is
-    available for as long as needed to satisfy these requirements.
-
-    e) Convey the object code using peer-to-peer transmission, provided
-    you inform other peers where the object code and Corresponding
-    Source of the work are being offered to the general public at no
-    charge under subsection 6d.
-
-  A separable portion of the object code, whose source code is excluded
-from the Corresponding Source as a System Library, need not be
-included in conveying the object code work.
-
-  A "User Product" is either (1) a "consumer product", which means any
-tangible personal property which is normally used for personal, family,
-or household purposes, or (2) anything designed or sold for incorporation
-into a dwelling.  In determining whether a product is a consumer product,
-doubtful cases shall be resolved in favor of coverage.  For a particular
-product received by a particular user, "normally used" refers to a
-typical or common use of that class of product, regardless of the status
-of the particular user or of the way in which the particular user
-actually uses, or expects or is expected to use, the product.  A product
-is a consumer product regardless of whether the product has substantial
-commercial, industrial or non-consumer uses, unless such uses represent
-the only significant mode of use of the product.
-
-  "Installation Information" for a User Product means any methods,
-procedures, authorization keys, or other information required to install
-and execute modified versions of a covered work in that User Product from
-a modified version of its Corresponding Source.  The information must
-suffice to ensure that the continued functioning of the modified object
-code is in no case prevented or interfered with solely because
-modification has been made.
-
-  If you convey an object code work under this section in, or with, or
-specifically for use in, a User Product, and the conveying occurs as
-part of a transaction in which the right of possession and use of the
-User Product is transferred to the recipient in perpetuity or for a
-fixed term (regardless of how the transaction is characterized), the
-Corresponding Source conveyed under this section must be accompanied
-by the Installation Information.  But this requirement does not apply
-if neither you nor any third party retains the ability to install
-modified object code on the User Product (for example, the work has
-been installed in ROM).
-
-  The requirement to provide Installation Information does not include a
-requirement to continue to provide support service, warranty, or updates
-for a work that has been modified or installed by the recipient, or for
-the User Product in which it has been modified or installed.  Access to a
-network may be denied when the modification itself materially and
-adversely affects the operation of the network or violates the rules and
-protocols for communication across the network.
-
-  Corresponding Source conveyed, and Installation Information provided,
-in accord with this section must be in a format that is publicly
-documented (and with an implementation available to the public in
-source code form), and must require no special password or key for
-unpacking, reading or copying.
-
-  7. Additional Terms.
-
-  "Additional permissions" are terms that supplement the terms of this
-License by making exceptions from one or more of its conditions.
-Additional permissions that are applicable to the entire Program shall
-be treated as though they were included in this License, to the extent
-that they are valid under applicable law.  If additional permissions
-apply only to part of the Program, that part may be used separately
-under those permissions, but the entire Program remains governed by
-this License without regard to the additional permissions.
-
-  When you convey a copy of a covered work, you may at your option
-remove any additional permissions from that copy, or from any part of
-it.  (Additional permissions may be written to require their own
-removal in certain cases when you modify the work.)  You may place
-additional permissions on material, added by you to a covered work,
-for which you have or can give appropriate copyright permission.
-
-  Notwithstanding any other provision of this License, for material you
-add to a covered work, you may (if authorized by the copyright holders of
-that material) supplement the terms of this License with terms:
-
-    a) Disclaiming warranty or limiting liability differently from the
-    terms of sections 15 and 16 of this License; or
-
-    b) Requiring preservation of specified reasonable legal notices or
-    author attributions in that material or in the Appropriate Legal
-    Notices displayed by works containing it; or
-
-    c) Prohibiting misrepresentation of the origin of that material, or
-    requiring that modified versions of such material be marked in
-    reasonable ways as different from the original version; or
-
-    d) Limiting the use for publicity purposes of names of licensors or
-    authors of the material; or
-
-    e) Declining to grant rights under trademark law for use of some
-    trade names, trademarks, or service marks; or
-
-    f) Requiring indemnification of licensors and authors of that
-    material by anyone who conveys the material (or modified versions of
-    it) with contractual assumptions of liability to the recipient, for
-    any liability that these contractual assumptions directly impose on
-    those licensors and authors.
-
-  All other non-permissive additional terms are considered "further
-restrictions" within the meaning of section 10.  If the Program as you
-received it, or any part of it, contains a notice stating that it is
-governed by this License along with a term that is a further
-restriction, you may remove that term.  If a license document contains
-a further restriction but permits relicensing or conveying under this
-License, you may add to a covered work material governed by the terms
-of that license document, provided that the further restriction does
-not survive such relicensing or conveying.
-
-  If you add terms to a covered work in accord with this section, you
-must place, in the relevant source files, a statement of the
-additional terms that apply to those files, or a notice indicating
-where to find the applicable terms.
-
-  Additional terms, permissive or non-permissive, may be stated in the
-form of a separately written license, or stated as exceptions;
-the above requirements apply either way.
-
-  8. Termination.
-
-  You may not propagate or modify a covered work except as expressly
-provided under this License.  Any attempt otherwise to propagate or
-modify it is void, and will automatically terminate your rights under
-this License (including any patent licenses granted under the third
-paragraph of section 11).
-
-  However, if you cease all violation of this License, then your
-license from a particular copyright holder is reinstated (a)
-provisionally, unless and until the copyright holder explicitly and
-finally terminates your license, and (b) permanently, if the copyright
-holder fails to notify you of the violation by some reasonable means
-prior to 60 days after the cessation.
-
-  Moreover, your license from a particular copyright holder is
-reinstated permanently if the copyright holder notifies you of the
-violation by some reasonable means, this is the first time you have
-received notice of violation of this License (for any work) from that
-copyright holder, and you cure the violation prior to 30 days after
-your receipt of the notice.
-
-  Termination of your rights under this section does not terminate the
-licenses of parties who have received copies or rights from you under
-this License.  If your rights have been terminated and not permanently
-reinstated, you do not qualify to receive new licenses for the same
-material under section 10.
-
-  9. Acceptance Not Required for Having Copies.
-
-  You are not required to accept this License in order to receive or
-run a copy of the Program.  Ancillary propagation of a covered work
-occurring solely as a consequence of using peer-to-peer transmission
-to receive a copy likewise does not require acceptance.  However,
-nothing other than this License grants you permission to propagate or
-modify any covered work.  These actions infringe copyright if you do
-not accept this License.  Therefore, by modifying or propagating a
-covered work, you indicate your acceptance of this License to do so.
-
-  10. Automatic Licensing of Downstream Recipients.
-
-  Each time you convey a covered work, the recipient automatically
-receives a license from the original licensors, to run, modify and
-propagate that work, subject to this License.  You are not responsible
-for enforcing compliance by third parties with this License.
-
-  An "entity transaction" is a transaction transferring control of an
-organization, or substantially all assets of one, or subdividing an
-organization, or merging organizations.  If propagation of a covered
-work results from an entity transaction, each party to that
-transaction who receives a copy of the work also receives whatever
-licenses to the work the party's predecessor in interest had or could
-give under the previous paragraph, plus a right to possession of the
-Corresponding Source of the work from the predecessor in interest, if
-the predecessor has it or can get it with reasonable efforts.
-
-  You may not impose any further restrictions on the exercise of the
-rights granted or affirmed under this License.  For example, you may
-not impose a license fee, royalty, or other charge for exercise of
-rights granted under this License, and you may not initiate litigation
-(including a cross-claim or counterclaim in a lawsuit) alleging that
-any patent claim is infringed by making, using, selling, offering for
-sale, or importing the Program or any portion of it.
-
-  11. Patents.
-
-  A "contributor" is a copyright holder who authorizes use under this
-License of the Program or a work on which the Program is based.  The
-work thus licensed is called the contributor's "contributor version".
-
-  A contributor's "essential patent claims" are all patent claims
-owned or controlled by the contributor, whether already acquired or
-hereafter acquired, that would be infringed by some manner, permitted
-by this License, of making, using, or selling its contributor version,
-but do not include claims that would be infringed only as a
-consequence of further modification of the contributor version.  For
-purposes of this definition, "control" includes the right to grant
-patent sublicenses in a manner consistent with the requirements of
-this License.
-
-  Each contributor grants you a non-exclusive, worldwide, royalty-free
-patent license under the contributor's essential patent claims, to
-make, use, sell, offer for sale, import and otherwise run, modify and
-propagate the contents of its contributor version.
-
-  In the following three paragraphs, a "patent license" is any express
-agreement or commitment, however denominated, not to enforce a patent
-(such as an express permission to practice a patent or covenant not to
-sue for patent infringement).  To "grant" such a patent license to a
-party means to make such an agreement or commitment not to enforce a
-patent against the party.
-
-  If you convey a covered work, knowingly relying on a patent license,
-and the Corresponding Source of the work is not available for anyone
-to copy, free of charge and under the terms of this License, through a
-publicly available network server or other readily accessible means,
-then you must either (1) cause the Corresponding Source to be so
-available, or (2) arrange to deprive yourself of the benefit of the
-patent license for this particular work, or (3) arrange, in a manner
-consistent with the requirements of this License, to extend the patent
-license to downstream recipients.  "Knowingly relying" means you have
-actual knowledge that, but for the patent license, your conveying the
-covered work in a country, or your recipient's use of the covered work
-in a country, would infringe one or more identifiable patents in that
-country that you have reason to believe are valid.
-
-  If, pursuant to or in connection with a single transaction or
-arrangement, you convey, or propagate by procuring conveyance of, a
-covered work, and grant a patent license to some of the parties
-receiving the covered work authorizing them to use, propagate, modify
-or convey a specific copy of the covered work, then the patent license
-you grant is automatically extended to all recipients of the covered
-work and works based on it.
-
-  A patent license is "discriminatory" if it does not include within
-the scope of its coverage, prohibits the exercise of, or is
-conditioned on the non-exercise of one or more of the rights that are
-specifically granted under this License.  You may not convey a covered
-work if you are a party to an arrangement with a third party that is
-in the business of distributing software, under which you make payment
-to the third party based on the extent of your activity of conveying
-the work, and under which the third party grants, to any of the
-parties who would receive the covered work from you, a discriminatory
-patent license (a) in connection with copies of the covered work
-conveyed by you (or copies made from those copies), or (b) primarily
-for and in connection with specific products or compilations that
-contain the covered work, unless you entered into that arrangement,
-or that patent license was granted, prior to 28 March 2007.
-
-  Nothing in this License shall be construed as excluding or limiting
-any implied license or other defenses to infringement that may
-otherwise be available to you under applicable patent law.
-
-  12. No Surrender of Others' Freedom.
-
-  If conditions are imposed on you (whether by court order, agreement or
-otherwise) that contradict the conditions of this License, they do not
-excuse you from the conditions of this License.  If you cannot convey a
-covered work so as to satisfy simultaneously your obligations under this
-License and any other pertinent obligations, then as a consequence you may
-not convey it at all.  For example, if you agree to terms that obligate you
-to collect a royalty for further conveying from those to whom you convey
-the Program, the only way you could satisfy both those terms and this
-License would be to refrain entirely from conveying the Program.
-
-  13. Use with the GNU Affero General Public License.
-
-  Notwithstanding any other provision of this License, you have
-permission to link or combine any covered work with a work licensed
-under version 3 of the GNU Affero General Public License into a single
-combined work, and to convey the resulting work.  The terms of this
-License will continue to apply to the part which is the covered work,
-but the special requirements of the GNU Affero General Public License,
-section 13, concerning interaction through a network will apply to the
-combination as such.
-
-  14. Revised Versions of this License.
-
-  The Free Software Foundation may publish revised and/or new versions of
-the GNU General Public License from time to time.  Such new versions will
-be similar in spirit to the present version, but may differ in detail to
-address new problems or concerns.
-
-  Each version is given a distinguishing version number.  If the
-Program specifies that a certain numbered version of the GNU General
-Public License "or any later version" applies to it, you have the
-option of following the terms and conditions either of that numbered
-version or of any later version published by the Free Software
-Foundation.  If the Program does not specify a version number of the
-GNU General Public License, you may choose any version ever published
-by the Free Software Foundation.
-
-  If the Program specifies that a proxy can decide which future
-versions of the GNU General Public License can be used, that proxy's
-public statement of acceptance of a version permanently authorizes you
-to choose that version for the Program.
-
-  Later license versions may give you additional or different
-permissions.  However, no additional obligations are imposed on any
-author or copyright holder as a result of your choosing to follow a
-later version.
-
-  15. Disclaimer of Warranty.
-
-  THERE IS NO WARRANTY FOR THE PROGRAM, TO THE EXTENT PERMITTED BY
-APPLICABLE LAW.  EXCEPT WHEN OTHERWISE STATED IN WRITING THE COPYRIGHT
-HOLDERS AND/OR OTHER PARTIES PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY
-OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,
-THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-PURPOSE.  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM
-IS WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
-ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
-
-  16. Limitation of Liability.
-
-  IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MODIFIES AND/OR CONVEYS
-THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY
-GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
-USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF
-DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD
-PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS),
-EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
-
-  17. Interpretation of Sections 15 and 16.
-
-  If the disclaimer of warranty and limitation of liability provided
-above cannot be given local legal effect according to their terms,
-reviewing courts shall apply local law that most closely approximates
-an absolute waiver of all civil liability in connection with the
-Program, unless a warranty or assumption of liability accompanies a
-copy of the Program in return for a fee.
-
-                     END OF TERMS AND CONDITIONS
-
-            How to Apply These Terms to Your New Programs
-
-  If you develop a new program, and you want it to be of the greatest
-possible use to the public, the best way to achieve this is to make it
-free software which everyone can redistribute and change under these terms.
-
-  To do so, attach the following notices to the program.  It is safest
-to attach them to the start of each source file to most effectively
-state the exclusion of warranty; and each file should have at least
-the "copyright" line and a pointer to where the full notice is found.
-
-    <one line to give the program's name and a brief idea of what it does.>
-    Copyright (C) <year>  <name of author>
-
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-Also add information on how to contact you by electronic and paper mail.
-
-  If the program does terminal interaction, make it output a short
-notice like this when it starts in an interactive mode:
-
-    <program>  Copyright (C) <year>  <name of author>
-    This program comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
-    This is free software, and you are welcome to redistribute it
-    under certain conditions; type `show c' for details.
-
-The hypothetical commands `show w' and `show c' should show the appropriate
-parts of the General Public License.  Of course, your program's commands
-might be different; for a GUI interface, you would use an "about box".
-
-  You should also get your employer (if you work as a programmer) or school,
-if any, to sign a "copyright disclaimer" for the program, if necessary.
-For more information on this, and how to apply and follow the GNU GPL, see
-<http://www.gnu.org/licenses/>.
-
-  The GNU General Public License does not permit incorporating your program
-into proprietary programs.  If your program is a subroutine library, you
-may consider it more useful to permit linking proprietary applications with
-the library.  If this is what you want to do, use the GNU Lesser General
-Public License instead of this License.  But first, please read
-<http://www.gnu.org/philosophy/why-not-lgpl.html>.
Binary files 1.9.14~dfsg-1/windows/Setup/src/gpl_installer.rtf and 1.9.16~dfsg-1/windows/Setup/src/gpl_installer.rtf differ
Binary files 1.9.14~dfsg-1/windows/Setup/src/jack.ico and 1.9.16~dfsg-1/windows/Setup/src/jack.ico differ
Binary files 1.9.14~dfsg-1/windows/Setup/src/logo_installer.bmp and 1.9.16~dfsg-1/windows/Setup/src/logo_installer.bmp differ
diff -pruN 1.9.14~dfsg-1/windows/Setup/src/README 1.9.16~dfsg-1/windows/Setup/src/README
--- 1.9.14~dfsg-1/windows/Setup/src/README	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/Setup/src/README	1970-01-01 00:00:00.000000000 +0000
@@ -1,73 +0,0 @@
-=============================================
-JACK on Windows
-=============================================
-
-This installer will install everything to use Jack Audio Connection Kit (JACK) (www.jackaudio.org) on Windows.
-
-
-=============================================
-QJACKCTL on Windows
-=============================================
-
-This is a latest version of Rui Nuno Capela QJACKCTL application (http://qjackctl.sourceforge.net/) compiled on Windows. 
-It is compiled from the latest CVS version which is using QT4 framework. To uses it:
-
-- start qjackctl.exe and configure it the following way:
-
-	- in Setup/Setting, use "jackd -S" at the "Server Path" item. WARNING: on Windows the "-S" parameter is *mandatory* to have the jack server correctly working!!
-
-	- in Setup/Setting, use "portaudio" at the "Driver" item
-
-	- in Setup/Misc, check the "Start JACK audio server at application startup" box
-
-- quit QJACKCTL and start is again, it should now launch the jack server. Quitting QJACKCTL will now close the jack server.
-
-Starting the jack server with another audio device installed on the machine (like an ASIO card) can now be done directly in QJACKCTL. 
-A ">" button at the right of the interface button allows to list the name of all available devices, driven either by "MME", "DirectSound", or "ASIO".
-Alternatively using the following command allows to display the names of available devices:
-
-- jackd -d portaudio -l to display the entire list of available audio devices. (jackd -d portaudio -h will display all portaudio driver features)
-
-Then start jackd with the device you want, by using its name, for example:
-
-- jackd -R -S -d portaudio -d "ASIO::MOTU Audio ASIO", then start QJACKCTL. QJACKCTL will see the jackd server already running and then can be used normally.
-
-
-=============================================
-Jack MIDI
-=============================================
-
-A first version of a JACK MIDI <==> Windows MIDI bridge (using Windows MME API) is available. 
-If can be activated using the -X parameter in jackd command line. So add "-X winmme" in QJACKCTL settings (something like "jackd -S -X winmme"). 
-The WinMME driver will scan MIDI input/output ports, open corresponding JACK MIDI ports and convert MIDI in/out into JACK MIDI messages. 
-QJACKCTL MIDI connection windows can then be used.
-
-
-=============================================
-JackRouter JACK/ASIO driver
-=============================================
-
-JackRouter is an ASIO driver that allows any ASIO compatible application to become a JACK client, thus exchange audio with any other "native" or "Jackified" application. This driver is registered in the system by the installer and becomes available in the list of ASIO drivers when the JACK server is running. A "JackRouter.ini" configuration file allows the application to configure how the JackRouter driver behaves.
-
-	- [IO]: 
-		- input/output : the application can obtain any number if JACK input/output ports (not necessarily equal to the audio card input/output number). [Note that some applications force their input/output channel number].
-		- float-sample : be default the JackRouter will present audio samples in integer format for the application. Use float-sample=1 so that audio samples are presented in float format for the application (thus saving float/integer conversion time).
-	
-
-	- [AUTO_CONNECT] : 
-		- input/output : when 1, the application JACK port will automatically be connected to the machine input/output JACK ports.
-		- alias : with ASIO drivers, real channels names will be associated to the JACK port as aliases and will be returned when the application request channels names.
-
-
-=============================================
-Known problems
-=============================================
-
-- starting/stopping the server several times in QJACKCTL may not work correctly. You may have to quit QJACKCTL and launch it again.
-
-
-=============================================
-Grame : Computer Music Research Laboratory
-Web : http://www.grame.fr/Research
-E-mail : letz@grame.fr
-=============================================
\ No newline at end of file
diff -pruN 1.9.14~dfsg-1/windows/winmme/JackWinMMEDriver.cpp 1.9.16~dfsg-1/windows/winmme/JackWinMMEDriver.cpp
--- 1.9.14~dfsg-1/windows/winmme/JackWinMMEDriver.cpp	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/winmme/JackWinMMEDriver.cpp	2020-10-16 19:10:40.000000000 +0000
@@ -204,8 +204,8 @@ JackWinMMEDriver::Open(bool capturing, b
                     new JackWinMMEOutputPort(fAliasName, client_name,
                                              playback_driver_name, i);
             } catch (std::exception& e) {
-                jack_error("JackWinMMEDriver::Open - while creating output "
-                           "port: %s", e.what());
+                jack_error("JackWinMMEDriver::Open - while creating output port: %s | %s, %s, %s",
+                           e.what(), fAliasName, client_name, playback_driver_name);
                 continue;
             }
             output_count++;
@@ -215,10 +215,7 @@ JackWinMMEDriver::Open(bool capturing, b
     jack_log("JackWinMMEDriver::Open - input_count  %d", input_count);
     jack_log("JackWinMMEDriver::Open - output_count  %d", output_count);
 
-    if (! (input_count || output_count)) {
-        jack_error("JackWinMMEDriver::Open - no WinMME inputs or outputs "
-                   "allocated.");
-    } else if (! JackMidiDriver::Open(capturing, playing, input_count,
+    if (! JackMidiDriver::Open(capturing, playing, input_count,
                                       output_count, monitor,
                                       capture_driver_name,
                                       playback_driver_name, capture_latency,
@@ -286,7 +283,7 @@ JackWinMMEDriver::Start()
     jack_log("JackWinMMEDriver::Start - Enabling input ports.");
 
     for (; input_count < fCaptureChannels; input_count++) {
-        if (input_ports[input_count]->Start() < 0) {
+        if (! input_ports[input_count]->Start()) {
             jack_error("JackWinMMEDriver::Start - Failed to enable input "
                        "port.");
             goto stop_input_ports;
@@ -296,7 +293,7 @@ JackWinMMEDriver::Start()
     jack_log("JackWinMMEDriver::Start - Enabling output ports.");
 
     for (; output_count < fPlaybackChannels; output_count++) {
-        if (output_ports[output_count]->Start() < 0) {
+        if (! output_ports[output_count]->Start()) {
             jack_error("JackWinMMEDriver::Start - Failed to enable output "
                        "port.");
             goto stop_output_ports;
@@ -308,14 +305,14 @@ JackWinMMEDriver::Start()
 
  stop_output_ports:
     for (int i = 0; i < output_count; i++) {
-        if (output_ports[i]->Stop() < 0) {
+        if (! output_ports[i]->Stop()) {
             jack_error("JackWinMMEDriver::Start - Failed to disable output "
                        "port.");
         }
     }
  stop_input_ports:
     for (int i = 0; i < input_count; i++) {
-        if (input_ports[i]->Stop() < 0) {
+        if (! input_ports[i]->Stop()) {
             jack_error("JackWinMMEDriver::Start - Failed to disable input "
                        "port.");
         }
@@ -334,7 +331,7 @@ JackWinMMEDriver::Stop()
     jack_log("JackWinMMEDriver::Stop - disabling input ports.");
 
     for (int i = 0; i < fCaptureChannels; i++) {
-        if (input_ports[i]->Stop() < 0) {
+        if (! input_ports[i]->Stop()) {
             jack_error("JackWinMMEDriver::Stop - Failed to disable input "
                        "port.");
             result = -1;
@@ -344,7 +341,7 @@ JackWinMMEDriver::Stop()
     jack_log("JackWinMMEDriver::Stop - disabling output ports.");
 
     for (int i = 0; i < fPlaybackChannels; i++) {
-        if (output_ports[i]->Stop() < 0) {
+        if (! output_ports[i]->Stop()) {
             jack_error("JackWinMMEDriver::Stop - Failed to disable output "
                        "port.");
             result = -1;
diff -pruN 1.9.14~dfsg-1/windows/winmme/JackWinMMEPort.h 1.9.16~dfsg-1/windows/winmme/JackWinMMEPort.h
--- 1.9.14~dfsg-1/windows/winmme/JackWinMMEPort.h	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/windows/winmme/JackWinMMEPort.h	2020-10-16 19:10:40.000000000 +0000
@@ -20,6 +20,9 @@ Foundation, Inc., 675 Mass Ave, Cambridg
 #ifndef __JackWinMMEPort__
 #define __JackWinMMEPort__
 
+#ifdef __MINGW32__
+#include <winsock2.h>
+#endif
 #include <windows.h>
 #include <mmsystem.h>
 
diff -pruN 1.9.14~dfsg-1/wscript 1.9.16~dfsg-1/wscript
--- 1.9.14~dfsg-1/wscript	2019-11-17 21:44:23.000000000 +0000
+++ 1.9.16~dfsg-1/wscript	2020-10-16 19:10:40.000000000 +0000
@@ -11,7 +11,7 @@ import sys
 from waflib import Logs, Options, Task, Utils
 from waflib.Build import BuildContext, CleanContext, InstallContext, UninstallContext
 
-VERSION='1.9.14'
+VERSION='1.9.16'
 APPNAME='jack'
 JACK_API_VERSION = '0.1.0'
 
@@ -61,20 +61,22 @@ def options(opt):
     opt.add_option('--htmldir', type='string', default=None, help='HTML documentation directory [Default: <prefix>/share/jack-audio-connection-kit/reference/html/')
     opt.add_option('--libdir', type='string', help='Library directory [Default: <prefix>/lib]')
     opt.add_option('--libdir32', type='string', help='32bit Library directory [Default: <prefix>/lib32]')
+    opt.add_option('--pkgconfigdir', type='string', help='pkg-config file directory [Default: <libdir>/pkgconfig]')
     opt.add_option('--mandir', type='string', help='Manpage directory [Default: <prefix>/share/man/man1]')
 
     # options affecting binaries
     opt.add_option('--platform', type='string', default=sys.platform, help='Target platform for cross-compiling, e.g. cygwin or win32')
     opt.add_option('--mixed', action='store_true', default=False, help='Build with 32/64 bits mixed mode')
     opt.add_option('--debug', action='store_true', default=False, dest='debug', help='Build debuggable binaries')
+    opt.add_option('--static', action='store_true', default=False, dest='static', help='Build static binaries (Windows only)')
 
     # options affecting general jack functionality
     opt.add_option('--classic', action='store_true', default=False, help='Force enable standard JACK (jackd) even if D-Bus JACK (jackdbus) is enabled too')
     opt.add_option('--dbus', action='store_true', default=False, help='Enable D-Bus JACK (jackdbus)')
     opt.add_option('--autostart', type='string', default='default', help='Autostart method. Possible values: "default", "classic", "dbus", "none"')
     opt.add_option('--profile', action='store_true', default=False, help='Build with engine profiling')
-    opt.add_option('--clients', default=64, type='int', dest='clients', help='Maximum number of JACK clients')
-    opt.add_option('--ports-per-application', default=768, type='int', dest='application_ports', help='Maximum number of ports per application')
+    opt.add_option('--clients', default=256, type='int', dest='clients', help='Maximum number of JACK clients')
+    opt.add_option('--ports-per-application', default=2048, type='int', dest='application_ports', help='Maximum number of ports per application')
     opt.add_option('--systemd-unit', action='store_true', default=False, help='Install systemd units.')
 
     opt.set_auto_options_define('HAVE_%s')
@@ -211,12 +213,22 @@ def configure(conf):
     if conf.env['IS_WINDOWS']:
         conf.env.append_unique('CCDEFINES', '_POSIX')
         conf.env.append_unique('CXXDEFINES', '_POSIX')
+        if Options.options.platform == 'msys':
+            conf.env.append_value('INCLUDES', ['/mingw64/include'])
+            conf.check(
+                header_name='asio.h',
+                includes='/opt/asiosdk/common',
+                msg='Checking for ASIO SDK',
+                define_name='HAVE_ASIO',
+                mandatory=False)
 
+    conf.env.append_unique('CFLAGS', '-Wall')
     conf.env.append_unique('CXXFLAGS', '-Wall')
     conf.env.append_unique('CXXFLAGS', '-std=gnu++11')
-    conf.env.append_unique('CFLAGS', '-Wall')
 
-    if conf.env['IS_MACOSX']:
+    if not conf.env['IS_MACOSX']:
+        conf.env.append_unique('LDFLAGS', '-Wl,--no-undefined')
+    else:
         conf.check(lib='aften', uselib='AFTEN', define_name='AFTEN')
         conf.check_cxx(
             fragment=''
@@ -235,6 +247,9 @@ def configure(conf):
             define_name='HAVE_AFTEN_NEW_API',
             mandatory=False)
 
+        # TODO
+        conf.env.append_unique('CXXFLAGS', '-Wno-deprecated-register')
+
     conf.load('autooptions')
 
     conf.recurse('compat')
@@ -274,6 +289,7 @@ def configure(conf):
 
 
     conf.recurse('example-clients')
+    conf.recurse('tools')
 
     # test for the availability of ucontext, and how it should be used
     for t in ['gp_regs', 'uc_regs', 'mc_gregs', 'gregs']:
@@ -302,6 +318,7 @@ def configure(conf):
     conf.env['BUILD_WITH_32_64'] = Options.options.mixed
     conf.env['BUILD_CLASSIC'] = Options.options.classic
     conf.env['BUILD_DEBUG'] = Options.options.debug
+    conf.env['BUILD_STATIC'] = Options.options.static
 
     if conf.env['BUILD_JACKDBUS']:
         conf.env['BUILD_JACKD'] = conf.env['BUILD_CLASSIC']
@@ -322,6 +339,11 @@ def configure(conf):
     else:
         conf.env['LIBDIR'] = conf.env['PREFIX'] + '/lib'
 
+    if Options.options.pkgconfigdir:
+        conf.env['PKGCONFDIR'] = Options.options.pkgconfigdir
+    else:
+        conf.env['PKGCONFDIR'] = conf.env['LIBDIR'] + '/pkgconfig'
+
     if Options.options.mandir:
         conf.env['MANDIR'] = Options.options.mandir
     else:
@@ -360,9 +382,14 @@ def configure(conf):
         # we define this in the environment to maintain compatibility with
         # existing install paths that use ADDON_DIR rather than have to
         # have special cases for windows each time.
-        conf.env['ADDON_DIR'] = conf.env['BINDIR'] + '/jack'
-        # don't define ADDON_DIR in config.h, use the default 'jack' defined in
-        # windows/JackPlatformPlug_os.h
+        conf.env['ADDON_DIR'] = conf.env['LIBDIR'] + '/jack'
+        if Options.options.platform == 'msys':
+            conf.define('ADDON_DIR', 'jack')
+            conf.define('__STDC_FORMAT_MACROS', 1) # for PRIu64
+        else:
+            # don't define ADDON_DIR in config.h, use the default 'jack' defined in
+            # windows/JackPlatformPlug_os.h
+            pass
     else:
         conf.env['ADDON_DIR'] = os.path.normpath(os.path.join(conf.env['LIBDIR'], 'jack'))
         conf.define('ADDON_DIR', conf.env['ADDON_DIR'])
@@ -390,13 +417,22 @@ def configure(conf):
 
     if Options.options.mixed:
         conf.setenv(lib32, env=conf.env.derive())
-        conf.env.append_unique('CXXFLAGS', '-m32')
         conf.env.append_unique('CFLAGS', '-m32')
+        conf.env.append_unique('CXXFLAGS', '-m32')
+        conf.env.append_unique('CXXFLAGS', '-DBUILD_WITH_32_64')
         conf.env.append_unique('LINKFLAGS', '-m32')
         if Options.options.libdir32:
             conf.env['LIBDIR'] = Options.options.libdir32
         else:
             conf.env['LIBDIR'] = conf.env['PREFIX'] + '/lib32'
+
+        if conf.env['IS_WINDOWS'] and conf.env['BUILD_STATIC']:
+            def replaceFor32bit(env):
+                for e in env: yield e.replace('x86_64', 'i686', 1)
+            for env in ('AR', 'CC', 'CXX', 'LINK_CC', 'LINK_CXX'):
+                conf.all_envs[lib32][env] = list(replaceFor32bit(conf.all_envs[lib32][env]))
+            conf.all_envs[lib32]['LIB_REGEX'] = ['tre32']
+
         # libdb does not work in mixed mode
         conf.all_envs[lib32]['HAVE_DB'] = 0
         conf.all_envs[lib32]['HAVE_DB_H'] = 0
@@ -524,14 +560,10 @@ def build_jackd(bld):
 
 # FIXME: Is SERVER_SIDE needed?
 def create_driver_obj(bld, **kw):
-    if bld.env['IS_MACOSX'] or bld.env['IS_WINDOWS']:
-        # On MacOSX this is necessary.
-        # I do not know if this is necessary on Windows.
-        # Note added on 2015-12-13 by karllinden.
-        if 'use' in kw:
-            kw['use'] += ['serverlib']
-        else:
-            kw['use'] = ['serverlib']
+    if 'use' in kw:
+        kw['use'] += ['serverlib']
+    else:
+        kw['use'] = ['serverlib']
 
     driver = bld(
         features = ['c', 'cxx', 'cshlib', 'cxxshlib'],
@@ -781,6 +813,8 @@ def build(bld):
     build_drivers(bld)
 
     bld.recurse('example-clients')
+    bld.recurse('tools')
+
     if bld.env['IS_LINUX']:
         bld.recurse('man')
         bld.recurse('systemd')
